/*=========================================================*/
/* Script de cration et initialisation de base de donnes */
/* Nom de la base GestionStocks                            */
/* JC DANIEL - Reporting                                   */
/*=========================================================*/

/* Structure */

CREATE TABLE MAGASINS (
   ID_MAG               VARCHAR(20)          NOT NULL,
   LIB_MAG              VARCHAR(50)          NULL,
   CONSTRAINT PK_MAGASINS PRIMARY KEY NONCLUSTERED (ID_MAG)
)
go

CREATE TABLE AD_STOCKAGE (
   ID_MAG               VARCHAR(20)          NOT NULL,
   ID_ADR               VARCHAR(20)          NOT NULL,
   CONSTRAINT PK_AD_STOCKAGE PRIMARY KEY NONCLUSTERED (ID_MAG, ID_ADR),
   CONSTRAINT FK_AD_STOCK_ADRESSE_D_MAGASINS FOREIGN KEY (ID_MAG)
      REFERENCES MAGASINS (ID_MAG)
         ON UPDATE CASCADE ON DELETE CASCADE
)
go

CREATE TABLE CENTRE_CHARGE (
   ID_CC                VARCHAR(20)          NOT NULL,
   CONSTRAINT PK_CENTRE_CHARGE PRIMARY KEY NONCLUSTERED (ID_CC)
)
go

CREATE TABLE TIERS (
   ID_TIERS             VARCHAR(40)          NOT NULL,
   NOM_TIERS            VARCHAR(50)          NULL,
   ID_COMPTA            VARCHAR(40)          NULL,
   ADRESSE              VARCHAR(200)         NULL,
   CP                   VARCHAR(10)          NULL,
   VILLE                VARCHAR(60)          NULL,
   PAYS                 VARCHAR(50)          NULL,
   NUMTEL               VARCHAR(20)          NULL,
   EMAIL                VARCHAR(60)          NULL,
   CONSTRAINT PK_TIERS PRIMARY KEY NONCLUSTERED (ID_TIERS)
)
go

CREATE TABLE COMMANDES (
   N_CDE                VARCHAR(20)          NOT NULL,
   ID_CC                VARCHAR(20)          NULL,
   ID_TIERS             VARCHAR(40)          NOT NULL,
   DCDE                 DATETIME             NULL,
   DLIVRDEM             DATETIME             NULL,
   ETAT_CDE             INT                  NULL,
   MT_CDE               REAL                 NULL,
   CONSTRAINT PK_COMMANDES PRIMARY KEY NONCLUSTERED (N_CDE),
   CONSTRAINT FK_COMMANDE_CC_CENTRE_C FOREIGN KEY (ID_CC)
      REFERENCES CENTRE_CHARGE (ID_CC)
         ON UPDATE CASCADE ON DELETE SET NULL,
   CONSTRAINT FK_COMMANDE_CDE_A_TIERS FOREIGN KEY (ID_TIERS)
      REFERENCES TIERS (ID_TIERS)
         ON UPDATE CASCADE
)
go

CREATE TABLE GRF_PIECES (
   ID_GRFP              VARCHAR(20)          NOT NULL,
   CONSTRAINT PK_GRF_PIECES PRIMARY KEY NONCLUSTERED (ID_GRFP)
)
go

CREATE TABLE FPIECES (
   ID_GRFP              VARCHAR(20)          NOT NULL,
   ID_FP                VARCHAR(25)          NOT NULL,
   CONSTRAINT PK_FPIECES PRIMARY KEY NONCLUSTERED (ID_GRFP, ID_FP),
   CONSTRAINT FK_FPIECES_GRFP_GRF_PIEC FOREIGN KEY (ID_GRFP)
      REFERENCES GRF_PIECES (ID_GRFP)
         ON UPDATE CASCADE ON DELETE CASCADE
)
go

CREATE TABLE PIECES (
   ID_PIECE             VARCHAR(50)          NOT NULL,
   ID_GRFP              VARCHAR(20)          NULL,
   ID_FP                VARCHAR(25)          NULL,
   DES_PIECE            VARCHAR(150)         NOT NULL,
   PRIX                 REAL                 NULL,
   QTE_STOCK            REAL                 NULL,
   SEUIL                REAL                 NULL,
   QT_DA                REAL                 NULL,
   QT_CDE               REAL                 NULL,
   CONSTRAINT PK_PIECES PRIMARY KEY NONCLUSTERED (ID_PIECE),
   CONSTRAINT FK_PIECES_FAM_PIECE_FPIECES FOREIGN KEY (ID_GRFP, ID_FP)
      REFERENCES FPIECES (ID_GRFP, ID_FP)
         ON UPDATE CASCADE ON DELETE SET NULL
)
go

CREATE TABLE LIGNES (
   N_CDE                VARCHAR(20)          NOT NULL,
   ID_LIGNE             INT                  NOT NULL,
   ID_PIECE             VARCHAR(50)          NOT NULL,
   DLPREV               DATETIME             NULL,
   VOL_CDE              REAL                 NULL,
   PRIX                 REAL                 NULL,
   REF_TIERS            VARCHAR(80)          NULL,
   CONSTRAINT PK_LIGNES PRIMARY KEY NONCLUSTERED (N_CDE, ID_LIGNE),
   CONSTRAINT FK_LIGNES_LIGNES_COMMANDE FOREIGN KEY (N_CDE)
      REFERENCES COMMANDES (N_CDE)
         ON UPDATE CASCADE ON DELETE CASCADE,
   CONSTRAINT FK_LIGNES_PIECE_CDE_PIECES FOREIGN KEY (ID_PIECE)
      REFERENCES PIECES (ID_PIECE)
         ON UPDATE CASCADE
)
go

CREATE TABLE STOCK (
   ID_PIECE             VARCHAR(50)          NOT NULL,
   ID_MAG               VARCHAR(20)          NOT NULL,
   ID_ADR               VARCHAR(20)          NOT NULL,
   QTE_STOCKEE          REAL                 NULL,
   CONSTRAINT PK_STOCK PRIMARY KEY NONCLUSTERED (ID_PIECE, ID_MAG, ID_ADR),
   CONSTRAINT FK_STOCK_STOCK_PIECES FOREIGN KEY (ID_PIECE)
      REFERENCES PIECES (ID_PIECE)
         ON UPDATE CASCADE,
   CONSTRAINT FK_STOCK_STOCK2_AD_STOCK FOREIGN KEY (ID_MAG, ID_ADR)
      REFERENCES AD_STOCKAGE (ID_MAG, ID_ADR)
         ON UPDATE CASCADE
)
go

/* Initialisations */

INSERT [dbo].[CENTRE_CHARGE] ([ID_CC]) VALUES (N'C1000')
INSERT [dbo].[CENTRE_CHARGE] ([ID_CC]) VALUES (N'CC101')
INSERT [dbo].[CENTRE_CHARGE] ([ID_CC]) VALUES (N'CC102')
INSERT [dbo].[CENTRE_CHARGE] ([ID_CC]) VALUES (N'CC103')
INSERT [dbo].[CENTRE_CHARGE] ([ID_CC]) VALUES (N'CC104')
INSERT [dbo].[CENTRE_CHARGE] ([ID_CC]) VALUES (N'CC105')
INSERT [dbo].[CENTRE_CHARGE] ([ID_CC]) VALUES (N'CC201')
INSERT [dbo].[CENTRE_CHARGE] ([ID_CC]) VALUES (N'CC202')
INSERT [dbo].[CENTRE_CHARGE] ([ID_CC]) VALUES (N'CC203')
INSERT [dbo].[CENTRE_CHARGE] ([ID_CC]) VALUES (N'CC204')
INSERT [dbo].[CENTRE_CHARGE] ([ID_CC]) VALUES (N'CC206')
INSERT [dbo].[CENTRE_CHARGE] ([ID_CC]) VALUES (N'CC301')
INSERT [dbo].[CENTRE_CHARGE] ([ID_CC]) VALUES (N'CC302')
INSERT [dbo].[CENTRE_CHARGE] ([ID_CC]) VALUES (N'CC303')
INSERT [dbo].[CENTRE_CHARGE] ([ID_CC]) VALUES (N'CC304')
GO

INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'01')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'02')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'05')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'07')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'08')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'09')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'10')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'11')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'12')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'14')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'16')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'17')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'18')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'19')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'20')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'21')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'22')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'23')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'24')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'25')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'26')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'28')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'31')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'32')
INSERT [dbo].[GRF_PIECES] ([ID_GRFP]) VALUES (N'33')
GO

INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'01', N'01FB')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'01', N'01SA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'02', N'02SC')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'05', N'05FA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'05', N'05FB')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'05', N'05FC')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'05', N'05FD')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'05', N'05FG')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'05', N'05FH')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'05', N'05FI')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'05', N'05FJ')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'05', N'05FL')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'05', N'05FM')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'05', N'05MA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'05', N'05SA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'07', N'07FA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'07', N'07FB')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'07', N'07FD')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'07', N'07MA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'07', N'07MB')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'07', N'07SA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'08', N'08FA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'08', N'08MB')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'09', N'09SA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'09', N'09SC')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'10', N'10FA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'11', N'11FA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'11', N'11FB')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'11', N'11FC')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'11', N'11MA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'11', N'11SA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'12', N'12 FA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'12', N'12 MC')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'12', N'12MB')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'12', N'12SC')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'14', N'14FA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'14', N'14FB')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'14', N'14FC')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'14', N'14FD')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'14', N'14MA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'14', N'14SC')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'16', N'16SB')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'17', N'17FA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'17', N'17FC')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'17', N'17MA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'18', N'18MB')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'18', N'18MC')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'18', N'18MD')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'19', N'19FB')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'20', N'20FB')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'20', N'20MA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'20', N'20MC')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'20', N'20SG')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'21', N'21FA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'21', N'21MA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'21', N'21MB')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'22', N'22FA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'22', N'22MA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'22', N'22MB')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'22', N'22MD')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'22', N'22ME')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'22', N'22MF')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'22', N'22SB')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'22', N'22SD')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'23', N'23MA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'24', N'24FA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'24', N'24FB')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'24', N'24MA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'25', N'25FA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'26', N'26FA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'26', N'26FD')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'26', N'26MA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'28', N'28MA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'28', N'28MB')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'28', N'28SC')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'28', N'28SE')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'31', N'31FA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'31', N'31MA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'31', N'31MD')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'31', N'31SA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'31', N'31SC')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'32', N'32SB')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'33', N'33FA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'33', N'33FB')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'33', N'33FC')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'33', N'33FD')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'33', N'33FE')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'33', N'33FF')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'33', N'33FG')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'33', N'33MC')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'33', N'33ME')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'33', N'33SA')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'33', N'33SB')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'33', N'33SC')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'33', N'33SD')
INSERT [dbo].[FPIECES] ([ID_GRFP], [ID_FP]) VALUES (N'33', N'33SF')
GO

INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'ACM DIFFUSION', N'ACM', N'70022', N'22 Rue de Boulogne', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'AGRIMATIC', N'AgrimatIC', N'70055', N'5 Route de Strasbourg', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'AIR SOFT', N'A S', N'48700', N'23 champ marin', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'ALVAXYS', N'alvaxys', N'77401', N'rue prince Herbert', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'ALSA NOVOS', N'Alsa novos', N'59582', N'12 Rue de la Lisiere', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'AMPLI SERVICE', N'ampli service', N'67427', N'place de l''Europe', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'AQUA OR', N'aqua or', N'81814', N'march aux herbes', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'AUMALE', N'AUMALE', N'97761', N'106 Rue Pecqueur', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'AUTO SYS', N'Auto Systeme', N'11173', N'11 avenue georges V', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'AVGE', N'AVGE', N'66922', N'18 Rue Dessiriez', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'AVNI', N'AVNI', N'71026', N'25 rue de la place', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'AZIDO', N'AZIDO', N'74658', N'1 rue sainte-Marie', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'BALDER', N'BALDER', N'51982', N'Ag
53 Rue Lavast', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'BATIF', N'BATIF', N'10663', N'Place de l''armistice', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'BECKEM', N'BeckeM', N'22498', N'Place rmy', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'BEHN', N'Behn', N'59837', N'1 rue Saint Remy', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'BERAER', N'Beraer', N'36186', N'21 place St Nicolas', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'BERGERY', N'BERGERY', N'01245', N'5 Rue Malraux', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'BERNATO', N'bernato', N'65351', N'31 Avenue de la voix', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'BERVELLER', N'BERVELLER', N'67080', N'60 place du Luxembourg', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'BEYO', N'Beyo', N'71006', N'12 rue du chat press', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'BIGREAL', N'BIGREAL', N'71412', N'Place de Nantes', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'BILLIAUX', N'BILLIAUX', N'71801', N'rue de Stein', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'BIOSYMBOLE', N'Biosymbole', N'78358', N'7 Rue de la libert', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'BORFLE', N'BORFLE', N'26869', N'Rue de Lille', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'BOUVV', N'Bouvv', N'81609', N'Route de Lyon', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'CARRIE', N'CARRIE', N'71219', N'4 rue du Lointain', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'CAT AX', N'CAT AX', N'11145', N'74 Avenue du Maroc', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'CAT AY', N'CAT AY', N'41503', N'6 Rue de Lombardie', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'CAT BK', N'CAT BK', N'07123', N'7 place grise', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'CCARM', N'CC ARM', N'63744', N'1 Rue Lavoisier
', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'CHIMIZ', N'Chimiz SA', N'87210', N'avenue du marechal Juin', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'CNSO', N'CNSO', N'64757', N'14 Rue du Cap Vert', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'COMMENDOR', N'Commendor', N'44637', N'15 Rue Bazin', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'COMPLEC', N'Complec', N'71005', N'Rue Aris', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'CONTI', N'Conti', N'21458', N'Place de la Sarre', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'COTECHI', N'Cotechi', N'71043', N'36 Avenue de strasbourg', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'CPEM', N'CPEM', N'67361', N'4 Rue Marin', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'CRA BR', N'CRA Br', N'67007', N'1025 AVE DE BRUMATH', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'CRA SF', N'CRA SF', N'39655', N'Place des mirroirs', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'DALLIER', N'Dallier', N'78224', N'1 Rue Benjamin Franklin', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'DICTEP', N'Dictep', N'17017', N'9 route Ouest', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'DISTRILAIX', N'distrilaix', N'13761', N'2 Rue Ampere', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'DSCOM', N'Dscom', N'20402', N'5 terrasse Bourgogne', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'ECSPSYS', N'ECSP systeme', N'30274', N'9 Rue Ampre', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'EFRAPP', N'EFRAPP', N'71500', N'1 Rue de Lyon', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'ELTYCH', N'ELTYCH', N'72469', N'6 rue Molitor', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'EMRAD', N'Emrad', N'79470', N'8 chemin de la source', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'EQUILEX', N'EQUILEX', N'16384', N'200 
Rue des Oiseaux', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'ETEX', N'Etex', N'81605', N'6 Rue Guillaume Tell', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'EUROPE BN', N'Europe BN', N'71025', N'10 Quai des russes', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'EUTEXIA', N'EUTEXIA', N'78108', N'12,Rue de la Breuchilliere', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'EVACU', N'EVACU', N'45791', N'4,impasse Danne', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'FIPRO', N'FIPRO', N'19736', N'4 Rue des Lapins', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'FOULER', N'Fouler', N'41412', N'Place des merles', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'FRANK', N'Frank', N'41737', N'17, Avenue Ren', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'FUCKLER', N'Fuckler', N'14718', N'81 Rue de Monaco', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'GRAVES', N'Graves SA', N'83889', N'1 place de la marine', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'GUERN', N'GUERN', N'71004', N'Parc du Bois', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'HAGER', N'Hager', N'71024', N'6 Rue de l''anciennet', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'HAPPY', N'HAPPY', N'13847', N'6 Rue de la joie', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'HENSEL', N'Hensel', N'71057', N'5 Rue de la tuile', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'HERRMO', N'Herrmo', N'70632', N'4 rue d''Italie', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'HOLTE', N'HOLTE', N'98541', N'Rue du lion', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'INTERF', N'Interf', N'74961', N'27 rue Ampere', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'JO CORNE', N'Jo Corne', N'77058', N'1Rue Saint Germain', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'JO FLEXCO', N'Jo FLEXCO', N'52689', N'4, rue de Nancy', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'KEIMENEUR', N'Keimeneur', N'71001', N'2 place des chats', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'KLEINNE', N'Ets Kleinne', N'31513', N'5 Rue Gilbert', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'KUTZ', N'Kutz', N'27111', N'4, Rue de L''hopital', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'LEJEUNE', N'Lejeune SARL', N'67417', N'1 chemin du parc agricole
', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'LEMEUR', N'LEMEUR', N'83084', N'17 Rue Claude Marle', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'LOGICO', N'Logico', N'50511', N'10 Rue d''Abbeville
', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'LORRAINE NATICA', N'Lorraine Natica SARL', N'04133', N'27 Rue des russes', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'LOXOM', N'Loxom', N'34478', N'14 rue des volcans gris', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'MABEOX', N'MABEOX', N'39040', N'2 Rue Chatelas', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'MANHATT', N'manhatt', N'69434', N'5 rue du parc', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'MANUO', N'MANUO', N'18120', N'rue des avanties', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'MGSYS', N'MG Sys', N'70563', N'2 Rue Bonaparte', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'NICOLI', N'Nicoli', N'80118', N'4 Rue d''Alsace', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'NISSEM', N'NISSEM', N'29799', N'40 Avenue Reaulte', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'NOREM', N'NOREM', N'71006', N'166 Rue des horizons', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'OBERY', N'Obery', N'54778', N'9 Rue de la libert', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'OUEST SYS', N'Ouest Sys', N'51811', N'21 avenue des invalides', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'PHOENYX', N'PHOENYX', N'41002', N'52 Boulevard Deau', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'PNEUSS', N'PNEUSS', N'71402', N'115 rue des arcades', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'POMPI', N'POMPI', N'71129', N'21 Rue de L artisanat', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'PPGA', N'PPGA', N'76506', N'21 avenue Drouet', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'RECAM', N'RECAM', N'78763', N'5 Rue Eddy', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'REXELOX', N'Rexel Oxy', N'59941', N'place des ateliers', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'REXELY', N'REXELY', N'31862', N'2 Rue Robert Schumann
', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'RHEAM', N'Rheam', N'15403', N'rue Desmoulin', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'RSO', N'RSO', N'71059', N'rue Normandie', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'RUDOL', N'Rudol', N'31669', N'115 avenue verte', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'SCHERM', N'Scherm', N'81781', N'117 avenue des allis', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'SEAR', N'SEAR', N'71168', N'rue desnoue', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'SIEHRI', N'Siehri', N'25225', N'7 Avenue du Rhin', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'SM BO', N'SM BO', N'28099', N'rue des Boers', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'SNEA', N'SNEA', N'29074', N'rue Eric le rouge', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'SODEA', N'Sodea Sarl', N'28208', N'12 avenue de l''est', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
GO
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'SODILO', N'SODILO', N'71049', N'21 Champ de Mars', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'STRAM', N'Stram', N'35802', N'37 route de Lyon', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'TETRADEC', N'Tetradec', N'71767', N'1 Rue du Marais', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'THOMYS', N'THOMYS', N'68480', N'Avenue des armes', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'THYSS', N'Thyss', N'50059', N'Rue Eperic', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'TPDO', N'TPDO', N'26691', N'2A Rue Parme', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'TRAFIV', N'Trafiv', N'61963', N'25 avenue de l''alter', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'TRUMPE', N'Trumpe', N'23565', N'Alles des haricots', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'VIOLAIX', N'Violaix', N'75525', N'rue des pes', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'VOVV', N'Vovv', N'21785', N'rue de la brume', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'WURTZ', N'Wurtz', N'17861', N'alles des anges', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
INSERT [dbo].[TIERS] ([ID_TIERS], [NOM_TIERS], [ID_COMPTA], [ADRESSE], [CP], [VILLE], [PAYS], [NUMTEL], [EMAIL]) VALUES (N'XL ME', N'XL ME', N'60647', N'1 rue des poles', N'75000', N'Paris', N'France', N'01 02 03 04 05', N'contact@entreprise.com')
GO 

INSERT [dbo].[MAGASINS] ([ID_MAG], [LIB_MAG]) VALUES (N'MAG FOURNI', N'Magasin Fournitures')
INSERT [dbo].[MAGASINS] ([ID_MAG], [LIB_MAG]) VALUES (N'MAG COLONNE 1', N'spray - nettoyage - pharmacie')
INSERT [dbo].[MAGASINS] ([ID_MAG], [LIB_MAG]) VALUES (N'MAG COLONNE 2', N'disques a tronconner - visserie')
INSERT [dbo].[MAGASINS] ([ID_MAG], [LIB_MAG]) VALUES (N'MAG COLONNE 3', N'visserie')
INSERT [dbo].[MAGASINS] ([ID_MAG], [LIB_MAG]) VALUES (N'MAG COLONNE 4', N'levage - mesure - peinture')
INSERT [dbo].[MAGASINS] ([ID_MAG], [LIB_MAG]) VALUES (N'MAGASIN 1ER ETAGE', N'Local technique')
INSERT [dbo].[MAGASINS] ([ID_MAG], [LIB_MAG]) VALUES (N'MAGASIN LUBRIFIANT', N'Lubrifiants et produits dangereux')
INSERT [dbo].[MAGASINS] ([ID_MAG], [LIB_MAG]) VALUES (N'MAGBU COLONNE 1', N'filtration')
INSERT [dbo].[MAGASINS] ([ID_MAG], [LIB_MAG]) VALUES (N'MAGBU COLONNE 2', N'engins')
INSERT [dbo].[MAGASINS] ([ID_MAG], [LIB_MAG]) VALUES (N'MAGBU COLONNE 3', N'Pieces automobiles')
INSERT [dbo].[MAGASINS] ([ID_MAG], [LIB_MAG]) VALUES (N'NM COLONNE 1', N'pneus - cantilever')
INSERT [dbo].[MAGASINS] ([ID_MAG], [LIB_MAG]) VALUES (N'NM COLONNE 2', N'fournitures de bureau  et electricit')
INSERT [dbo].[MAGASINS] ([ID_MAG], [LIB_MAG]) VALUES (N'NM COLONNE 3', N'epi - pieces de rechange')
INSERT [dbo].[MAGASINS] ([ID_MAG], [LIB_MAG]) VALUES (N'NM COLONNE 4', N'Pieces outillage')
INSERT [dbo].[MAGASINS] ([ID_MAG], [LIB_MAG]) VALUES (N'PARC', N'stock exterieur')
INSERT [dbo].[MAGASINS] ([ID_MAG], [LIB_MAG]) VALUES (N'TRANSIT STOCK', N'Transit')
GO

INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 1', N'A - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 1', N'A VERT')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 1', N'B - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 1', N'B - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 1', N'B - VERT')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 1', N'C - JAUNE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 1', N'C - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 1', N'C - VERT')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 1', N'D - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 1', N'D - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 1', N'E - BLANC')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 1', N'E - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 1', N'E - JAUNE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 1', N'E - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 1', N'E - VERT')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 1', N'F - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 1', N'F - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 1', N'G- VERT')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 2', N'H - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 2', N'H - VERT')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 2', N'I - BLANC')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 2', N'I - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 2', N'I - JAUNE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 2', N'I - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 2', N'I VERT')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 2', N'J - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 2', N'K - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 2', N'K - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 2', N'L - BLANC')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 2', N'L - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 2', N'L - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 2', N'M - BLANC')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 2', N'M - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 2', N'M - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 2', N'M - VERT')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 2', N'N - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 2', N'O - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 2', N'O - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 2', N'P - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 3', N'Q - BLANC')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 3', N'Q - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 3', N'Q - VERT')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 3', N'R - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 3', N'S - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 3', N'T - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 3', N'U - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 3', N'V - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 3', N'V - JAUNE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 3', N'V - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 3', N'W - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 3', N'X - BLANC')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 3', N'X - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 3', N'Y - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 4', N'A - BLANC')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 4', N'A - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 4', N'A - VERT')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 4', N'B - BLANC')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 4', N'B - JAUNE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 4', N'B - ROSE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 4', N'B - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 4', N'B - VERT')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 4', N'C - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 4', N'C - JAUNE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 4', N'D - JAUNE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 4', N'E - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 4', N'E - VERT')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 4', N'E- JAUNE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 4', N'F - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 4', N'G - JAUNE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG COLONNE 4', N'G - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG FOURNI', N'DIVERS')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG FOURNI', N'LUBRIFIANT')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAG FOURNI', N'PEINTURE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGASIN 1ER ETAGE', N'SOL')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGASIN LUBRIFIANT', N'C1 ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGASIN LUBRIFIANT', N'C2 JAUNE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGASIN LUBRIFIANT', N'C2 ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGASIN LUBRIFIANT', N'C3 ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGASIN LUBRIFIANT', N'C4 VERT')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 1', N'A - JAUNE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 1', N'A - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 1', N'B  - BLANCHE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 1', N'B - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 2', N'B - BLANCHE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 2', N'B - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 2', N'C - JAUNE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 2', N'C - NOIR')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 2', N'C - ROSE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 2', N'C - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 2', N'C - VERT')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 2', N'D - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 2', N'D - JAUNE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 2', N'D - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 2', N'E - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 2', N'E - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 2', N'E- JAUNE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 2', N'F - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 3', N'G - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 3', N'H - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 3', N'H - ROSE')
GO
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 3', N'H - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 3', N'H - VERTE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 3', N'I - BLANC')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 3', N'I - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 3', N'I - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'MAGBU COLONNE 3', N'I - VERTE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 1', N'A - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 1', N'B - VERT')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 1', N'C - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 1', N'D - GRIS')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 2', N'C - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 2', N'C - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 2', N'D - JAUNE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 2', N'D - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 2', N'E - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 2', N'E - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 2', N'F - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 2', N'F - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 2', N'G - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 2', N'G - VERT')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 3', N'H - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 3', N'H - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 3', N'I - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 3', N'I - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 3', N'I - VERT')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 3', N'J - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 3', N'K - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 3', N'K - JAUNE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 3', N'K - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 3', N'K - VERT')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 3', N'L - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 3', N'L - JAUNE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 3', N'L - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 3', N'L - VERT')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 4', N'M - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 4', N'M - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 4', N'M - VERT')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 4', N'N - BLEU')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 4', N'O - PALETTE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'NM COLONNE 4', N'P - ROUGE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'PARC', N'ACIERS ET METAUX')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'PARC', N'CARBURANT')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'PARC', N'METAUX')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'PARC', N'SERRURERIE')
INSERT [dbo].[AD_STOCKAGE] ([ID_MAG], [ID_ADR]) VALUES (N'TRANSIT STOCK', N'NON STOCKE')
GO

INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ADAP.EAD727810', N'20', N'20FB', N'Adaptateur display port M/ HDMI F 15cm', 14.213, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AGRA.N10', N'17', N'17FC', N'La boite d''agrafes N10 galvanis 1000', 0.1444973, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AIMA.SCHBP20S', N'12', N'12MB', N'Aimant  BP20S', 29.98578, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.92W_E27', N'05', N'05MA', N'Ampoule baonnette E27 92W', 1.69, 13, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.NAVE12V3W', N'33', N'33FA', N'Ampoule 3W 12V S7 pour lampe testeur', 1.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ANTI_RET.FOXT6 10', N'22', N'22FA', N'Anti retour quickmatic femelle OX (bleu) T6 10', 62.2062, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AXE_NOR102877', N'14', N'14FC', N'Axe lisse', 27, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BACH.4X6NYLON', N'26', N'26FD', N'Bache nylon de couverture', 21.58, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.ECH10021302830', N'14', N'14FC', N'Bague tanche ECHO', 11.787, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.STH00003591220', N'14', N'14FC', N'Bague etanche STIHL', 0.68, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BALA.EGCLA6005012539', N'14', N'14FC', N'Balai essuie-glace  tracteur PALES AV et AR', 23.12, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAND.ABRP80', N'26', N'26FD', N'Bande sf de toile abrasive 110x620 P80', 68.25, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BATT.FUL30', N'33', N'33FD', N'batterie  12V 110 ah 349X175X135', 146, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.SAR04510', N'12', N'12 FA', N'Boite  sceller 105x105x42', 2.6358, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BORN.CES040031', N'12', N'12 FA', N'Borne de mise a la terre TRL', 9.8, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOTT.T45', N'18', N'18MB', N'Bottes CAOUTCHOUC T45 SAS', 80, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.HYDC3/8M', N'14', N'14FC', N'Bouchon coupleur hydraulique 3/8 GROM male', 10.84, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUL.1ERG12X60', N'14', N'14FC', N'Boulon de charrue 1 ergot brut 12x60 6.8', 1.762179, 116, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BP_SCHENN33026', N'12', N'12MB', N'Bouton poussoir etanche', 2.6618, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.STH00003500900', N'14', N'14FC', N'Cable de bouchon', 1.078, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAIL.MEISTEPCLAIR4005X356X30', N'28', N'28MA', N'Caillebotis STEPCLAIR GALVA', 0, 0, 0, 0, 14)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE_M400G', N'26', N'26FD', N'Cale ronde pour manche bois', 0.5, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CD-R', N'20', N'20FB', N'Lot de CD-R', 29.4, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.7X35', N'26', N'26FD', N'Cheville nylon  7x35', 2.305, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.PARCR8X16MM', N'26', N'26FD', N'Chevilles paroie creuse 8x16mm AC ZI avec vis', 0.3905, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CIRC.ECH90070200028', N'14', N'14FC', N'Circlips pour ECHO 4605', 1.29, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLAP.NOR103130', N'14', N'14FC', N'Clapet parachute', 59.42, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COIN_AC2.5KG', N'26', N'26MA', N'Coin acier 2500 gr', 19.3776, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.PER19609', N'33', N'33FD', N'Collier', 3.51, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COMB.PLUIE_XXL', N'18', N'18MB', N'Combinaison de pluie TXXL marine', 120.84, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONV.AIRA688254', N'22', N'22MF', N'Convecteur 6 ordres de telecommande 1250W 52x40x8', 193, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.POLY04.5', N'26', N'26FD', N'Rouleau de corde polypropilne DN 4.5mm rl de 450ml blanc', 26.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.BPL-D13A_SOUD', N'33', N'33FB', N'Cosse de batterie PL - fut a souder dn 13mm 75mm', 3.87, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.EW16S', N'22', N'22FA', N'Coude EW 16S nu orientable', 16.86, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUP.AC_PAS8SECURITE', N'22', N'22FA', N'COUPLEUR SEC.FEM.A BARBE PASS.8MM a bouton', 46.94, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.POUR_L2T', N'05', N'05FA', N'Couvercle pour chambre de tirage avec fond L2T', 148.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CYLI.30X35/PG', N'26', N'26FD', N'Cylindre de porte double DOM  SIGMA+ 30x35 3 cles sur PG', 38.25, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DEMI_RAC.ALU25/1"F', N'22', N'22FA', N'Demi raccord douille alu male 25 mm / 1"', 38.47, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DIFF.INTENSITY', N'24', N'24MA', N'diffuseur pour coque intensity', 19.79, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.230TR.EP1.9INOX', N'26', N'26FD', N'Disque 230x1.9x22 a tronconner inox', 3.11, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.REN7701204286', N'33', N'33FA', N'Collection disques de frein KANGOO', 80.4372, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOMI.25MM', N'12', N'12MB', N'Barrette de domino 25mm', 6.78, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.STH00009550801', N'14', N'14FC', N'Ecrou pour guide chane STIHL M8', 0.937, 1, 0, 0, 4)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELEC.DS800_4', N'22', N'22MD', N'Electrode DS 800  DN 4', 165.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBA.SCHABE7R16T230*', N'12', N'12MB', N'Embase de sortie equipe de relais electromagnetique', 178.38, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.EH3-1.5-50', N'26', N'26MA', N'Embout pour vis six pans creux long.50mm N1.5', 3.38, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EPUI.50CM', N'26', N'26MA', N'Epuisette 50cm/10mm maille fil 210/24', 60.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.TX27', N'26', N'26MA', N'Embout torx N27', 6.76, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENSE.HON1017292', N'18', N'18MB', N'Ensemble de debroussaillage (casque antibruit + ecran grillag)', 33.6, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_P050X30', N'05', N'05FC', N'Fer plat 50x30 long.6ml', 11.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_UAC40X20X5', N'05', N'05FC', N'Fer UAC 40x20x5', 2.5755, 36, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEU_RVI5800201334', N'33', N'33FC', N'Feu de gabarit souple blanc et rouge sur silenbloc', 4.374, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HIFSO053', N'33', N'33FD', N'Filtre a huile moteur HATZ ( le Sarre)', 16.18, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.NIL185X140', N'24', N'24FA', N'Cartouche filtrante pour aspirateur Nilfisk VL200', 75.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FLAS.ECHC535000011', N'14', N'14FC', N'Flasque dbroussailleuse SRM4605', 16.4824, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+06X210', N'26', N'26FD', N'Fort SDS plus 6x210', 6.863191, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FOYE.TRA020206_LV', N'12', N'12 MC', N'Circuit 95 leds verte alim 24V cable 1M lentille polycarbonate + siliconage complet', 195, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.2BR20A', N'33', N'33FA', N'Fusible 2 broches 20A', 0.4052, 16, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GACH.ELEC12V_APPLIQ', N'26', N'26FD', N'Gache lectrique contact stationnaire en applique   impulsion 12V gold gauche', 56.48, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_DEF.T9/10', N'18', N'18MB', N'Gant defender taille unique', 2.35, 18, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GEOT.110G_2M', N'05', N'05FA', N'Geotextile  2ML x150ml 110gr', 205.92, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUJ.ENC08/120/55', N'26', N'26FD', N'Goujons d''encrage', 0.57, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_NITRIL9', N'18', N'18MB', N'Gant tout enduit nitrile noir T9', 17, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.1/2L8X45', N'26', N'26FD', N'Goupille 1/2 lune 8x45', 1.895, 13, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.F3.2X63', N'26', N'26FD', N'Goupille fendue 3.2x63', 0.05, 200, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.CONTRANSTACK-50KGS', N'33', N'33FG', N'graisse en fut de 50 kgs', 5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.2TBIO1', N'14', N'14FD', N'Huile 2T bio avec bouchon doseur en bidon de 1L', 21.41357, 64, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INDI.PIEZO6-28VCC', N'12', N'12MB', N'Indicateur piezo kpe 650 6-28 Vcc continu impulsion rapide', 11.46, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.LOM4680039', N'22', N'22FA', N'joint pour filtre de reniflard de pompe a eau genelec', 0.774, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.TOR.R08', N'22', N'22FA', N'Joint torique R 08 SH dn int.11mm dn ext 16mm epais.2.5mm', 0, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAIT.0/32', N'05', N'05FH', N'Laitier 0/32', 16.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_SAB.BOIS300', N'26', N'26FD', N'Lame de scie sabre BIM.BOIS LG300', 55.6, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.70ACR', N'26', N'26MA', N'Manchon peinture acrylique 70mm', 9.89, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_TRAPEZE', N'26', N'26MA', N'Lame trapezoidale pour cutter', 5.216667, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LASU.CM5', N'05', N'05FL', N'Lasure chene moyen bidon de 5 litre', 149, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MARQ.NOIR_TAB', N'17', N'17FC', N'Marqueur noir pour tableau', 0.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MONT.ROUL400', N'26', N'26MA', N'Monture rouleau radiateur longueur 400', 3.634, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NITR.1400X10MEP.3MM', N'26', N'26FD', N'Feuille de caoutchouc nitrile 1400x10M ep.3mmm', 375, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PALI.NOR102837', N'14', N'14FC', N'Palier complet rouleau palpeur', 272.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANN.AK5_700CL1', N'28', N'28MA', N'Panneau AK5 chantier dimension 700 CL1 sur support mobile', 72.0458, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAPI.A4BLEU160', N'19', N'19FB', N'Papier A4 bleu 160 grammes', 4.8, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAUM.SOUD100', N'26', N'26FD', N'Paumelles a souder', 0.804, 14, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.AR1RAL6005', N'05', N'05FL', N'Peinture antirouille vert mousse 1L', 17.868, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.SP3020_SOL', N'05', N'05FL', N'Peinture rouge tracage au sol ral 3020', 34.45, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIGN.STH11256402000', N'14', N'14FC', N'Pignon STIHL - 3/8 7dts', 21.78933, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIST.COLLE', N'26', N'26MA', N'Pistolet a colle', 78.54, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PNEU_MOB2P1/4-17M259', N'33', N'33FC', N'Pneu mobylette DAKOTA', 42.1, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.TP70', N'26', N'26FD', N'Pointes TP 31x70mm 5kgs', 20.8, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.LEG555108', N'12', N'12 FA', N'Prise mobile 16A 3P+T', 7.398, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROF.ROU4700353', N'14', N'14FC', N'Profil de protection J17 10 164330', 15, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROT.FACIALE', N'28', N'28MA', N'Protection faciale meulage PROVISO', 16, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HA06A12RO18A', N'14', N'14FC', N'Raccord hydraulique', 4.48, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.RMO', N'22', N'22FA', N'Raccord rapide oxygene male etage', 14.93675, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REDU.GCU.M16-3/4*', N'11', N'11FC', N'Raccord GCU 16-3/4 laiton', 1.47, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REGL.50', N'17', N'17FC', N'Rgle de bureau 50cm', 5.7, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RALL.FACS.215', N'26', N'26MA', N'Rallonge', 7.18, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RAYO.CL1536', N'23', N'23MA', N'Rayonnage charge lourde LARG1536 / PROF621 / HT1981 3 niveaux rayonnage de base', 309.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REPU.TIQUE_VET.', N'25', N'25FA', N'Repulsif tique 100ml vetement', 13, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.ECH12311315030', N'14', N'14FC', N'Ressort de rappel gaz SRM4600', 2.3672, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RIVE.4.8X10TL', N'26', N'26FD', N'Blister de 61 rivets alu 4,8x10 tete large', 9.56, 0, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CLA11570030', N'14', N'14FC', N'Rondelle', 1.75, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.GR18', N'26', N'26FD', N'Rondelle grower M18', 0.0991, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.PL.CH14', N'26', N'26FD', N'Rondelle plate chanfrein M14x28', 0.06, 33, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.IVIOL15', N'26', N'26FD', N'Ruban isolant violet 15mmx10m PVC', 0.864, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAC_FACBS.R20', N'26', N'26FD', N'Sac roulant textile', 80.65, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAND.L60', N'22', N'22MB', N'Sandow lg 60cm Dia,10', 2.77, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAVO.GELGS', N'24', N'24FB', N'Savon gel rouge grosse salissures en tube', 9.3, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SEGM.ECHA101000070', N'14', N'14FC', N'Segment de debroussailleuse ECHO 5000', 0, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SERR.CABLE10', N'22', N'22MB', N'Serre cable 10mm AC GN', 1.44, 28, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SOCL.HAG896023', N'12', N'12MB', N'Socle plinthe SL20115 PALOMA graphite noir', 4.37, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SOUF.HUS580BTS', N'14', N'14MA', N'Souffleur', 590, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.MOUST+TIQ', N'25', N'25FA', N'Spray cran rpulsif anti moustique et tique 75ml', 6.53125, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.ECH17804805630', N'14', N'14FC', N'Support Echo', 1.111, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.RS221-7531', N'26', N'26FD', N'Support de carte de circuit imprim', 8.54, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TALO.GOUT60PVC', N'05', N'05MA', N'Talon pour gouttiere PVC de 60', 2.46, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TE_PVC.MF100+T', N'11', N'11FC', N'T PVC dia.100 MF avec tampon a visser', 3.6969, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TEST.BAT12V', N'26', N'26MA', N'Testeur de batterie 12V', 269, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIGE_FIL16BI', N'26', N'26FD', N'Tige filetee AC BI 8.8 M16', 9.05, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TH08X120', N'26', N'26FD', N'Tirefond 8x120 TH AC ZI', 0.164, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.F2.5X60', N'26', N'26MA', N'Tournevis plat 2.5x60', 4.53, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.JWER05105631001', N'26', N'26MA', N'Jeu  de  tournevis isols 1000V', 102.35, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRIA.REM.', N'33', N'33FC', N'Triangle remorque ADED12553', 1.34632, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_CONT10/10', N'22', N'22FA', N'tube contact pour Poste a souder', 1.2, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.REF50', N'11', N'11FC', N'Tuyau de refoulement de 50 pour pompe a eau', 10.71, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'UNIO.G12L-INOXTI', N'22', N'22FA', N'Union double quip de bagues et ecrous inox titane', 14.38, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT3.5X035', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 3.5x35', 16.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VERR.105X50N13', N'18', N'18MB', N'ecran verre inactinique N11 - 105x50 pour masque a souder T.13', 0.9, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VERR.ARNOV', N'26', N'26FD', N'Verrou de porte  a cylindre profile europeen 1005EU01', 34.41, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VERR.AVIN', N'24', N'24FB', N'Lot de 12 pieces de verre a vin', 5.18, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VERR.BC', N'24', N'24FB', N'Lot de 500 verres boissons chaudes', 80.84, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VERR.CLA079525258XR', N'14', N'14FC', N'Kit verrou pour fourche tracteur', 23.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT3.5X040', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 3.5x40', 8.85, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT3.5X050', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 3.5x50', 10.9, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT4.5X030', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 4.5x30', 11.9, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT4.5X040FT', N'26', N'26FD', N'Vis a bois TF torx filetage total4.5x40', 10.55, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT4.5X045', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 4.5x45', 11.11667, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT4.5X060', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 4.5x60', 15.56, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT4.5X070', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 4.5x70', 14.34, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT4.5X080', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 4.5x80', 18.86, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT5X50A2', N'26', N'26FD', N'vis vba torx inox a2', 0.16, 80, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TRC3.5X20', N'26', N'26FD', N'Vis a bois Tete ronde cruciform 3,5x20', 7.8, 0.35, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VERI.CLAA1096', N'14', N'14FC', N'Verin de D 40x63 C 643 EF855 F400 Faucheux', 647.46, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VERI.NOR107656', N'14', N'14FC', N'Verin de balancier equip de bagues de frottement', 674.92, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VERI.NOR117393', N'14', N'14FC', N'Verin d''orientation du bras', 595.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VERN.MARIN', N'05', N'05FL', N'Vernis marin 1l', 15.554, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VERR.105X50I', N'18', N'18MB', N'ecran verre incolore 105x50 pour masque a souder T.12', 0.8100001, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VERR.105X50N11', N'18', N'18MB', N'ecran verre inactinique N11 - 105x50 pour masque a souder T.12', 1.5, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VERR.105X50N12', N'18', N'18MB', N'ecran verre inactinique N12 - 105x50 pour masque a souder T.12', 0.9582, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VERR.PORTE100', N'26', N'26FD', N'Verrou de porte coulissant a cadenas long.100mm', 6.63, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VEST.FOR.FIO_3XL', N'18', N'18MB', N'Veste de tronconnage taille 3XL', 131.27, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VEST.FOR.L', N'18', N'18MB', N'Veste forestiere protegee vert sapin orange EN381-5', 245.08, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VEST.FOR.M', N'18', N'18MB', N'Veste forestiere protegee M vert sapin orange EN381-5', 74.125, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VEST.FOR.S', N'18', N'18MB', N'Veste forestiere protegee vert sapin orange EN381-5', 75.4, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VEST.FOR.XL', N'18', N'18MB', N'Veste forestiere protegee vert sapin orange EN381-5', 75.4, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VINA.BLANC', N'05', N'05FI', N'Vinaigre blanc', 3.461715, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_AIL8X80', N'26', N'26FD', N'Vis a il 8x80 0160 80880', 0.85, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_AWTR3X10', N'26', N'26FD', N'vis assy aw tete ronde', 20.93, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_AWTR3X16', N'26', N'26FD', N'vis assy aw tete ronde', 23.52, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_AWTR3X30', N'26', N'26FD', N'vis assy aw tete ronde', 36.12, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_AXE_BASCUL', N'33', N'33FD', N'Vis pour arret axe de basculement tige', 2.2, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_BIZ700049', N'26', N'26FD', N'vis pour emporte piece', 20.35, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC04X10', N'26', N'26FD', N'Ecrou CHC AC ZI 4x10', 0.027, 500, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC04X20', N'26', N'26FD', N'Ecrou CHC AC ZI 4x20', 0.041, 245, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC04X25', N'26', N'26FD', N'Ecrou CHC AC ZI  4 x 25', 0.34, 86, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC04X70', N'26', N'26FD', N'Vis acier brut CHC  8.8  4x70', 0.12, 80, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC05X10', N'26', N'26FD', N'Vis AC ZI CHC  8.8  5x10', 0.12, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC05X16', N'26', N'26FD', N'Vis AC ZI CHC  8.8  5x16', 0.036, 250, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC05X20', N'26', N'26FD', N'Ecrou CHC  5x20 8.8 AC ZI', 0.0432, 250, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC05X20A2', N'26', N'26FD', N'Ecrou CHC inox A2 5x20', 0.1186, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC05X25', N'26', N'26FD', N'Vis AC ZI CHC  8.8  5x25', 0.12, 40, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC05X30', N'26', N'26FD', N'Vis AC ZI CHC  8.8  5x30', 0.12, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC05X40', N'26', N'26FD', N'Vis AC ZI CHC  8.8  5x40', 0.12, 75, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC05X70', N'26', N'26FD', N'Vis AC ZI CHC  8.8  5x70', 0.081, 92, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC06X16', N'26', N'26FD', N'Vis AC ZI CHC  8.8  6x16', 0.0432, 250, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC06X20', N'26', N'26FD', N'Vis AC ZI CHC  8.8  6x20', 0.039, 185, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC06X30', N'26', N'26FD', N'Vis AC ZI CHC  8.8  6x30', 0.081, 47, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC06X40', N'26', N'26FD', N'Vis AC ZI CHC  8.8  6x40', 0.0808, 75, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC06X60', N'26', N'26FD', N'Vis AC ZI CHC  8.8  6x60', 0.0808, 82, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC06X70', N'26', N'26FD', N'Vis AC ZI CHC  8.8  6x70', 0.1802, 200, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC06X80', N'26', N'26FD', N'Vis AC ZI CHC  8.8  6x80', 0.168, 200, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC08X25', N'26', N'26FD', N'Vis CHC 8.8 8x25 AC ZI', 0.3, 59, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC08X45', N'26', N'26FD', N'Vis CHC AC ZI 8.8 8x45', 0.39, 64, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC08X50', N'26', N'26FD', N'Vis CHC AC ZI 8.8 8x50', 0.39, 90, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC08X55', N'26', N'26FD', N'Vis CHC acier brut 8.8 8x55', 0.39, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC08X70', N'26', N'26FD', N'Vis CHC AC ZI 8.8 8x70', 0.4726, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC10X40', N'26', N'26FD', N'Vis CHC AC ZI 8.8 10x40', 0.44, 24, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC10X50', N'26', N'26FD', N'Vis CHC AC ZI 8.8 10x50', 0.2664, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CHC14X40', N'26', N'26FD', N'Vis CHC AC ZI 8.8 14x40', 0.531, 44, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CLA11570000', N'14', N'14FC', N'Vis', 4.59, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_CLA6005012731', N'14', N'14FC', N'Vis', 1.73, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_ECH17723640630', N'14', N'14FC', N'Vis ECHO', 3, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_ECH90010505012', N'14', N'14FC', N'Vis TH ISO pour SRM 4600', 0.69, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_ECH90016205020', N'14', N'14FC', N'Vis ECHO pour RM 380', 0.81, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_ECH90023804010', N'14', N'14FC', N'Vis debroussailleuse ECHO', 0.24, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_ECH90024204010', N'14', N'14FC', N'Vis ECHO', 0.24, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_EUT12X30', N'14', N'14FC', N'Vis HM 12x30 FP 8.8 Attila', 1.7989, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_EUT27915', N'14', N'14FC', N'Vis pointeau  ATTILA', 16.39, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_FHC05X10', N'26', N'26FD', N'Vis AC ZI FHC 5x10', 0.09, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_FHC06X10A2', N'26', N'26FD', N'Vis AC ZI FHC 6x10 inox A2', 0.0755, 200, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_FHC10X40', N'26', N'26FD', N'Vis FHC ACBR 10x40 10,9', 0.5, 46, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_FHC12X40', N'26', N'26FD', N'Vis FHC ACBR 12x40 10,9', 0.3374407, 94, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_FHC12X50', N'26', N'26FD', N'Vis FHC acier zingu 12x50 10.9', 0.3625641, 84, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_FHC12X60', N'26', N'26FD', N'Vis FHC ACBR 12x60 10,9', 0.5001267, 319, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_FHC12X70A2', N'26', N'26FD', N'Vis FHC 12x70 inox A2', 0.95, 20, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_FHC12X80', N'26', N'26FD', N'Vis FHC ACZI 12x80 10.9', 0.721, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_FHC12X90', N'26', N'26FD', N'Vis FHC acier brut 12x90 10.9', 0.619, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_FHC14X50', N'26', N'26FD', N'Vis FHC ACBR 14x50 10.9', 0.701, 44, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_FHC14X70', N'26', N'26FD', N'Vis FHC ACBR 14x70 10.9', 0.884, 16, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_INV10X105', N'26', N'26FD', N'Vis inviolable FT WUPPO 105mm', 0.953, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_KUB0123280', N'14', N'14FC', N'vis', 1.74, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_KUHA5411862', N'14', N'14FC', N'VIS 12*1.25 LG84  manille pour broyeur', 0.75, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_MUT980416', N'14', N'14FC', N'Vis + ecrou', 5.89, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_NOR101960', N'14', N'14FC', N'Vis d''assemblage', 1.59, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_NOR101961', N'14', N'14FC', N'Vis d''assemblage pour LN1600', 0.41, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_NOR101964', N'14', N'14FC', N'Vis  MAGISTRA TCC', 10.56, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_NOR103073', N'14', N'14FC', N'Vis LN1600 dia.10x75  12.9 noir', 1.10311, 15, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_NOR103077', N'14', N'14FC', N'Vis de 14 pour fleau MAGISTRA', 1.199505, 121, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_NOR103085', N'14', N'14FC', N'Vis 11x84 LN1600', 0.5668205, 91, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_NOR104158', N'14', N'14FC', N'Vis d''assemblage', 0.46, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_NOR104160', N'14', N'14FC', N'Vis HM 16x40 8.8 ZN', 1.28, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_NOR104230', N'14', N'14FC', N'Vis', 0.43, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_NOR104245', N'14', N'14FC', N'Vis d''assemblage', 0.74, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_NOR106160', N'14', N'14FC', N'Vis HM 20x50 8.8 ZN', 2.17, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_PIAS4.8X13', N'26', N'26FD', N'Vis pias autoperceuse et taraudeuse 4.8x13', 0.0906, 900, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_PIAS4.8X16', N'26', N'26FD', N'Vis pias autoperceuse et taraudeuse 4.8x16', 0.0933, 970, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_PIAS4.8X19', N'26', N'26FD', N'Vis pias autoperceuse et taraudeuse 4.8x19', 0.0978, 1000, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_PIAS4.8X22', N'26', N'26FD', N'Vis pias autoperceuse et taraudeuse 4.8x22', 0.1053, 813, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_PIAS5.5X45', N'26', N'26FD', N'Vis pias autoperceuse et taraudeuse tete fraisee plate 5.5x45', 0.028, 399, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_PLACO3.9X35', N'26', N'26FD', N'Vis placo 3.9x35 / boite de  mille', 7.06, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_ROU11009121', N'14', N'14FC', N'Vis de patin rotobroyeuse', 0.41, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_STA3960137R', N'14', N'14FC', N'Vis protge courroie tondeuse', 2.765, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_STH00009536605', N'14', N'14FC', N'Vis d''assemblage a embase', 1.63, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_STH11216407110', N'14', N'14FC', N'Vis sans fin', 9.8736, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_STH11257916200', N'14', N'14FC', N'Vis 034', 1.25, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_STH90223130680', N'14', N'14FC', N'Vis cylindrique M4x16 / STIHL 020', 0.79, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_STH90223711020', N'14', N'14FC', N'Vis ISO 5x20', 0.69, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_STH90744784435', N'14', N'14FC', N'Vis PARKER IS P6x19', 1.0912, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_STH90744784475', N'14', N'14FC', N'Vis cylindrique ISP 6x21.5', 2.3144, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_STH90744784675', N'14', N'14FC', N'Vis cylindrique ISP 6x32.5', 1.7512, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_STH91040033004', N'14', N'14FC', N'Vis cylindrique is pt 4x14', 1.012, 0, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TCAB16X180_AB', N'26', N'26FD', N'Vis tete carre', 0, 36, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TCAB20X100_6.8', N'26', N'26FD', N'Vis tete carre', 0, 170, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TCAB20X160_6.8', N'26', N'26FD', N'Vis tete carre', 0, 91, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TCB04X45', N'26', N'26FD', N'Vis metaux TCB AC ZI 4x45', 0.1555, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TCB05X10', N'26', N'26FD', N'Vis metaux TCB AC ZI 5x10', 0.0254, 200, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TCB05X12', N'26', N'26FD', N'Vis metaux TCB AC ZI 5x12', 0.0265, 200, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TCB05X50', N'26', N'26FD', N'Vis TCB AC ZI 5x50', 0.15, 16, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TCB06X60', N'26', N'26FD', N'Vis metaux TCB AC ZI 6X60', 0.111, 98, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TCB06X70', N'26', N'26FD', N'Vis metaux TCB AC ZI 6X70', 0.128, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TCB2.5X6A2', N'26', N'26FD', N'Vis inox TCB 2.5x6mm', 0.052, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TCBAP3.5X13', N'26', N'26FD', N'Vis metaux autoperforante TCB 3.5x13', 0.056, 890, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TCBAP3.5X9.5', N'26', N'26FD', N'Vis metaux autoperforante TCB 3.5x9.5', 0.0547, 900, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TCF04X25', N'26', N'26FD', N'Vis Tte cylindrique Fendue 4x25 AC ZI', 0.0148, 484, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TCF04X35', N'26', N'26FD', N'Vis Tte cylindrique Fendue 4x35 AC ZI', 0.01, 95, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TCF04X45', N'26', N'26FD', N'Vis Tte cylindrique Fendue 4x45 AC ZI', 0.01, 85, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TCF05X20', N'26', N'26FD', N'Vis Tete Cylindrique  fendue ACZI mtaux  5x20', 0.045, 200, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TCF05X30', N'26', N'26FD', N'Vis Tte cylindrique Fendue 5x30 AC ZI', 0.04, 42, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TCF05X45', N'26', N'26FD', N'Vis Tte cylindrique Fendue 5x45 AC ZI', 0.09, 96, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TCF05X50', N'26', N'26FD', N'Vis Tte cylindrique Fendue 5x50 AC ZI', 0.07, 91, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TCF05X70', N'26', N'26FD', N'Vis Tte cylindrique Fendue 5x70 AC ZI', 0.22, 60, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TCF06X35', N'26', N'26FD', N'Vis Tte cylindrique Fendue 6x35 AC ZI', 0.16, 69, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TCF06X60', N'26', N'26FD', N'Vis Tte cylindrique Fendue 6x60 AC ZI', 0.0905, 108, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TCF06X70', N'26', N'26FD', N'Vis Tte cylindrique Fendue 6x70 AC ZI', 0.22, 47, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TFC06X30A2', N'26', N'26FD', N'Vis metaux tete fraisee cruciforme AC ZI 6X30  inox A2', 0.364, 190, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TFF04X20', N'26', N'26FD', N'Vis TF fendue ACZI mtaux  4x20', 0.012, 87, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TFF04X60', N'26', N'26FD', N'Vis TF fendue ACZI mtaux  4x60', 0.027, 26, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TFF05X16', N'26', N'26FD', N'Vis TF fendue ACZI mtaux  5x16', 0.015, 145, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TFF05X20', N'26', N'26FD', N'Vis TF fendue ACZI mtaux  5x20', 0.04, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TFF05X80', N'26', N'26FD', N'Vis TF fendue ACZI metaux  5x80', 0.038, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TFF05X90A2', N'26', N'26FD', N'Vis TF fendue A2 mtaux 5x90', 0.229, 190, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TFF06X30A2', N'26', N'26FD', N'Vis TF fendue inox a2 a  mtaux  6x30', 0.184, 92, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TFF06X80A2', N'26', N'26FD', N'Vis TF fendue A2 mtaux 6x80', 0.381, 33, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TFF08X25A2', N'26', N'26FD', N'Vis TF fendue A2 mtaux 8x25', 0.305, 38, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TFF08X40', N'26', N'26FD', N'Vis TF fendue ACZI mtaux  8x40', 0.037, 169, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TFF08X50', N'26', N'26FD', N'Vis TF fendue ACZI mtaux  8x50', 0.047, 77, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TFF08X90', N'26', N'26FD', N'Vis TF fendue ACZI mtaux  8x90', 0.13, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TFF10X45', N'26', N'26FD', N'Vis TF fendue ACZI mtaux 10x45', 0.061, 30, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TFF10X50', N'26', N'26FD', N'Vis TF fendue ACZI mtaux 10x50', 0.088, 176, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP06X50', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8,8 6x50', 0.08398347, 163, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP06X60', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 6x60', 0.05469076, 159, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP06X70', N'26', N'26FD', N'Vis TH filetage partiel 6x70 AC ZI 8.8', 0.1309, 108, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP06X80', N'26', N'26FD', N'Vis TH filetage partiel 6x80 AC ZI 8.8', 0.236, 98, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP06X90', N'26', N'26FD', N'Vis TH filetage partiel 6x90 AC ZI 8.8', 0.258, 96, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP08X100', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 8x100', 0.247, 98, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP08X110', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 8x110', 0.207, 45, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP08X120', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 8x120', 0.319, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP08X150', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 8x150', 0.267, 47, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP08X50', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 8x50', 0.106, 200, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP08X60', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 8x60', 0.1136, 18, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP08X70', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 8x70', 0.1364931, 192, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP08X80', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 8x80', 0.162, 64, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP08X90', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 8x90', 0.206, 83, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP10X100', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 10x100', 0.89, 26, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP10X100A2', N'26', N'26FD', N'Vis TH filetage partiel Inox A2 10x10', 0.9659, 69, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP10X110', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 10x110', 0.221, 23, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP10X120', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 10x120', 0.236, 22, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP10X140', N'26', N'26FD', N'Vis TH filetage partiel 10x140 AC ZI 8.8', 1.174, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TETE_THERMO.SI', N'11', N'11FC', N'Tete de robinet thermostatique sonde integree par senso', 15.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TETI.GAL414116', N'22', N'22FA', N'Ttine valve Gallia 104', 1.275, 17, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TETI.RECH.SAVON', N'24', N'24FA', N'Ttine pour recharge savon alpha mousse 2', 2.5, 1, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TGAP', N'09', N'09SC', N'taxe sur les produits petroliers', 2.66, 0, 0, 0, 12)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'THER.CAFE', N'24', N'24FB', N'thermos a cafe', 24.75, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'THER.CAFE_PPE', N'24', N'24FB', N'thermos a cafe  pompe', 47.375, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'THER.CHAUF-EAU', N'11', N'11FC', N'Thermostat pour chauffe eau', 74, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIGE_FIL+E+R08', N'26', N'26FD', N'Tige filete+ecrou+rondelle M8 pour scellement chimique', 0.48, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIGE_FIL+E+R20', N'26', N'26FD', N'Tige filete+ecrou+rondelle M20/scellement chimiqu', 3.2375, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIGE_FIL04AB', N'26', N'26FD', N'Tige filete AC BR M4 ml', 1.07, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIGE_FIL05AZ', N'26', N'26FD', N'Tige filete M5 AC ZI 4.6 ML', 2.64, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIGE_FIL06AZ', N'26', N'26FD', N'Tige filete AC ZI M6 ml', 1.6, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIGE_FIL07AZ', N'26', N'26FD', N'Tige filete AC ZI M7 ml', 17.623, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIGE_FIL07BI', N'26', N'26FD', N'Tige filete AC BI M7X150 ml', 1.66, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIGE_FIL08AZ', N'26', N'26FD', N'Tige filete AC ZI M8 ml 8.8', 3.92, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIGE_FIL10AZ', N'26', N'26FD', N'Tige filete AC ZI M10 ML', 4.4775, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIGE_FIL12AZ', N'26', N'26FD', N'Tige filete M12  AC ZI ML', 6.547143, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIGE_FIL14AZ', N'26', N'26FD', N'Tige filetee M14 8.8 AC.ZI ML', 7.24, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIGE_FIL18AZ', N'26', N'26FD', N'Tige filetee M18 8.8 AC.ZI ML', 6.625263, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIGE_FIL20AZ', N'26', N'26FD', N'Tige filetee M20 AC ZI 8.8', 16.58, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIGE_FIL24AZ', N'26', N'26FD', N'Tige filetee M24 8.8 AC.ZI ML', 15.85, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIGE_FIL30AZ4.6', N'26', N'26FD', N'Tige filete AC ZI  M30 1ml', 8.02, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIGE_OEILLET250MM', N'05', N'05FA', N'Tige  oeillet pour suspente rapide 250mm', 0.16, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIGE_SCHXUZ2001', N'12', N'12 FA', N'Tige M12 pour fixation rotule pour detecteur photoelectrique osiconcept XUX 0', 2.19, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TC06X060', N'26', N'26FD', N'Tirefond 6x60 TC AC ZI', 0.0372, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TC06X070', N'26', N'26FD', N'Tirefond 6x70 TC AC ZI', 0.047, 200, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TC08X080', N'26', N'26FD', N'Tirefond 8x80 TC AC ZI', 0.096, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TC08X120', N'26', N'26FD', N'Tirefond 10x120 TC AC ZI', 0.465, 408, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TH06X040', N'26', N'26FD', N'Tirefond 6x40 TH AC ZI', 0.035, 205, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TH06X050', N'26', N'26FD', N'Tirefond 6x50 TH AC ZI', 0.0367, 180, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TH06X050A2', N'26', N'26FD', N'Tirefond 6x50 inox A2 TH AC ZI', 0.28, 40, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TH06X060', N'26', N'26FD', N'Tirefond 6x60 TH AC ZI', 0.027, 195, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TH06X060A2', N'26', N'26FD', N'Tirefond 6x60 TH inox A2', 0.29, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TH06X100', N'26', N'26FD', N'Tirefond 6x100 TH AC ZI', 0.066, 49, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TH08X040', N'26', N'26FD', N'Tirefond 8x40 TH AC ZI', 0.061, 79, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TH08X045', N'26', N'26FD', N'Tirefond 8x45 TH AC ZI', 0.066, 99, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TH08X060', N'26', N'26FD', N'Tirefond 8x60 TH AC ZI', 0.1142152, 54, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TH08X070', N'26', N'26FD', N'Tirefond 8x70 TH AC ZI', 0.1032, 150, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TH08X100', N'26', N'26FD', N'Tirefond 8x100 TH AC ZI', 0.3144132, 212, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TH10X040', N'26', N'26FD', N'Tirefond 10x40 TH AC ZI', 0.12, 64, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TH10X050', N'26', N'26FD', N'Tirefond 10x50 TH AC ZI', 0.086, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TH10X060', N'26', N'26FD', N'Tiefond 10x60 TH AC ZI', 0.1772, 32, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TH10X070', N'26', N'26FD', N'Tirefond 10x70 TH AC ZI', 0.1359, 28, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TH10X080', N'26', N'26FD', N'Tirefond 10x80 TH AC ZI', 0.2412, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TH10X100', N'26', N'26FD', N'Tirefond 10x100 TH AC ZI', 0.2389, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TH10X120', N'26', N'26FD', N'Tirefond 10x120 TH AC ZI', 0.375, 71, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TH12X 70', N'26', N'26FD', N'Tirefond 12x70 TH AC ZI', 0.2058, 42, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE.TH12X120', N'26', N'26FD', N'Tirefond 12x120 TH AC ZI', 0.313, 17, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TIRE_FIL30', N'26', N'26MA', N'Tire fil 30ml pour fil lectrique', 54.88, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOIL.ABR50X120', N'26', N'26FD', N'Toile abrasive 50mm 25m gr120', 56, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOIL.ABR50X40', N'26', N'26FD', N'Toile abrasive 50mm 25m gr40', 47.81, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOIL.ABR50X60', N'26', N'26FD', N'Toile abrasive 50mm 25m gr60', 61.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOIL.ABR50X80', N'26', N'26FD', N'Toile abrasive 50mm 25m gr80', 59, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOIL.FIBRE_MUR50X1', N'05', N'05MA', N'Toile a peindre pour mur rouleau de 50ml', 65, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOIT_CLA6005014214', N'14', N'14FC', N'Toit ergos', 981.44, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOLE_1.5MX3MX8MM', N'05', N'05FC', N'Tole 1500x3000x8mm', 267.97, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOLE_1MX2MX10MM', N'05', N'05FC', N'Tole 1000x2000x10 noire', 87.8106, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOLE_1MX2MX2MMA2', N'05', N'05FC', N'Tole 1000x2000x2mm inox', 148.28, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOLE_1MX2MX4MM', N'05', N'05FC', N'Tole 1000x2000x4mm', 53.3572, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOLE_CRICS', N'22', N'22SB', N'Realisation de 2 toles avec bague bronze auto lubrifi et roulement', 649.7, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOLE_LAR5/7_1.25X2.5', N'05', N'05FC', N'Tole larmee 5/7-1250x25 S235JRG200', 234.96, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOLE_LAR5/7_1.5X3', N'05', N'05FC', N'Tole larme 5/7 1500x3000', 125, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOLE_LAR5/7_1X2', N'05', N'05FC', N'Tole larmee 5/7-1000x2000', 24.58, 2.5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOND.VIKMB756GS', N'14', N'14MA', N'Tondeuse VIKING', 1250, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TONE.SAMML-D2850', N'20', N'20FB', N'Toner monobloc Samsung  d''encre noir MQ', 85.77, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TORC.MIG', N'22', N'22FA', N'Torche MIG 4M faisceau  501', 267.86, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TORC.VAISSEL', N'24', N'24FB', N'Torchon vaisselle coton', 17.2, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.F2X60', N'26', N'26MA', N'Tournevis plat 2x60', 4.53, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.F3X150', N'26', N'26MA', N'Tournevis plat 3x150', 7.31, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.F6.5X150', N'26', N'26MA', N'Tournevis plat 6.5x150', 14.39, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.FAC831.1', N'26', N'26MA', N'Tourne a gauche', 11.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.FFACAN2.5X75', N'26', N'26MA', N'Tournevis plat 2.5x75', 10.1, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.FFACAN4X200', N'26', N'26MA', N'Tournevis plat 4x200', 3.068, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.FVE0.4X2.5X80', N'26', N'26MA', N'tournevis isole fente 0,4x2.5x80', 8.53, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.FVE0.5X3X100', N'26', N'26MA', N'Tounevis isole fente 0,5x3x100', 8.81, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.FVE0.5X3X80', N'26', N'26MA', N'Tounevis isole fente 0,5x3x80', 4.4, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.FVE0.6X3.5X100', N'26', N'26MA', N'tournevis isole fente 0,6x3,5x100 lame a diametre reduit', 5.38, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.H08MM', N'05', N'05FA', N'Tourillon hetre 8mm - 1ml', 0.7, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.H10MM', N'05', N'05FA', N'Tourillon hetre10mm - 1ml', 0.88, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.H12MM', N'05', N'05FA', N'Tourillon hetre12mm - 1ml', 1.12, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.J10TOURN.', N'26', N'26MA', N'Jeu de 10 tournevis fente - PZ', 43.2185, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.JFACAD.J8VE', N'26', N'26MA', N'Jeu  de 8 tournevis isols', 34.89, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.JFACATHH.JS5', N'26', N'26MA', N'Jeu ratelier de 5 tournevis fente bois', 41.55, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.JROB412100', N'26', N'26MA', N'Jeu  de 6 tournevis isols', 33.44, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.JWER05133355001', N'26', N'26MA', N'Jeu  de  tournevis isols 1000V', 67.17, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.JWER05134000001', N'26', N'26MA', N'Jeu  de  tournevis isols 1000V', 89, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.MAGASIN', N'26', N'26MA', N'tournevis a magesin', 6.64, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.PZ11X150VE', N'26', N'26MA', N'Tournevis isole borneo pz1', 21.93, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.PZ1VE1X100', N'26', N'26MA', N'Tournevis isole borneo pz1', 4.316, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.PZ2X200', N'26', N'26MA', N'Tournevis isole borneo pz2', 23.18, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.ROB412103', N'26', N'26MA', N'Tournevis dynacom lectrique isol', 134.45, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TOUR.TFACAEX6X35', N'26', N'26MA', N'Tournevis torx 6x35', 3.653, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRAC.BL.HYDRO', N'05', N'05FL', N'Traceur de chantier blanc en phase aqueuse fluorescent', 20, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRAC.BLEU', N'05', N'05FL', N'Traceur de chantier bleu fluo', 17.1775, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRAC.CARREL', N'26', N'26MA', N'Traceur de carrelage', 65.37, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRAC.JAUNE', N'05', N'05FL', N'Traceur de chantier jaune', 17.3, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRAC.ORANGE', N'05', N'05FL', N'Traceur de chantier orange', 17.2508869, 17, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRAC.ROUGE', N'05', N'05FL', N'Traceur de chantier rouge fluo', 16.4456, 31, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRAC.VERT', N'05', N'05FL', N'Traceur de chantier vert', 17.104, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRAN.AUMZ002.880', N'22', N'22FA', N'Transmetteur de position RWG 4-20 mA', 425, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRAP.600X600', N'05', N'05FA', N'Trappe de visite laque blanche clic 600/600', 38.61, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TREI.20/20PAFC', N'05', N'05FA', N'Panneau de treillis 20/20-360/240 pour dalle beton', 10.17, 0, 0, 0, 7)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRES.E4MM', N'22', N'22FA', N'Tresse d''tanchit carr de 4mm type 1727', 258, 1, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRES.PRO239', N'33', N'33FA', N'Boite de 60 tresse VL marrons 100mm - D', 41.7, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRES.PRO242BRN', N'33', N'33FA', N'Boite de 30 tresse PL marrons 200mm - D', 51.28, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TREU.300KG_SANG', N'33', N'33FC', N'Treuil de halage 300kgs avec 12m de sangle textile dyneema pour remorque bateau', 310, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TREU.HUCSUPERWINCH_TALON18', N'22', N'22MB', N'8165 kgs cable dn13mm avec crochet longcable 27.4m poids du treui 65kgs 4.48kw', 1670, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRIE.12C', N'23', N'23MA', N'Trieur a 12 compartiments carte lustr', 6.8, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRIE.24C', N'23', N'23MA', N'Trieur a 24 compartiments carte lustr', 12.2, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRIF.500LEDS', N'28', N'28MA', N'Triangle lumineux de signalisation a leds avec double effets a ressort', 245, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TROM.25', N'17', N'17FC', N'Boite de 1000 trombonnes bout chevron nickel', 1.99, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRONC.MS201TCM', N'14', N'14MA', N'Trononneuse elagueuse STIHL MS201TC-M', 485, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRONC.MS261', N'14', N'14MA', N'Trononneuse STIHL MS261', 545, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRONC.MS362', N'14', N'14MA', N'Trononneuse STIHL MS362', 495, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TROU.ASEP_P35', N'23', N'23MA', N'Trousse de secours', 28.64, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRUE.ANGLE', N'26', N'26MA', N'Truelle d''angle intrieur', 10.9763, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRUE.C20', N'26', N'26MA', N'Truelle carr N20', 5.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRUE.I20', N'26', N'26MA', N'Truelle italienne ronde N20', 6.09, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRUE.JOINT12', N'26', N'26MA', N'Truelle joint plat 12mm', 4.37, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TRUE.LC160', N'26', N'26MA', N'Truelle langue de chat 160 mm long', 5.41, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_C30/2', N'05', N'05FC', N'Tube carre de 30 paisseur 2mm longueur 6,2ml', 3.581014, 24.8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_C40', N'05', N'05FC', N'Tube carre de 40', 2.6994, 24.8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_C50X4', N'05', N'05FC', N'Tube carre de 50 longueur 6,2ml ep.4mm', 3.7929, 18, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_CONT12/10', N'22', N'22FA', N'Tube contact pour poste a souder', 1.2, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_ECH61020643130', N'14', N'14FC', N'Tube ECHO pour debroussailleuse', 117.3744, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_ECHC050000050', N'14', N'14FC', N'Tube ECHO', 168.75, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_ECHC050000880', N'14', N'14FC', N'Tube ECHO', 175.076, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_ETANCHE', N'05', N'05FI', N'Tubetanche LOCTITE 577', 32.94, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_GERM30W', N'11', N'11FC', N'Tube SYLVANIA 00503 G30 T8 germicide', 11.8, 21, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_HAL230W', N'05', N'05MA', N'Tube halogene 230W 230V R7S haloline eco', 7, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_HAL400W', N'05', N'05MA', N'Tube halogene 400W economique 230V R7S', 5.2, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_HYDTU-AC--30-3-HX', N'22', N'22FA', N'Tube hydraulique de 24 - 30 - pn 201 B', 11.73, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_HYDTU-AC--30-3-ZS', N'22', N'22FA', N'Tube hydraulique de 24 - 30 - pn 201 B', 11.73, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_IRL20', N'12', N'12MB', N'Tube tulipe diametre 20 IRL en 3ml', 0.3155, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_IRL25', N'12', N'12MB', N'Tube tulipe dia:25 ICTA en 3ml', 0.5128, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_IRL32', N'12', N'12MB', N'Tube IRL dia:32mm', 0.6990615, 16, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_KAR69021540', N'22', N'22FA', N'Tube inox aspirateur NT351 DN35', 48.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_LED6W', N'05', N'05MA', N'Tube leds dimensions 78 mm  6W / 4000 K R7S', 25.8, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_N14W', N'05', N'05MA', N'Tube pour non 1,2ml  14W  2100lm', 17, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_N18W', N'05', N'05MA', N'Tub fluo TFP 18W/840 G13 SLV/2 brillant', 2.255769, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_N18WLEDS', N'05', N'05MA', N'Tube non 1,2ml  leds 4000K  T8', 14.97, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_N22WLEDS', N'05', N'05MA', N'Tube leds pour non 1,5ml 4000K T8', 17.96, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_N36W', N'05', N'05MA', N'Tube pour non 1,2ml F36W 133 ES standard', 2.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_N55W', N'05', N'05MA', N'Tub EFL 55W BRL/840 2G11 4B 1C', 9.14, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_N58W', N'05', N'05MA', N'Tube non 1,5ml F58W/840', 2.899439, 17, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_NOR102774', N'14', N'14FC', N'Tube entretoise pour LN 1600', 30.535, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_ORB131640', N'05', N'05MA', N'Tub G13 28x452 15W ACTINIC.UVA', 9.8, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_R21.3X2.3', N'05', N'05FC', N'Tube acier 21,3x2,3x6ml', 0.915, 30, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_R26.9X2.3', N'05', N'05FC', N'Tube rond acier dia:26,9x2,3x6ml', 1.143, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_R33.7X2.5', N'05', N'05FC', N'Tube rond acier dia:33,7x2,5x6ml', 1.6408, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_R48.3X2A2', N'05', N'05FC', N'Tube inox rond dia:48,3x2x6.15ml', 13.78, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_RECT100/50/5', N'05', N'05FC', N'Tube rectangulaire100/50 ep.5', 7.25, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_RECT40/27/2', N'05', N'05FC', N'Tube rectangulaire 40x27 ep.2', 1.777, 24.4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_RECT50/30/4', N'05', N'05FC', N'Tube rectangulaire 50/30 ep,4', 3.38, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_RECT60/30/3', N'05', N'05FC', N'Tube rectangulaire 60/30 ep.3', 3.81, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_RVI5689110248', N'33', N'33FA', N'tube polyamide D=8x1', 4.83, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_SMINOX', N'22', N'22FA', N'Tube cintr suivant plan + cone et ecrou en inox', 241.9583, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_STH41387107115', N'14', N'14FC', N'Tube de protection intrieur pour HT75', 79.5872, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUBE_VERIN120/100/6000', N'22', N'22FA', N'Tube verin SS Galete E355 120/100/6000', 113.14, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TURB.AG120MM', N'26', N'26FD', N'turbine melangeuse 120mm', 15.95, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TURB.AG80MM', N'26', N'26FD', N'turbine lg.400MM 80mm', 10.7, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.56X60TELECOM', N'05', N'05FA', N'Tuyau rigide 56/60 fibre', 1.35, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.AC10X15', N'26', N'26FD', N'Tuyau air comprim 10x15 polyurethane tress', 2.41, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.AC10X17', N'26', N'26FD', N'Tuyau air comprim 10x17 polyurethane tress', 4.46, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.ALIM.INJ', N'33', N'33FD', N'Tuyau alimentation injecteur pour ponton grue', 68.29, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.ASPI25', N'22', N'22FA', N'Tuyau caoutchouc pour pompe a eau DN25mm', 10.65, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.ASPI32', N'22', N'22FA', N'Tuyau caoutchouc pour pompe a eau DN32mm', 16.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.ECH13201043130', N'14', N'14FC', N'Tuyau plongeur ECHO pour debroussailleuse', 9.68, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.ESS11.3X3.0', N'33', N'33FA', N'Tuyau essence noir 11.3x3.0', 1, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.ESS12', N'33', N'33FA', N'Tuyau essence noir diametre 12 mm', 6.72, 15, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.ESS3.5X2.25X8.0', N'33', N'33FA', N'Tuyau essence noir basse pression 3.5x2.25x8.0', 6.08, 15, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.ESS6', N'33', N'33FC', N'Tuyau essence noir', 8.13, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.ESS7.5X12.5', N'33', N'33FC', N'Tuyau essence noir', 10.2857, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.ESS7.5X3.0', N'33', N'33FC', N'Tuyau essence noir', 10.2857, 13, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.ESS9.3X3.0', N'33', N'33FC', N'Tuyau essence noir', 1, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.HYD_PARK2CH-6', N'14', N'14FC', N'Tuyau hydraulique moyenne pression noir DN10 330 bars 6 modules EN875', 19.66, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.PE32', N'11', N'11FC', N'Tuyau PE 32mm couronne de 100m PN10 A 16', 1.66, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.PVC100', N'11', N'11FC', N'Tuyau PVC dia:100 gris', 2.9, 0, 0, 0, 4)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.PVC160CR', N'05', N'05FA', N'Tuyau PVC Dia 160 CR8 au ml', 8.435, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.PVC32', N'11', N'11FC', N'Tube PVC dia:32mm', 4.82, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.PVC40', N'11', N'11FC', N'Tube PVC dia:40mm', 5.59, 0, 0, 0, 8)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.SOL0064234', N'14', N'14FC', N'Pulverisateur SOLO', 5, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.STH11233587703', N'14', N'14FC', N'Tuyau STIHL / 023', 8.5184, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.TRANSP10', N'26', N'26FD', N'Tuyau PVC transparent 10mm ep 2mm C10m', 2.2, 2.5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TUYA.TRANSP6', N'26', N'26FD', N'Tuyau transparent DN:6mm ep:1,5mm C15ml prix/ml', 0.25, 7.8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TWIS.UP', N'31', N'31FA', N'Ttwist up standard  pour telephone', 4.95, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'UNIO.M_EGE15LR_ED', N'22', N'22FA', N'Union male orientable EGE 15-LR-ED', 8.99, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'UNIO.M_GE12S1/2ED', N'22', N'22FA', N'Union male GE 12-S-1/2 -ED nu', 3.88, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'UNIO.M_GE15L1/2ED', N'22', N'22FA', N'Union male GE 15L-1/2 ED nu', 3.63, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'UNIO.M_GE16S1/2ED', N'22', N'22FA', N'Union male GE 16S-1/2 ED nu', 4.62, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'UNIT.DC LUCA05BL', N'12', N'12 FA', N'Unit de controle standard pour dmarreur controleur modle tsys U de 1.5kw plage de reglage de 1.25 a 5A', 42.22, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VALV.CLA6005011557', N'14', N'14FC', N'Valve prise d''huile hydraulique M+F PALES', 34.43, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VALV.TR413', N'33', N'33FA', N'Valve courte de 42mm', 40, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VALV.TR414L', N'33', N'33FA', N'Valve longue tr414L', 0.0065, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VALV.V8R_GROM', N'14', N'14FC', N'Valve a visser agricole', 29.60667, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VANN.ABS1"', N'11', N'11FC', N'Vanne a boisseau sphrique gaz 1" MF', 28.28, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VANN.ABS3/4+P', N'11', N'11FC', N'Vanne sphrique 3/4 +purge', 6.2, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VANN.ABS3/8F', N'11', N'11FC', N'Vanne sphrique 3/8 air comprime femelle G', 10.41, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VASE_PER34136', N'33', N'33FD', N'Vase d''expansion pour PMF', 374.72, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TCF3.5X16', N'26', N'26FD', N'Vis a bois  tete fraisee 3,5x16', 6.136, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TCF3.5X20', N'26', N'26FD', N'Vis a bois  tete fraisee 3,5x20  1000Pc', 6.136, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TCF3.5X45', N'26', N'26FD', N'Vis a bois  tete fraisee 3,5x45 500pces', 19.25, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TCF3X20', N'26', N'26FD', N'Vis a bois tete fraisee 3x20 1000 pces', 6.14, 1, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TCF3X25', N'26', N'26FD', N'Vis a bois tete fraisee 3x25 1000 pces', 6.48, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TCF4.5X20', N'26', N'26FD', N'Vis a bois tete fraisee 4,5x20', 12.81, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TCF4.5X40', N'26', N'26FD', N'Vis a bois tete fraisee 4,5x40 500 pces', 12.35, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TCF4.5X50', N'26', N'26FD', N'Vis 4,5x50 a bois tete fraisee 250Pc', 9.783333, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TCF4X16', N'26', N'26FD', N'Vis a bois tete fraisee 4x16 1000 pces', 8.095, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TCF4X20', N'26', N'26FD', N'Vis a bois tete fraisee 4x20 1000 pces', 23.4045, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TCF4X35', N'26', N'26FD', N'Vis a bois tete fraisee 4x35', 7.746, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TCF5X 30', N'26', N'26FD', N'Vis a bois tete fraisee 5x30', 7.915, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TCF5X 35', N'26', N'26FD', N'Vis a bois tete fraisee 5x35 0186 500pces Wuppo', 12.158, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SEL_ADOUCIS.', N'24', N'24FB', N'Sac de sel adoucisseur sac de 25 kgs', 5.9375, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SEL_DNEIG.', N'05', N'05FI', N'Sel de dneigement', 74.83334, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SELE.FAUA3199', N'14', N'14FC', N'Selecteur 6V SVB -04-12V BSP1/2', 482.32, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SELL.100/40MF', N'05', N'05MA', N'Selle PVC 100/40 MF', 5.55, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SEPA.VERT.H19', N'17', N'17FC', N'separateurs verticaux hauteur 19 gris anthracite SC', 59.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SERF.PAN+LANG.ERG', N'26', N'26MA', N'serfouette panne + langue manche bois', 16.97, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SERP.', N'24', N'24FB', N'Serpillere gauffree blanche', 4.635, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SERP.ITALIEN.', N'26', N'26MA', N'Serpe italienne cuir', 18.392, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SERR.AXE50', N'05', N'05MA', N'Serrure 725 CLE I reversible axe 50 7x70 TR20 gris axe 50', 9.04, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SERR.AXE55L', N'05', N'05MA', N'Serrure 114 1/2 PZ axe 55 8/72acier T18 BR gris DIN  L 3301442', 7.37, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SERR.AXE55R', N'05', N'05MA', N'Serrure 114 1/2 PZ axe 55 8/72acier T18 BR gris DIN  L 3301441', 7.37, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SERR.CABLE03', N'22', N'22MB', N'Serre cable 3mm AC din741', 0.0133, 54, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SERR.CABLE06.5', N'22', N'22MB', N'Serre cable 6.5mm AC din741', 0.805, 52, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SERR.CABLE08', N'22', N'22MB', N'Serre cable 8mm AC GN', 2.09, 28, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SERR.CABLE13', N'22', N'22MB', N'Serre cable 13mm DIN 1142', 0.5758, 33, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SERR.CABLE14', N'22', N'22MB', N'Serre cable 14mm AC GN', 0.4, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SERR.CABLE16', N'22', N'22MB', N'Serre cable 16 mm AC ZI', 0.626, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SERR.CABLE19', N'22', N'22MB', N'Serre cable 19mm AC ZI DIN741', 0.76, 13, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SERR.CABLE22', N'22', N'22MB', N'Serre cable 22mm AC ZI DIN741', 1.087, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SERR.CLA6005012546', N'14', N'14FC', N'Serrure', 36.85, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SERR.ENC.AX30', N'26', N'26FD', N'Serrure encastrable axe 72mm carr 5 larg.coffre 46', 36.03, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SERR.HER', N'28', N'28MA', N'Serrure pour cloture mobile', 24, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SERR.LARD.AX50', N'26', N'26FD', N'Serrure  larder axe 50mm 8x72 cle I1/2T  tet.noir', 13.63, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SERR.WIL856460', N'26', N'26FD', N'Serrure / magasin bureau AXE 29 LARG44 8X92 T24ZG', 50.885, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SERV.AUMSA07.6', N'22', N'22MA', N'Servomoteur multitours AUMA-NORM', 1334, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SERV.AUMSA10.2', N'22', N'22MA', N'Servomoteur multitours AUMA-NORM', 1862, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SERV.PHOFLSNMPOPCSERVERV3', N'20', N'20MC', N'Serveur SNMP-OPC  allemand/anglais pour la surveillance et la configuration  d''appareils SNMP dans le systme IHM et SCA', 1389.44, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SIEG.ASS/DEB54-74', N'23', N'23MA', N'Siege  assis debout reglable en hauteur par lift  gaz 54  74 cm pittement sur roulette 5 branches', 173, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SIEG.ASS/DEB56-76', N'23', N'23MA', N'Siege  assis debout BILL reglable en hauteur par lift  gaz 56  76 cm pittement sur patin 5 branches', 216, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SIEG.BUREAU*', N'23', N'23MA', N'Siege de bureau', 202, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SIEG.CLA6005010612', N'14', N'14FC', N'Siege tiss', 340.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SIEG.VERSL4000', N'23', N'23MA', N'Siege de gamer', 400, 0, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SILE.ECH10090714730', N'14', N'14FC', N'Silenbloc ECHO pour RM380', 10.69, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SILE.ECH61091040430', N'14', N'14FC', N'Silenbloc ax de transmission ECHO 4600', 8.45, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SILE.ECH61091051830', N'14', N'14FC', N'Silenbloc ax de transmission ECHO 5000', 7.3799, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SILE.STH11297909700', N'14', N'14FC', N'Silenbloc MS200', 11.05, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SILI.NEUT.BLC', N'05', N'05FA', N'Silicone neutre blanc', 8.18, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SILI.NEUT.GRIS', N'05', N'05FA', N'Silicone neutre gris', 8.18, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SILI.NEUT.TRANS', N'05', N'05FA', N'Silicone neutre translucide', 8.18, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SILI.SAN.BLC', N'05', N'05FA', N'Silicone sanitaire blanc', 7.37, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SILI.SAN.GR', N'05', N'05FA', N'Silicone sanitaire gris', 7.66, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SILI.SAN.TRANS', N'05', N'05FA', N'Silicone sanitaire translucide', 5.9, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SIRE.WERMA11100075', N'12', N'12 FA', N'Sirene d''avertissement OF des portes d''ecluses', 94.675, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SOCL.LEG052249*', N'12', N'12 FA', N'Boite plastique ML / socle 052249 3P+T3P+N+T 16A', 7.95, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SOCL.LEG052949', N'12', N'12MB', N'Socle sailllie simple 3P+N+T 32A', 10.2, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SOCL.LEG055558', N'12', N'12MB', N'Socle en sailllie  3P+N+T 16A', 7.2575, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SOCL.LEG055707', N'12', N'12MB', N'Socle saillie 3P+N+T 20A IP44 gris', 12.84, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SOCL.LEG057671', N'12', N'12 FA', N'Socle pour tableau 2P+T 16A 230V', 6.456, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SOCL.SCH83171', N'12', N'12 FA', N'Socle pour prise saillie 32A 3PNT', 34.26, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SOND.PER41192', N'33', N'33FD', N'Sonde alarme pression d''huile C-10B', 154.46, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SOND.VEG52/12M', N'21', N'21MA', N'Sonde hydrostatique  0-0.2 bars avec cellule ceramique long.12M', 960.4, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SOND.VEG52/6M', N'21', N'21MA', N'Sonde hydrostatique  0-0.2 bars avec cellule ceramique long.6M', 493.26, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SORT.LEG069888', N'12', N'12 FA', N'Sortie de cable blanc', 3.05, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SORT.LEG664795', N'12', N'12 FA', N'Sortie de cable blanc', 2.442, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SOUD.33%Z', N'26', N'26FD', N'Soudure 33% Zinc au kg', 11.6, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SOUF.BUSE_110', N'26', N'26MA', N'Souflette buse metal 110mm', 13.96, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SOUF.BUSE_90', N'26', N'26MA', N'Souflette buse metal 90mm', 21.38, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SOUP.KAR28848720', N'22', N'22FA', N'Jeu de 3 soupapes nettoyeur HP KARCHER HD650 electrique', 15.54, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SOUR.DEL', N'20', N'20FB', N'Souris sans fil laser  molette 6 boutons ragent et noir', 10, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SOUR.FILAIRE', N'20', N'20FB', N'Souris filaire', 20, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SOUR.OPT.', N'20', N'20FB', N'Souris sans fil laser ne necessite aucun driver', 29, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SOUR.OPT.VERT.', N'20', N'20FB', N'Souris optique verticale ergonomique avec fil', 94.2, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SOUR.OPT.VERT.SF', N'20', N'20FB', N'Souris optique verticale ergonomique sans fil', 30.81, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SOUS_CHEM.ASS', N'17', N'17FC', N'Lot de 100 sous chemises assorties 22x31cm', 3.998333, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SP95.E5LUTZ', N'33', N'33FF', N'Super sans plomb 95 qualit E5 Lutzelbourg', 1.2734493, 1409.33, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SP95E5', N'33', N'33FF', N'Super sans plomb 95 qualit E5', 1.267531, 2657.86, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPID.', N'33', N'33FD', N'Spidometre', 65.833, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPIR.N10', N'17', N'17FC', N'Boite de 100 spirales 21 anneaux noir N10', 1.916667, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPIR.N6', N'17', N'17FC', N'Boite de 100 spirales 21 anneaux noir N6', 1.47335, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPIR.N8', N'17', N'17FC', N'Boite de 100 spirales 21 anneaux noir N8', 1.8, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.CARB', N'05', N'05FI', N'Spray nettoyant carburateur', 9.418043, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.COKP', N'05', N'05FI', N'Spray nettoyant cockpit', 11.5952635, 18, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.COKP750ML', N'24', N'24FB', N'Spray  nettoyant habitacle BIO', 15.28, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.COLLE', N'05', N'05FI', N'Spray colle multi-usages matiere SRB', 28.58, 1, 0, 0, 3)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.DECO', N'05', N'05FI', N'Spray dcolle etiquette', 13.2, 6, 0, 0, 6)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.DEGI', N'05', N'05FI', N'Spray degivrant', 12.02, 13, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.DEGI.750', N'05', N'05FI', N'Spray degivrant', 11.731, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.DEGO', N'05', N'05FI', N'Spray degoudronnant', 17.91, 14, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.DEGR.FB', N'24', N'24FB', N'Degraissant four bio', 11.02, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.DEGRIP', N'05', N'05FI', N'Spray techno degrippant 400ml', 9.863428, 28, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.DEPOUS.', N'24', N'24FB', N'Spray depoussierant', 9.65, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.DESI.ONE_SHOT', N'24', N'24FB', N'Desinfectant one shot', 11.55429, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.DESO', N'24', N'24FB', N'Spray dsodorisant WC', 11.6607065, 28, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.DESO.D', N'24', N'24FB', N'Spray dsodorisant et desinfectant WC', 10.1674, 19, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.DEST.OD', N'24', N'24FB', N'Spray destructeur d''odeurs BIO GAMME VEHICULE 750ML', 16.38, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.DETA.', N'24', N'24FB', N'Spray detartrant ANTIKAL 750ml', 5.64, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.DETE.FUIT', N'05', N'05FI', N'Spray detecteur de fuite', 8.9132, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.HUILE_COUPE', N'33', N'33FE', N'Spray d''huile de coupe', 17.97, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.LISSE_JOINT', N'05', N'05FI', N'Sparay lisse joint silicone finish 400ml', 5.99, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.LUBR.BLANC', N'05', N'05FI', N'Spray lubrifiant  graisse blanche au lithium', 13.1, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.LUBR.CM', N'05', N'05FI', N'Spray lubrifiant chaine de mobylette', 12.098, 11, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.LUBR.INTFGOG', N'05', N'05FI', N'Spray pour graissage des pignons de vannes et crmaillres', 35.2, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.LUBR.INTFLTF', N'05', N'05FI', N'Spray lubrifiant pour tige de verin et cylindre de porte', 20.05, 19, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.LUBR.TEF', N'05', N'05FI', N'Spray lubrifiant au teflon', 11.62, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.LUBR.TOTENS700', N'33', N'33FG', N'Spray lubrifiant  ENS700 plan inclin', 7.88, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.MOUS.N', N'24', N'24FB', N'Spray mousse nettoyante', 0, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.MOUS.NDD', N'24', N'24FB', N'Spray mousse nettoyante , degraissante et desinfectante', 16.0725, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.NETT.CLIM', N'24', N'24FB', N'Spray  nettoyant climatisation', 12.9976, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.NETT.ECR', N'24', N'24FB', N'Spray nettoyant cran', 10.32, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.NETT.ELEC', N'05', N'05FI', N'Spray nettoyant electrique sous tension', 21.95, 18, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.NETT.ELECSR', N'05', N'05FI', N'Spray nettoyant electrique hors tension sechage rapide', 8.12, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.NETT.FR', N'05', N'05FI', N'Spray nettoyant frein', 9.917765, 42, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.NETT.FR.B', N'05', N'05FI', N'Spray nettoyant frein bio', 14.88, 0, 0, 0, 12)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.NETT.VIT', N'05', N'05FI', N'Spray nettoyant vitre', 15.0961895, 21, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.NEUT.ROUIL', N'05', N'05FL', N'Spray neutraliseur de rouille', 35.855, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.SILICONE', N'05', N'05FI', N'Spray silicone', 16.7, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.SOUD', N'05', N'05FI', N'Spray soudure', 14.2223, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.SOUF', N'05', N'05FI', N'Spray souffleur pour informatique', 13.94192, 20, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.START', N'05', N'05FI', N'Additif pour dmarrage facile des vhicules', 18.9, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SPRA.VERN.PROT', N'05', N'05FI', N'Spray vernis de protection pour branchement electrique', 21.85, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'STAR.4-22W', N'12', N'12 FA', N'Starter 4-22W', 0.42255, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'STAR.4-65W', N'12', N'12 FA', N'Starter 4-65W', 0.4747166, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'STAR.U', N'12', N'12 FA', N'Starter Universel industriel', 0.5023, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'STAT.RTSK-97-900209', N'20', N'20MC', N'Station d''exploitation pour une visualisation sur 2 ecrans 32 CAM', 1697.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'STIC.APAISANT', N'25', N'25FA', N'Stick de 50ml de gel  anti moustique apaisant', 3.87885, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'STIC.VNF', N'28', N'28MA', N'Autocollant "Voies Navigables De France - Ce materiel peut sauver une vie"', 9.95, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TCF5X80', N'26', N'26FD', N'Vis a bois tete fraisee 5x80 0186 100 pces', 8, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TCF6X160', N'26', N'26FD', N'Vis a bois tete fraisee 6x160  100 pces', 15.164, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TCF6X70', N'26', N'26FD', N'Vis a bois tete fraisee 6x70  100 pces', 16.4912, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT03X016', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 3x16', 6.2, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT04X030', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 4x30', 12.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT04X040', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 4x40', 14.51, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT04X050', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 4x50', 12.55, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT04X060', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 4x60', 6.86, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT04X070', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 4x70', 10.812, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT05X050', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 5x50', 11.48, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT05X060', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 5x60', 11.74, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT05X070', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 5x70', 16.9, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT06X040', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 6x40', 13.4, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT06X050', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 6x50', 5.18, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT06X070', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 6x70', 7.06, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT06X090', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 6x90', 8.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT06X110', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 6x110', 9.14, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT06X120', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 6x120', 23.94, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT06X40', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 6x40', 6.76, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VBA_TFT08X110', N'26', N'26FD', N'Vis a bois TF torx filetage partiel 8x110', 22.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'STYL.+SOCL', N'17', N'17FC', N'Stylo avec socle', 3.96, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'STYL.DEL_PN579X', N'20', N'20FB', N'Stylet actif', 50, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'STYL.G-2BL', N'17', N'17FC', N'Stylo ecriture 0.4mm a controle debit d''encre bleu', 1.089383, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'STYL.G-2N', N'17', N'17FC', N'Stylo ecriture 0.4mm a controle debit d''encre', 1.069267, 29, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'STYL.G-2R', N'17', N'17FC', N'Stylo ecriture 0.4mm a controle debit d''encre rouge', 1.09, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'STYL.G-2V', N'17', N'17FC', N'Stylo ecriture 0.4mm a controle debit d''encre vert', 1.04, 19, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'STYL.TOPBALL_R', N'17', N'17FC', N'Feutre bille rouge', 1.9696, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUCE.KAR69062400', N'24', N'24FA', N'Suceur pour aspirateur', 4.7, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUCR.DOSE', N'01', N'01FB', N'sucre en dosette', 26.215, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.AUMZ032.002', N'22', N'22FA', N'Support de contact REP.560.2', 7, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.BANSMB30FA', N'12', N'12 FA', N'Support de montage pour barriere de SAS', 29.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.BANSMB30SC', N'12', N'12 FA', N'Support fixation emetteur recepteur', 9.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.ECR_PC', N'23', N'23MA', N'Support cran PC tournant  45', 31.74, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.GUIPON', N'26', N'26FD', N'Support pinceau guipon', 5.66, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.HAG873840', N'12', N'12MB', N'Support d''appareillage  SL20115 blanc PALOMA', 9.92, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.HORCBRD2UNR0002', N'12', N'12 FA', N'Support de rail DIN 2U 19" noir', 51.4, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.LEG080251', N'12', N'12 FA', N'Support batibox 1 poste 2modules', 1.08, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.LEG080261', N'12', N'12 FA', N'Support batibox 2M sur plaque', 2.2307, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.LOM79511090', N'22', N'22FA', N'support soupape pompe genelec', 6.193, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.NOR102838', N'14', N'14FC', N'Support de rouleau palpeur', 98.82, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.NOR102839', N'14', N'14FC', N'Support de rouleau palpeur', 98.82, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.NY2826202000', N'33', N'33FC', N'support de levier 2 cplt complet mobylette', 61.75, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.P80X40X2500', N'28', N'28MA', N'Support pour panneaux galva 80x40', 44, 0, 0, 0, 26)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.PO', N'23', N'23MA', N'Lot de supports porte outils comprenant 11 lments', 58.38, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.RCAA-20-000401', N'21', N'21FA', N'Support modem P400 - 1U', 45.085, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.SAMSBP-300WM1', N'31', N'31MD', N'Support pour cCamera dme QNV Samsung', 30, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.SCHXUZX2003', N'12', N'12 FA', N'Support de fixation pour Support de fixation pour tige M12 pour detecteur photoelectrique osiconcept XUX 0', 7.74, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.STH56057504327', N'26', N'26MA', N'Support de lime dia:3,5 pour tronconneuse 1/4-3/8P', 9.44, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.STH56057504328', N'26', N'26MA', N'Support lime 325', 9.44, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.STH56057504329', N'26', N'26MA', N'Support de lime dia:5,5mm  3/8-404', 9.44, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUPP.SVHK-40-190115893', N'23', N'23MA', N'Support pour moniteur LED 42  55" DS-DM4255W', 11.64, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SURL.JNE', N'17', N'17FC', N'Surligneur stabilo jaune', 0.57, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SURL.LAV.', N'17', N'17FC', N'Surligneur stabilo lavande', 0.29, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SURL.OR.', N'17', N'17FC', N'Surligneur stabilo orange', 0.29, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SURL.POLYC.', N'18', N'18MB', N'surlunette polycarbonate', 5.0435, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SURL.RGE', N'17', N'17FC', N'Surligneur stabilo rouge', 0.29, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SURL.ROSE', N'17', N'17FC', N'Surligneur stabilo rose', 0.29, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SURL.TURQ', N'17', N'17FC', N'Surligneur stabilo turquoise', 0.29, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SURL.VERT', N'17', N'17FC', N'Surligneur stabilo vert', 0.29, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SUSP.PLAF/RESSORT', N'05', N'05FA', N'Suspente plafond pour ressort', 1.26, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SWIT.HP2915', N'20', N'20MC', N'Switch E2915-8G-POE COMM-GERE', 498, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SWIT.PHO2702909', N'20', N'20MC', N'Managed switch 2000 16 ports RJ45 IP20', 685.44, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SWIT.PHOFLSWITCH23042GC2SFP', N'20', N'20MC', N'Manager switch 2000,4 ports rj45 10/100/1000 Mbits, 2 ports SFP, 2 ports Combo IP20', 560.9898, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SWIT.TET_SVHK50301800855', N'20', N'20MC', N'POE switch 4 ports DS 3E0105P-E', 35, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SWIT.TPLSG1008D', N'20', N'20MC', N'Switch 8 ports 10/100/1000', 26.64, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SYST.NIV1015', N'21', N'21MA', N'Systme de montage sur conduite type RMS2 pour DN200-DN800', 520, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TABL.CHAUSSURE/2000', N'23', N'23MA', N'Tablette  claire voie pour chaussures long.2000', 44.97, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TABL.FAUCH', N'18', N'18MB', N'Tablier de fauchage PVC vert 120x90', 8.98, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TABL.LIEG90X120', N'23', N'23MA', N'Tableau liege 90x120', 28.98, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TABL.PER41244', N'33', N'33FD', N'Tableau de bord complet 24V', 1549.1, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TABL.SOUDEUR', N'18', N'18MB', N'Tablier de soudeur', 30.59, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TABL.SUR_PIED120CM', N'17', N'17FC', N'tablette sur pied de 80cm', 141.79, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TABL.SUR_PIED80CM', N'17', N'17FC', N'tablette sur pied de 80cm', 121.03, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAIL.32MM', N'22', N'22FA', N'Taillant dia:32mm pour ROCAIR', 75.46, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAIL.45MM', N'22', N'22FA', N'Taillant dia:45mm pour ROCAIR', 91.65, 2, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAIL.CRAY+RES', N'17', N'17FC', N'Taille crayon avec reservoir', 1.7, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAMB.DR2000', N'20', N'20FB', N'Tambour noir pour brother 2825', 58.94, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAMB.DR241CL', N'20', N'20FB', N'Tambour noir pour brother mfc-9140CDN', 76.71, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAMB.ECH17500543130', N'14', N'14FC', N'Tambour dbroussailleuse 4600', 64.2048, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAMI.12X50', N'26', N'26FD', N'Tamis d''injection 12x50mm pour mortier chimique', 0.24, 60, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAMI.15X130', N'26', N'26FD', N'Tamis d''injection 15x130mm pour mortier chimique', 0.48, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAMI.16X85', N'26', N'26FD', N'Tamis 16x85mm pour mortier chimique', 0.424, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAMI.18X85', N'26', N'26FD', N'Tamis 18x85mm pour mortier chimique', 0.25, 36, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAMI.20X85', N'26', N'26FD', N'Tamis d''injection 20x85mm pour mortier chimique', 0.37, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAMI.22', N'26', N'26FD', N'Tamis d''injection 22X1 ML pour mortier chimique', 8.46, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAMI.BOB1B6650239', N'22', N'22FA', N'Tamis', 12.186, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAMP.', N'24', N'24FB', N'Tamponge 8,5x12,5', 1.63106191, 133, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAMP.A_FACON', N'17', N'17FC', N'TAMPON A FACON', 71.84, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAMP.PVC100', N'11', N'11FC', N'Tampon PVC DN 100', 3.35, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAMP.PVC100/40', N'05', N'05FA', N'Tampon de rduction PVC 100/40', 3.5, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAMP.PVC100MF', N'11', N'11FC', N'Tampon PVC MF DN 100', 4.47, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAMP.PVC32', N'11', N'11FC', N'Tampon PVC FF dia:32', 0.8315, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAMP.PVC40', N'11', N'11FC', N'Tampon PVC dia:40', 0.8385, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAMP.PVC50', N'11', N'11FC', N'Tampon PVC dia:50', 0.8575, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAMP.SPI011876', N'26', N'26FA', N'Tampons hc6-017 + gaz P700', 114.63, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAMP.SPI046320', N'26', N'26FA', N'Tampons hc6-25 + gaz P700', 111.09, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAPI.CAILL150X100', N'24', N'24FB', N'Tapis caillebotis noir 150 X 100CM', 72.84, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAPI.CAILL60X80', N'24', N'24FB', N'Tapis caillebotis noir ep.24mm', 36.04, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAPI.COCO40X80', N'24', N'24FB', N'Tapis coco 24mm 40x80', 15.88, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAPI.COCO60X80', N'24', N'24FB', N'Tapis coco 24mm 60x80', 40.26333, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAPI.COULOIR60X90', N'24', N'24FB', N'Tapis d''entree 60x90', 32.94, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAPI.COULOIR900/1200', N'24', N'24FB', N'Tapis de couloir gris interieur / exterieur 900x1200', 105, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAPI.COULOIR900/1500', N'24', N'24FB', N'Tapis de couloir gris interieur / exterieur 900x1500', 109.21, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAPI.SOURIS', N'20', N'20FB', N'Tapis de souris  rectangulaire en plastique dur', 5.47, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAPI.SOURIS_XXL', N'20', N'20FB', N'Tapis de souris  EGG XXL anti bactrien', 14.71, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TARA.M8', N'26', N'26MA', N'Jeu de 3 tarauds M8 pas mtrique', 31.8, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TARG.40MM', N'26', N'26FD', N'Targette 40mm blanc', 4.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TASS.SAPIN28X72', N'05', N'05FJ', N'Tasseau sapin 28X72 2m40', 7.83, 0, 0, 0, 9)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TAXE', N'09', N'09SC', N'eco taxe', 0.08, 0, 0, 0, 15)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TE_ACO523339', N'11', N'11FC', N'T gal 16X16 ACOME ref:523339', 4.0094, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TE_CU12', N'11', N'11FC', N'Te cuivre de 12', 0.4, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TE_CU14', N'11', N'11FC', N'T CU egal de 14', 0.4269, 13, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TE_CU14-12-14', N'11', N'11FC', N'Te cuivre 14-12-14', 0.45, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TE_CU16-14-16', N'11', N'11FC', N'T CU de 16-14-16 sachet de 2 pieces', 0.83, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TE_GAL.F1/2-90', N'11', N'11FC', N'T F 1/2 galva ref:130', 1.4036, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TE_GAL1"F', N'11', N'11FC', N'T F 1" F galva', 2, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TE_GCU.PE32', N'11', N'11FC', N'T egal laiton tube PE32 ref 10050006PFB', 19.67, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TE_PVC.F40', N'11', N'11FC', N'T PVC gris dia:40mm FFF', 1.8782, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TE_PVC.F50', N'11', N'11FC', N'T PVC gris dia:50mm FFF', 1.89, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TE_PVC.MFF40', N'11', N'11FC', N'T PVC dia:40 MFF', 1.56, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TE_PVC100-87MF', N'05', N'05FA', N'Culotte simple PVC 8730 MF D100', 4.53526, 8, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TECH.5L', N'05', N'05FL', N'Technobois prt a l''emploi Deproma 5l', 19.8946, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TELE.FAACXT4_868SLH', N'12', N'12 FA', N'Telecommande de portail noir XT4 868 SLH', 42, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TELE.FIND26.01', N'12', N'12 FA', N'Telerupteur FINDER 10A type 26.01', 13.195, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TELE.RHE_CHS-A1', N'31', N'31MA', N'Telecommande metteurs 4 touches sur LEXAN module radiometrix TDH2-433-RSSI', 247.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TELE.SSFIL', N'31', N'31MA', N'Tlphone sans fil + base', 30, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TEMP.GOT01557', N'12', N'12 FA', N'Temporisation I10', 28.25, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TENA.230', N'26', N'26MA', N'Tenaille longueur 230mm', 23.47963, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TENA.250', N'26', N'26MA', N'Tenaille russe longueur 250mm', 22.92, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TEND.ACTL0014', N'26', N'26FD', N'Tendeur a lanterne il-il N14', 3, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TENT.3X3', N'18', N'18MD', N'Tente pliante 3x3 gamme standard gris (BARNUM)', 450, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TEST.AGI221171', N'21', N'21MA', N'Eurotesteur 3 x 65mm  TT145', 3.21, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TEST.CIN24-517', N'21', N'21MA', N'Testeur de de cble BNC, RJ11, RJ45', 142.96, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TEST.DEX_C818083', N'21', N'21MA', N'Trousse pince  + testeur rseau', 38.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TEST.IDE_R151006', N'21', N'21MA', N'Testeur de rseau RJ45 fibre', 588, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TETE_ATTILINA', N'14', N'14FC', N'Tete fil pieuvre pour debrousailleuse', 19.49965, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TETE_ECHX047000330', N'14', N'14FC', N'Tete fil nylon echo automatique', 31.67, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TETE_HUS531009225', N'14', N'14FC', N'Tte fil nylon semi automatique', 30.91, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TETE_PEPIQH1-F61-V1', N'20', N'20MC', N'Tte de lecture RFID', 351.12, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TETE_SCHZC2JE01', N'12', N'12 FA', N'Tete pour interrupteur de position sans levier a rappel', 30.01, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TETE_STH40027102170', N'14', N'14FC', N'tete fil nylon supercut 36-2 pour debroussailleuse stihl', 26.4, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'TETE_STH40037102115', N'14', N'14FC', N'Tete fil nylon autocut 46-2 2 fils pour debroussailleuse stihl', 28.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESE.CLA7700065294', N'14', N'14FC', N'Reservoir d''huile', 22.44, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESE.DIMBC100L', N'22', N'22FA', N'Reservoir 100 litres oval + couvercle vissant', 435.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESI.3M92802', N'12', N'12 FA', N'Resine 40 taille C - 426 G', 53.51, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESI.AUMZ022.918', N'22', N'22FA', N'Rsistance chauffage 110-250 volts pour servomoteurs 110-250V 300-SA+SM/Sn [151.0-1]', 44.5, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESI.AUMZ025.084', N'22', N'22FA', N'Resistance de chauffage HZ5.2 complet 24 volts pour servomoteurs', 43.61667, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESI.EP/AC', N'05', N'05FA', N'Baton de resine epxy acier', 16.7429, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESI.EP/AL', N'05', N'05FA', N'Baton de resine epoxy aluminium', 13.6, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESI.EP/MH', N'05', N'05FA', N'Baton de resine epoxy milieu humide', 13.6, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESI.EP/PL', N'05', N'05FA', N'Baton de resine epoxy plastique', 13.6, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESI.EP/TM', N'05', N'05FA', N'Baton de resine epoxy tous matriaux', 13.6, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.ECH12311347530', N'14', N'14FC', N'Ressort  SRM4600', 5.16, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.ECH12312247530', N'14', N'14FC', N'Ressort ECHO', 2.27, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.ECH15901103432', N'14', N'14FC', N'Ressort pour coiffe ECHO 4605', 1.98, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.ECH17722040630', N'14', N'14FC', N'Ressort a spirale dbroussailleuse', 15.07, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.ECH17723440630', N'14', N'14FC', N'Ressort cliquet dbroussailleuse', 5.8344, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.ECH17801307530', N'14', N'14FC', N'Ressort ECHO', 1.17, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.ECH17801322130', N'14', N'14FC', N'Ressort ECHO', 1.3199, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.ECH17801335631', N'14', N'14FC', N'Ressort SRM 4600', 1.46, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.ECH17801342230', N'14', N'14FC', N'Ressort ECHO', 1.18, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.ECH17801352630', N'14', N'14FC', N'Ressort ECHO', 4.092, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.ECH17804305230', N'14', N'14FC', N'Ressort ECHO', 0.7, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.ECH17804342230', N'14', N'14FC', N'Ressort ECHO', 1.32, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.ECHA426000000', N'14', N'14FC', N'Ressort echo', 1.2848, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.ECHP022002090', N'14', N'14FC', N'Ressort SRM 4600', 6.41, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.ECHP022010370', N'14', N'14FC', N'Ressort  de tete fil nylon automatique', 14.3, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.ECHV450000141', N'14', N'14FC', N'Ressort echo', 7.79, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.ECHV451000480', N'14', N'14FC', N'Ressort echo', 3.41, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.ECHV452000050', N'14', N'14FC', N'Ressort echo', 3.828, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.EUT27480', N'14', N'14FC', N'Ressort de tension  ATTILA', 10.92, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.JM467004', N'22', N'22FA', N'Ressort clapet aspiration Gallia 104 467004', 4.291, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.JM467005', N'22', N'22FA', N'Ressort clapet refoulement Gallia 104', 4.291, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.JM467006', N'22', N'22FA', N'Ressort de clapet Gallia 204', 3.676, 16, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.NOR102946', N'14', N'14FC', N'Lame ressort', 61.205, 1, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.STH00009971018', N'14', N'14FC', N'Ressort de tension', 6.15, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.STH11231900600', N'14', N'14FC', N'Ressort de rappel lanceur MS200', 9.191999, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.STH11241953500', N'14', N'14FC', N'Ressort rappel / epingle 064 STIHL', 3.1152, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.STH11281223000', N'14', N'14FC', N'Ressort', 3.73480034, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.STH11291627800', N'14', N'14FC', N'Ressort a lames', 4.13, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.STH11291900601', N'14', N'14FC', N'Ressort de rappel', 13.48, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.STH11387908303', N'14', N'14FC', N'Ressort anti vibration', 11.12, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RESS.STH41387119100', N'14', N'14FC', N'Ressort  elagueuse HT75', 9.592, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RIVE.4,X17A2', N'26', N'26FD', N'Rivet aveugle inoxTP 4x17', 200, 0.5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RIVE.4.8X12', N'26', N'26FD', N'Rivet aveu,TPK14 4,8x12 500pces', 22.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RIVE.4.8X14', N'26', N'26FD', N'Rivet Aveu,TP K14 4,8x14', 21.1, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RIVE.4.8X14TL', N'26', N'26FD', N'blister de 53 rivets alu 4,8x14 tete large', 9.56, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RIVE.4.8X16A2', N'26', N'26FD', N'Rivet aveugle inox TP 4,8x16', 231.68, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RIVE.4.8X18AV', N'26', N'26FD', N'Rivet aveugle TP large AL 14 mm 4.8x18', 44.19, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RIVE.4.8X25AV', N'26', N'26FD', N'Rivet aveugle TP large AL 14 mm 4.825', 44.19, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROBI.A_SOUD18', N'11', N'11FC', N'Robinet  souder avec purge dia:18', 5.2, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROBI.ABS1/2', N'11', N'11FC', N'Robinet de puisage 1/2 avec vanne spherique quard de tour', 5.65, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROBI.ABS3/4', N'11', N'11FC', N'Robinet de puisage 3/4 avec vanne spherique1/4 de tour', 11.893, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROBI.BM000543', N'22', N'22FA', N'Robinet pompe DN40mm', 23.54, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROBI.D''ARRET1/2', N'11', N'11FC', N'Robinet d''arrt + purge 1/2', 3.4453, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROBI.D''ARRET12', N'11', N'11FC', N'Robinet d''arret + purge DN12', 3.1, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROBI.DE_PURGE1/4', N'11', N'11FC', N'Robinet de purge laiton 1/4', 2.2867, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROBI.EQR.ROS.1/2', N'11', N'11FC', N'Robinet querre de reglage 1/2 avec rosace', 11.05, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROBI.EQR.ROS.3/8', N'11', N'11FC', N'Robinet querre avec rosace  3/8', 7.8, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROBI.MAL', N'11', N'11FC', N'Robinet pour machine a laver', 5.2, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROBI.PRE13088', N'26', N'26FD', N'Robinet plastique brise jet 3/4', 4.9, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROBI.PUIS1/2', N'11', N'11FC', N'Robinet de puisage 1/2 laiton', 15.23, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROLL.CORRECT2', N'17', N'17FC', N'Devidoir roller de correction 4.2x10 deroulement lateral', 1.950769, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.AXE_BASCUL', N'33', N'33FD', N'Rondelle pour axe de basculement tige', 5.35, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR04X12X1,25', N'26', N'26FD', N'Rondelle carrossier AC ZI 4x12x1,25', 0.0158, 114, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR04X20', N'26', N'26FD', N'Rondelle plate large 4x20', 0.0371, 303, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR05X20X1,25', N'26', N'26FD', N'Rondelle carrossier 5x20x1,25 AC ZI', 0.024, 200, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR06X17X3', N'26', N'26FD', N'Rondelles plates larges 6x16x3', 0.049, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR06X18', N'26', N'26FD', N'Rondelles plates larges 6x18', 0.032, 148, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR06X20', N'26', N'26FD', N'Rondelle carrossier 6x20 AC ZI', 0.067, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR06X22X2', N'26', N'26FD', N'Rondelle carrossier 6x22x2 AC ZI', 0.0577, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR06X25X1.25', N'26', N'26FD', N'Rondelle carrossier 6.25x25x1.25 AC ZI', 0.0278, 254, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR08X24X3', N'26', N'26FD', N'Rondelle carrossier AC ZI 8x24x3', 0.0592, 150, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR08X25X1,5', N'26', N'26FD', N'Rondelle carrossier AC ZI 8x25x1,5', 0.0485, 81, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR10X30X1.5', N'26', N'26FD', N'Rondelle carrossier 10x30x1.5 AC ZI', 0.0418, 345, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR10X30X3', N'26', N'26FD', N'Rondelle carrossier 10x30x3', 0.08, 47, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR10X30X4', N'26', N'26FD', N'Rondelle carrossier 10x30x4 AC ZI', 0.2911, 40, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR12X40X2', N'26', N'26FD', N'Rondelle carrossier 12x40x2 AC ZI', 0.0975, 140, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR12X50X4', N'26', N'26FD', N'Rondelle carrossier 12x50x4 AC ZI', 0.6036, 52, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR14X50X2,5', N'26', N'26FD', N'Rondelle carrossier 14x50x2,5 AC ZI', 0.5796, 75, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR16X30X3', N'26', N'26FD', N'Rondelle carrossier 16x30x3 AC ZI', 0.25, 125, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR16X50X3', N'26', N'26FD', N'Rondelle carrossier 16x50x3 AC ZI', 0.25, 63, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR18X36X3', N'26', N'26FD', N'Rondelle carrossier 18x36x3 AC ZI', 0.16, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR18X56X4', N'26', N'26FD', N'Rondelle carrossier 18x56x4 AC ZI', 0.38, 54, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR20X60X3', N'26', N'26FD', N'Rondelle carrossier AC ZI 20x60x3', 0.7765, 140, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR24X50X2', N'26', N'26FD', N'Rondelle carrossier  AC ZI 24X50X2', 0.5, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR24X60X4', N'26', N'26FD', N'Rondelle carrossier 24x60x4 AC ZI', 0.59, 26, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CAR30X60X4', N'26', N'26FD', N'Rondelle carrossier 30x60x4 AC ZI', 2.51, 24, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CLA6005014284', N'14', N'14FC', N'Rondelle', 0.84, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CLA6005014287', N'14', N'14FC', N'Rondelle', 4.44, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CON05X12', N'26', N'26FD', N'Rondelle contact 5x12', 0.1189, 96, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CON06X14', N'26', N'26FD', N'Rondelle contact M 6x14', 0.1006, 255, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CON07X18', N'26', N'26FD', N'Rondelle contact M 7x18', 0.1052, 266, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CON08X18', N'26', N'26FD', N'Rondelle contact M8x18', 0.049, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CON10X22', N'26', N'26FD', N'Rondelle contact M10x22', 0.1159, 28, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CON12X26', N'26', N'26FD', N'Rondelle contact M12x26', 0.122, 138, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CUV4X9A2', N'26', N'26FD', N'Rondelles cuvette inox A2 4x9x2.6', 0.17, 40, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.CUV6X13A2', N'26', N'26FD', N'Rondelles cuvette nickele A2 6x13', 0.0831, 41, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.ECH17721441030', N'14', N'14FC', N'rondelle plate', 0.77, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.ECH61023904130', N'14', N'14FC', N'rondelle plate (cote scie)', 0.68, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.EUT27358', N'14', N'14FC', N'Rondelle 27358 ATTILA AV95', 0.3506, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.EV04', N'26', N'26FD', N'Rondelle evantail dia.4', 0.03, 130, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.EV05', N'26', N'26FD', N'Rondelle evantail dia.5', 0.04, 160, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.EV06', N'26', N'26FD', N'Rondelle evantail dia.6', 0.04, 105, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.EV07', N'26', N'26FD', N'Rondelle evantail dia.7', 0.05, 200, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.EV08', N'26', N'26FD', N'Rondelle evantail M8', 0.6, 40, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.EV10', N'26', N'26FD', N'Rondelle evantail M10', 0.07, 28, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.EV14', N'26', N'26FD', N'Rondelles evantail M14', 0.1, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.EV16', N'26', N'26FD', N'Rondelles evantail M16', 0.09739999, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.EV18', N'26', N'26FD', N'Rondelles evantail M18', 0.13, 26, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.GAL448004', N'22', N'22FA', N'Rondelle caoutchouc clapet Gallia 104', 4.578, 19, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.GR04', N'26', N'26FD', N'Rondelle grower D.4', 0.029, 70, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.GR05', N'26', N'26FD', N'Rondelle grower D5 AC BI', 0.0213, 151, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.GR06', N'26', N'26FD', N'Rondelle grower M6', 0.3, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.GR08', N'26', N'26FD', N'Rondelle grower M8', 0.03302931, 107, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.GR10', N'26', N'26FD', N'Rondelle grower D.10', 0.0747, 53, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.GR12', N'26', N'26FD', N'Rondelle grower M12', 0.08957808, 133, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.GR14', N'26', N'26FD', N'Rondelle grower M14', 0.0915, 51, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.GR16', N'26', N'26FD', N'Rondelle grower M16', 0.076, 31, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.GR16A2', N'26', N'26FD', N'Rondelle grower M16 inox A2', 0.2, 30, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.GR20', N'26', N'26FD', N'Rondelle grower M20 AC BI', 0.167058825, 70, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.GR22', N'26', N'26FD', N'Rondelle grower M22 AC BI', 0.12, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.GR24', N'26', N'26FD', N'Rondelle grower M24 AC BI', 0.18, 23, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.NOR101682', N'14', N'14FC', N'Rondelle  de butee', 10.29, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.NOR101913', N'14', N'14FC', N'Rondelle M18 8.8 ZI', 0.49, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.NOR102505', N'14', N'14FC', N'Rondelle de calage pour LN 1600', 2.681111, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.NOR104120', N'14', N'14FC', N'Rondelle frein', 0.13, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.NOR104121', N'14', N'14FC', N'Rondelle frein', 0.18, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.NOR104124', N'14', N'14FC', N'Rondelle ressort', 0.55, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.NOR104126', N'14', N'14FC', N'Rondelle ressort', 0.24, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.NOR104137', N'14', N'14FC', N'Rondelle pour magistra', 0.15, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.NOR106838', N'14', N'14FC', N'Rondelle d''arrt d''axe', 5.82, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.NOR107690', N'14', N'14FC', N'Rondelle d''arrt d''axe', 9.42, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.PL.CH06', N'26', N'26FD', N'Rondelle plate chanfrein M6 AC ZI', 0.01957343, 1287, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.PL.CH10', N'26', N'26FD', N'Rondelle plate chanfrein M10', 0.05114456, 427, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.PL.CH12', N'26', N'26FD', N'Rondelle plate chanfrein M12x24', 0.04353726, 255, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.PL.CH16', N'26', N'26FD', N'Rondelle plate chanfrein M16', 0.0603, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.PL.CH17AB', N'26', N'26FD', N'Rondelle plate chanfrein acier brut M17x30x3', 0.034, 96, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.PL.CH18', N'26', N'26FD', N'Rondelle plate chanfrein M18x34', 0.12, 18, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.PL.CH20', N'26', N'26FD', N'Rondelle plate chanfreine M20', 0.009, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.PL.CH22', N'26', N'26FD', N'Rondelle plate chanfrein M22x38', 0.23, 69, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.PL.CH24', N'26', N'26FD', N'Rondelle plate chanfrein M24 AC ZI 0407 24', 0.2651612, 67, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.PL.CH26', N'26', N'26FD', N'Rondelle plate chanfrein M26 AC ZI 0407 26', 0.36, 35, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.PL.CH27', N'26', N'26FD', N'Rondelle plate chanfrein M27 AC ZI', 0.36, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.PL.CH40', N'26', N'26FD', N'Rondelle plate chanfrein M40 diametre ext.72mm ep.6mm AC ZI', 1.21, 15, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.PL.DEC05', N'26', N'26FD', N'Rondelle 5x10 plate decollete chanfreine', 0.01, 500, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.PL.DEC06A2', N'26', N'26FD', N'Rondelle plate dcollete dn 6mm inox A2', 0.0159, 250, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.PL.DEC08', N'26', N'26FD', N'Rondelle F decol.125 plate AC ZI M8 140508', 0.0229, 234, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.PL.DEC08A2', N'26', N'26FD', N'Rondelle plate dcollete dn 8mm inox A2', 0.017, 140, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.PL.DEC10A2', N'26', N'26FD', N'Rondelle plate dcollete inox A2', 0.04705845, 284, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.PL.DEC12A2', N'26', N'26FD', N'Rondelle plate dcollete inox A2 M12', 0.047, 136, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.PL.DEC14', N'26', N'26FD', N'Rondelle plate M14 AC ZI F Decolete', 0.047, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.PL10A2', N'26', N'26FD', N'Rondelles plates larges Inox A2  M10x30', 0.431, 46, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.PL20', N'26', N'26FD', N'Rondelle plate M20 Bichromat', 0.1951, 49, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.RESS10', N'26', N'26FD', N'Rondelle ressort M10', 0.05, 470, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.RESS12', N'26', N'26FD', N'Rondelles ressort M12', 0.055, 99, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.RESS8', N'26', N'26FD', N'Rondelles ressort M8', 0.198, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.STH00009580923', N'14', N'14FC', N'Rondelle', 2.01, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.STH00009581021', N'14', N'14FC', N'Rondelle  d''arret  MS460', 4.796, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROND.STH11191628925', N'14', N'14FC', N'Rondelle M12 pour 064 STIHL', 1.4784, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROTA.KAR47632530', N'22', N'22FA', N'Rotabuse KARCHER', 127.8, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROTA.KAR47670220', N'22', N'22FA', N'Rotabuse KARCHER / HESSE', 83.48, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROTO.ECH15680142230', N'14', N'14FC', N'rotor echo', 141.26, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROTU.EUT27577', N'14', N'14FC', N'Rotule LHSA 10DE21 - 125 ATTILA', 26.2064, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROTU.EUT27580', N'14', N'14FC', N'Rotule G LHSA 10D21-125 pour ATTILA', 27.8696, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUE_200 X20X50', N'22', N'22FA', N'roue caoutchouc 200mm alesage de 20mm largeur 50mm', 76.6, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUE_JOCKEY', N'33', N'33FC', N'Roue jockey  a collier', 26.93, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUL.CLA60050044782', N'14', N'14FC', N'Rouleau caoutchouc 25M', 0.44, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUL.COLLEUR', N'26', N'26MA', N'Roulette de colleur bonite manche bois', 4.37, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUL.ECH90080006001', N'14', N'14FC', N'Roulement 90080006001 (6000) pour ECHO4605', 9.264, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUL.ECH90080036000', N'14', N'14FC', N'Roulement ECHO', 13.54, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUL.ECH90080406001', N'14', N'14FC', N'Roulement (6001-2Z) pour ECHO4605', 9.268, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUL.ECH90080706001', N'14', N'14FC', N'Roulement ECHO 4600', 12.815, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUL.ECH90081000629', N'14', N'14FC', N'Roulement  (629NSK) pour ECHO 4605', 19.027, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUL.ECH90081006201', N'14', N'14FC', N'Roulement 90081006201(6201) pour ECHO RM380', 9.879, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUL.ECH90081206201', N'14', N'14FC', N'Roulement (6201-2RSI) pour ECHO 4605', 8.144, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUL.JETABLE180', N'26', N'26MA', N'Rouleau a peindre jetable 180mm', 4.43, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUL.KUH81103578', N'14', N'14FC', N'roulement pour broyeur', 72.65, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUL.NOR102571', N'14', N'14FC', N'Roulement / LN 1600', 92.39999, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUL.NOR102811', N'14', N'14FC', N'Rouleau palpeur  LN1600 complet avec paliers sans support', 823.27, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUL.NOR104028', N'14', N'14FC', N'Roulement XL1600', 47.11667, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUL.SAD_50MM', N'23', N'23MA', N'Jeu de roulette de 50mm sol dur pour sige assis debout.', 8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUL.SCHGE30-FO-2RS', N'22', N'22FA', N'Roulement  rotule  schaeffler ge30-FO-2RS', 22.81, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUL.SCHGE40-DO-2RS', N'22', N'22FA', N'Roulement  rotule  schaeffler ge40-dO-2RS', 21.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUL.SCHGE40-FO-2RS', N'22', N'22FA', N'Roulement  rotule  schaeffler ge40-FO-2RS', 33.68, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUL.SKF16011', N'33', N'33FC', N'Roulement pour les verin de portes d''ecluses', 39.19, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUL.SKF6000-2RSI', N'14', N'14FC', N'Roulement 6000-2RSI pour ECHO', 8.144, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUL.TIM30215-9X025', N'22', N'22FA', N'Kit a rouleaux coniques', 43.96, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUL.TIM30310-90KA1', N'22', N'22FA', N'Kit a rouleaux coniques', 34.92, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUL.TIM33210-9X025', N'22', N'22FA', N'Kit a rouleaux coniques', 35.38, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUT.CIS_RV345P', N'20', N'20FB', N'Routeur', 0, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ROUT.PHOTCDSLROUTERX500A/B', N'20', N'20MC', N'Routeur large bande industriel avec modem ADSL pour debit jusqu''a 25m/bits', 611.77, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.2FACE12/10M', N'26', N'26FD', N'Scotsch double face 12mmx10m 2eme generartion', 30.58, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.3M_SJ3560/25MM', N'26', N'26FD', N'Ruban systme ouvrable/refermable 25mm', 356.32, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.3M_VHB', N'26', N'26FD', N'Ruban double face adhsif mousse', 53.86, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.3M800.12', N'26', N'26FD', N'Ruban autofusionnant 9.15M x 19mm', 14.01, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.3M800.14', N'26', N'26FD', N'Ruban autofusionnant 7M x 25mm', 13.99, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.3M9080HL', N'26', N'26FD', N'Ruban double face 25mmx50m', 12.68, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.AB', N'17', N'17FC', N'Ruban adhsif  bureau', 1.502, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.AB19X66', N'17', N'17FC', N'Ruban adhsif  bureau 19x66', 0.44, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.AUTOFUS', N'26', N'26FD', N'Ruban autofusionnant', 29.12, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.DYMS0720530S', N'17', N'17FA', N'Ruban de dymo largeur 12mm blanc / noir', 16.58591, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.IBLC15', N'26', N'26FD', N'Ruban isolant blanc 15mmx10m PVC', 0.864, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.IBLC50', N'26', N'26FD', N'ruban pvc blanc 50mm reperage et isolation', 8.9, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.IBLEU15', N'26', N'26FD', N'Ruban isolant bleu 15mmx10m PVC', 0.864, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.IBLEU50', N'26', N'26FD', N'ruban pvc bleu 50mm reperage et isolation', 8.9, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.IBRUN15', N'26', N'26FD', N'Ruban isolant brun 15mmx10m PVC', 0.864, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.IGRIS15', N'26', N'26FD', N'Ruban isolant gris 15mmx10m PVC', 0.864, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.IJAUNE15', N'26', N'26FD', N'Ruban isolant jaune 15mmx10m PVC', 0.9618537, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.IJAUNE50', N'26', N'26FD', N'Ruban isolant jaune 50mm PVC', 7.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.INOIR15', N'26', N'26FD', N'Ruban isolant noir 15mmx10m PVC', 0.864, 30, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.INOIR19', N'26', N'26FD', N'Ruban isolant noir 19mmx15m PVC', 7.9, 22, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.INOIR50', N'26', N'26FD', N'ruban pvc et isolant large noir', 8.9, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.IORANGE50', N'26', N'26FD', N'ruban pvc orange 50mm reperage et isolation', 8.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.IROUG15', N'26', N'26FD', N'Ruban isolant rouge 15mmx10m PVC', 0.864, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.IROUG50', N'26', N'26FD', N'ruban pvc rouge 50mm reperage et isolation', 8.9, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.IVERT15', N'26', N'26FD', N'Ruban isolant vert 15mmx10m PVC', 0.864, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.IVERT50', N'26', N'26FD', N'ruban pvc vert 50mm reperage et isolation', 8.9, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.IV-J15', N'26', N'26FD', N'Ruban isolant vert/jaune 15mmx10m PVC', 0.864, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.MASQ25', N'26', N'26FD', N'Ruban de masquage 25 mmx50m', 1.66, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.MASQ25CL', N'26', N'26FD', N'Ruban de masquage 25 mmx50m crp lisse', 1.66, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.MASQ40', N'26', N'26FD', N'Ruban de masquage 40mmx50m', 2.58, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.MASQ50CL', N'26', N'26FD', N'Ruban de masquage 50mmx50m crp lisse', 3.08, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.MU33X50', N'26', N'26FD', N'ruban multi usages pour le batiment 33mx50mm', 8.544286, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.SIGN', N'26', N'26FD', N'Ruban de signalisation rouge et blanc', 3.89, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.SIGNLARG', N'26', N'26FD', N'Ruban de signalisation rouge et blanc haute resistance', 19.43, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.TEFLON', N'26', N'26FD', N'Ruban teflon 12mx12mm-ep,0,08mm', 0.733101, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.TOILE', N'26', N'26FD', N'Rouleau de ruban toile tesa 50mlx48mm epaisseur 230m', 7, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUBA.TRANSLUCDE50', N'26', N'26FD', N'Rouleau de ruban translucide 50mm', 1.56, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUST.DN25MM', N'33', N'33FA', N'Rustine DN 25mm', 20.62, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RUST.DN35MM', N'33', N'33FA', N'Rustine DN 35 mm bte de50 pieces', 18.95, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SABL.0/3', N'05', N'05FA', N'Sable 0-3', 22.45, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SABL.DM0/6', N'05', N'05FA', N'Sable de moselle rouge 0/6 rouge', 41.47, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SABL.ROUTE', N'05', N'05FA', N'Sable route', 42.79, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAC.PC15/17"', N'20', N'20FB', N'Sac  dos PC 17" professionnel', 43.9, 0, 0, 0, 1)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAC_BIGBAG', N'26', N'26FD', N'Sac nylon de 1m3', 12, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAC_DIM/ASAC21L', N'24', N'24FA', N'Sac aspirateur poussiere 21 Litres', 7.92, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAC_KAR69074790', N'24', N'24FA', N'Sacs filtrant papier NT361 ECO', 21, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAC_LESTAGE', N'26', N'26FD', N'Sac de lestage pour panneaux', 3.442857, 15, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAC_NILFAERO21/26/31', N'22', N'22FA', N'Sac aspirateur aero (21/26/31) * 4 + 1 filtre a eau', 24.05, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAC_NILFVL200', N'22', N'22FA', N'Lot de 4 sacs aspirateur papier filtrant pour aspirateur Nilfisk VL200', 31.19, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAC_PET89S42Y045', N'18', N'18MB', N'Sac de transport 45 litres', 59.59999, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAC_POUB120LB', N'26', N'26FD', N'Sacs poubelle pour conteneur a tri  120 bleu', 92.2, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAC_POUB130L', N'26', N'26FD', N'Sacs poubelle 130l gris rouleau de 20 pieces 65microns', 0.7296054, 308, 0, 0, 500)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAC_POUB130LAP', N'26', N'26FD', N' sac poubelle participation au travail des handicapes', 147.8, 0, 0, 0, 3)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAC_POUB30L', N'26', N'26FD', N'Sacs poubelle bleu 30L ep 30 microns  liens coulissants carton de 500', 0.5488, 18, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAC_POUB50L', N'26', N'26FD', N'Sacs poubelle  noir 50l ep 30 microns  liens coulissants', 137.25, 26, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAC_POUB6L', N'26', N'26FD', N'Sacs poubelle 6L ep 25 microns', 39, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAC_SPI620922', N'22', N'22FA', N'Sac filtrant X 5', 65.03, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAC_STH49015009031', N'14', N'14FC', N'Lot de 5 sacs aspirateur SE 120', 46.79, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SACH.PLAST.HT280', N'26', N'26FD', N'Sachet plastique fermeture ZIP hauteur 280mm', 99, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SACO.HUS505690510', N'18', N'18MB', N'Sacoche arriere porte outil d''abbatage', 26.4, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAND.L100', N'26', N'26FD', N'Sandow L100 D10', 5.092653, 19, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAND.L90', N'26', N'26FD', N'Sandow lg 90cm Dia,10', 3.25, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAND.LOT', N'26', N'26FD', N'Lot de 10 Sandow', 26, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SANG.13191721530', N'22', N'22MB', N'sangle caoutchouc', 5.38, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SANG.2T2.5M', N'22', N'22MB', N'Sangle plate 2.5m cmu 2.T + 2 boucles retournes', 8.9, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SANG.2T2M', N'22', N'22MB', N'Sangle plate 2M cmu 2T + 2 boucles retournes', 7.35, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SANG.2T3M', N'22', N'22MB', N'Sangle plate cmu 2T + 2 boucles retournes', 10.5975, 0, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SANG.3T2M', N'22', N'22MB', N'Sangle plate jaune cmu 3T + 2 boucles retournes', 15.78, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SANG.3T3M', N'22', N'22MB', N'Sangle plate lg.3ml CMU 3To jaune boucle retourne', 16.1, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SANG.3T4M', N'22', N'22MB', N'Sangle plate lg.4ml CMU 3To jaune boucle retourne', 17.7, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SANG.3T5M', N'22', N'22MB', N'Sangle plate jaune cmu 3T + 2 boucles retournes', 28.54667, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SANG.AR10M2.5TDGEC', N'22', N'22MB', N'Sangle d''arrimage  cliquet 10M doigt cartes TMU 2500 jaune', 28.13, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SANG.AR25AUTO', N'22', N'22MB', N'Sangle d''arrimage larg.25mm autoretractable', 22, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SANG.AR5M1T2DGEC', N'22', N'22MB', N'Sangle d''arrimage avec cliquet doigts ecartes  1200kgs', 11.14286, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SANG.AR5M900', N'22', N'22MB', N'Sangle d''arrimage avec cliquet 5ml 900kgs', 14.6, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SANG.AR5M900SF', N'22', N'22MB', N'Sangle d''arrimage sans fin larg.25mm 5ml 900kgs', 12.4, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SANG.AR9M2TDGEC', N'22', N'22MB', N'Sangle d''arrimage  cliquet 9M doigt cartes TMU 2000 bleu', 15.42105, 14, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SANG.AR9M5TDGSR', N'22', N'22MB', N'Arrimage TMU 5To LG=9ml doigts serrs', 17, 0, 0, 0, 4)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SANG.ARSF1T35MM', N'22', N'22MB', N'Sangle d''arrimage sans fin a cliquet 1tonne 35mm', 12.8, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAPI.STH00008812800', N'26', N'26MA', N'sapie a main 500gr', 24.0902, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAPI-HACHE70CM', N'26', N'26MA', N'Sapie hache manche frne de 70cm', 47.99, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SATU.BOIS_CLAIR', N'05', N'05FL', N'saturateur  bois clair', 72.0607, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAVO.AT4L', N'24', N'24FB', N'Savon microbille pour distributeur 4L', 30.66571, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAVO.GEL350', N'24', N'24FB', N'Savon gel alphamouss main, corps et cheveux parfum', 7.02960539, 66, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SAVO.GEL500ML', N'24', N'24FB', N'Savon gel pousse mousse', 3.5625, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PORT.STH56057504304', N'26', N'26MA', N'Porte lime  2 en 1 P.325', 29.26, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PORT.WOLUTM', N'26', N'26MA', N'Porte outils wolf multistar', 24.7104, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POST_IT38X51', N'17', N'17FC', N'lot de 12 blocs de 100 feuilles tutti frutti de post it 38x51', 6.44, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POST_IT76X127FLUO', N'17', N'17FC', N'Bloc de 100 feuilles de post it 76x127 jaune fluo', 1.15, 33, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POST_IT76X76', N'17', N'17FC', N'lot de 12 blocs de 100 feuilles de post it 76x76 jaune', 1.82, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POST_IT76X76_4C', N'17', N'17FC', N'Lot de 12 blocs de 100 feuilles de post it 76x76 4 couleurs diffrentes', 8.28, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POTE.DN220ESC.', N'28', N'28MA', N'Potelet escamotable acier diametre 220 Hauteur 650 RAL gris 7004 20kgs', 920, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POTE.DN7.6/LG4M', N'28', N'28MA', N'Poteau universel diametre 7.6 cm longueur 4m pour tout miroir', 68.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POTE.POMP1.18M', N'05', N'05MA', N'Poteaux diametre 70mm  1.18 metre hors sol  rouge/blanc rtrorflchissant + fourreau a cl', 123.7, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POUB.50L_INOX', N'26', N'26FD', N'poubelle inox avec poigne et seau amovible Ht 484* diam292 ouverture par pedale hydraulique', 102.64, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POUB.GP', N'24', N'24FB', N'Poubelle galvaplast + ancrage - marron galva  volume 130 litres', 384.2667, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POUB.M50L', N'24', N'24FB', N'Poubelle plastique 50 Litres avec couvercle amovible', 34.8, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POUC.6-29', N'26', N'26MA', N'Pouce extra N.6 dia.29', 8.94, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POUC.R0-18', N'26', N'26MA', N'Pouce N.0 a rechampir dia.18', 4.655, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POUC.R03-15', N'26', N'26MA', N'Pouce N.3/0 a rechampir dia.15', 4.487, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POUC.R2-21', N'26', N'26MA', N'Pouce N.2 a rechampir  dia.21', 6.2492, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POUC.R2-21BL', N'26', N'26MA', N'Pouce N.2 a rechampir  dia.21', 9.44, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POUC.R4-25', N'26', N'26MA', N'Pouce N.4 a rechampir dia.25', 8.580878, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POUC.R4-25BL', N'26', N'26MA', N'Pouce N.4 a rechampir  dia.25', 10.61, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POUC.R6-29', N'26', N'26MA', N'Pouce a rechampir N.6  dia.29', 9.965907, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POUD.400GR', N'05', N'05FL', N'Poudre bleu pour cordeau', 4.47, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POUD.CATAL.', N'05', N'05FI', N'poudre catalytique de ramonage', 36, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POUD.FOURMI', N'05', N'05FI', N'Paquet de poudre anti fourmis', 21.47, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POUL.ECH17721515133', N'14', N'14FC', N'Poulie de lanceur pour ECHO', 11.78, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POUL.ECH17721543130', N'14', N'14FC', N'Poulie de lanceur pour ECHO', 11.78, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POUL.ECHP22002080', N'14', N'14FC', N'poulie echo', 19.29, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POUL.HUS537420001', N'14', N'14FC', N'Poulie a cable plastique 064 STIHL', 38.55, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POUL.STH11221950400', N'14', N'14FC', N'Poulie a cable plastique 064 STIHL', 15.1712, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POUL.STH11231950400', N'14', N'14FC', N'Poulie a cable STIHL 020-023', 17.64, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POUL.STH11251950401', N'14', N'14FC', N'Poulie a cable', 12.6875, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POUS.STH11211412100', N'14', N'14FC', N'Poussoir', 0.74, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PREF.STH00001410300', N'14', N'14FC', N'Filtre a air mtallique MS880', 4.95, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PREL.10', N'05', N'05FA', N'Prelinteau de 10', 10.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRES.AMPOULES', N'14', N'14FC', N'presentoir  ampoules OSRAM', 240, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRES.BM13353', N'22', N'22FA', N'Presse etoupe pour pompe a eau dn40 rouge mot.bern', 12.36, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRES.CAROUSSEL', N'23', N'23MA', N'Prsentoir carrousel noir 24 cases format A4 pieds mobils', 212.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRES.ET16', N'12', N'12MB', N'Presse etoupe electrique iso 16', 1.0227, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIM.BP', N'05', N'05FI', N'primaire bouche pores pour racrage seau de 4kgs', 47.04, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIM.COL', N'05', N'05FI', N'primaire pour colle 15ml', 7, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SCHA.BIO5', N'24', N'24FB', N'Schampoing vhicule bio', 47.7, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SCIE_BOSGSA18V-LI', N'22', N'22MD', N'Scie sabre sur accu 18V - VI', 362.09, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SCIE_BUC530MM', N'26', N'26MA', N'Scie a buche 530mm', 7.34, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SCIE_BUC762MM', N'26', N'26MA', N'Scie a buche 762mm', 8.98, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SCIE_CIRC.GKS65', N'26', N'26FD', N'Scie circulaire 1200W', 199, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SCIE_DOS300MM', N'26', N'26MA', N'Scie a dos de 300 mm 11 dents', 16.58, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SCIE_DTS_DOUCES', N'14', N'14FC', N'Scie  dents douces 24dents dn 250mm', 21.996, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SCIE_MIL.M18FHZ-0X', N'22', N'22MD', N'Scie sabre compacte fuel', 195.07, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SCIE_MIL.M18FSX-0C', N'22', N'22MD', N'Scie sabre', 369, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SCIE_TREPAN52', N'26', N'26FA', N'Scie trepan BIM 52mm', 30.15, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SCIE_WOLOYM3', N'26', N'26MA', N'Scie d''lagage', 24.57, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SCOR.', N'05', N'05FH', N'scories', 25, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SEAU_MAON11', N'26', N'26MA', N'Seau de maon 11l', 9.32, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SEAU_PLAST.N10L', N'26', N'26FD', N'seau plastique noir 10l gradu large', 1.65, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SEAU_POLY.12L', N'26', N'26FD', N'seau polypropylene 12l', 4.32, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'SEGM.ECH10001143230', N'14', N'14FC', N'Segment de debroussailleuse ECHO', 0, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.CLA7701017668', N'14', N'14FC', N'Prise de courant', 3.33, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.FLASH05006', N'12', N'12 FA', N'Prise programmable jour', 13.7003, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.HAGSNS216', N'12', N'12 FA', N'Prise de courant pour rail DIN 2P+T SANVIS', 11.55, 0, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.HAGWXF100', N'12', N'12 FA', N'Prise de courant Gallery 2P+T WXF100', 2.59, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.LEG051181', N'12', N'12 FA', N'Prise de courant mobile 3P+T+N 16A ROUGE', 48.9, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.LEG052082', N'12', N'12 FA', N'Prise mobile 2P+T 16A 220V PLAST BLEU', 30.65, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.LEG052984', N'12', N'12 FA', N'Prise mobile 3P+N+T 32A rouge femelle', 26.33, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.LEG057518', N'12', N'12 FA', N'Prise de courant mobile 3P+T+N 16A IP44 400V', 6.06, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.LEG057667', N'12', N'12 FA', N'Prise a encombrement reduit bleu 220V', 4.161, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.LEG067111', N'12', N'12 FA', N'Prise 2P+T F/B  BA', 3.4064, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.LEG067124', N'12', N'12 FA', N'Prise 2X2+T F/B precable EWO', 7.9827, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.LEG067126', N'12', N'12 FA', N'Prise 3X2+T F/B precable EWO', 11.9775, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.LEG067345', N'12', N'12 FA', N'Prise RJ45 DATA/TEL FTP CELIANE', 11.9134, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.LEG069551', N'12', N'12 FA', N'Prise etanche  16A 2P+T 230V', 5.195, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.LEG076546', N'12', N'12 MC', N'Prise RJ45X2 C6 FTP clip mosaic', 17.85, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.LEG076566', N'12', N'12 MC', N'Prise pour RJ 45 C6 2 modules mosaic STP', 12.84, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.LEG077101', N'12', N'12 MC', N'Prise pour goulotte a clippage direct 2 MOD 2P+T blanc', 10.45, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.LEG077103', N'12', N'12 MC', N'Prise pour goulotte a clippage direct 3 x 2P+T', 18.22, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.LEG555109', N'12', N'12 FA', N'Prise mobile 16A 3P+N+T', 7.698, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.LEG555189', N'12', N'12 FA', N'Prise fixe 16A 3P+N+T', 8.63, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.LEG555304', N'12', N'12 FA', N'Prise mobile 2P+T 16A 230V IP67 PLAST BLEU', 21, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.MG15306', N'12', N'12 FA', N'PC 250V 16A a obturateur 2P+T', 6.75, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.SCH_PKF32M735', N'12', N'12 FA', N'Prise mobile 32A IP67 380V 5P', 26.51, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PRIS.SCHENN36030', N'12', N'12 FA', N'Prise de courant MUREVA IP55 IK07  72X72X58 mm', 5.873739, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROF.CAOUT/BATARD', N'22', N'22FA', N'Profil caoutchouc 6ml / batardeau-prix a la piece', 152.4, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROF.CAOUT12.95.02', N'22', N'22FA', N'Profil caout.note de musique  en CR 70 LONGUEUR 6ML - DN int 36mm - DN ext 60mm - larg.totale120mm - ep.12mm', 54.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROF.D65/80/2545', N'26', N'26FD', N'Profil delta ref: 01.86.06 lg 5ml   matiere:475050-0E noir EX65/80/2545/0010', 18.42, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROF.D70/80/2960', N'26', N'26FD', N'Profil delta ref: 07.93.08 lg 5ml   matiere:475050-0E noir dimensions 70/80/2960/0008', 20.8223, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROF.EX52/60/1350/010', N'26', N'26FD', N'Profil delta ref:09.86.13 lg au ml   matiere:475060-0vV EPDM 75 +-5SH noir  perage dn10mm suivant modle', 19.95, 54, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROF.MOUS47/12ANGLH', N'28', N'28MA', N'profil mousse H corniere epaisseur 12mm 47 / 47 mmm', 0, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROJ.20WLED', N'12', N'12 FA', N'Projecteur 20 W led + detecteur IP44', 39, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROJ.30WLED', N'12', N'12 FA', N'Projecteur 30 W led + detecteur IP44', 39.9, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROJ.50WLED', N'12', N'12 FA', N'Projecteur 50 W led + detecteur IP44 slim', 46.93, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROJ.ARI50406', N'12', N'12 FA', N'Projecteur 2 led twister25W/4000K', 38.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROJ.ARI50407', N'12', N'12 FA', N'Projecteur 2 LEDtwister 45W/4000K', 74.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROJ.ARI50482', N'12', N'12 FA', N'Projecteur 2 MW twister 25W/4000K', 58.5, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROJ.ARI50483', N'12', N'12 FA', N'Projecteur 2 MW twister 45W/4000K', 105.95, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROJ.GEN0232269', N'33', N'33FB', N'prjecteur led 20W pour camion', 43.27, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROJ.MEG_MM07698', N'12', N'12 FA', N'Projecteur LED 90W 11000LM 4000K', 267.75, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROJ.MIL.M18HSAL-0', N'12', N'12 FA', N'Projecteur M18 avec trepied LED avec chargeur intgr 12 leds 3 rglages d''clairage comparable  500W', 399, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROT.D12/25', N'26', N'26FD', N'Protection jrouge pour piquet balisage dia12mm 25 ieces', 8.69, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROT.DOC80V', N'17', N'17FC', N'Protege document 21x29.7 semi rigide 80 vues', 3.842576, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROT.ECH69900150430', N'14', N'14FC', N'Protecteur complet Echo', 37.4364, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROT.ECHC550000090', N'14', N'14FC', N'protecteur pour debroussailleuse a dos', 11.75, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROT.ECHC550000100', N'14', N'14FC', N'protecteur de base pour debroussailleuse a dos', 12.395, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROT.OREQ515062', N'28', N'28MA', N'Protection faciale  avec protege oreilles', 15.17, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROT.SCHGV2ME16', N'12', N'12MB', N'Protection magntothermique TRI 9  14 A', 44.15, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROT.SOUBASSEMENT', N'05', N'05FA', N'Protection soubassement au dtail', 2.76, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROT.STA66070644R', N'14', N'14FC', N'Protge courroie', 12.97, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROT.STH00007929129', N'14', N'14FC', N'Protege guide', 6.644, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROT.STH00007929132', N'14', N'14FC', N'Protege chaine rallonge', 3.47, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROT.STH11297929100', N'14', N'14FC', N'Protge main', 22.55, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROT.STH11417929100', N'14', N'14FC', N'Protege mains pour MS 200', 17.8904, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PROT.WALTERS', N'14', N'14FC', N'Protecteur Walters pour prise de force', 64.7383, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PULV.1.5L', N'26', N'26FD', N'Pulverisateur 1,5l avec pompe a pression', 28.16021, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PULV.5L', N'26', N'26FD', N'Pulverisateur 5l avec pompe a pression', 64, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PULV.600ML', N'26', N'26FD', N'Pulvrisateur plastique vide 600ml', 1.1467, 17, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PUNA.', N'17', N'17FC', N'Punaise de bureau', 0.77, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.', N'22', N'22FA', N'Raccord', 23.03, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.+ECROU', N'33', N'33FC', N'raccord coude + ecrou mobylette', 14.33, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.10F', N'22', N'22FA', N'raccord express queue canele en fonte', 5.78, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.FOGU210-37', N'22', N'22FA', N'Raccord demonte pneu', 94.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.GAZ1/2M', N'22', N'22FA', N'Raccord air comprim filetage M 1/2 gaz', 2.4, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.GAZ1/4F', N'22', N'22FA', N'Embout air comprim femelle 1/4 gaz IRP 066101', 2.1, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.GAZ1/4M', N'22', N'22FA', N'raccord male 1/4 gaz conique prtflonn passage 6mm bsp', 3.367955, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.GAZ1/4M+B', N'22', N'22FA', N'Embout air comprim filetage M 1/4 gaz  barbe', 2.317273, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.GAZ1F', N'22', N'22FA', N'Raccord air comprim express filetage F 1 pouce gaz', 9.62, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.GAZ3/4F', N'22', N'22FA', N'Raccord air comprim express filetage F 3/4 gaz', 4.14, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.GAZ3/4M', N'22', N'22FA', N'Raccord air comprim express filetage M 3/4 gaz', 6.17, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.H1/2-12S', N'14', N'14FC', N'Raccord hydraulique 1/2-12S tournant', 19.89, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.H4G8FDLORX', N'14', N'14FC', N'Raccord hydraulique femelle OR 08L M14X150', 4.2827, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.H5G12FDLORX', N'14', N'14FC', N'Raccord hydraulique FEMELLE DIN OR 12L M18X150', 6, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.H8G15FDLORX', N'14', N'14FC', N'Raccord hydraulique FEMELLE DIN OR 15L M22X150', 6.7167, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HA05A10MZ16A', N'14', N'14FC', N'Raccord hydraulique male', 3.9, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HA05A10RO16A', N'14', N'14FC', N'Raccord hydraulique HA05A10RO16A', 3.61, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HA05A10RO16A90', N'14', N'14FC', N'Raccord hydraulique HA05A10RO16A90', 6.4135, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HA05A12MZ18A', N'14', N'14FC', N'Raccord hydraulique HA05A12MZ18A', 3.9, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HA05A12RO20A', N'14', N'14FC', N'Raccord hydraulique HA05A12RO20A', 4.1, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HA05A12RO20A90', N'14', N'14FC', N'Raccord hydraulique', 6.4135, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HA06A08MU', N'14', N'14FC', N'Raccord hydraulique HA06A08MU LN1600', 8.17, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HA06A12MZ18A', N'14', N'14FC', N'Raccord hydraulique HA06A12MZ18A', 3.9, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HA06A12RO18A90', N'14', N'14FC', N'Raccord hydraulique', 6.4135, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HA06A13RY20A', N'14', N'14FC', N'Raccord hydraulique HA06A13RY20A', 3.3097, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HA06A14MZ20A', N'14', N'14FC', N'Raccord hydraulique', 5.91, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HA06A14RO20A', N'14', N'14FC', N'Raccord hydraulique HA06A14RO20A', 4.48, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HA08A15RO22A', N'14', N'14FC', N'Raccord hydraulique HA08A15RO22A', 5.07, 1, 0, 0, 8)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HA08A16RO24A', N'14', N'14FC', N'Raccord hydraulique HA08A16RO24A', 5.1, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HA08A16RO24A90', N'14', N'14FC', N'Raccord hydraulique HA08A16RO24A90', 9.8894, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HA08A17MZ24A', N'14', N'14FC', N'Raccord hydraulique HA08A17MZ24A', 5.1, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HA10A18MZ26A', N'14', N'14FC', N'Raccord hydraulique HA10A18MZ26A', 5.46, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HA10A18RO26A', N'14', N'14FC', N'Raccord hydraulique HA10A18RO26A', 6.65, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HCP0606FG90B', N'14', N'14FC', N'raccord hydraulique coud 90 LN1600', 2.88, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HDNPPAV11313', N'14', N'14FC', N'Prise d''huile hydraulique cplte Fem.+ Male 1/2', 9.18, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HES12A25MZ36B', N'14', N'14FC', N'Raccord hydraulique ES12A25MZ36B', 6.65, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HES12A25RO36B', N'14', N'14FC', N'Raccord hydraulique', 6.65, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.HES12A25RO36B90', N'14', N'14FC', N'Raccord hydraulique', 6.65, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.MAL6A7', N'22', N'22FA', N'mle  barbe pasage 6mm pour tuyau 6a7mm  epaul.12mm lg.54mm', 3.6, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.MAL8', N'22', N'22FA', N'mle  barbe pour tuyau 8mm passage de 6mm epaul.12mm lg.56mm', 7.385683, 17, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.MAL9A10', N'22', N'22FA', N'male a barbe passage 6mm pour tuy. de 9 a 10mm epaul.12mm lg.56mm', 3.33, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.MCAD272220', N'12', N'12 FA', N'Raccord RJ45 CAT.6 femelle/femelle blind', 12.5, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.MCAD902830', N'12', N'12 FA', N'Raccord RJ45 CAT.5 femelle/femelle blind', 8.6, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.MODY3/4', N'22', N'22FA', N'Raccord express femelle', 24.36, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.PARK299-0135', N'14', N'14FC', N'Raccord hydraulique femelle droit acier BSP 3/8 330 bars', 17.36, 0, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.RFA', N'22', N'22FA', N'Raccord rapide acetylene femelle etage', 26.54075, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.RFO', N'22', N'22FA', N'Raccord rapide oxygene femelle etage', 26.54075, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.RMA', N'22', N'22FA', N'Raccord rapide acetylene male etage', 14.93675, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.SYM.ALU25/30', N'22', N'22FA', N'Raccord symetrique 2410 alu annel 25/30', 21.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.U_MF_20/27', N'11', N'11FC', N'Raccord union sachet de 2 pieces MF 20/27 94 altech', 19.86, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.UNGAL.F1/2', N'11', N'11FC', N'Raccord union galva 1/2 F', 2.0093, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.UNGAL.F3/4', N'11', N'11FC', N'Raccord union galva F 3/4', 2.2898, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REDU.CU14-12', N'11', N'11FC', N'Rduction cuivre 14-12', 0.8, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REDU.CU16-12', N'11', N'11FC', N'Reduction cuivre 16-12', 0.85, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REDU.CU16-14', N'11', N'11FC', N'Reduction cuivre 16-14', 1.07, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REDU.GALMF1"-1/2', N'11', N'11FC', N'Rduction galva 1"M-1/2F', 0.81, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REDU.GALMF1"-3/4', N'11', N'11FC', N'Rduction 1"M-3/4F galva', 0.6982, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REDU.GALMF1/2-3/8', N'11', N'11FC', N'Rduction galva MF 1/2x3/8', 0.36, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REDU.GALMF3/4-1/2', N'11', N'11FC', N'Rduction galva 3/4M-1/2F', 0.55, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REDU.GCU.F14-1/2', N'11', N'11FC', N'Rduction F GCU 14x1/2F', 1.4406, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REDU.GCU.M16-3/4', N'11', N'11FC', N'Raccord GCU 16-3/4 male laiton', 1.47, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REDU.PREVA4_1238', N'11', N'11FC', N'Rduction acier M1/2 - F 3/8', 1.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REDU.PVC100/40', N'05', N'05FA', N'Rduction PVC MF 100mm/40mm', 3.455712, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REDU.PVC100/50', N'05', N'05FA', N'Rduction PVC 100/50 gris', 3.80288, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REDU.PVC100/63', N'05', N'05FA', N'Rduction PVC MF 100mm/63mm', 2.6, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REDU.PVC100/75', N'05', N'05FA', N'Rduction PVC MF 100mm/75mm', 2.6, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REDU.PVC100/80EXC', N'05', N'05FA', N'Rduction PVC MF excentr100mm/80mm', 4.18, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REDU.PVC40/32', N'11', N'11FC', N'Rduction PVC 40/32', 0.5484, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REDU.PVC40/32P', N'11', N'11FC', N'Rduction PVC 40/32 pression', 0.96, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REDU.PVC50/40P', N'11', N'11FC', N'Rduction PVC 50/40 pression', 0.8, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REDU.PVC80/63', N'05', N'05FA', N'Rduction PVC MF 80mm/63mm', 4.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REDU.STH41286400101', N'14', N'14FC', N'Reducteur FS450', 141.98, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REDU.TUBAGE125/153', N'07', N'07FA', N'Reduction tubage bleuie tuyau de pole 125/153', 30.17, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REDU.TUBAGE180/150', N'07', N'07FA', N'Reduction tubage tuyau de pole 150/180', 28.73, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REGA.BET30X30', N'05', N'05FA', N'Regard bton 30/30', 22.46, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REGA.BET50X50X34', N'05', N'05FA', N'Regard bton 50x50 hauteur 34 ADG', 43.89, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REGL.20CM', N'17', N'17FC', N'Rglette 20cm', 1.69, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REGL.30', N'17', N'17FC', N'Rgle de bureau 30cm', 3.734756, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REGL.30CM', N'17', N'17FC', N'Rglette 30cm', 2.42, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REGL.COL.', N'26', N'26MA', N'Rgle de colleur acier inox', 13.52, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.UNGCU08-3/8M', N'11', N'11FC', N'Raccord union laiton 8-3/8M laiton', 4.93, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACC.UNGCU16-1/2F', N'11', N'11FC', N'Raccord union laiton 16-1/2 laiton', 2.2105, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACL.NOR102806', N'14', N'14FC', N'Racleur de rouleau palpeur', 215.03, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACL.VIT35', N'26', N'26MA', N'Raclette pour vitre longueur 35 cm', 18.95, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RACR.SOL', N'05', N'05FA', N'Racreage pour sol', 31.0392, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RADI.T22_300X800', N'22', N'22FA', N'Radiateur chauffage', 122.91, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RAIL_HILTI', N'12', N'12 FA', N'Rail perfor HILTI p:2,5x3ml MS-21', 11.4337, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RAIL_M48', N'05', N'05FA', N'Rail M48 3ml', 1.06, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RAIL_PHOFLDINRA', N'20', N'20FB', N'Le FL DIN RA est mont sur rack norm 19 pouces qui permet de monter en rack des equipements electriques', 187.11, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RAIL_R48', N'05', N'05FA', N'Rail R48 3ml', 0.84, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RALL.GAL.M60X1/2', N'11', N'11FC', N'Rallong galva M 1/2 lg 60', 0.8, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RALL.GAL.M60X3/4 M', N'11', N'11FC', N'Rallonge galva M 3/4 lg60mm', 0.73, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RALL.SOL50CM', N'22', N'22FA', N'Rallonge plastique 50cm / pulverisateur SOLO', 9.1, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RAMP.2ML', N'22', N'22MB', N'Rampe de chargement 2ml long incurve', 124.17, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RAMP.SIGNAL', N'14', N'14FC', N'Rampe de signalisation', 29.5, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RAMP.SIGNAL.MAGNETIQ.', N'14', N'14FC', N'Rampe de signalisation magntique', 29.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RAPE.CHIM800CC', N'05', N'05FI', N'rapeur chimique 800CC', 20.397, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RAPE_PLAT300', N'26', N'26MA', N'Rape plate  main 300mm', 10.938, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RATE.WOLDOM40', N'26', N'26MA', N'Rateau arc 40cm', 17.97, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RATI.', N'14', N'14FB', N'Bloc raticide hydrofuge pret a l''emploi', 2.52, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RATI.WOLHUM15', N'26', N'26FD', N'ratissoir 15cm', 10.9296, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RAYO.3T1000X500X2000AD', N'23', N'23MA', N'Rayonnage additionnel charges l150 kgs 3 travees lg 1000mm prof.500mm ht 2000mm', 137.774, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RAYO.3T1000X500X2000DEP', N'23', N'23MA', N'Rayonnage dpart charges l150 kgs 3 travees lg 1000mm prof.500mm ht 2000mm', 174.72, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RAYO.3T800X500X1920AD', N'23', N'23MA', N'Rayonnage additionnel charges 230 kgs 5 tablettes lg 800mm prof.500mm ht 1920mm', 181.09, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RAYO.3T800X500X1920DEP', N'23', N'23MA', N'Rayonnage dpart charges 230 kgs 5 tablettes lg 800mm prof.500mm ht 1920mm', 221.585, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RECE.RHEARE-CHS-A1AL', N'12', N'12MB', N'Recepteur alarme type rx alarme', 407.3333, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RECE.RHEARE-CHS-A1AV', N'12', N'12MB', N'Recepteur annonce aval type rx aval', 418.6667, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RECE.RHEARE-CHS-A1BA', N'12', N'12MB', N'Recepteur base type base rs485', 326, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RECE.RHEARE-CHS-AAM', N'12', N'12MB', N'Recepteur annonce amont type rx amont', 414.75, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RECH.CAMION14L', N'26', N'26FD', N'Recharge camion 5 membranes 14l', 10.79286, 4.2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RECH.CAMION7L', N'26', N'26FD', N'Recharge camion 5 membranes 7l', 6.8356, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REGU.RS8064116', N'12', N'12MB', N'Regulateur de tension MC78L05ACP sachet de 50 pieces', 0.138, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RELA.PHO2961121', N'12', N'12 FA', N'Relais sans accrochage 1 RT montage sur CI bobine 24V dc', 5.11, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RELA.PHO2966472', N'12', N'12 FA', N'Relais d''nterface 1RT pour montage sur rail DIN', 9.76, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RELA.SCHABR7S33', N'12', N'12 FA', N'Relais electromagnetique pour embase de sortie ABE7P08T330', 4.76, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RELA.SCHRM22TR33', N'12', N'12 FA', N'Relais RM22TR33', 153.18, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RELA.WEI1129421001', N'12', N'12 FA', N'Relais RS 30 12 VDC LD LP LA', 24, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REMO.ROUT.750KG', N'33', N'33MC', N'Remorque PTAC 750kgs  - essieu 2 x 750kgs  242x135x40', 1187, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REMP.PALIER', N'22', N'22SB', N'Remplacement palier sur cric d''ecluses', 258.75, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RENI.CLA7700037706', N'14', N'14FC', N'Reniflard', 19.337, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'RENO.SURFACE', N'05', N'05FI', N'Rnovateur pour surfaces fortement encrass, oxyd ou entartr', 20.3375, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REPA.APPAREIL_LEVAGE', N'22', N'22SB', N'reparation appareil de levage', 142, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REPA.MAT.AGRI', N'14', N'14SC', N'reparation materiel agricol', 1153.35, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REPA.MATERIEL', N'22', N'22SB', N'Reparation materiel', 217.17, 0, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REPA.SPE190689', N'31', N'31FA', N'Reparatiteur telephonique RJ45 1 entre 4 sorties', 24, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REPE.LEG038442', N'12', N'12 FA', N'Repere duplix signe plus', 3.98, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REPE.LEG038443', N'12', N'12 FA', N'Repere duplix signe moins', 3.98, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REPE.TET_SVCT-04-S40102', N'20', N'20MC', N'Repeteur POE+ 100mbps', 25, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REPU.MART.', N'25', N'25FA', N'Repulsif martre', 19.93, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REPU.MOUST.', N'25', N'25FA', N'Repulsif moustique', 5.56, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'REPU.TIQUE_PEAU', N'25', N'25FA', N'Repulsif tique 100ml peau', 12, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.AR2.5RAL3020', N'05', N'05FL', N'Peinture antirouille rouge', 115.05, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.AR2.5RAL9003', N'05', N'05FL', N'Peinture antirouille blanc de securite RAL9003 / L', 45.255, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.AR3RAL6001', N'05', N'05FL', N'Peinture antirouille vert emeraude', 43.8, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.AR3RAL6005', N'05', N'05FL', N'Peinture antirouille vert mousse 3L', 48.8754, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.AR3RAL7000', N'05', N'05FL', N'Peinture antirouille gris petit gris 3L', 47.4, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.AR3RAL9003', N'05', N'05FL', N'Peinture antirouille blanc de securite 3L / L', 115, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.AR3RAL9005', N'05', N'05FL', N'Peinture antirouille noir profond', 55.575, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.AR4RAL1018', N'05', N'05FL', N'Peinture jaune  RAL 1018 / bollards', 60.89, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.BLMAT6', N'05', N'05FL', N'Peinture blanc mat pour mur interieur', 34.12, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.BOIS3020', N'05', N'05FL', N'Peinture  rouge 4l RAL 3020', 17.74, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.COMUSPISCINE15', N'05', N'05FL', N'Peinture COMUS PISCINE blanc 15L', 193.59, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.GAU_G4025', N'05', N'05FL', N'Peinture acrylique satin  15l G4025  collection Arc en ciel', 143.85, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.GAU_G6215GLYCIL', N'05', N'05FL', N'Peinture acrylique satin  15l   Gauthier G6215 GLYCIL collection Arc en Ciel', 143.85, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.MAPBLANC3', N'05', N'05FL', N'Peintur mat a plafond blanc 3L gamme chantier', 24.84, 0, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.NOIR', N'05', N'05FL', N'peinture en phase aqueuse noir pour application en immersion', 217.6875, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.SATBLANC10', N'05', N'05FL', N'Peinture acrylique satin  10l blanc mur et plafond', 51.61, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.SATBLANC10TEINTE', N'05', N'05FL', N'Peinture acrylique satin  10l blanc mur et plafond a teinte', 85.104, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.SATBLANC2.5TEINTE', N'05', N'05FL', N'Couche satinee de finition blanc  teinter', 39.688, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.SATBLANC5', N'05', N'05FL', N'Couche satinee de finition blanc', 10.03, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.SATRAL7035', N'05', N'05FL', N'Peinture acrylique satin  10l gris ral 7035 mur et plafond', 104.2644, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.SIGNBLANC', N'05', N'05FL', N'Peinture route blanc 7,5kgs', 26.55, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.SOLBLANC5', N'05', N'05FL', N'Peinture de marquage au sol blanche 5 kgs', 47.23, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.SOLRAL2012', N'05', N'05FL', N'Peinture de marquage au sol orange saumon RAL2012 5 kgs', 81.45, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.SOLRAL5001', N'05', N'05FL', N'Peinture de marquage au sol bleu RAL5001 5 kgs', 72.31, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.SOLRAL6025', N'05', N'05FL', N'Peinture de marquage au sol vert RAL6025 5 kgs', 65.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.SP1023_SOL', N'05', N'05FL', N'Peinture jaune tracage au sol ral 1023', 31.05, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.SP9003', N'05', N'05FL', N'Peinture blanche ral 9003', 25.1, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.SP9016_SOL', N'05', N'05FL', N'Peinture blanche tracage au sol ral 9016', 22.64371, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.SPGALV', N'05', N'05FL', N'Peinture galva brillant en spray', 17.278595, 17, 0, 0, 12)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.SPINOX', N'05', N'05FL', N'Peinture inox en spray', 35.19, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.SPNOIRB', N'05', N'05FL', N'Peinture noir brillant en spray 600ml', 12.55, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.SPNOIRM', N'05', N'05FL', N'Peinture noir mat en spray 600ml', 25.1, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.SPZI', N'05', N'05FL', N'Peinture zinc en spray', 26.616, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PELL.NEIGE', N'26', N'26MA', N'Pelle  neige (poussoir) acier galva', 21.01, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PELL.PM_MET', N'26', N'26MA', N'Pelle petit modele metal', 4.11, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PELL.PM+BAL.', N'26', N'26MA', N'Pelle petit modele + balayette plastique', 8.1, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PELL+MANCHE', N'26', N'26MA', N'Pelle emmenche', 15.79, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEND.NOIR', N'21', N'21MB', N'Pendule radio pilotee noir', 19.12, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PERF.2TR20F', N'17', N'17FC', N'Perforateur 2 trous 20 feuilles', 15.26, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PERF.2TR60F', N'17', N'17FC', N'Perforateur 2 trous 60 feuilles', 26.95, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIEC.HAG873864', N'12', N'12MB', N'Piece de recouvrement de support d''appareillage', 2.94, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIEC.STH11356561500', N'14', N'14FC', N'Piece de de protection', 4.07, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIED_AC_FAC805.1', N'21', N'21MA', N'Pied   coulisse mcanique d''atelier 200mm  - 1/50eme', 78.73, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIED_AC_FAC805.2', N'21', N'21MA', N'Pied   coulisse mcanique d''atelier 200mm  - 1/50eme', 98.01, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIED_ACU', N'21', N'21MA', N'Pied   coulisse universelle', 15.6, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIEG.SUPERCAT', N'26', N'26FD', N'Piege a souris SUPERCAT', 3.25, 0, 0, 0, 80)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIGE_STH41308937800', N'14', N'14FC', N'Pige de blocage', 5.1302, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIGN.ECH61030056930', N'14', N'14FC', N'Lot de 2 pigons pour ECHO 4605', 97.374, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIGN.STH11136402000', N'14', N'14FC', N'Pignon 020 STIHL', 20.55, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIGN.STH11146402001', N'14', N'14FC', N'Pignon 020 STIHL', 18.059, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIGN.STH11216402000', N'14', N'14FC', N'Pignon 026 325 7Z', 19.9354, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIGN.STH11216402004', N'14', N'14FC', N'Pignon  profile 325 7dts', 16.1656, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIGN.STH11220071001', N'14', N'14FC', N'Jeu de pignon a anneau', 26.71, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIGN.STH11226402000', N'14', N'14FC', N'Pignon  3/8 8Dts', 23.71, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIGN.STH11236402073', N'14', N'14FC', N'Pignon pour trononneuse 3/8 6dts', 20.35, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIGN.STH11250071002', N'14', N'14FC', N'Jeu de Pignon a anneau 3/8 7dts', 26.712, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIGN.STH11280071000', N'14', N'14FC', N'Pignon STIHL 3/8 7 DTS', 26.25, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIGN.STH11286402000', N'14', N'14FC', N'Pignon STIHL 3/8 7 DTS', 21.9648, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIGN.STH11296402000', N'14', N'14FC', N'Pignon STIHL  3/8', 19.18, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PILE_6V', N'12', N'12 FA', N'Pile 6V pour lampe torche', 11.9, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PILE_6V50AHLD', N'12', N'12 FA', N'Pile 6V 50AH longue dure pour feu de chantier', 55.33333, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PILE_9V', N'12', N'12 FA', N'Pile 9V 6LR61 bloc', 4.710386, 21, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PILE_CR1/2 AA', N'12', N'12 FA', N'PILE a souder cr1/2 aa 3V ref 95029', 15.34, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PILE_CR17335SE', N'12', N'12 FA', N'PILE 2 pattes a souder cr17335SE 3V', 39.32, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PILE_CR2016', N'12', N'12 FA', N' pile CR2016', 1.65, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PILE_CR2032', N'12', N'12 FA', N'Pile bouton CR2032', 1.684955, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PILE_CR2430', N'12', N'12 FA', N'Pile bouton CR2430 lithium', 4.9, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PILE_LR03', N'12', N'12 FA', N'Pile alcaline LR03', 1.97604275, 41, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PILE_LR03_32PCES', N'12', N'12 FA', N'Pack de 32 piles LR03 1,5V', 6.3, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PILE_LR1', N'12', N'12 FA', N'Pile alcaline LR1 N2 1,5V pour lampe POWER LUX', 4.54, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PILE_LR14', N'12', N'12 FA', N'Pile LR 14 BABY', 4.59, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PILE_LR20', N'12', N'12 FA', N'Pile LR 20', 4.28, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PILE_LR2025', N'12', N'12 FA', N'Pile bouton R2025', 2.3, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PILE_LR44', N'12', N'12 FA', N'Pile alcaline LR44', 2.29818177, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PILE_LR6', N'12', N'12 FA', N'Pile LR6 1,5V', 1.363558, 60, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PILE_LR6_32PCES', N'12', N'12 FA', N'Pack de 32 piles LR6 1,5V', 10.84, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PILE_LS26500', N'26', N'26FD', N'Pile au lithium 3.6v 7.3AH', 18.64, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PINC.CL40', N'26', N'26FD', N'Pince uniclip pour agrafes CL40', 50.4, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PINC.COUP.TUB42MM', N'26', N'26MA', N'Pince coupe tube jusqu''au diametre 42mm', 65.93, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PINC.DECOF600', N'26', N'26MA', N'Pince a decoffrer de 600', 14.15, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PINC.FAC180VE', N'26', N'26MA', N'Pince multiprise isollee 1000 V 25cm', 20.37, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PINC.FAC181A.25G', N'26', N'26MA', N'Pince multiprise isollee verrou 250mm', 16.78, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PINC.FAC185.20VE', N'26', N'26MA', N'Pince  a becs 1/2 rond electricien', 20.75, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PINC.FAC187.20CPE', N'26', N'26MA', N'Pince universelle chrome long.200', 12.8375, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PINC.FAC192.16VE', N'26', N'26MA', N'Pince coupante diagonale isole 1000V', 20.19, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PINC.FAC195.20VE', N'26', N'26MA', N'Pince a becs demi ronds couds isole 1000 volts', 21.92, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PINC.FAC405.12MT', N'26', N'26MA', N'Pince coupe axiale puiss.MT', 33.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PINC.FAC407E', N'26', N'26MA', N'Pince coupe rase compacte ESD', 40.87, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PINC.FAC455B', N'26', N'26MA', N'Pince a colliers plastique', 39.66, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PINC.FAC491.20G', N'26', N'26MA', N'Pince coupante type comte 200', 14.36, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PINC.GRILLAGE', N'26', N'26MA', N'Pince a grillage', 19.361, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PINC.KNI8705300', N'26', N'26MA', N'Pince multiprise reglable cobra long.300mm', 47.55, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PINC.KRA3290-230', N'26', N'26MA', N'Pince combine a denuder et pour cosse 3290-160', 20.56, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PINC.MASSE', N'26', N'26MA', N'Pince de masse', 11.42, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PINC.REN7703297520', N'26', N'26MA', N'Pince pour cosse de batterie VL', 3.9359, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PINC.SAFW000010882', N'26', N'26MA', N'Pince porte electrodes', 39.492, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PINC.TIQUE', N'25', N'25FA', N'Kit de 2 pinces  tique', 5.4625, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIOC.CANT2', N'26', N'26MA', N'Pioche de cantonnier 2KGS + manche fibre', 34.7, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIOC.CANT2.5', N'26', N'26MA', N'Pioche de cantonnier 2.5KGS + manche fibre', 35.73, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIPE.KST150.9221', N'26', N'26MA', N'Pipette d''aspiration et de niveau 0', 21.72, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIPE_DN100-350', N'05', N'05MA', N'Pipe WC longue dn 100mm 350 85 /107mm', 7.61, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIQU.ACACIA3.5', N'05', N'05FJ', N'Piquets acacia points longueur 3.5ml section 14/18', 20, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIQU.FER16-1M', N'05', N'05FA', N'Piquet en fer dn 16 hauteur 1ml', 2.8, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIQU.K5B', N'28', N'28MA', N'Piquet de chantier 2 faces classe 1 blanc et rouge hauteur 110cm', 25, 20, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIQU.T1', N'12', N'12MB', N'Piquet de terre 1ml', 9.62, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIQU.T2', N'12', N'12MB', N'Piquet de terre 2ml cruciforme', 7.1705, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIST._JOINT', N'26', N'26MA', N'Kit pistolet  joint de parement', 72.1, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIST.EAU_LAITON', N'14', N'14FC', N'Pulverisateur pistolet a eau laiton', 22.32, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIST.EAU_MULTJ', N'11', N'11FC', N'Pistolet multijet rglable a eau', 24.94, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIST.GONFSTD', N'26', N'26MA', N'Pistolet de gonflage std', 97.34, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIST.MOUSSE_PU', N'26', N'26MA', N'pistolet a mousse pu pistolable', 40.76, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIST.SILMC', N'26', N'26MA', N'Pistolet a silicone  professionnel multi cartouche', 33.36, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIST.SOUDER1000W', N'26', N'26MA', N'Pistolet  souder 1000W instantan', 19.84, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PIST.SOUDER75W', N'26', N'26MA', N'Pistolet  souder 230V-75W instantan', 89.82, 0, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PITO.12-120', N'26', N'26FD', N'Piton d''amarrage diametre 12 - lg120', 1.1, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PITO.ORD4.5X30', N'26', N'26FD', N'Piton ordinaire bois AC ZI 4,5x30', 0.191, 96, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLAN.BULBE80MM', N'26', N'26MA', N'Plantoir a bulbe diametre du bas 80mm - haut du cone 13cm manche en T', 134, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLAN.CH.TL_EP29', N'05', N'05FA', N'Planches chne toutes largeurs epaisseur 29mm longueur 2 mtres', 390, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLAN.R2.5X12X280', N'05', N'05FA', N'Planches recycling  2.5x12x280 brun', 16.7, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLAN.R2X10X280', N'05', N'05FA', N'Planches recycling  2x10x280 brun', 13.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLAN.SAPTTL3C4M', N'05', N'05FA', N'Planches 3e choix 4ml TL', 4.8, 0, 0, 0, 25)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLAQ.AUMZ035.679', N'22', N'22FA', N'Plaque rouge/noir anti-horaire LH', 6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLAQ.ECH10153442230', N'14', N'14FC', N'Plaque ECHO', 8.3, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLAQ.ECH61044456830', N'14', N'14FC', N'Plaque pour ECHO4605', 1.166, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLAQ.IV', N'33', N'33FB', N'Plaque mineralogique pour vehicule', 12.53, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLAQ.JM448001', N'22', N'22FA', N'Plaque intermdiaire Gallia 104', 14.842, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLAQ.LEG066631', N'12', N'12 FA', N'Plaque legrand YESTERDAY blanc', 1.466, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLAQ.LEG066632', N'12', N'12 FA', N'Plaque legrand 2P YESTERDAY blanc', 2.932, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLAQ.LEG066633', N'12', N'12 FA', N'Plaque legrand 3P YESTERDAY blanc', 4.398, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLAQ.LEG078802', N'12', N'12 FA', N'Plaque legrand 2 modules', 1.26, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLAQ.PERF1029/457', N'23', N'23MA', N'Plaque perfor pour outils L1029 x H457 mm  bleu Ral 5010', 70.44, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLAQ.REN7701208142', N'33', N'33FA', N'Plaquette de frein KANGOO', 27.48, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLAQ.REN7701209864', N'33', N'33FA', N'Plaquette de frein KANGOO', 34.212, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLAQ.REN7701210142', N'33', N'33FA', N'Plaquette de frein', 27.4572, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLAT.BISEAUTE', N'26', N'26MA', N'Platoir biseaute inox 280x120x0,6 2695966113', 18.39, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLAT.COURBE', N'26', N'26MA', N'platoir inox courbe 280x120x0,6 2695966107', 21.2, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLAT.DENT10', N'26', N'26MA', N'Platoir dentel 10/10', 6.1178, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLAT.FIN2.5KG', N'05', N'05FA', N'Sac de pltre fin 2.5kgs', 4.7, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLIN.S14/70', N'05', N'05FA', N'Plinthe sapin 14/70 35x3,5ml', 5.408, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PLOT_HERPLAST', N'28', N'28MA', N'Plot en plastique massif  19 kgs avec encoche pour cloture de chantier mobile', 7.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PNEU_11.5-80-14PLY', N'14', N'14FC', N'Pneu 11.5/80-15.3 14 ply', 183.3, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PNEU_13.6-24', N'14', N'14FC', N'Pneu 13.6-24 (340.85R24) BKT RT855 agraire', 345, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PNEU_145/80R13', N'33', N'33FA', N'Pneu compresseur de chantier 145/80r13 79N AW414 TT', 49.16, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PNEU_155/70/13W*', N'33', N'33FA', N'Pneu contact hivers 155/70/13', 40.3533, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PNEU_155R15R560', N'33', N'33FA', N'Pneu / roulotte de chantier', 53.63, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PNEU_16.9-34', N'14', N'14FC', N'Pneu 16.9-34 (420: 85R34) BKT RT855 agraire', 599, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PNEU_165/65/14W', N'33', N'33FA', N'Pneu contact hivers 165-65-14 79T', 45.54, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PNEU_175/65/14', N'33', N'33FA', N'Pneu 175/65/14 82T', 77.7778, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PNEU_175/65/14W', N'33', N'33FA', N'Pneu contact hivers 175/65/14', 47.32, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PNEU_195/70/15C', N'33', N'33FB', N'Pneu 195/70/15C - Ford transit', 72.548, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PNEU_207/75R17.5', N'14', N'14FC', N'Pneu de remorque agricole 207/75R17.5', 155.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PNEU_215/70/15CW', N'33', N'33FB', N'Pneu 215/70/15C renforce contact hivers', 109.693, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PNEU_225/65/16CW', N'33', N'33FB', N'Pneu 225/65/16C renforce contact hivers - Master benne', 138.61, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PNEU_27375', N'14', N'14FC', N'Pneu arriere pour attila', 266.2528, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PNEU_4.00-8', N'14', N'14FC', N'Pneu 480x400-8 pour brouette', 33.0704, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POCH.A_PIVOT_CA', N'17', N'17FC', N'Lot de 10 poches a pivots coloris assortis', 23, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POCH.CPFCCA', N'17', N'17FC', N'Pochette coin papier fenetre cristal 120g coloris assortis boite de 100', 16.58833, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POCH.PERF.TR', N'17', N'17FC', N'Pochette perfor transparentes et trs resistante 12/100e', 6.66, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POCH.PLASTA3-125', N'17', N'17FC', N'Boite de 100 pochette a plastifier A3 125 microns', 21.87, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POCH.PLASTA3-75/80', N'17', N'17FC', N'Boite de 100 pochette a plastifier A3 75/80 microns', 17.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POCH.PLASTA4-125', N'17', N'17FC', N'Boite de 100 pochette a plastifier A4 125 microns', 10.36, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POCH.PLASTA4-75/80', N'17', N'17FC', N'Boite de 100 pochette a plastifier A4 75/80 microns', 6.12, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POCH.POLYA4', N'17', N'17FC', N'Pochette coin courrier polypro antistatique incolore A4', 6.813889, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POEL.GOD389144', N'07', N'07MA', N'Poele Fontemont 12KW', 785.77, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIG.ALU', N'05', N'05MA', N'Simple poigne de porte alu carr de 7mm', 8.23, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIG.BOIS', N'22', N'22FA', N'Poignee bois DELCO', 15, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIG.CLA6005012705', N'14', N'14FC', N'Kit poignee de porte PALES', 51.04, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIG.ECH17722811120', N'14', N'14FC', N'Poigne de lanceur pour SRM 4605', 3.925, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIG.PARE_COUP16', N'26', N'26MA', N'Poigne pare coup octogonal 16 mm', 10.19, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIG.PARE_COUP18', N'26', N'26MA', N'Poigne pare coup octogonal 18 mm', 4.93, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIG.PIST.PEINT.', N'26', N'26MA', N'Poigne de psitolet  peinture routiere spray', 32.4, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIG.STH00001903402', N'14', N'14FC', N'Poignee elastostar dn 3mm STIHL', 17.47, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIG.STH11221903400', N'14', N'14FC', N'Poignee elastostar STIHL', 13.36, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIG.STH11281903400', N'14', N'14FC', N'Poignee elastostar STIHL', 18.375, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIG.STH11297911701', N'14', N'14FC', N'Poignee', 53.62, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIG.STH11417911706', N'14', N'14FC', N'Poigne tubulaire', 27.544, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIG.TIRAGE', N'26', N'26MA', N'poignee de tirage power disc pour aiguille', 4.75, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.50AS', N'26', N'26FD', N'Boite de 250 pointes acier stri de 3.5x55mm', 12.84, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.BOS2608690106', N'26', N'26FA', N'Pointrolle 400 MM HEX 28MM', 40.73, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.ECH12313704260', N'14', N'14FC', N'Pointeau carburateur SRM 4600', 8.67, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.ECH12313719830', N'14', N'14FC', N'Pointeau carburateur SRM 5000', 8.343, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.FAC234', N'26', N'26MA', N'Pointe a tracer acier  190mm', 3.45, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.FAC985959', N'26', N'26MA', N'Pointe pour denude cable', 9.76, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.JT+RESS', N'26', N'26MA', N'Pointeau joint + ressort 891158 /pistolet moussePU', 17.131, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.LASER', N'20', N'20FB', N'Pointeur lasersans fil PR1000-R', 39, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.MAC300X16', N'26', N'26MA', N'Pointrolle 300x16mm de maon', 10.78333, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.MAC400X18', N'26', N'26MA', N'Pointrolle de maon 400x18mm', 8.29, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.MP19X50', N'22', N'22FA', N'Pointrolle pour GV5 19x50xcolerette de 33mm longueur totale 300mm', 14.58, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.MP25X75', N'22', N'22FA', N'Pointrolle 25x75 pour CJ10 et CE7', 24.8268, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.SDS+', N'22', N'22FA', N'Burin pointu SDS + L250', 14.79, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.SDSMAX', N'22', N'22FA', N'Burin pointu SDS MAX lg400 06470400', 22.39, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.STH41161215100', N'14', N'14FC', N'Pointeau d''admission', 10.0729332, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.TP100', N'26', N'26FD', N'Pointes TP 100mm', 5.389, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.TP120', N'26', N'26FD', N'Pointes TP 120mm', 23.39, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.TP160', N'26', N'26FD', N'Pointes TP 60x160 mm', 11.53, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.TP180', N'26', N'26FD', N'Pointes TP 60x180 5kgs', 11.53, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.TP50', N'26', N'26FD', N'Pointe TP de 22x50mm pqt de 5kg', 11.53, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.TP60', N'26', N'26FD', N'Pointe TP de 22x60mm pqt de 5kg', 15.6, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.TP70TOR', N'26', N'26FD', N'Pointes TP 70 torsad', 21.28, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POIN.TP80', N'26', N'26FD', N'Pointes TP 31x80mm 5kgs', 10.06, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POMP.8+8CM3', N'22', N'22MA', N'Pompe 8+8 cm3 ROT D Cone 1/5 centrage 80mm bride 40x35', 420, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POMP.ENGRENAGE_GR', N'22', N'22FA', N'Pompe a engrenage externe GR1 8cm" PN250', 425, 0, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POMP.GRAISSE_ACCU', N'26', N'26MA', N'Pompe a graisse avec accu', 329.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POMP.GRAISSEKLD2', N'26', N'26MA', N'Pompe a graisse KLD2', 41.52, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POMP.HON06193ZV1000', N'33', N'33FD', N'Kit pompe a eau pour moteur Honda', 122.58, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POMP.RVI5010316436', N'33', N'33FB', N'Pompe hydraulique basculeme', 540.54, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POMP.SDMO_CLEAR1.7', N'22', N'22MA', N'Pompe a eau moteur 2T diametre des raccords 25mm', 250, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MEMB.CLA6000145465', N'14', N'14FC', N'Membrane', 4.3447, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MEMB.ECH12311240630', N'14', N'14FC', N'Membrane pour ECHO RM5000', 6.8552, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MEMB.ECHP003001850', N'14', N'14FC', N'Membrane pour ECHO RM 5000', 18.2072, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MEMB.STH11231214700', N'14', N'14FC', N'Menbrane 020 STIHL', 15.18, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MEMB.STH11291214800', N'14', N'14FC', N'Menbrane de pompe 020 STIHL', 7.4536, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MEMB.STH41291214700', N'14', N'14FC', N'Menbrane MS200 STIHL', 11.02, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MENT./CASQUE', N'18', N'18MB', N'Mentonniere pour casque de chantier', 2.23, 16, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MERL.ECL2.5', N'26', N'26MA', N'Merlin eclateur 2.5kgs avec manche novagrip', 25.4, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MERL.ECL3.5', N'26', N'26MA', N'Merlin eclateur 3.5kgs avec manche novagrip', 29.3, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MESU.3ML', N'21', N'21MA', N'Mesure roulante 3ml', 5.036667, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MESU.5ML', N'21', N'21MA', N'Mesure roulante 5m ERGO', 12.3475, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MESU.8ML', N'21', N'21MA', N'Mesure roulante 5m ERGO', 13.52, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'METR.ALU', N'21', N'21MA', N'double metre alu', 10.94, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'METR.POL.', N'21', N'21MA', N'Double metre polyamide', 5.753153, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'METR.STH00008811200', N'26', N'26MA', N'metre a tracer Stihl', 25.17, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MEUL.125', N'22', N'22MD', N'Meuleuse d''angle diametre125', 208.91, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MEUL.AXIALE', N'22', N'22MD', N'Meuleuse axiale pneumatique pince de serrage 6mm', 195.19, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MEUL.BOSGWS18V-10PC', N'22', N'22MD', N'Meuleuse d''angle aAccu dn 125', 239, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MEUL.CRAYON', N'26', N'26FD', N'Meules crayon', 3.947, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'POMP.TSULSC4', N'22', N'22ME', N'Pompe  eau lectrique "serpillre"TSURUMI LSC4', 490, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PORT', N'32', N'32SB', N'Frais de port', 11, 0, 0, 0, 3)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PORT.', N'14', N'14FA', N'portulaca', 20, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PORT.BLOC A4', N'17', N'17FC', N'Porte bloc A4 cristal', 1.4, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PORT.BRET.SOL4074412', N'14', N'14FC', N'Porte bretelle / pulverisateur SOLO', 7.47, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PORT.DEX333418', N'20', N'20MC', N'Porte verre seul pour coffret eco 9.U', 37, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PORT.ECRAN_S54CE', N'18', N'18MB', N'Porte ecran centurion livr avec clip connect et euro pour tous les casques', 14.39436, 20, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PORT.EMB.MAG.', N'26', N'26FD', N'Porte embout magntique', 6.38, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PORT.ETIQ.AS100', N'26', N'26FD', N'Assortiment de 100 portes etiquettes de forme rectangulaire', 0.2691, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PORT.FACEF.6R', N'26', N'26FA', N'Porte douille 1/4 long.50mm', 10.12, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PORT.HERASM90', N'28', N'28MA', N'Portillon pour cloture mobile', 57.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PORT.MANTEAU2M', N'24', N'24FB', N'Porte manteaux  20 paterres longueur 2m', 134.85, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PORT.REST17018', N'33', N'33FA', N'Porte fusible standard', 2.432, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PORT.REST6833*', N'33', N'33FA', N'Porte fusible auto l''unite', 1.9925, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PORT.SAF11380', N'22', N'22FA', N'Diffuseur isolant pour poste semi', 11.9, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MEUL.SPHERIQ.', N'26', N'26FD', N'Meules spherique tige diametre 6mm', 0, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MEUL.STH52027507010', N'14', N'14FC', N'Meule 140x4.5x12', 12.54, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MEUL.STH52037507010', N'14', N'14FC', N'Meule 140x3.8x12', 11.72, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MEUL.STH52037507013', N'14', N'14FC', N'Meule 140x3.2x12', 5.1568, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MEUL.TIGE10X13', N'26', N'26FD', N'Meules cylindrique sur tige 10x13 gr46', 2.91, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MEUL.TIGE13X20OG', N'26', N'26FD', N'Meules cylindrique sur tige ogive 13x20 gr30', 0.345, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MEUL.TIGE20X25', N'26', N'26FD', N'Meules cylindrique sur tige 20x25', 4.83, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MEUL.TIGEPL10X50', N'26', N'26FD', N'Meules  plate sur tige 50x10', 0, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MEUL.TIGEPL40X10', N'26', N'26FD', N'Meules  plate sur tige 40x10 grain de 60', 4.754, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MICR.ONDE', N'22', N'22MF', N'micro onde', 98, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MINE_HB0.7', N'17', N'17FA', N'Mine pour porte mine HB0.7', 0.15, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MINI_GBIC1000-LX', N'31', N'31FA', N'Mini gbic SFP 1000base-lx compatible pour switsch HP 1310nm distance 20km', 120, 18, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MIRO.VOIRIE_600', N'28', N'28MA', N'Miroir de voirie systeme anti bue et systme antigel', 492, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MITI.', N'11', N'11FC', N'Mitigeur', 90.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MITI.DOUCHE', N'11', N'11FC', N'Mitigeur de douche', 79.05, 0, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MO_MAT.AGRI', N'14', N'14SC', N'Main d''oeuvre materiel agricole', 18.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MO_MATERIEL', N'22', N'22SB', N'Main d''oeuvre matriel', 150, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MODE.EG_GENPAC92C', N'20', N'20FB', N'Modem COMPACT WORLDLINE RTC DATAFAX RS232', 168, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MODI.SCHBMXNOE0110', N'12', N'12 FA', N'Module ethernet Modicon M340', 889.85, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MODI.SCHBMXNOE0110*', N'20', N'20MC', N'Modicon serveur Factorycast M340', 1144.09, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MODI.SCHTM221CE24T', N'12', N'12 FA', N'Modicon M221 contrleur 24E/S PNP Port Ethernet+serie 24VCC', 269.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MODU.ECHA411000050', N'14', N'14FC', N'Module', 85.18401, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MODU.G/V5T', N'17', N'17FC', N'module de rangement 5 tiroirs  gris vert H26xL30xP37.5 cm', 79.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MODU.GOT01020', N'12', N'12 FA', N'Module VM206', 39.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MODU.HERM300', N'28', N'28MA', N'Cloture de chantier 3.47x200 - 15 kilos', 36.25, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MODU.IDE_MGKLX2', N'21', N'21MA', N'Module SFP LX 1000MB/S NONOMODE  1310NM A', 397, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MODU.PHO.FLSFPLX', N'20', N'20FB', N'Module entree/sortie pour FO en fibre de verre avec une long.d''onde de 1300mm', 145.1993, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MODU.SCHA9A26946', N'12', N'12MB', N'Module d''arret d''urgence IMX + OF', 48.78, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MODU.SCHABL8PRP24100', N'12', N'12 FA', N'phaseo module de protection electronique 28..28.8', 104.495, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MODU.SCHBMXDDO3202K', N'12', N'12MB', N'X80 32S TOR TR 24VDC 0.1A', 363.74, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MODU.SCHBMXP342000', N'12', N'12 FA', N'Module de processeur pour automate M340', 678.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MODU.SCHBMXP342020', N'12', N'12 FA', N'Module d''expension automate processeur 1 024 (E/S discrete) 256 (analogique) entre', 859.42, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MONT.ROUL', N'26', N'26MA', N'Monture rouleau bois largeur 180mm', 2.515, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MONT.SCIE_MET.', N'26', N'26MA', N'monture de scie a metaux', 18.82, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MOP_PRESTO', N'24', N'24FB', N'Mop presto', 1.95, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MORT.CH330', N'05', N'05FI', N'Mortier chimique 330ml', 14.05, 26, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MORT.SAKVKT30KGS', N'05', N'05FI', N'Mortier parement', 9.99, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MORT.WEBREPEXPRESS', N'05', N'05FA', N'Mortier de reparation rapide fibr en sac de 25 kgs', 46.06, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MORT.WEBVM216', N'05', N'05FI', N'Mortier d''etanheite 25kgs palette de 48 sacs', 19.71, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MOTE.2.2KW1450TR/MIN', N'22', N'22FA', N'Moteur electrique 2.2kw 1450 tr/min', 610, 0, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MOTE.4KW1450TR/MIN', N'22', N'22FA', N'Moteur electrique 4kw 1450 tr/min', 470, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MOTE.AUMZ011.892', N'22', N'22MA', N'Moteur AD00-063-2/80 75KW 400V 50HZ CI.F', 545, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MOTE.GAL104', N'11', N'11FC', N'Moteur 220V 0,25KW B3 1500tr/mn pour pompe a eau gallia 104', 214.26, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MOTE.MERF20MLH', NULL, NULL, N'Moteur de bateau 4 temps arbre long demarrage manuel', 2540.83, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MOUI.25', N'24', N'24FB', N'Mouilleur complet 25 cm pour vitre', 6.38, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MOUI.35', N'24', N'24FB', N'Mouilleur 35 cm pour vitre', 27.99, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MOUL.LEG030008', N'12', N'12 FA', N'Moulure 20 x 12.5 blanche AV S/cloison cent.', 1.33, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MOUS.100MM', N'26', N'26FD', N'Mousqueton 100x10mm AC ZI', 0.8036, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MOUS.60MM', N'26', N'26FD', N'Mousqueton 60x6mm AC ZI', 1.15, 1, 0, 0, 20)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MOUS.CANALISATION', N'24', N'24FA', N'Mousse expansive pour nettoyage des canalisations', 23.333, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MOUS.CLA7700039030', N'14', N'14FC', N'mousse d''tanchit', 56.87, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MOUS.PU500ML', N'05', N'05FI', N'Mousse PU  500ml', 6.484, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MOUS.PUPIST.', N'05', N'05FI', N'Mousse de montage pistolable 750ml', 8.03, 0, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MOYE.STA66070232R', N'14', N'14FC', N'Moyeu de lame de tondeuse', 18.37, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MVA_18-MBSPCT 1/2', N'22', N'22FA', N'mva_18-mbspct 1/2', 20.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NETT.BACT1L', N'24', N'24FB', N'Nettoyant bactericide virucide et fongicide pour bac d''carissage spectre N5', 14.7, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NETT.CHLORE', N'24', N'24FB', N'Nettoyant surface chlor', 10, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NETT.DALLE', N'24', N'24FB', N'Nettoyant dalles', 23.95, 15, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NETT.DIM18240HE', N'24', N'24MA', N'nettoyeur eau froide 240 bars debit 1100L/min moteur 13CV Honda', 3429, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NETT.INJ.DIES', N'05', N'05FI', N'Nettoyant injecteur diesel 300ml', 29.83, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NETT.INJ.ESS', N'05', N'05FI', N'Nettoyant injecteur essence 300ml', 29.83, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NETT.KAR.TRACER550', N'24', N'24MA', N'Nettoyeur a vapeur pour sol exterieur', 110.83, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NETT.MORT.CBC', N'05', N'05FI', N'Nettoyant ciment beton calcaire fut de 30 litre', 107, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NETT.MORTIER', N'05', N'05FI', N'Nettoyant mortier', 18.76, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NETT.SOL_ET_SURF.', N'24', N'24FB', N'Nettoyant sol et surface', 29.51, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NETT.SOLBIO1L', N'24', N'24FB', N'Nettoyant sol ecologique en bidon doseur', 6.539999, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NETT.SURFACE', N'24', N'24FB', N'Nettoyant surface desinfectant detartrant', 15.2, 33, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NETT.TC A4', N'24', N'24FB', N'Nettoyant ultrason tec clean 2.5 litres', 62.4, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NEZ_ROB15/21', N'11', N'11FC', N'Nez de robinet 15/21', 1.025, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NEZ_ROB15/21L', N'11', N'11FC', N'Nez de robinet 15/21 laiton', 2.39, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NEZ_ROB20/27', N'11', N'11FC', N'Nez de robinet 20/27', 6.9, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NEZ_ROB20/27L', N'11', N'11FC', N'Nez de robinet 20/27 laiton', 4.84, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NEZ_ROB26/34L', N'26', N'26FD', N'Nez de robinet 26/34 laiton', 3.94, 0, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NICH.SIMPLE', N'14', N'14FA', N'Nichoir pour hirondelles', 20, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NICH.TRIPLE', N'14', N'14FA', N'Nichoir pour hirondelles x 3', 60, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NIPP.L25-1"', N'26', N'26FD', N'Nipple conique laiton nickel L25 - 1"', 7.6, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NIPP.LN20-1"', N'22', N'22FA', N'Niple conique laiton 20 mm / 1"', 6.75, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NITR.1400X10MEP.2MM', N'26', N'26FD', N'Feuille de caoutchouc nitrile 1400x10M ep.2mmm', 302, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NITR.1400X10MEP.4MM', N'26', N'26FD', N'Feuille de caoutchouc nitrile 1400x10M ep.4mmm', 446, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NIVE.RECT60', N'21', N'21MA', N'Niveau rectangulaire 60cm', 28.16, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NIVE.RECT80', N'21', N'21MA', N'Niveau rectangulaire 80cm', 37.51, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NIVE.TUB100CMAG.', N'21', N'21MA', N'Niveau tubulaire magnetique de 100cm', 77.92, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'NIVE.TUB40CMAG.', N'21', N'21MA', N'Niveau tubulaire magnetique de 40cm', 55.33, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'OBTU.DN27/30MM', N'26', N'26FD', N'Obturateurs pour trous dn 27mm  30mm noir', 0.65, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'OBTU.VKA12L/S', N'14', N'14FC', N'Obturateur hydraulique nu', 1.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'OEIL.DEX26205022', N'12', N'12 FA', N'Oeillets noir verticaux 80x60mm', 8.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'OEIL.DEX26205023', N'12', N'12 FA', N'Oeillets noir verticaux 40x80mm', 11.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'OEIL.DEX26205024', N'12', N'12 FA', N'Oeillets noir verticaux 80x80mm', 11.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ONDU.S2SMSRT3000', N'20', N'20MC', N'Onduleurs S2S SYRIUS msrt 3000 pro + LCD 4U + carte ethernet', 1180, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ONDU.S2SSRS1000', N'20', N'20MC', N'Onduleurs S2S SYRIUS SRS 1000 + pack batterie + carte ethernet SNMP WEB', 1222.16, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'OREI.DN12', N'26', N'26FD', N'Oreille  visser DN12mm finition bronze', 25.14, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'OUTI.A_DEGFAC.872271', N'26', N'26MA', N'Outil a degainer multifonction', 25.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'OUTI.AUMZ007.735', N'26', N'26MA', N'Pochette d''outils AUMA', 55, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'OUTI.DREMEL', N'26', N'26FA', N'Lot de 3 pointes carbure pour outil de gravure', 18.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'OUTI.FAC985962', N'26', N'26MA', N'outil a degainer', 18.1, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'OXYG.10.5M3', N'11', N'11FB', N'Oxygene standard 10,5m3', 86, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'OXYG.4.2M3', N'11', N'11FB', N'Oxygene standard 4,2m3', 67.5, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PACK_BOS1600A01C4K', N'22', N'22FA', N'Pack 2 batteries + chargeur 18V 8AH', 291.61, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAGA.2.1M', N'33', N'33FD', N'Pagaie long.2.10m et poigne de 35mm', 58.25, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PALE.PLAST. CL', N'26', N'26FD', N'Palette plastique charge lourde 1200x800x150 nid d''abeille bord anti glisse 1500kgs', 276, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PALE.TYPE_F', N'05', N'05FA', N'Palette de consignation non rendu', 19.52, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PALI.59.6EP25', N'22', N'22FA', N'Palier en diametre 59.6 ep 25mm en nofrix pour guidage tige de verin', 28, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PALI.STH41387403200', N'14', N'14FC', N'Palier / HT75', 51.2468, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANC.KM9_700X200', N'28', N'28MA', N'Pannonceau M9 700x200 + deco "fauchage cycliste mettre pied  terre"', 35, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANC.KM9_700X200CL2', N'28', N'28MA', N'Pannonceau KM9 700x200 classe 2', 72, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANC.M8F350X150CL1', N'28', N'28MA', N'Pannoneau M8F 350xx150 CL1', 35, 0, 0, 0, 10)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANN."AC.INT.ECH"', N'26', N'26FD', N'Panneau "acces a l''echaffaudage interdit au publi"', 6.75, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANN."CASQ.OBLIG"', N'26', N'26FD', N'Panneau "casque obligatoire" plastique', 5.82, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANN."CHANT.INT"', N'28', N'28MA', N'Panneau "chantier interdit au public" plastique', 9.750306, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANN."DEF.DE_FUMER"', N'28', N'28MA', N'Panneau rigide defense de fumer', 23.97814, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANN."DEF.FUM"', N'28', N'28MA', N'Panneau "defense de fumer" adhesif', 5.3256, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANN."INT.STAT"200', N'28', N'28MA', N'Panneau "stationnement interdit" adhesif diametre 200mm', 3.43, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANN."LOGO"', N'28', N'28MA', N'Panneau PVC rigide suivant modle', 78, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANN."PK"', N'28', N'28MA', N'Panneau PK 500/500 fond blanc liser bleu logo VNF + PK sur film reflecto classe 1', 76, 0, 0, 0, 26)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANN.A14_500CL2', N'28', N'28MA', N'Paneau triangulaire LX3 500 type A14 classe 2 "danger" + support potence', 290, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANN.AK5_700CL2', N'28', N'28MA', N'Panneau AK5 chantier dimension 700 CL2 sur support mobile', 72.9, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANN.B6D_600CL2', N'28', N'28MA', N'Panneau B6d dn600mm CL2 interdiction de stationner et s''arrter', 78, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANN.B9A_450CL1', N'28', N'28MA', N'Panneau BA diametre 450 classe 1 acces interdit aux pietons', 86, 0, 0, 0, 10)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANN.C13A_500CL2', N'28', N'28MA', N'Paneau carr 500 type C13a classe 2 impasse"', 88.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANN.CYCL.PATERRE', N'28', N'28MA', N'Panneau magnetique 600x400 "cycliste mettez pied  terre" bords arrondis anti UV', 35, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANN.DEX258156', N'20', N'20MC', N'Panneau 1U 24 ports STP KEYSTONE avec support', 32, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANN.KC1_800/600CL2', N'28', N'28MA', N'Panneau KC1 dim.800x600 classe 2 avec support', 89.15, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANN.MDF19MM', N'05', N'05FJ', N'Panneau MDF 19 mm 2.80/2.07', 55.81, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANN.PAF10', N'05', N'05FA', N'Panneau grillage paf10 - 420/240 F5.5 20/20', 21.55, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANT.FOR.FIO_2XL', N'18', N'18MB', N'Pantalon de tronconnage taille 2XL', 152, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANT.FOR.ORE295453/M', N'18', N'18MB', N'Pantalon de tronconnage  Taille M Yukon', 76.42, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANT.FOR.ORE295453/XL', N'18', N'18MB', N'Pantalon de tronconnage taille XL  noir - orange yukon', 76.42, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANT.FOR.ORE295453L', N'18', N'18MB', N'Pantalon de tronconnage taille L  noir - orange', 76.42, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANT.FOR.STH60', N'18', N'18MB', N'Pantalon de tronconnage dynamic VENT taille 60', 128.33, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANT.PLUIE_3IG', N'18', N'18MB', N'Pantalon de pluie ignifug orange  + Souf', 27.822, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANT.STH00008886244', N'18', N'18MB', N'Pantalon de debroussaillage Taille XS', 84.08, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANT.STH00008886248', N'18', N'18MB', N'Pantalon de debroussaillage Taille S', 84.08, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PANT.STH00008886252', N'18', N'18MB', N'Pantalon de debroussaillage Taille M', 84.08, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAPI.A3BLANC', N'19', N'19FB', N'Papier a3 blanc 80g blancheur 169 CIE - opacit 95 % - epaisseur 110', 5.03, 14, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAPI.A3BLEU', N'19', N'19FB', N'Papier a3 bleu 80g', 8.368571, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAPI.A3BRIST', N'19', N'19FB', N'Bloc de 20 feuilles de papier a3 blanc bristol 29.7x42cm', 13.98, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAPI.A3IV160', N'19', N'19FB', N'Papier a3 ivoire 160 grammes', 10.19, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAPI.A3JAUNE', N'19', N'19FB', N'Papier a3 jaune canari 80g', 8.38, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAPI.A3V160', N'19', N'19FB', N'Papier a3 vert pale 160grammes', 9.7025, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAPI.A4BLANC', N'19', N'19FB', N'Papier A4 blanc ramette de 500 feuilles 80g', 3.97344, 158, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAPI.A4BLANC160G', N'19', N'19FB', N'Papier A4 blanc 160g lot de 250 feuilles', 4.483334, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAPI.A4BLEU', N'19', N'19FB', N'Papier A4 bleu 80g', 4.162407, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAPI.A4IV', N'19', N'19FB', N'Papier A4 ivoire 80 grammes', 4.68, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAPI.A4IV160', N'19', N'19FB', N'Papier A4 ivoire 160 grammes', 4.8, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAPI.A4JAUNE', N'19', N'19FB', N'Papier A4 jaune 80g', 4.178571, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAPI.A4SAUM', N'19', N'19FB', N'Papier A4 saumon 80g', 4.143333, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAPI.A4VERT', N'19', N'19FB', N'Papier A4 vert  rame de 250 feuilles 80g', 4.156667, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAPI.A4VG160', N'19', N'19FB', N'Papier A4 vert golf 160grammes rame de 250 feuilles', 4.8, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAPI.E/M_BLC1000', N'24', N'24FB', N'Papier essuie main blanc 1000 formats', 15.1217117, 266, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAPI.E/M_TORK', N'24', N'24FB', N'Papier essuie main blanc TORK', 2.312, 24, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAPI.TOIL380M', N'24', N'24FB', N'Bobine de papier toilette 380m dn 260 mandrin de 63mm', 5.241246, 109, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PASS.', N'24', N'24FB', N'Passoire plastique', 3.54, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PASS.DEXDPVPP1', N'20', N'20MC', N'Passe cordons 19 1U 5 anneaux 40x50 95.2620508', 16.3, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PASS.ECH69621206032', N'14', N'14FC', N'Passe fil porcelaine pour tte fil nylon', 4.801, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PASS.HAGSL1807507030', N'12', N'12 FA', N'Passage de plancher SL 17x75', 10.84, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAST.NET.WC', N'24', N'24FB', N'Pastille auto nettoyante pour WC', 22.3, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAST.URINOIR', N'24', N'24FB', N'Pastille urinoir', 11.74, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PATE_AMERICAINE', N'05', N'05FI', N'Rouleau de pate americaine noir 15mm x 30ml', 120.99, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PATE_HT1200', N'05', N'05FI', N'Pate HT 1200  pour filetage', 29.625, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PATI.ECH169920040431', N'14', N'14FC', N'Patin glisseur pour ECHO 4600', 13.72, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PATI.ECHA553000030', N'14', N'14FC', N'Patin', 20.65, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PATI.ESCAB.', N'26', N'26FD', N'Pour escabeau (la paire)', 8.37, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PATI.NOR102828', N'14', N'14FC', N'Patin d''usure', 28.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PATI.NOR102941', N'14', N'14FC', N'Patin pour dbrouss,LN1600', 93.13, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PATI.NOR14505700', N'14', N'14FC', N'Patin pour rotobroyeuse', 28.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PATT.LEG035802', N'12', N'12 FA', N'Patte de fixation murale', 11.27, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PATT.SCHENN48934', N'12', N'12 FA', N'Boite de 100 pattes cheville filete 8', 17.94, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PATT.VIS10_L316', N'26', N'26FD', N'Patte a vis M10x80 inox L316', 1.2, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PATT.VIS7X40', N'26', N'26FD', N'Patte a vis 7x40', 0.0986, 33, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PATT.VIS7X60', N'26', N'26FD', N'Patte a vis 7x60', 0.08, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PATT.VIS8X80BI', N'26', N'26FD', N'Patte a vis bichromate 8x80', 0.3405, 51, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAUM.GRIL100', N'26', N'26FD', N'Paumelles de grille R100mm', 12.71, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAUM.SOUD120', N'26', N'26FD', N'Paumelle a souder 120mm', 3.114893, 1, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAUM.SOUD60', N'26', N'26FD', N'Paumelle a souder 60mm', 1.17, 17, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAUM.SOUD80', N'26', N'26FD', N'Paumelle asouder 80mm', 1.341818, 16, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAVI.ALLEMAGNE', N'26', N'26FD', N'Pavillon Allemagne 100/150', 24, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAVI.EUROPE', N'26', N'26FD', N'Pavillon Europe 100/150 en toile nautique antivent 115g + couture de renfort sur le primetre', 39, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PAVI.FRANCE', N'26', N'26FD', N'Pavillon France 100/150  toile nautique antivent 115g + couture de renfort sur le primetre', 24, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PC_DEL_G7_17-7790_16GO', N'20', N'20MA', N'Pc iwindows 10 i7 turbo boost', 11500, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PC_DEL_G7_17-7790_8GO', N'20', N'20MA', N'Pc iwindows 10 i7 turbo boost', 1709.44, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEDA.YNY1278500000', N'33', N'33FC', N'Jeu de pedales pour mobylette dakota', 19.95, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'PEIN.ACCRGRIS', N'05', N'05FL', N'Peinture d''accrochage gris', 52.2, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_SAB.CARB230', N'26', N'26FD', N'Paquet de 5 lames de scie sabre carbure TCT torch long.230 ep.1.27mm ht 25mm', 79.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_SAB.MU150', N'26', N'26FD', N'Paquet de 5 lames de scie sabre BIM.MULTIUSAGE LG150', 7.14, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_SAB.PROG150', N'26', N'26FD', N'Lame de scie sabre PROGRESSOR LG150', 23.18, 23.18, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_SAB.PROG225', N'26', N'26FD', N'Lame de scie sabre PROGRESSOR LG225', 30.83, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_SAB.PROG300', N'26', N'26FD', N'Lame de scie sabre PROGRESSOR LG300', 38.46, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_SAB.SET12PCES', N'26', N'26FD', N'Paquet de 12 lames de scie sabre', 45.69, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MALE.ASTREINTE', N'17', N'17FC', N'Malette d''astreinte', 69, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MALE_ACO523303', N'11', N'11FC', N'Mle fixe Dia:16-1/2 ACOME Ref:523303', 2.22, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MAME.26/34-20/27', N'11', N'11FC', N'Mamelon MM reduit brut 26/34 - 20/27 8245 sachet de 2pieces altech', 60.01, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MAME.CONIQ1/2', N'11', N'11FC', N'Mamelon double hydraulique conique 1/2 pel-araigne', 4.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MAME.DM1/2 Z', N'11', N'11FC', N'Mamelon double M 1/2 air comprime', 2.85, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MAME.GAL.DM3/4', N'11', N'11FC', N'Mamelon double 3/4 galva', 1.35, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MAME.GCU.DM1/2', N'11', N'11FC', N'Mamelon GCU double 1/2 male', 1.3589, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MAME.GCU.DM3/4', N'11', N'11FC', N'Mamelon GCU double 3/4 male', 2.169, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MAME.GCU.DMR3/4-1/2', N'11', N'11FC', N'Mamelon double rduit male GCU 3/4-1/2', 1.33, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MAME.GCU.MF1/2-3/4', N'11', N'11FC', N'Mamelon rduit MF 1/2-3/4 GCU', 1.2432, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MAME.ZIN.F1/2', N'11', N'11FC', N'Mamelon cylindrique zingue F 1/2 air comprime', 3.01, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.180_12MM', N'26', N'26MA', N'Manchon a peindre 12mm pour surface crpis 180mm', 8.184, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.180CREPIS', N'26', N'26MA', N'Manchon a peindre pour surface crpis 180mm', 6.28, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.180LAQTEN', N'26', N'26MA', N'Manchon a laquer aspect tendu 180mm', 5.01, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.180MUR-PLAF', N'26', N'26MA', N'Manchon 180 antigoutte court mur et plafond', 8.14, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.70_12MM', N'26', N'26MA', N'Manchon peinture acrylique 70mm poil de 12mm', 1.808, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.ACO523348', N'11', N'11FC', N'Manchon 16x16 ACOME ref:523348', 2.0596, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.BC', N'24', N'24FB', N'Manche de balai de cantonnier diametre 28', 5.97, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.BECHE', N'26', N'26MA', N'Manche de bche en frene 1m', 4.84, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.BM', N'24', N'24FB', N'Manche balai menage bois', 4.18, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.BM.VIS', N'24', N'24FB', N'Manche balai intrieur bois embout vis', 3.383922, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.CAR88LG180', N'22', N'22FA', N'Manchon filet diam.100 carr de 88 longueur 180 filetat interieur 1cot M52x5.00 D et M52x5.00 G', 274.56, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_SAUT.BOIS_STRAT100', N'26', N'26FD', N'Lame de scie sauteuse bois long.100mm dos de lame avec dpouille conique double denture', 8.57, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_SAUT.BOIS100', N'26', N'26FD', N'Lame de scie sauteuse bois long.100mm', 3.096667, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_SAUT.BOIS105', N'26', N'26FD', N'Lame de scie sauteuse bois long.105mm', 4.32, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_SAUT.BOIS50', N'26', N'26FD', N'Lame de scie sauteuse bois 50mm', 2.43, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_SAUT.BOIS75', N'26', N'26FD', N'Lame de scie sauteuse bimet. HHS bois', 2.5815, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_SAUT.INV69', N'26', N'26FD', N'Lame de scie sauteuse inv.bois', 1.8, 0.5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_SAUT.MU105', N'26', N'26FD', N'Lame de scie sauteuse multi usage long.105mm', 4.106667, 15, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_SCIE_ EL.', N'26', N'26MA', N'lame de scie d''lagage 3092a super turbo cut TL27 Rf:', 16, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_SCIE_INVERSE', N'26', N'26FD', N'Jeu de 2 lames de scie inversees', 142.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_SCIE_METAUX', N'26', N'26MA', N'Lame de scie a metaux 24dts', 2.3, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_SCIE_PL.', N'26', N'26MA', N'Lame de scie  laguer pliable 3127A', 10.367, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_SCIE760', N'26', N'26MA', N'Lame de scie a buche longueur  760 mm', 2.5, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_SEG85BI-MATIRE', N'26', N'26FA', N'Lame segment bi-matiere 85', 27.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_SEG85BOIS-MET', N'26', N'26FA', N'Lame segment bois metal 85', 26.28, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_STA66070440R', N'14', N'14FC', N'Lame de tondeuse Staub', 15.18, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_STH44046823103', N'14', N'14FC', N'Lame pour meche de forage D120mm', 15.44, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_VIK63607609992', N'26', N'26MA', N'Lame de tondeuse', 0, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_VOLET', N'05', N'05MA', N'Lame de volets', 4.83, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_WOLPROTZ51', N'14', N'14FC', N'Lame de tondeuse WOLF pro 51 cm', 34.715, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAMP.2X18W_LED', N'05', N'05MA', N'Lampe non tanche 1,2ml 2x18 watts  leds', 58, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAMP.2X36W', N'05', N'05MA', N'Lampe non tanche 1,2ml 2x36 watts IP66 corps polyester renforc fibre de verre', 36, 0, 0, 0, 6)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAMP.39WLED', N'05', N'05MA', N'Lampe LED tanche 1,2ml 39W /4000K IP6', 50, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAMP.A_SOUDER', N'26', N'26FD', N'Lampe a souder allumage autoavec cartouche', 45.55, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAMP.CUR18438355', N'12', N'12 FA', N'Lampe a leds pour tirette de bassine (autorisation de bassine - arrt de bassine)', 54, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAMP.F_PETNAO+', N'12', N'12 FA', N'lampe frontale nao+ rechargeable et connect 750LM', 147.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAMP.LED30W_G1', N'12', N'12 FA', N'Lampe tungstene 30W MARINER 840S', 49, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAMP.LEDSF', N'12', N'12 FA', N'Lampe d''inspection a leds sans fil + chargeur', 89, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAMP.LEDSF3W', N'12', N'12 FA', N'Lampe d''inspection a leds sans fil + chargeur 3W 7.4V 280mm', 95.38126, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAMP.LEDSFM', N'12', N'12 FA', N'Lampe d''inspection a leds sans fil  magntique et articul + chargeur', 129.14, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAMP.LEDSTYLO', N'12', N'12 FA', N'Lampe stylo rechargeable a base aimant 15+3 leds', 72.77778, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAMP.PHI386474', N'12', N'12 FA', N'Lampe leds 34S/840 W60L60 UGR19', 42, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAMP.POSTE_TRAVAIL', N'12', N'12 FA', N'Lampe  diode pour poste de travail  6W haut:6000mm dport 670mm 394 lumens', 60.84, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAMP.RA3LED', N'12', N'12 FA', N'Lampe ronde aimant  3 leds', 12.18, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAMP.SANE.SWL120', N'12', N'12 FA', N'Lampe a leds pour tirette de bassine (autorisation de bassine - arrt de bassine)', 182, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LANC.DIMLT40090006', N'22', N'22FA', N'Lance turbo nettoyeur HP 900mm ( buse 06)', 225, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LANC.FLAMME', N'26', N'26FD', N'Lance flamme dard', 46.2732, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LANT.POMPE250/110/453', N'22', N'22FA', N'Lanterne support de pompe 250/110/453', 450, 0, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LASU.CD5', N'05', N'05FL', N'Lasure chene dore WOODLINE THIXO SAT BASE BY/GAJ', 119.946, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LASU.IG3', N'05', N'05FL', N'Lasure gel incolore 3 litres', 78.23334, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LASU.IG5', N'05', N'05FL', N'Lasure gel satin  incolore interieur', 78.892, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LASU.VCG5', N'05', N'05FL', N'Lasure Satizol 500-Liswood gel satin chro SJ vieux chene', 62.75, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LATT.TOIT3ML', N'05', N'05FA', N'Latte de toiture traites 3ml', 0.42, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAVE_GLACE2LH', N'05', N'05FI', N'Lave glace hiver 2l', 4.40724134, 29, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAVE_GLACE5LH', N'05', N'05FI', N'Lave glace detergent demoustiqueur 5l     -20', 6.44, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAVE_PONT_CH.', N'24', N'24FB', N'Balai brosse chiendent (lave pont)', 15.75, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAVE_PONT_NYL', N'24', N'24FB', N'Lave pont nylon', 15.51, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAVE_PONT_NYL.', N'24', N'24FB', N'Balai brosse (lave pont) nylon avec manche', 31.08333, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAVE_PT_MET.', N'26', N'26MA', N'Brosse mtallique lave-pont/manche', 2.744, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LECT.DEL_DW316', N'20', N'20FB', N'Lecteur DVD USB DELL', 45, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LECT.DVD', N'20', N'20MC', N'Lecteur DVD noir Externe USB 2.0 150x142x13.2mm', 57.44, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LECT.HAM39878', N'20', N'20FB', N'Lecteur multi cartes externe USB 3.0', 36, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LED_MUR3124049', N'12', N'12 FA', N'Leds jaune + VDR 230 U 3124049', 11.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LEVI.1', N'33', N'33FC', N'NY1H39120000 MOBYLETTE DAKOTA', 2.341, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LEVI.130CM', N'26', N'26MA', N'Levier d''abattage 130 cm', 55.83, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LEVI.2', N'33', N'33FC', N'NY1H39220000 MOBYLETTE DAKOTA', 2.341, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LEVI.ECHA235000060', N'14', N'14FC', N'Levier pour dbroussailleuse SRM 5000', 3.168, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LEVI.EUT27200', N'14', N'14FC', N'Levier variateur levier ATTILA', 38.17, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LEVI.SCHZC2JY31', N'12', N'12 FA', N'Levier a galet', 9.811, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LEVI.STH11251215000', N'14', N'14FC', N'Levier d''admission 020 STIHL', 4.24536371, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LEVI.STH11281605000', N'14', N'14FC', N'Levier d''admission MS200 STIHL', 11.25, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LEVI.STH12312303930', N'14', N'14FC', N'Levier de pointeau pour carburateur SRM 4600', 2.878, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LICE.CAMERA', N'20', N'20SG', N'Licence camera supplmentaire ebo serveur', 158, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LICE.IP_MIVOICE', N'20', N'20SG', N'Licence haut parleur Ecluses', 69, 0, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LICE.RTSK-97-900207', N'20', N'20SG', N'Pack de 2 licence VXCORE-NVR-H25 visu+enr ss disque dur', 1746, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LICE.RTSK-97-900208', N'20', N'20SG', N'Licence supplmentaire (1 cam) pour visualisation et enregistrement', 64.02, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LICE.RTSK-97-900210', N'20', N'20SG', N'Software licence  camra + viewer + mobile VXCORENVR', 0, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LICE.SCHFSACSAUCDGUTYS', N'20', N'20SG', N'Licence evol unity S 1 poste vers 3 postes avec abonnement', 707.26, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LICE.WINDOWS10PRO', N'20', N'20SG', N'Licence windows 10 pro', 190, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LIME 3,2MM', N'26', N'26MA', N'Lime de trononneuse dia:3,2mm', 1.26564, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LIME_04.8MM', N'26', N'26MA', N'lime de trononneuse dia:4,8mm  3/16', 1.240086, 4, 0, 0, 12)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LIME_04MM', N'26', N'26MA', N'Lime de trononneuse dia:4mm', 1.78202176, 13, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LIME_05.2MM', N'26', N'26MA', N'Lime de trononneuse Dia 5,2', 1.13, 0, 0, 0, 12)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LIME_05.5MM', N'26', N'26MA', N'Lime de trononneuse Dia 5,5 7/32', 1.354, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LIME_05MM', N'26', N'26MA', N'Lime de trononneuse dia:5,2mm 13/64', 1.1322, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LIME_4.5MM', N'26', N'26MA', N'Limes de tronconneuse DN 4,5mm', 2.37, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LIME_CAR.EFF125', N'26', N'26MA', N'Lime carre ffile 125 mm', 4.497, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LIME_FRAISE360', N'26', N'26MA', N'Lime fraiseuse 360mm', 13.416, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LIME_OR12211', N'26', N'26MA', N'Lime plate pour affutage chaine', 3.1336, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LIME_TIERS_PT100', N'26', N'26MA', N'Lime tiers point 100mm 0714 61 27', 5.36, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LIME_TRI.MD200', N'26', N'26MA', N'Lime triangulaire mi-douce 200mm', 12.1, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LIME_TRI.MD300', N'26', N'26MA', N'lime triangulaire 300mmm', 18.23, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LIMI.24VDC', N'22', N'22FA', N'Limiteur de pression VDC 24V', 420, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LING.100', N'24', N'24FB', N'Seau de 100 lingettes nettoyantes', 23.48953, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LING.15', N'24', N'24FB', N'Seau de 15 lingettes nettoyantes', 5.6, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LING.90', N'24', N'24FB', N'Seau de 90 lingettes nettoyantes', 26.1215668, 8, 0, 0, 18)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LING.DEGR.SOLV', N'24', N'24FB', N'Boite de lingettes degraissante solvant pour l''industrie', 38, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LING.DEPOUS', N'24', N'24FB', N'Boite de 20 lingettes DUSTER dpoussierante pour swiffer', 9.95, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LING.DEPOUS.SOL', N'24', N'24FB', N'Boite de 48 lingettes dpoussierante pour swiffer maxi xxl', 5.85, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LING.LUNET', N'18', N'18MB', N'Lingette nettoyant pour lunette', 9, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LING.WC', N'24', N'24FB', N'lingettes desinfectantes WC', 11.7248344, 52, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LIQU.FREIN_ESP', N'33', N'33FE', N'Liquide de frein', 7.2876, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LIQU.LR30_20L', N'14', N'14FD', N'Liquide lr -30 bleu', 75.523, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LIQU.LRD_5L', N'33', N'33FE', N'Liquide D VL', 16.2025, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LIQU.MOLY', N'05', N'05FI', N'Liquide moly', 12.7463, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LIQU.VAISSEL1L', N'24', N'24FB', N'Liquide vaisselle 1l', 4.33847237, 52, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LONG.SAR638201', N'12', N'12MB', N'Longeron SAREL STD HT2000 Rf:638201', 15.7785, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LONG.SAR63840', N'12', N'12MB', N'Longeron technique H2000 / 2 pieces', 24.47, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LONG.TRACT58582', N'18', N'18MB', N'Longe de securite stopfor km pour travaux d''l&gage', 148, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LOQU.4GK', N'26', N'26FD', N'Loqueteau magnetique 4 GK brun X 2', 1.12, 0, 0, 0, 5)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LOQU.ECH17801222130', N'14', N'14FC', N'Loquet pour dbroussailleuse 4600 ECHO', 2.57, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LOQU.ECH17809052632', N'14', N'14FC', N'Loquet pour debroussailleuse ECHO', 3.95, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LOT_MANC-BROS', N'26', N'26MA', N'Lot manchons et brosses pour peinture', 340, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LOUP.', N'17', N'17FC', N'Loupe', 1.66, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LOUP.RS162-5345', N'26', N'26FD', N'Loupe pour poste de travail montage sur bureau', 34.19, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LUMI.600X600LED', N'12', N'12 FA', N'Luminaire 600 X 600 led 3250 HF L840 597 40W', 40, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LUNE.BOL_VIPPSI', N'18', N'18MB', N'Lunette incolore VIPER', 9.06, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LUNE.DE PROTECT.', N'18', N'18MB', N'Lunette de protection mousse amovible avec bandeau elastique srable', 8.46, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LUNE.DIODE', N'18', N'18MB', N'Lunette incolore equipe de 2 diodes et piles au lithium fournies', 11.11, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LUNE.FUMEE', N'18', N'18MB', N'Lunette polycarbonate fumee', 10.6, 28, 0, 0, 10)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LUNE.JETABLE', N'18', N'18MB', N'Lunette "jetable" Visitor incolore', 1.68, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LUNE.SANBUE', N'18', N'18MB', N'Lunette incolore sanbu', 11.10342, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LUNE.SOUD.', N'18', N'18MB', N'Lunette masque teintee 5 + oculaire translucide', 8.985001, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LUNE.TEINT4', N'18', N'18MB', N'Lunette teintee 4 Tecnik irex', 12.09, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LUNE.TEINT6', N'18', N'18MB', N'Lunette teintee 6 Tecnik irex', 12.09, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LUNE.X1.5', N'18', N'18MB', N'Lunette de protection loupe 1.5', 16, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LUNE.X2', N'18', N'18MB', N'Lunette de protection loupe 2', 16, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LUNE.X2.5', N'18', N'18MB', N'Lunette de protection loupe 2.5', 13.12857, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MAIL.RAC.10.8', N'22', N'22MB', N'MAILLE DE raccordement 10.8 - cmu 3150kgs', 9.26, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MAIL.RAC.13.8', N'22', N'22MB', N'MAILLE DE raccordement 13.8 - cmu 5300kgs', 13.24, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MAIL.RAP.GO6MM', N'22', N'22FA', N'Maillon rapide Grande ouverture 6mm', 5.21, 22, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MAIL.RAP.ON3MM', N'22', N'22FA', N'Maillon rapide 3mm ouverture normale', 2.015, 20, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MAIL.RAP.ON6MM', N'22', N'22FA', N'Maillon rapide 6mm ouverture normale 151916', 0.947, 1, 0, 0, 10)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MAIL.RAP.ON8MM', N'22', N'22FA', N'Maillon rapide 8mm ON AC ZI', 0.6, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MAJO.SCHFSACSARCDVJD', N'20', N'20SG', N'Maj video DSGN 1 poste + abonnement', 152.1, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.CU12', N'11', N'11FC', N'Manchon cuivre DN 12', 0.18, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.CU14', N'11', N'11FC', N'Manchon cuivre DN 14 sachet de 2 pieces', 0.59, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.EP3730', N'11', N'11FC', N'lot de 2 manchons 100microns', 18.76, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.EPUISETTE1.8', N'24', N'24FB', N'Manche pour epuisette long.1.8m diametre 36mm', 15.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.FAUCIL', N'26', N'26MA', N'Manche de faucille en frene', 10.188, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.FRENE_HACHET', N'26', N'26MA', N'Manche de hachette', 4.85, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.FRENE450G', N'26', N'26MA', N'Manche de marteau frene 450/520gr', 2.698, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.GAL.F3/4', N'11', N'11FC', N'Manchon F galva 3/4', 0.68, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.HOUE', N'26', N'26MA', N'Manche de houe bois dur long.1100 55/28', 6.289524, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.J1.5', N'12', N'12 FA', N'Manchon de jonction avec derivation a gel 1.5', 30.38, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.J2.5', N'12', N'12 FA', N'Manchon de jonction avec derivation a gel 2.5', 13.63, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.LB200', N'26', N'26MA', N'Manche bois pour lime de 200mm', 1.6783, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.LB250', N'26', N'26MA', N'Manche bois pour lime de 250mm', 1.3936, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.LPA', N'24', N'24FB', N'Manche lave pont alu', 24.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.LPF', N'24', N'24FB', N'Manche lave pont fibre', 15.62, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.MCAD253161', N'12', N'12 FA', N'manchon RJ45 gris 5.5mm par 10 pieces', 2.1, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.MERLFIB', N'26', N'26MA', N'Manche de merling NOVAGRIP', 16.95667, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.NOR102592', N'14', N'14FC', N'Manchon de serrage pour LN 1600', 21.57, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.NOR103979', N'14', N'14FC', N'Manchon XL1600', 9.936667, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.PIO60/40', N'26', N'26MA', N'Manche de pioche 60/40 bois', 7.982, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.PIO60/40FIB', N'26', N'26MA', N'Manche de pioche 60/40 fibre', 24.24, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.PIO65/45', N'26', N'26MA', N'Manche de pioche oval 65/45 en bois', 4.3358, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.PVC100FF', N'05', N'05FA', N'Manchon PVC D100 FF avec bute', 2.795087, 21, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.PVC32FF', N'11', N'11FC', N'Manchon PVC de 32 FF', 0.5092, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.PVC50FF', N'11', N'11FC', N'Manchon PVC de 50 FF', 1.1586, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.PVC80FF', N'11', N'11FC', N'Manchon PVC de 80 FF', 4.91, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.RAT', N'26', N'26MA', N'Manche pour rateau', 5.7064, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.SAPIE40CM', N'26', N'26MA', N'Manche de sapie 40 cm', 6.78, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.STH8812100', N'26', N'26MA', N'Manche de hache HICKORY', 17.31, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.STH8812101', N'26', N'26MA', N'Manche de hache HICKORY 80cm', 25.52, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.STH8812102', N'26', N'26MA', N'Manche de hache HICKORY', 5.4, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.STH8812143', N'26', N'26MA', N'Manche de merlin HICKORY (pour merlin 30 x 50)', 15.8813, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.SWIFFER', N'24', N'24FB', N'manche de swiffer court', 10.25, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.TEL.1.5X2.75', N'24', N'24MA', N'manche telescopique 1.5x2.75 pour vehicules', 37.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.TRON.', N'18', N'18MB', N'Manchette de trononnage taille unique classe 1 resistance anti coupure 20m/s', 42.09, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.WOLZMA150', N'26', N'26MA', N'Manche  aluminium multistar', 15.4, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.WOLZMT1', N'26', N'26MA', N'Manche 1,75/2,8', 22.3747, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANC.WOLZMT2', N'26', N'26MA', N'Manche  - 2,25/3,8', 40.26, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANE.ECH1780100533', N'14', N'14FC', N'Manette gaz SRM4600', 2.5, 2, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANI.DRTE1.6TO', N'22', N'22MB', N'Manille droite galva cmu 1.6to dn20mm', 6.9, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANI.DRTE10', N'22', N'22FA', N'Manille droite AC GN 82101 10mm cmu.0.40', 1.603333, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANI.DRTE12', N'22', N'22FA', N'Manille droite AC GN 82101 12mm cmu 0.63', 2.783333, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANI.DRTE14', N'22', N'22FA', N'Manille droite AC GN 82101 14mm cmu 0.80', 3.1, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANI.DRTE16', N'22', N'22FA', N'Manille droite M16 cmu1.00', 2.48, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANI.DRTE18', N'22', N'22FA', N'Manille droite M18 cmu 1.25', 2.6, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANI.DRTE2.8TO', N'22', N'22MB', N'Manille droite galva cmu 2.8to', 8.62, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANI.DRTE2TO', N'22', N'22MB', N'Manille droite galva cmu 2to dn 22mm', 6.532, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANI.DRTE3.15TO', N'22', N'22MB', N'Manille droite galva cmu 3.15to', 11.86, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANI.DRTE6', N'22', N'22FA', N'Manille droite M6 cmu 0.16', 8.9, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANI.DRTE8', N'22', N'22FA', N'Manille droite AC GN 82101  cmu.25', 1.311667, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANI.KUHA5411236', N'14', N'14FC', N'Manille pour broyeur', 2.47, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANI.LYRE12MM', N'22', N'22FA', N'Manille lyre  12mm', 19.3, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANI.LYRE1T300', N'22', N'22FA', N'Manille lyre HR galva  cmu 1.3 tonne', 5, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANI.LYRE2T', N'22', N'22FA', N'Manille lyre galva 25mm cmu 2 tonne', 18.40714, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANI.LYRE2T6', N'22', N'22FA', N'Manille lyre 2t600 dn 28mm', 6, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANI.LYRE3/4', N'22', N'22FA', N'Manille lyre galva 20mm cmu', 6.19, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANI.NOR103066', N'14', N'14FC', N'Manille renforce', 2.26, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANI.NOR103067', N'14', N'14FC', N'Manille pour MAGISTRA', 2.256049, 58, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANI.NOR103068', N'14', N'14FC', N'Manille torse', 2.13, 49, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANI.NOR103071', N'14', N'14FC', N'Manille LN 1600', 3.35, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANI.PALP.CAP3T', N'22', N'22MB', N'Manille palplanche cap 3to', 104.3, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANI.PALPCAP5T', N'22', N'22MB', N'Manille palplanche cap 5to', 115, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MANO_0-10BG', N'21', N'21MA', N'Mano inox 0 - 10 bars vertical 1/4 dans bain de glycerine', 14.18, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MARQ.BLC', N'17', N'17FC', N'Marqueur blanc', 2.29, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MARQ.BLEU_MED', N'17', N'17FC', N'Marqueur bleu lyra medium 2-6mm', 2.09, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MARQ.JAUNE', N'17', N'17FC', N'Marqueur jaune en tube 3mm', 3.679545, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MARQ.MULTI_SURF.', N'17', N'17FC', N'Marqueur noir multi surface permanent pointe fine 1mm resistant  l''eau', 0.91, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MARQ.NOIR_PER.2.5', N'17', N'17FC', N'Marqueur noir permanent pointe ogive fine 2.5mm a base alcool', 0.49, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MARQ.NOIR_TAB1.9', N'17', N'17FC', N'Marqueur noir pour tableau ogive 1.9', 0.73, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MARQ.ROUG_PER.2.5', N'17', N'17FC', N'Marqueur rouge permanent pointe ogive fine 2.5mm a base alcool', 0.9374999, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MARQ.TAB.ASS', N'17', N'17FC', N'Pochette de marqueurs 4 couleurs pour tableau blanc', 2.57, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MART.COF.', N'26', N'26MA', N'marteau de coffreur manche fibre 700g', 25.13, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MART.FAC200H.28', N'26', N'26MA', N'Marteau mecanicien hicory type rivoir de 28mm', 7.43, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MART.FAC200H.32PB', N'26', N'26MA', N'Marteau mecanicien manche graphite type rivoir de 32mm', 9.54, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MART.FAC200H.36PB', N'26', N'26MA', N'Marteau mecanicien manche graphite type rivoir de 32mm', 11.79, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MART.MIL4933451430', N'22', N'22MD', N'Marteau perforateur 18V SDS+', 305.15, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MART.MUT000306', N'14', N'14FC', N'Marteau "M"', 22.63, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MART.PGBH18V-20', N'22', N'22MD', N'Marteau perforateur 18V-20 avec accu', 379, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MART.PGBH3-28-DFR', N'22', N'22MD', N'Marteau perforateur dn de percage 4  28mm beton-13mm acier - 3.1 joules 800W', 235.46, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MASQ.AP', N'18', N'18MB', N'MASQUE ANTI POUSSIERE JETABLE AVEC SOUPAPE', 5.6, 40, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MASQ.SIL1/2', N'18', N'18MB', N'1/2 masque nu reutilisable sans filtre', 22, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MASS.1,5ME', N'26', N'26MA', N'Massette 1,5kg manche ergonomique', 35.99, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MASS.4KGME', N'26', N'26MA', N'Masse couple avec manche fibre 4kgs', 40.48, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MASS.UNI15GR', N'33', N'33FA', N'Masse universelle zinc 15gr', 36, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MASS.UNI20GR', N'33', N'33FA', N'Masse universelle zinc 20gr', 37, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MASS.UNI40GR', N'33', N'33FA', N'Masse universelle zinc 40gr', 38.573, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MASS.UNI45GR', N'33', N'33FA', N'Masse universelle zinc 45gr', 43.028, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MASS.UNI50GR', N'33', N'33FA', N'Masse universelle zinc 50gr', 47.355, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MASS.UNI5GR', N'33', N'33FA', N'Masse universelle zinc 5gr', 0.28, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MAST.290DC', N'05', N'05FI', N'Mastic de calfatage mono composant noir en cartouche de 300 ml', 16.62636, 32, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MAST.ACRYL.BLC', N'05', N'05FI', N'Mastic acrylique blanc', 3.75857139, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MAST.COL.INST.BL', N'05', N'05FI', N'Cartouche de mastic colle instantan blanc', 7.55, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MAST.FIXALI', N'05', N'05FA', N'mastic colle d''tanchit appliquable en immersion agr contact alimentaire', 21.9178047, 16, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MAST.POLY.BLC', N'05', N'05FA', N'mastic polymer blanc', 23.04, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MAST.POLY.CRYST', N'05', N'05FA', N'mastic polymer crystal', 23.04, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECA.DCU', N'11', N'11FC', N'Mecanisme de chasse universel', 40.72, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC01', N'26', N'26FD', N'Meche AC HSS DN:1mm', 3.5, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC01.5', N'26', N'26FD', N'Meche AC HSS DN:1,5mm', 2.97, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC02', N'26', N'26FD', N'Meche AC HSS DN:2mm', 3.3, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC02.5', N'26', N'26FD', N'Meche acier HSS DN 2,5', 3.9508, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC03', N'26', N'26FD', N'Meche acier HSS 3', 1.692384, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC03.5', N'26', N'26FD', N'Meche acier HSS 3.5', 2.311645, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC04', N'26', N'26FD', N'Mche acier dia:4', 4.57, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC04.2', N'26', N'26FD', N'Meche acier dia:4,2', 3.7081, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC04.5', N'26', N'26FD', N'Meche acier dia:4,5', 3.38, 14, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC05', N'26', N'26FD', N'Mche cier dia:5', 1.26, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC05.5', N'26', N'26FD', N'Meche acier dia:5,5', 4.398334, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC06', N'26', N'26FD', N'Meche acier dia:6', 6.068282, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC06.5', N'26', N'26FD', N'Mche acier dia:6,5mm', 6.322293, 21, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC06.75', N'26', N'26FD', N'Mche acier dia:6.75mm', 2.11, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC07', N'26', N'26FD', N'Mche acier HSS 7mm', 4.62094, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC07.5', N'26', N'26FD', N'Meche HSS 7,5mm', 6.31075, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC08', N'26', N'26FD', N'Meche acier dia:8', 8.551963, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC08.5', N'26', N'26FD', N'Meche AC HSS DN:8,5mm', 7.385294, 17, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC09', N'26', N'26FD', N'Meche AC DN9mm', 7.309091, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC09.5', N'26', N'26FD', N'Meche AC HSS DN:9,5mm', 11.03333, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC10', N'26', N'26FD', N'Meche acier 10 HSS', 14.12423, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC10.5', N'26', N'26FD', N'Meche acier 10,5', 15.13875, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC11', N'26', N'26FD', N'Meche acier 11', 17.3575, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC11.5', N'26', N'26FD', N'Meche acier 11,5', 6.14, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC12', N'26', N'26FD', N'Meche acier 12', 6.693333, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC12.5', N'26', N'26FD', N'Meche acier 12,5 HSS', 20.9692, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC13', N'26', N'26FD', N'Meche acier 13', 12.74667, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC13.5', N'26', N'26FD', N'Meche acier 13,5', 22.9253, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC14', N'26', N'26FD', N'Meche acier de14 decolletee HSS', 38.1, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC14.5', N'26', N'26FD', N'Meche acier 14,5 decolletee', 18.55, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC15', N'26', N'26FD', N'Meche acier de15 decolletee', 25.4407, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC15.5', N'26', N'26FD', N'Meche acier de 15,5 decolletee', 3.1069, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC16', N'26', N'26FD', N'Meche acier de 16 decolletee', 45.67167, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC16C', N'26', N'26FD', N'Meche acier de 16 conique', 22.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC18C', N'26', N'26FD', N'Meche acier de 18 cone morse', 27.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC20C', N'26', N'26FD', N'Meche acier de 20 cone morse', 34.55, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AC22C', N'26', N'26FD', N'Meche acier de 22 cone morse', 41.74, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AF50MM', N'26', N'26FA', N'Meche a faonner bois 50mm', 29.6, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.AF55MM', N'26', N'26FA', N'Meche a faonner machine bois 55mm', 29.6, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'MECH.BOIS18/360', N'26', N'26FD', N'Meche bois de 18 queue de 11.1 long.utile 360mm long.totale 450mm', 24.79, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.5W40FAP', N'33', N'33FE', N'Fut de 60 litres d''huile labo FM FAP 5w40', 4.62, 19, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.5W40FAP-5', N'33', N'33FE', N'Bidon de 5 litres d''huile labo FM FAP 5w40', 18.45, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.75W/80-2', N'33', N'33FE', N'Huile GEAR SAE 75W/80W 2l', 14.29, 8, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.ASMC10W40', N'33', N'33FE', N'Huile AGRIFARM STOU MC 10W40', 5.6396, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.BIOECOHYDI3268-20', N'33', N'33FE', N'Huile hydraulique bio3268 eco bio fut de 20 litres', 6.5175, 80, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.BIOHYD46-205', N'33', N'33FE', N'Huile hydraulique bio eco label enviro hyd 46hvi esters saturs fut de 205 litres', 10.9, 205, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.BIOHYDI46-20', N'33', N'33FE', N'Huile hydraulique bio eco label enviro hyd 46hvi esters saturs fut de 20 litres', 71.83824, 26, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.CHAINBIO1', N'14', N'14FD', N'Huile chaine bio planto enviro tac 150', 10.367, 35, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.CHAINBIO5', N'14', N'14FD', N'Huile de chaine bio enviro TAC 150', 38.60327, 15, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.COF5', N'33', N'33FE', N'Huile de decoffrage 5l', 30.75, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.COUPE5L', N'33', N'33FE', N'Huile de coupe en bidon de 5 litres', 62.59, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.EMBASE1', N'33', N'33FE', N'Huile speciale embase', 13.3, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.MOBGEAR632-200L', N'33', N'33FE', N'Huile mobil gear 632 en fut de 200 litres', 580, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.MOUW80W90-5', N'33', N'33FE', N'Huile MOUWAN GEAR SAE 80W90', 45.87, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.MP100 -5', N'33', N'33FE', N'Huile MP100 materiel pneumatique 5l', 16.263, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.MP46-5', N'33', N'33FE', N'Huile MP46 materiel pneumatique 5l', 17.695, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.RINCIL5', N'33', N'33FE', N'Huile de rincage RINCIL 5l', 19.24, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.SEATEAM-5', N'33', N'33FE', N'Huile seateam IB ESSENCE 5L', 28.37, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.TC3_5W30-5L', N'33', N'33FE', N'Bidon de 5 litres TITAN GT PRO-C3 5W-30', 26.25, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.TCMAXX10W40-60', N'33', N'33FE', N'Fut de 60 litres d''huile TITAN CARGO MAXX 10 W 40', 4.4256, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.TCMC10W40', N'33', N'33FE', N'Bidon de 5l d''huile TITAN CARGO MC 10W40', 31.49714, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.TGLS90-5', N'33', N'33FE', N'Bidon de 5 litres d''huile TITAN GEAR LS90', 24.77, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.TRANSATF', N'33', N'33FE', N'Huile ATF transmatic', 10.63, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.TSP80W90-1', N'14', N'14FD', N'HuileTITAN SUPER GEAR  80W90 1l / carter noremat', 7.0836, 18, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.TT+15W40-20', N'33', N'33FE', N'Fut de 20 litres d''huile TITAN TRUCK PLUS 15W40 SD/L EU', 4.13, 20, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.TT+15W40-60', N'33', N'33FE', N'Fut de 60 litres d''huile TITAN TRUCK PLUS 15W40 SD/L EU', 4.0427947, 148, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.TUB-60', N'33', N'33FE', N'Huile TITAN  UTTO B multifonctionnelle pour transmissions et relevages hydrauliques', 3.547471, 120, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.TUUMC10W40-60', N'33', N'33FE', N'Fut de 60 litres d''huile lTITAN UNIC ULTRA MC 10W40 D/L EU', 4.108, 60, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HYDR.CLEANER', N'33', N'33FE', N'Hydraulique cleaner', 29.6, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HYST.ROS.STH-FH', N'12', N'12 FA', N' Hystrsis rglable 0,5 - 5 K (Chauffage/ventilation) -15  +45 C contact 1 NO (T) ou 1 NF coupure 16 A Rose LM STH-FH', 59, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INDI.AK9400U1', N'12', N'12MB', N'Indicateur numrique 1entree 4-20mA 1 sortie numrique RS 485 isole de l''entre', 279, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INFU.', N'01', N'01FB', N'Boite de sachets infusion', 6.65, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INJE.COMC-PA15WPOE', N'31', N'31MA', N'Injecteur POE simple port 15,4W POE avec cable d''alimentation KAB-C13-EU', 53, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INJE.PHOINJ1000-T', N'20', N'20FB', N'Injecteur PoE, 30W 2 connecteurs femelles RJ45 montage sur rail DIN plage de temperature etendue', 178.965, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INJE.SVHK-40-101700361', N'20', N'20FB', N'Injecteur HI PoE 60W PoE60W', 58.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INSE.MOUSSE', N'05', N'05FI', N'Insecticide pompier mousse', 22.69, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INSE.POMP.', N'05', N'05FI', N'Insecticide pompier', 16.37, 54, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INSE.PUNAISE', N'05', N'05FI', N'Insecticide laque rmanant pour punaise', 16.05, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INSE.VOLANT', N'05', N'05FI', N'Spray insecticide volant', 15.81, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INTE.A4_12ONG', N'17', N'17FC', N'Intercalaire en carte lustr  A4 12 onglets', 0.5535651, 17, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INTE.A4_6ONG', N'17', N'17FC', N'Intercalaire A4 6 onglets', 0.2861494, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INTE.A4_ALPHA.', N'17', N'17FC', N'Intercalaire A4 alphabetique 20 touches', 0.7106667, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INTE.APE647H/2K', N'33', N'33FB', N'Interrupteur on-off-on bipolaire, 5A @ 25V c.c.', 15.73, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INTE.BER013353', N'22', N'22FA', N'Inter bague / pompe a eau dn40 rouge moteur Bernar', 12.76, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INTE.ECH16340041030', N'14', N'14FC', N'Interrupteur ECHO 4600', 10.973, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INTE.HAG04505', N'12', N'12 FA', N'Inter crepusculaire compact evolue 16A', 86.65, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INTE.LEG008694', N'12', N'12 FA', N'Inter differentiel 30MA / 40A 3 phases + neutre ICC 6000A', 114, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INTE.LEG080601', N'12', N'12 FA', N'Interrupteur  va et vient fixation vis et griffes', 1.7144, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INTE.LEG67001', N'12', N'12 FA', N'Inter V et V 10AX blanc', 4.6235, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INTE.LEG69711', N'12', N'12 FA', N'Inter  V et V tanche gris saillie', 6.72, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INTE.LEG69715', N'12', N'12 FA', N'Inter double V et V gris saillie plexo complet', 13.63, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INTE.LEG69731', N'12', N'12 FA', N'Inter gris saillie plexo complet', 7.22, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INTE.MENS', N'17', N'17FC', N'Intercalaire mensuel A4 12 onglets janvier  decembre', 0.75, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INTE.PEPIC-KP2-2HB17-2V1D', N'20', N'20MC', N'Interface de contrle RFID', 956.56, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INTE.RS607-7781', N'14', N'14FC', N'Interrupteur a bascule vert etanche', 21.68, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INTE.SCHA9R11440', N'12', N'12 FA', N'Inter dif.4P 40A 30MA AC', 126.37, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INTE.SCHBN310-01Z', N'12', N'12 FA', N'Inter magntique', 33.9, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INTE.SCHBN310RZ-5', N'12', N'12 FA', N'Inter magntique bistable / automatisation cable de 5m', 39.28187, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INTE.SCHBN31-10RZ-5', N'12', N'12 FA', N'Inter magnetique BN31-10-RZ cble de 5M', 58.7, 0, 0, 0, 35)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INTE.SCHENN35021', N'12', N'12 FA', N'Inter tanche  V et V gris', 5.948689, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INTE.SCHENN35022', N'12', N'12 FA', N'Inter tanche double   V et V gris MUREVA', 11.38, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'INVE.LEG027510', N'12', N'12 FA', N'inverseur de phase', 36.08, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ISIF.105-32XM1"-1/4', N'11', N'11FC', N'Raccord isiflo type 105 32XM1"-1/4', 10.73, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ISOL.COM4B3', N'22', N'22FA', N'isolateur pour poste a souder', 0.8, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JAMB.SIP', N'18', N'18MB', N'Jambiere de debroussaillage', 77, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JANT.4J13', N'14', N'14FC', N'Jante 4J13 4/20 85x130x18.5 675kgs MET MEFRO', 33.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JANT.CLA6000149629', N'14', N'14FC', N'Jante de roue pour pales', 664.36, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JAUG.EUT27212', N'14', N'14FC', N'Jauge a huile Attila 27212', 23.155, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JAVE.2.6%', N'24', N'24FB', N'Eau de javel 2l 2.6%', 3.0564, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JERR.05LRGE', N'26', N'26FD', N'Jerrican plastique essence 5L rouge', 7.18, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JERR.20LRGE', N'26', N'26FD', N'Jerrican plastique rouge 20l', 13.85, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JERR.DBLE', N'26', N'26FD', N'Jerrican double', 35.17, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JERR.RAP6', N'26', N'26FD', N'Jerrican rapidon 6 plastique translucide 10l special petit materiel', 37.0656, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_AUMS1', N'22', N'22FA', N'Jeu d''etancheite petit', 7, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_AUMS2', N'22', N'22FA', N'Jeu d''etancheite large', 76, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_CLE_M', N'26', N'26MA', N'Jeu de cles male six pans compacte', 16.83, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_CLE_MIXTE6-19', N'26', N'26MA', N'Jeu de cle mixte 6-19 RECA', 60.58, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_CLE_ML', N'26', N'26MA', N'Jeu de cles male six pans longues', 18.7, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_FAC467B.JP12PB', N'26', N'26MA', N'Jeu de 12 cle mixte a cliquet en etui', 186.3, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_FAC467F.JP10', N'26', N'26MA', N'Jeu de 10 cles articulees mixte de 8  19', 154.22, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_FAC75.J12PB', N'26', N'26MA', N'Jeu de 12 cle a pipe debouche', 93.33, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_FAC89.JP8L', N'26', N'26MA', N'Jeu de cles torx coudes 10 a 45 longues', 17.46, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_FAC89SR.J7PB', N'26', N'26MA', N'Jeu de cles torx coudes 10 a 45 longues', 41.94, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_FACATP..J6PB', N'26', N'26MA', N'Jeu de 7 tournevis 3 ph + 5 plat', 28.3, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_FACCPE.A4', N'26', N'26MA', N'Jeu de 4 pinces  maintenance', 55.82, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_FACGJP.A4PB', N'26', N'26MA', N'Jeu de 4 pinces serie G', 59.67, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_FLUAC280', N'26', N'26MA', N'Jeu de sonde  pince crochet Surgrip', 36, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_FLUTL224', N'26', N'26MA', N'Jeu de cordon de mesure silic', 29.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_FLUTLAC220', N'26', N'26MA', N'Jeu de S a pinces croco surgrip', 53.3, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_FLUTLAC283', N'26', N'26MA', N'Jeu de sondes + pinces surgrip', 39.36, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_KNI002012', N'26', N'26MA', N'Jeu de 3 pinces electricien', 69, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_KRA3401-54', N'26', N'26MA', N'Jeu de 12 cle mixte a cliquet en etui', 132.72, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_KRA4161', N'26', N'26MA', N'Jeu de 8 tournevis fente/PZ ergokraft', 25.68, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_KRA4165', N'26', N'26MA', N'Jeu de 8 tournevis TX ergokraft', 30.88, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_TOURN.PH-PZ', N'26', N'26MA', N'Jeu de 10 tournevis philips et pozidrive', 45, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_TOURN.SL-PH', N'26', N'26MA', N'Jeu de tournevis VDE PH/SL ultra slim', 84.32, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_TOURN.TX', N'26', N'26MA', N'Jeu de 4 tournevis VDEultra slim', 51.05, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JEU_WER05073601001', N'26', N'26MA', N'Jeu de 2 tournevis PZH/ a fente  1 + 2 pour bornier', 23, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.', N'22', N'22FA', N'joint', 2.48, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.70X20X4750', N'22', N'22MA', N'Bande SBR  larg.70mm-p.20mm-lg.4750mm', 27.2743, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.A_LEVRE', N'22', N'22FA', N'Joint noir a levre pour raccord express air comprime', 0.7196, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.BELPA 1"', N'22', N'22FA', N'Joint BELPA 1" - 22 x 30 x 2', 0.801, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CAOUT20/27', N'11', N'11FC', N'Joint caoutchouc noir 20/27', 0.5, 70, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CLA0123040400', N'14', N'14FC', N'Joint', 1.55, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CLA6005010620', N'14', N'14FC', N'Joint de couvercle', 2.58, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CU06X10', N'33', N'33FA', N'Joint CU massif 6x10', 0.078, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CU06X15', N'33', N'33FA', N'Joint CU massif 6x15', 0.18, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CU08X14', N'33', N'33FA', N'Joint CU massif 8x14', 0.18, 14, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CU10X16', N'33', N'33FA', N'Joint CU massif 10x16', 0.1005, 117, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CU12X18', N'33', N'33FA', N'Joint CU massif 12x18', 0.18, 20, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CU13X18', N'33', N'33FA', N'Joint CU massif 13x18', 0.18, 38, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CU14X20', N'33', N'33FA', N'Joint cuivre', 0.3827, 70, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CU15X20', N'33', N'33FA', N'Joint cuivre 15X20', 0.192, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CU16.2X21.9X2', N'33', N'33FA', N'Joint cuivre 16,2x21,6x2 metaloplastique', 0.1872, 95, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CU16X22', N'33', N'33FA', N'Joint cuivre 16X22', 0.3827, 21, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CU17X22', N'33', N'33FA', N'Joint cuivre 17X22', 0.171, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CU18X22', N'33', N'33FA', N'Joint CU 18x22', 0.22, 20, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CU18X24', N'33', N'33FA', N'Joint CU 18x24', 0.192, 132, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CU18X24X2', N'33', N'33FA', N'Joint cuivre metaloplastique 18x24x2 -  MP7603/C', 0.34, 207, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CU20X26', N'33', N'33FA', N'Joint CU massif 20x26', 0.247, 44, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CU21X26', N'33', N'33FA', N'Joint CU massif 21x26', 0.247, 20, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CU21X28', N'33', N'33FA', N'Joint CU massif 21x28', 0.247, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CU22X27', N'33', N'33FA', N'Joint massif cuivre plat 22x27', 0.1886, 57, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CU22X29', N'33', N'33FA', N'Joint CU massif 22x29', 0.197, 41, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CU24X30', N'33', N'33FA', N'Joint CU massif 24x30', 0.267, 55, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CU26X32', N'33', N'33FA', N'Joint CU massif 26x32', 0.197, 32, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.CU30X36', N'33', N'33FA', N'Joint CU massif 30x36', 0.2, 15, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.ECH10101042231', N'14', N'14FC', N'Joint SRM 4600', 2.38, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.ECH12312424430', N'14', N'14FC', N'Joint', 0, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.ECH12312515030', N'14', N'14FC', N'Joint', 1.979, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.ECH12312540630', N'14', N'14FC', N'Joint pour RM5000', 7.8144, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.ECH12314003930', N'14', N'14FC', N'Joint debroussailleuse echo', 1.95, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.ECH12314005560', N'14', N'14FC', N'Joint pour ECHO RM 5000', 6.1864, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.ECH13001006231', N'14', N'14FC', N'Jt pour dbroussailleuse ECHO', 0.778, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.ECH13001022430', N'14', N'14FC', N'Joint carburateur ECHO SRM380', 0.44, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.ECH13001603932', N'14', N'14FC', N'Joint echo', 0.56, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.ECH13001606232', N'14', N'14FC', N'Joint SRM4600', 1.3992, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.ECH13001642231', N'14', N'14FC', N'Joint SRM 4600', 0.703, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.ECH13101621230', N'14', N'14FC', N'Joint ECHO caoutchouc bouchon essence', 1.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.ECH13101640030', N'14', N'14FC', N'Joint liege ECHO', 2.02, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.ECH90072000012', N'14', N'14FC', N'Joint torique pour RM 380', 0.9, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.ECHV100000040', N'14', N'14FC', N'Joint pour ECHO RM 5000', 2.42, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.ECHV103000070', N'14', N'14FC', N'Joint pour ECHO RM 5000', 1.108, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.ECHV104000210', N'14', N'14FC', N'Joint pour ECHO RM 5000', 12.56, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.EUT27254', N'14', N'14FC', N'Joint 27254 Attila AV95', 10.0677, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.EUT27838', N'14', N'14FC', N'Joint TORIQUE 45 ATTILA', 1.701, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.EUT27949', N'14', N'14FC', N'Joint spy ATTILA', 18.22, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.FAUF400', N'14', N'14FC', N'Pochette de joint  pour chargeur F400 verin 40-63', 80.06, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.KAR53631000', N'22', N'22FA', N'Joint d''tanchit HD 1050B', 1.22, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.KAR63624840', N'22', N'22FA', N'joint torique pour nettoyeur HD1050B', 3.76, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.KAR63626100', N'22', N'22FA', N'Jeu de 3 joints torique HD 1050B Karcher 6.362.610.0', 2.397, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.KAR63653300', N'22', N'22FA', N'Joint pour nettoyeur HP thermique HD1050', 6.47, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.KAR63653400', N'22', N'22FA', N'Joint a levre pour nettoyeur HP KARCHER HD650 electrique 14x22x5/7', 9.38, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.LOC1721267', N'05', N'05FI', N'Joint d''tancheite SI5660 gris 200ml', 26.25, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.LOM12130560', N'22', N'22FA', N'joint spi av. pour pompe genelec', 4.57, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.LOM44000720', N'22', N'22FA', N'joint d''admission d''echappement', 1.43, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.NOR102531', N'14', N'14FC', N'Joint a levre LN1600', 10.85, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.NOR102545', N'14', N'14FC', N'Joint torique LN1600', 4.13, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.NOR102596', N'14', N'14FC', N'Joint labyrinthe LN1600', 11.46667, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.NOR103890', N'14', N'14FC', N'Joint a levre Magistra', 5.133333, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.NOR103944', N'14', N'14FC', N'Joint', 0.69, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.NOR104041', N'14', N'14FC', N'Joint en U pour MAGISTRA', 13.3725, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.ORE49816', N'14', N'14FC', N'Pochette de joint pour carburateur ECHO et STIHL ORK10-WAT', 6.72, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.ORE49831', N'14', N'14FC', N'Pochette de joint pour carburateur ECHO et STIHL ORK20-WAT', 13.70533, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.PAPIER1000/1000/4MM', N'22', N'22FA', N'feuille de joint papier indechirable 1000x1000ep.4mm', 19.89, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.STH11201290900', N'14', N'14FC', N'Jeu de joint carbu 064', 3.2082, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.STH11231290901', N'14', N'14FC', N'Joint de membrane  020 STIHL', 1.8, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.STH11231290905', N'14', N'14FC', N'Joint 020 STIHL', 1.75, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.STH11291290900', N'14', N'14FC', N'Joint MS200 STIHL', 5.006934, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.STH96459457570', N'14', N'14FC', N'Joint', 2.14, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.TOR.NBR90SH', N'22', N'22FA', N'Joint torique NBR 90 SH 9x2', 0.67, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JOIN.UNIVERSEL', N'05', N'05FI', N'Joint universel 120grammes noir', 27.1, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JONC.AQU19L', N'11', N'11FC', N'Reparateur pour tuyau d''eau 19mm laiton', 9.24, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JONC.DBLE100/80', N'22', N'22FA', N'Jonction alu double demi raccord symetrique 100/80', 69.75, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JONC.HAG221795', N'12', N'12MB', N'Jonction pour plinthe SL20115 blanc PALOMA', 2.88, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JONC_ECH12316910630', N'14', N'14FC', N'Jonc pour debrousailleuse ECHO', 1.14, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JONC_ECH90070600010', N'14', N'14FC', N'Jonc de 10 ECHO 4600', 0.7, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JUGU.4 PTS', N'18', N'18MB', N'Jugulaire 4 points pour casque de chantier', 6.551216, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JUPE_BXT206', N'14', N'14FC', N'Jupe pour raccord hydraulique LN 1600', 2.84, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JUPE_BXT208', N'14', N'14FC', N'Jupe pour raccord hydraulique', 3.6, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'JUPE_SAT208', N'14', N'14FC', N'Jupe pour raccord hydraulique', 1.0274, 15, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'KIT_ACCES.TABLEAU', N'17', N'17FC', N'Kit accessoires tableau blanc', 26.12, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'KIT_ACCU+CHARG18V6.0AH', N'22', N'22FA', N'Kit 2 accu + chargeur 6Ah', 225.04, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'KIT_AXIUM', N'28', N'28MA', N'Kit de nettoyage pour bouchon moul', 40.95, 0, 0, 0, 13)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'KIT_BAHCO4', N'26', N'26MA', N'kit affutage bahco 4', 17.8904, 2, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'KIT_BAHCO4.8', N'26', N'26MA', N'kit affutage bahco 4.8', 17.8904, 1, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'KIT_BAHCO5.5', N'26', N'26MA', N'kit affutage bahco 5.5', 17.8904, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'KIT_BROUET.2BRAS', N'22', N'22FA', N'Kit brouette pour nettoyeur HP 2 bras', 145, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'KIT_DEX755273', N'20', N'20MC', N'Kit de visserie 50pces', 18.69, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'KIT_DIMBF34', N'22', N'22FA', N'Kit boitier filtre 5 pouces + cartouche filtrante 2xR3420', 123.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'KIT_ENIKEP0023', N'12', N'12 FA', N'Kit solaire autonome panneau solaire controleur de charge batterie plomb 12V', 227.69, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'KIT_FLUTOOLPAK', N'26', N'26FD', N'Kit tool pak pour accrocher le multimetre', 41, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'KIT_LOM3906438', N'22', N'22FA', N'Kit de reparation moteur Lombardini', 182, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'KIT_NETTOYAGE', N'24', N'24FA', N'Kit balai pulse + microfibre le produit', 107.225, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'KIT_NOR', N'22', N'22FA', N'Kit de joints  pour reparation verin d''orientation ref:100992', 79.98, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'KIT_NOR103461', N'14', N'14FC', N'Kit de reparation / MAGISTRA', 81.26, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'KIT_PHARMA10', N'23', N'23MA', N'Kit pour armoire a pharmacie 10 personnes', 65.44, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'KIT_RASANT', N'24', N'24FB', N'Systeme de lavage complet comprenant un seau et un balai a frange microfibre', 167.12, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'KIT_ROU_B43008', N'14', N'14FC', N'kit de 2 supports pour broyeur', 470, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'KIT_RS542-5426', N'26', N'26FD', N'Kit de vis crous et rondelles en nylon', 0.69, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'KIT_SPR6019', N'12', N'12 FA', N'Kit solaire 100W autonome panneau solaire controleur de charge batterie plomb 12V', 262, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'KLAX.CLOCHE12V', N'33', N'33FB', N'Klaxon cloche 12V  faible impusion VA 190034', 52, 0, 0, 0, 10)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'KLAX.WER14095050', N'33', N'33FB', N'Klaxon 12V', 67.09, 0, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAIN.DVPV120', N'05', N'05FA', N'Laine de verre pare vapeur 1.2 / m2 en rouleau', 5.88, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAIN.DVPV80', N'05', N'05FA', N'Laine de verre pare vapeur 9.000*1.200*80.0 en rouleau', 4.11, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FRAI.CBP6MM', N'26', N'26FA', N'Fraise cylindre bout plat queue de 6mm avec denture frontale', 15.77, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FRAI.MAK.PJ7000J', N'22', N'22MD', N'Fraiseuse  lamello 700W 2.5 kgs en coffret', 290, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FRAI.OGIV6MM', N'26', N'26FA', N'Fraise sur tige en carbure 6mm SKM forme M-OGIVE', 15.89, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FRAI.OGIV6MMPOINTU', N'26', N'26FA', N'Fraise sur tige en carbure 6mm SKM forme G-BOUT POINTU/OGIVE', 15.66, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FRAI_FONCT-FACT', N'33', N'33SA', N'frais fonctionnement, facturation', 4.57, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FRAISAGE', NULL, NULL, N'Fraisage de pieces', 2.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FREI.AXE_B10', N'26', N'26FD', N'Frein d''axe benzing dia,10 679910', 0.549, 49, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FREI.FIL.LOCT271', N'05', N'05FI', N'Frein filet fort flacon de 50ml', 36.66, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FREI.FIL.NORM', N'05', N'05FI', N'Frein filet normal loctite 243', 36.39, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FREI.REN7701207640', N'33', N'33FA', N'Collection de frein AR kangoo', 112.0049, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSE.ROU_B42742', N'14', N'14FC', N'Kit fusee pour rouleau palpeur', 390, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.1000V11A', N'21', N'21MA', N'Fusibles FLUKE 80 et 860 1000V 11A', 13.2, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.1000V440', N'21', N'21MA', N'Fusible Fluke 1000V440MA  pour serie 80 et 860', 7.199999, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.2BR.MAX.60A', N'33', N'33FA', N'Blister de 2 fusibles bleu 2 broches grand modele 60A', 4.95, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.2BR.MAX.ASS', N'33', N'33FA', N'Fusible 2 broches grand modele sachet asssortiment', 9.98, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.2BR10A', N'33', N'33FA', N'Fusible 2 broches 10A', 0.172, 20, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.2BR15A', N'33', N'33FA', N'Fusible 2 broches 15A', 0.2958, 17, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.2BR25A', N'33', N'33FA', N'Fusible 2 broches 25A', 0.3221, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.2BR2A', N'33', N'33FA', N'Fusible 2 broches 2A', 0.364, 40, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.2BR30A', N'33', N'33FA', N'Fusibles 2 broches 30A', 0.316, 27, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.2BR3A', N'33', N'33FA', N'Fusible 2 broches 3A', 0.172, 27, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.2BR5A', N'33', N'33FA', N'Fusible 2 broches 5A', 0.29, 21, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.2BR7.5A', N'33', N'33FA', N'Fusible 2 broches 7.5A', 0.4422, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.LEG013320', N'12', N'12 FA', N'Fusible GG 10x38 20A', 0.94, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.M2BR10A', N'33', N'33FA', N'Fusible mini 2 broches 10A', 0.28, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.M2BR15A', N'33', N'33FA', N'Fusible mini 2 broches 15A', 0.4602439, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.M2BR20A', N'33', N'33FA', N'Fusible mini 2 broches 20A', 0.28, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.M2BR30A', N'33', N'33FA', N'Fusible mini 2 broches 30A', 0.28, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.M2BR4A', N'33', N'33FA', N'Fusible mini 2 broches 4A', 0.28, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.M2BR5A', N'33', N'33FA', N'Fusible mini 2 broches 5A', 0.28, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.S15A', N'14', N'14FC', N'Fusible statite 15A', 0.1, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.S16A', N'14', N'14FC', N'Fusible statite 16A', 0.0457, 47, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.S25A', N'14', N'14FC', N'Fusible statite 25A', 0.0457, 16, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.S40A', N'14', N'14FC', N'Fusible statite 40A', 0.1, 16, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.S5A', N'14', N'14FC', N'Fusible statite  5A', 0.0457, 92, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.S8A', N'14', N'14FC', N'Fusible statite  8A', 0.0457, 33, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FUSI.VER5X20_15A', N'14', N'14FC', N'Fusible verre 5x20 15A T', 0.21, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GABI.1000/1000/1000', N'05', N'05FA', N'kit gabion 1000/1000/1000 a agrafes', 78.97, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GACH.ECH17801052130', N'14', N'14FC', N'Gachette accelerateur SRM 4000', 7.8936, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GACH.ELEC10/24V', N'26', N'26FD', N'Gache 118E SPE sans tetiere 10/24V', 96.65, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GACH.ELEC12V', N'26', N'26FD', N'Botier gache lectrique  impulsion 12V avec/TETIE', 64.62, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAFF.1.8M', N'33', N'33FD', N'Gaffe lgre 1.8m', 12.75, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAIN.12/10', N'22', N'22FA', N'Gaine guide fil 12/10 5ml 25x45', 14.483, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAIN.40TPC25M', N'05', N'05FA', N'Gaine+tirefil de 40', 13.75, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAIN.40VERTE', N'05', N'05FA', N'Gaine cariplast + tire fil de 40 verte', 0.55, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAIN.63TPC25M', N'05', N'05FA', N'Gaine rouge TPC DN63mm', 0.5285, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAIN.63VERT50M', N'05', N'05FA', N'Gaine annele verte  DN63mm', 1.08, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAIN.90BLEU50M', N'05', N'05FA', N'Gaine bleu DN90mm cour.de 50ml', 1.74, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAIN.90TPC25M', N'05', N'05FA', N'Gaine rouge DN90mm cour.de 25ml', 1.74, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAIN.ECH17812743230', N'14', N'14FC', N'Gaine', 4.36, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAIN.ECHC508000020', N'14', N'14FC', N'Gaine ECHO RM4000 pour axe flexible', 118.2456, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAIN.ICTA20', N'12', N'12MB', N'Gaine ICTA dia:20 100m', 28.4, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAIN.ICTA25', N'12', N'12 FA', N'Gaine ICTA dia:25 100m', 0.399, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAIN.NOR102256', N'14', N'14FC', N'Gaine flexible hydraulique', 14.29, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAIN.THER3M85815', N'12', N'12 FA', N'Gaine thermoretractable hsr-3000 3/1 HSR 3 rouleau de 10m', 31.355, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAIN.THER3M85824', N'12', N'12 FA', N'Gaine thermoretractable hsr-3000 6/2 HSR 6 rouleau de 10m', 39.52, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAIN.THER3M85833', N'12', N'12 FA', N'Gaine thermoretractable hsr-3000 9/3 HSR 9 rouleau de 7m', 32.7, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAIN.THER3M85833*', N'26', N'26FD', N'Gaine thermoretractable boit de lg 7m rtreint 9  3mm', 42.56, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAIN.THER3M85842', N'12', N'12 FA', N'Gaine thermoretractable hsr-3000 18/6  HSR 18 rouleau de 5m', 24.528, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAIN.THER3M85851', N'12', N'12 FA', N'Gaine thermoretractable hsr-3000 24 0/8.0MM   HSR 18 rouleau de 5m', 49.47, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAIN.THERBIZ217004', N'26', N'26FD', N'Gaine thermoretractable boit de lg 6m rtreint 12  4mm', 43.87521, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAIN.VELC120', N'14', N'14FC', N'Gaine textile velcro dn 120mm', 38.25, 15, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GALE.60', N'05', N'05FH', N'Galet de 60', 61.4, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GALE.BOB_TR10120700', N'22', N'22FA', N'Galet pour BOBCAT', 150.91, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_ACTIVGRIPT10', N'18', N'18MB', N'Gant de manutention antiglisse T10', 4.042553, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_ACTIVGRIPT9', N'18', N'18MB', N'Gant de manutention antiglisse', 3.84772, 24, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_FOREST.10', N'18', N'18MB', N'Gant de travail pour la manutention forestiere T10', 19.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_FOREST.9', N'18', N'18MB', N'Gant de travail pour la manutention forestiere T9', 24.1296, 0, 0, 0, 30)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_FOURRE10', N'18', N'18MB', N'Gant fourre fleur de bovin double molleton errage elastique T10', 5.2069, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_FOURRE11', N'18', N'18MB', N'Gant fourre fleur de bovin double molleton serrage elastique T11', 4.8, 22, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_FOURRE12', N'18', N'18MB', N'Gant fourre fleur de bovin double molleton serrage elastique T12', 4.8, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_FOURRE8', N'18', N'18MB', N'Gant fourre fleur de bovin double molleton serrage elastiqueT8', 4.9122, 18, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_GLADIA.10', N'18', N'18MB', N'Gant gladiator T10', 2.4, 43, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_GLADIA.7', N'18', N'18MB', N'Gant gladiator T7', 2.4, 42, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_GLADIA.9', N'18', N'18MB', N'Gant gladiator T9 latex', 2.4, 46, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_GRIPFRIZ9', N'18', N'18MB', N'Gant de protection thermique textile t9 risques courants', 6.65, 49, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_HYCR.10', N'18', N'18MB', N'gant hycron dos aere', 1.5, 51, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_HYCR.8', N'18', N'18MB', N'Gant hycron  dos aere', 1.5, 36, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_HYCR.9', N'18', N'18MB', N'gant hycron de manutention dos aere', 1.5, 32, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_HYDRO10', N'18', N'18MB', N'Gant cuir hydrofuge T10 elastique au dos es25', 7.120121, 30, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_HYDRO7', N'18', N'18MB', N'Gant cuir hydrofuge T7 elastique au dos es25', 6.9, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_HYDRO8', N'18', N'18MB', N'Gant cuir hydrofuge T8 elastique au dos es25', 7.162383, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_HYDRO9', N'18', N'18MB', N'Gant cuir hydrofuge T9 elastique au dos es25', 8.000329, 0, 0, 0, 50)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_HYFLEX10', N'18', N'18MB', N'gant ultra leger pour travaux demandant une sensibilitee', 2.53882337, 204, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_HYFLEX11', N'18', N'18MB', N'gant ultra leger pour travaux demandant une sensibilitee T11', 3.13861537, 48, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_HYFLEX9', N'18', N'18MB', N'gant ultra leger pour travaux demandant une sensibilitee', 2.55520225, 183, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_ISLANDT10', N'18', N'18MB', N'Gant pleine fleur de vachette entirement fourr T10 conditionn par 12', 20.25667, 17, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GEL_SIPHON1', N'24', N'24FB', N'gel pour entretien canalisation eaux uses', 14.88, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GEL_WC', N'24', N'24FB', N'Nettoyant et dtartrant pour cuvette de WC', 6.1, 24, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GENO.', N'18', N'18MB', N'Genouillre i-gel professionnel', 29.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GEOT.200G_5M', N'05', N'05FA', N'Geotextile 200g/m larg.5ML x100ml', 1.26, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GEOT.S51_3M', N'05', N'05FA', N'Geotextile BIDIM S51 3ML x180ml 200GRAMMES / M', 599.4, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GILE.SECALPHA150', N'18', N'18MB', N'Gilet de sauvetage alpha 150 -140 ENV', 269.1, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GILE.SECDV150', N'18', N'18MB', N'Gilet de sauvetage DV 150', 174, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GIRO. REN5010468860', N'14', N'14FC', N'Girophare orange 24V', 196.09, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GIRO. SOD17389', N'14', N'14FC', N'Girophare orange tournant bitension ampoule H1', 44.35, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GIRO.MAGLED', N'28', N'28MA', N'Feu rotatif magntique goutte d''eau tension 12V orange', 55.55, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GIRO.MAGNET*', N'28', N'28MA', N'feu rotatif kl7000 12v magnet. orange pour embase', 55.55, 0, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GNR_BF', N'33', N'33FF', N'GNR biofree qualit B0', 0.7747666, 1084.38, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOMM.', N'17', N'17FC', N'gomme', 0.1703333, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOND.HER', N'28', N'28MB', N'Gond pour barriere Heras', 10.4, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOND_RAV12', N'26', N'26FD', N'Gond rglable  visser finition bronze DN 12mm  h67mm H87mm', 22.95, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUJ.ENC10/60', N'26', N'26FD', N'Goujons d''encrage', 0.56, 44, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUJ.ENC16/30/145A4', N'26', N'26FD', N'Goujon d''encrage A4 16/30/145', 14.03, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUJ.ESSIEU14', N'14', N'14FC', N'Goujon d''essieu de 14mm', 3.3616, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUJ.RTN', N'14', N'14FC', N'Goujon RTN', 8.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUL.LEG075601', N'12', N'12MB', N'Goulotte 50x80 + couvercle', 15.88, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUL.LEG075602', N'12', N'12MB', N'Goulotte 50x105 + couvercle MOSAIC 1CV45 blanc 2M', 15.54, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_ISLANDT9', N'18', N'18MB', N'Gant pleine fleur de vachette entirement fourr T9 conditionn par 12', 20.385, 24, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_JERS.10', N'18', N'18MB', N'Gant jersette 300 bleu 10', 3.7875, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_JERS.8', N'18', N'18MB', N'Gant jersette 300 bleu 8', 2.7684, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_JERS.9', N'18', N'18MB', N'Gant jersette 300 bleu 9', 4.116106, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_MONOTHERM', N'18', N'18MB', N'Gant monotherm ambidextre tricot sans couture avec poigne tram latex', 1.9, 42, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_MT10', N'18', N'18MB', N'Gant de manutentions maxgrip grip taille 10', 2.89923072, 48, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_MT8', N'18', N'18MB', N'Gant de manutentions maxgrip grip taille 8', 6.36, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_MT9', N'18', N'18MB', N'Gant de manutentions maxgrip grip taille 9', 2.88375, 47, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_MTH10', N'18', N'18MB', N'Gant de manutentions maxitherm hivers taille 10', 2.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_NITRIL10', N'18', N'18MB', N'Gant jetable tout enduit nitrile noir T10 boite de 200 paires', 12, 13, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_NITRIL11', N'18', N'18MB', N'Gant jetable tout enduit nitrile noir T11 boite de 200 paires', 26, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_RIP.10', N'18', N'18MB', N'Gant ripeur T10 anti piquure pour debroussaillage', 13.8, 47, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_RIP.11', N'18', N'18MB', N'Gant ripeur T11 anti piquure pour debroussaillage', 13.2, 32, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_RIP.8', N'18', N'18MB', N'Gant ripeur T8 anti piquure pour debroussaillage', 13.2, 33, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_RIP.9', N'18', N'18MB', N'Gant ripeur T9 anti piquure pour debroussaillage', 13.6167, 19, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_SOLV.9', N'18', N'18MB', N'Gant solvant vert fonc', 1.53, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_SOUD.L', N'18', N'18MB', N'Gant soudeur  MIG CONFOFLEX renfort paume 413x4x2121', 4.67, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_TNT.8-9', N'18', N'18MB', N'Gant touchnnuff T7,5-8 nitrile vert 100 pces', 11.05148, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_TNT.9-10', N'18', N'18MB', N'Gant touchntuff T9/10', 10.58273, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_TRONC.L', N'18', N'18MB', N'Gants de trononnage L', 23.61708, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_TRONC.M', N'18', N'18MB', N'Gants de trononnage M', 23.32, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_TRONC.XL', N'18', N'18MB', N'Gants de trononnage XL', 23.59657, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_VIBRA.10', N'18', N'18MB', N'Gant vibraguard', 55.1, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_VIBRA.8', N'18', N'18MB', N'Gant vibraguard taille 8', 40.84, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_VIBRA.9', N'18', N'18MB', N'Gant vibraguard taille 9', 55.1, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GANT_WELLNIT9', N'18', N'18MB', N'Gant de manutention moyenne nitrile t9', 3.3569, 95, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GARN.CLA6005012706', N'14', N'14FC', N'Garniture fix.po./ PALES 5756TB62', 5.55, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GARN.CLA6005012707', N'14', N'14FC', N'Garniture fix.po./ PALES 5756TB62', 5.55, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GARN.CLA6005014215', N'14', N'14FC', N'Garniture feu AR D', 87.98, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GARN.CLA6005014216', N'14', N'14FC', N'Garniture feu AR G', 87.98, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GARN.CLA6005014217', N'14', N'14FC', N'Garniture feu AV D', 57.95, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GARN.CLA6005014218', N'14', N'14FC', N'Garniture feu AV G', 57.95, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GARN.P100', N'26', N'26FD', N'Garniture auto agrip poncage a sec gr 100', 0.464, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GARN.P120', N'26', N'26FD', N'Garniture auto agrip poncage a sec gr 120', 0.624, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GARN.P80', N'26', N'26FD', N'Garniture auto agrip poncage a sec gr 80', 0.624, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GARN.STH11281220100', N'14', N'14FC', N'Garniture cellulaire STIHL / 020', 0.49, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAZ_BUT.VRAC', N'11', N'11FA', N'Gaz en vrac pour citerne chauffage ateliers', 1880.3, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAZ_BUT13KGS', N'11', N'11FB', N'Bouteille de gaz butane', 31.44, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAZ_PROP13KGS', N'11', N'11FB', N'Bouteille de gaz propane', 31.44, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAZO.', N'33', N'33FF', N'Gazole', 1.211808, 436.89, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAZO.*', N'33', N'33FF', N'Gazole cuve rouge', 1.1695, 0.8999863, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GAZO.LUTZ', N'33', N'33FF', N'Gazole lutzelbourg', 1.21105242, 1193.11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GEL_ANTI-BRLURE', N'25', N'25FA', N'Sachet de gel anti brlure', 1.138385, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GEL_ANTISEP.100ML', N'25', N'25FA', N'gel desinfectant antiseptique pour les mains', 5.408475, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GEL_ANTISEP.350ML', N'25', N'25FA', N'gel desinfectant antiseptique pour les mains avec pompe', 12.55, 16, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GEL_CAP599990', N'05', N'05FI', N'Lubrifiant 1 litre', 6.54, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GEL_DOUCHE', N'24', N'24FB', N'gel douche', 5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GEL_JAVEL_WC', N'24', N'24FB', N'gel desinectant douche et wc', 5.42930937, 31, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUL.SICGPC35-35ALU', N'12', N'12 FA', N'Goulotte alu 35-35', 32.52, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUL.SICS2565012', N'12', N'12MB', N'Goulotte de protection corniere 30x30 en alu longueur 2.5ml', 17, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.1/2L10X45', N'26', N'26FD', N'Goupille 1/2 lune 10x45', 1.996, 23, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.1/2L10X50', N'26', N'26FD', N'Goupille 1/2 lune 10x50', 1.996, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.1/2L6X45', N'26', N'26FD', N'Goupille 1/2 lune 6x45', 1.895, 22, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.1/2L8X40', N'26', N'26FD', N'Goupille 1/2 lune 8x40', 1.895, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.BETA03', N'26', N'26FD', N'Goupille beta double spire 3mm', 0.81, 64, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.BETA04', N'26', N'26FD', N'Goupille Beta Type 3 double spire 4mm 047343', 1.0567, 14, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.BETA05', N'26', N'26FD', N'Goupille Beta type 3 double spire 5mm 047353', 1.448, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.BETA06', N'26', N'26FD', N'Goupille beta double spire 6mm', 2.46, 24, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.BETA07', N'26', N'26FD', N'Goupille beta double spire 7mm', 1.65, 22, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.BOB1B6560382', N'22', N'22FA', N'Goupille pour BOBCAT', 9.846, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.CJ10', N'22', N'22FA', N'Goupille pour marteau CJ10 - 6105553', 1.799, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.CLIP04.5', N'26', N'26FD', N'Goupilles clip 4.5', 0.24, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.CLIP07.5', N'26', N'26FD', N'Goupille de scurit clip 7,5mm', 3.81, 14, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.CLIP10.5', N'26', N'26FD', N'Goupille clip 10,5mm double securite', 3.72, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.CLIP6', N'26', N'26FD', N'Goupilles clip 6mmX45', 0.4438, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.CLIP9.5', N'26', N'26FD', N'Goupille clip 9,5mm', 3.959475, 13, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.EL10X30', N'26', N'26FD', N'Goupille elastique 10x30', 0.191, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.EL10X40', N'26', N'26FD', N'Goupille elastique 10x40', 0.1899, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.EL10X50', N'26', N'26FD', N'Goupille elastique 10x50', 0.2712, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.EL10X60', N'26', N'26FD', N'Goupille elastique 10x60', 0.3249, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.EL10X80', N'26', N'26FD', N'Goupille elastique 10x80', 0.4556, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.EL12X50', N'26', N'26FD', N'Goupille elastique 12x50', 0.837, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.EL12X60', N'26', N'26FD', N'Goupille elastique 12x60', 0.9051, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.EL12X80', N'26', N'26FD', N'Goupille elastique 12x80', 1.0637, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.EL6X80', N'26', N'26FD', N'Goupille elastique 6x80', 0.2289, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.EL8X30', N'26', N'26FD', N'Goupille elastique 8x30', 0.1416, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.EL8X40', N'26', N'26FD', N'Goupille elastique 8x40', 0.1515, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.EL8X50', N'26', N'26FD', N'Goupille elastique 8x50', 0.1789, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.EL8X60', N'26', N'26FD', N'Goupille elastique 8x60', 0.2272, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.EL8X80', N'26', N'26FD', N'Goupille elastique 8x80', 0.3765, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.EUT27327', N'26', N'26FD', N'Goupille 3x25 pour corps de lame', 0.1799, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.F2,5X50', N'26', N'26FD', N'Goupille fendue 2,5x50', 0.05, 400, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.F2.8X25', N'26', N'26FD', N'Goupille fendue 2,8x25', 0.05, 500, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.F2.9X35', N'26', N'26FD', N'Goupille fendue 2,9x35', 0.05, 400, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.F2X50', N'26', N'26FD', N'Goupille fendue  AC ZI', 0.03, 307, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.F3.5X60', N'26', N'26FD', N'Goupille fendue 3.5x60', 0.05, 200, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.F4.2X50', N'26', N'26FD', N'Goupille fendu 4.2x50', 0.2, 200, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.F4X40', N'26', N'26FD', N'Goupille fendu 4x40', 0.2, 385, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.F4X80', N'26', N'26FD', N'Goupille fendu 4x80', 0.2, 200, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.F5.8X60', N'26', N'26FD', N'Goupille fendu 5.8x60', 0.2, 48, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.F5X80', N'26', N'26FD', N'Goupille fendu 5x80', 0.0664, 250, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.F6,3X 80', N'26', N'26FD', N'Goupille fendue 6.3x80 AC ZI', 0.0861, 38, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.F6,3X100', N'26', N'26FD', N'Goupille fendue 6.3x100 AC ZI', 0.1101, 95, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.F8X100', N'26', N'26FD', N'Goupille fendue 8x100 AC ZI', 0.71, 20, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.F8X63', N'26', N'26FD', N'Goupille fendue 8x63 AC ZI', 0.2, 22, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.KUB0123279', N'14', N'14FC', N'Goupille de maillon inf.', 9.96, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.STH93785432640', N'14', N'14FC', N'Goupille pour MS200', 0.52, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUP.STH93785432700', N'14', N'14FC', N'Goupille pour MS200', 0.4576, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GOUT.PVC60', N'05', N'05MA', N'Gouttire PVC de 60  4ml', 7.27, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GPS_TOM_VIA52', N'21', N'21MA', N'GPS XL LIVE EUROPE 52 PAYS', 171.35, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.10X125H1', N'14', N'14FC', N'Graisseur droit H1 10x125', 0.54, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.10X150H1', N'14', N'14FC', N'Graisseur droit H1 10x150', 0.4478082, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.10X150H2', N'14', N'14FC', N'Graisseur droit H2 10x150', 0.31, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.10X150H3', N'14', N'14FC', N'Graisseur droit H3 10x150', 0.31, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.6X100H1', N'14', N'14FC', N'Graisseur droit six pans  H1 6x100', 0.3572727, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.8X100', N'14', N'14FC', N'Graisseur droit 8x100', 0.37, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.8X100_45', N'14', N'14FC', N'Graisseur coud 8x100 45', 0.749, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.8X125H1', N'14', N'14FC', N'Graisseur droit 8x125', 0.3769411, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.BIO', N'33', N'33FG', N'Cartouche de graisse bio plantogel 2S a base de synthese d''ester', 6.193767, 20, 0, 0, 20)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.BIO50KGS', N'33', N'33FG', N'Graisse bio plantogel 2S a base de synthese d''ester en tonnelet', 11.8398, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.BIO5KG', N'33', N'33FE', N'Graisse BIOGREASE EP 2', 66.6933, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.CONDAKRON_XHD2', N'33', N'33FG', N'graisse en fut de 50 kgs', 248.26, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.CTFLON_AL', N'14', N'14FD', N'Graisse CT FLON 618 1 kgAL', 55.53, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.CUIVRE100GR', N'05', N'05FA', N'Graisse cuivre 100 grammes pour pour outillage electrique (tete de perforateur)', 9.87, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.DE_MONTAGE', N'33', N'33FG', N'Graisse de montage et d''assemblage pot de 500ml', 25.05, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.EPLITH00', N'33', N'33FG', N'Pot de 5 kgs de graisse pour motorducteur Auma', 52.5, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.IBINEOLUBGRV190', N'14', N'14FD', N'Cartouche de graisse neolub GRV190', 5.3, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.INT.LS1/2', N'14', N'14FD', N'Graisse LS 1/2 seau de 10 litres', 420.4, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.INT.LS1/2C', N'14', N'14FD', N'Cartouche de graisse  LS 1/2  400ml', 24.65, 17, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.LXC2', N'33', N'33FG', N'Cartouche de graisse', 6.39395, 92, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.LXC2-5KG', N'33', N'33FE', N'Graisse LXC2', 56.34999, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.MS_TUBE', N'05', N'05FA', N'Graisse multi service pour divers travaux', 2.85, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.MW5KG', N'33', N'33FE', N'Graisse MOUWAN VERTE en pot de 5kgs', 31.06, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.NOIR', N'33', N'33FG', N'Graisse noir  -30  +130 bte de 1kg', 33.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.RENOLIT_F_EP3', N'33', N'33FG', N'Cartouche de graisse pour la station de pompage de Wittring', 4.08, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAI.TOTENS400-50KG', N'33', N'33FG', N'Graisse  en fut de 50kgs  ENS400 plan inclin', 3.216667, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAT.GIVRE', N'26', N'26MA', N'Grattoir a givre pour vehicules', 1.735, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAT.WOLFKM', N'26', N'26MA', N'Grattoir multi star', 6.7848, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAV.0-15', N'05', N'05FA', N'Gravier 0-15', 41.47, 0, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAV.DREF0130290JC', N'26', N'26MA', N'Graveur a percussion 15 positions metal, verre, plastique, ceramique, cuir et bois', 47.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRAV.SUP60', N'05', N'05FA', N'Gravier sup 60', 61.4, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRIL.AERAT140_MOUSTQ', N'05', N'05FA', N'Grille d''aration 140 PVC avec moustiquaire', 10.66, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRIL.AERAT150', N'05', N'05FA', N'Grille d''aration 150 PVC', 10.09, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRIL.AV.BLANC100', N'05', N'05FA', N'Rouleau de grillage avertisseur blanc fibre optique 100ml', 22, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRIL.AV.ROUGE', N'05', N'05FA', N'Rouleau grillage avertisseur rouge 20cm  couronne de 100ml', 18.43, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRIL.CAM14L_PLAST', N'26', N'26MA', N'Grille plastique avec oreille pour camion 14L', 2.732572, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRIL.CAM14L_TOLE', N'26', N'26MA', N'Grille tole perfore avec oreille pour camion 14L', 2.2888, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRIL.CAM7L_PLAST', N'26', N'26MA', N'Grille plastique avec oreille pour camion 7L', 2.4, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRIL.CAM7L_TOLE', N'26', N'26MA', N'Grille tole perfor avec oreille pour camion 7L', 0.81, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRIL.CLA6005014651', N'14', N'14FC', N'Grille de filtre pales', 180.39, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GRIL.SERR.4X4X40X40', N'05', N'05FC', N'Grillage serrurier galva 4x4x40x40  2000x1600', 36.99, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GROU.HYDRAU', N'22', N'22MA', N'Groupe hydraulique', 4854, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GROU.NOR1200', N'14', N'14MA', N'Groupe de fauchage complet pour Magistra 1200 Pdf 1000 Trs', 6145, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GROU.SDMOK22-C3', N'22', N'22ME', N'Group electrogene 20KVA 16KW', 13105, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GUID.HUS501589601', N'14', N'14FC', N'Guide chane 84talon 404 1.6mm LM', 101.5696, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GUID.HUS503138001', N'14', N'14FC', N'Guide  pour chaine', 5.88, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GUID.HUS503141201', N'14', N'14FC', N'Guidage  pour chaine', 5.98, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GUID.HUS503141301', N'14', N'14FC', N'Guidage  pour chaine', 6.34, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GUID.HUS503141401', N'14', N'14FC', N'Guidage  pour chaine', 4.1184, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GUID.HUS503141501', N'14', N'14FC', N'Guidage  pour chaine', 4.8664, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GUID.HUS505698101', N'26', N'26MA', N'Guide de profondeur 3/8 professionnel pour chane 3/8', 3.784, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GUID.HUS505698103', N'26', N'26MA', N'Guide professionnel de profondeur pour chane 3/8', 3.784, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GUID.STH17722705530', N'14', N'14FC', N'Guide cordepour dbroussailleuse ECHO 4600', 2.91, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GUID.STH30020009741', N'14', N'14FC', N'Guide chane MS880 75cm', 108.16, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GUID.STH30030005217', N'14', N'14FC', N'Guide chane 3/8 1.6 45cm', 47, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GUID.STH30030006813', N'14', N'14FC', N'Guide chane 40cm 024-028 ROL', 48.6042, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GUID.STH30030009413', N'14', N'14FC', N'Guide STIHL 40cm RS /036', 62.66, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GUID.STH30030009417', N'14', N'14FC', N'Guide STIHL 45cm ROL /036', 61.5824, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GUID.STH30030009421', N'14', N'14FC', N'Guide chane 50cm ROLLO', 64.988, 1, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GUID.STH30030086817', N'14', N'14FC', N'Guide STIHL 45cm 3/8 1.6mm R', 50.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GUID.STH30050003905', N'14', N'14FC', N'Guide chane ROLLOMATIC', 37.534, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GUID.STH30050004809', N'14', N'14FC', N'Guide chane 021/023 ROLLOMATIC', 40.04, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GUID.STH30050004813', N'14', N'14FC', N'Guide chane 40CM ROLLOMATIC MS211', 55.28, 1, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GUID.STH30050007409', N'14', N'14FC', N'Guide chaine light 35 cm pour 020 STIHL', 47.09573, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'GUIP.NC14', N'26', N'26MA', N'Guipon ecrou papillon -50mm sortie 69mm', 18.53, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HACH.600GR', N'26', N'26MA', N'Hache a fendre 600gr', 13.55, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HACH.60CM', N'26', N'26MA', N'Hache a fendre 60 cm 1000g', 17.24, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HACH.80CM', N'26', N'26MA', N'Hache a fendre 80 cm 2,5kgs', 65, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HAMP.GIRO', N'14', N'14FC', N'Support de girophare', 12, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME.20', N'26', N'26FD', N'Boite de 1000 lamello', 61.48, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_200X30X20', N'26', N'26FA', N'Lame pour scie a table fox f36-524', 93.38, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_BOS2608661642', N'26', N'26FA', N'Lame segmente ACZ 85 RT carbure', 33.12, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_CUTPOCHE', N'26', N'26MA', N'Lame de cutter de poche 9mm', 0.480925, 80, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_CUTPROF.', N'26', N'26MA', N'Lame de cutter professionnel 18mm', 4.54903173, 29, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_D190', N'26', N'26FD', N'Lame de scie circulaire de chantier D.190', 126.8, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_D315X2.5X32_120DTS', N'26', N'26FA', N'Lame de scie 315x2.5x32 120 DTS pour scie fraise', 191, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_DES37701', N'14', N'14FC', N'lame caoutchouc pour raboteuse et Chasse neige DESVOYS', 124.12, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_DES37702', N'14', N'14FC', N'lame caoutchouc pour raboteuse et Chasse neige DESVOYS', 117.17, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_FAC872272', N'26', N'26MA', N'Kit de 6 lames pour outil a degainer', 11.11, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_GRAT08CM', N'26', N'26MA', N'Lot de 10 lames pour grattoir', 3.16, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_GRAT12CM', N'26', N'26MA', N'Lot 5 lames pour grattoir', 10.38, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_OTE32020112', N'26', N'26MA', N'Lame pour appareil a restaurer les filets', 37.56, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_PLONG32/40BSPC', N'26', N'26FA', N'paquet de 5 lames plongeantes bois spciaux et panneau colls  32x40', 63.27, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_PLONG32/40METAL', N'26', N'26FA', N'Lame plongeante metal 32x40', 26.45, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_PLONG32BOIS', N'26', N'26FA', N'paquet de 5 lames plongeantes bois 32', 16.54, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_PLONG65/40B/M', N'26', N'26FA', N'Paquet de 5 lames plongeantes metal 65x40 bi matire', 86.17, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_PVC', N'05', N'05MA', N'Lames de parquet PVC', 24.958, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_RABOT82MM', N'26', N'26FD', N'paquet de 10 lames de rabot reversible 82mm', 1.12, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_SAB.ACIER150', N'26', N'26FD', N'Paquet de 5 lames de scie sabre BIM.ACIER LG150', 7.94, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'LAME_SAB.BOIS225', N'26', N'26FD', N'Paquet de 5 lames de scie sabre BIM.BOIS LG225', 8.69, 10, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HARN.OR539172', N'18', N'18MB', N'Harnais double confort oregon', 41.5833, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HARN.PET89C71AAA.01', N'18', N'18MB', N'Harnais AVAO BOD taille 01', 177.44, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HARN.STH00007109001', N'18', N'18MB', N'Harnais advance X-treem', 156.29, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HAUT_BEH20-9237', N'31', N'31MA', N'Haut parleur a chambre de compression 15W 8 Ohms botier aluminium', 94.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HAUT_COMC-AFLS10HHG', N'31', N'31MA', N'Haut-parleur chambre de compression hybride IP/SIP 10W gris', 597, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HAUT_PARLEUR130', N'33', N'33FA', N'Jeu de 2 hauts parleurs 130mm', 31.89, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HELI.580MM', N'33', N'33FD', N'helice 4 pales DN 580mm pour ponton Denise', 0, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HELI.HON58130ZV1940ZB', N'33', N'33FD', N'Helice 3 pales', 102.94, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HORA.24V_TFX', N'33', N'33FD', N'Horametre 24V TFX NOIR', 141.8, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HOUE_+M', N'26', N'26MA', N'Houe forgee 14cm + manche', 23.46, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HOUS.SIEGE/500', N'26', N'26FD', N'Rouleau de 500 housses de siges', 0.178, 340, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUB_USB3.0', N'20', N'20FB', N'hub USB 3.0 4 ports', 18.86, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUBL.LED7.7W', N'12', N'12 FA', N'Lampe HUBLOT ovale  leds blanc 7.7W 4000 lumens', 24, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUBL.LEG177764', N'12', N'12 FA', N'Lampe HUBLOT 100W E27', 7.3, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'HUIL.10W40/5', N'33', N'33FE', N'Huile moteur 10W40 en bidon de 5 litres', 15.50032, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEU_RVI7484553913', N'33', N'33FB', N'Feu  lanterne arriere droit complet', 48.08, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEU_SOR68015', N'33', N'33FC', N'Feu de remorque blanc pour remorque SOREL', 6.776, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEU_SOR6867', N'33', N'33FC', N'Feu de remorque droitRADEX pour remorque SOREL', 30.99, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEU_SOR6868', N'33', N'33FC', N'Feu de remorque gauche RADEX pour remorque SOREL', 30.99, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEU_TRA160434-24', N'12', N'12 MC', N'Feu plat D200mm  lleds ambre + lentille de Fresnel  et caisson alu 240x240 angles arrondis', 240, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEU_TRIBORD', N'33', N'33FD', N'Feu tribord corps noir grand modle Hella marine 12V', 34.583, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEUT.ALU/MAMMOUTH', N'05', N'05FA', N'Feutre alu/mammouth longueur 8m/larg 1m', 88.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEUT.BLANC_P', N'17', N'17FC', N'Feutre blanc permanent pointe fine pour materiaux non poreux', 3.71, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEUT.PNF', N'17', N'17FC', N'Feutre noir permanent pointe fine', 0.8147059, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEUT.PNM', N'17', N'17FC', N'Feutre noir permanent pointe moyenne', 0.8319445, 16, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEUT.PNSF', N'17', N'17FC', N'Feutre noir permanent pointe super fine', 0.9528571, 14, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEUT.PRF', N'17', N'17FC', N'Feutre rouge permanent pointe  fine', 0.8377778, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEUT.PRM', N'17', N'17FC', N'Feutre rouge permanent pointe moyenne', 0.835, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEUT.PRSF', N'17', N'17FC', N'Feutre rouge permanent pointe super fine', 0.924706, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEUT.V5BLEU', N'17', N'17FC', N'Feutre bleu V5 pointe aiguille', 1.16, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEUT.V5NOIR', N'17', N'17FC', N'Feutre noir V5 pointe aiguille', 1.16, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEUT.V7N0.7', N'17', N'17FC', N'Feutre noir V7 pointe aiguille 0.7mm', 1.101892, 23, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.BALS22053', N'12', N'12 FA', N'Fiche 3P+T 16A rouge femelle inverseur', 12.09, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.BIZ620160', N'12', N'12 FA', N'fiche DCL 2P+T', 1.6135, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.BRISTOL125/200', N'17', N'17FA', N'Assortiment de 5 couleurs de fiches bristol 125 par 200', 3.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.CF10/16A', N'12', N'12 FA', N'Fiche caoutchouc F 10/16A', 6.654545, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.CM10/16A', N'12', N'12 FA', N'Fiche normalise M 10/16A', 5.09014, 13, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.CM10/16AALL', N'12', N'12 FA', N'Fiche caoutchouc male allemand butyl. 10/16A', 3.576996, 17, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.HANOUKA13X40', N'26', N'26FD', N'Fiches anouka 13 x 40', 4.04, 0, 0, 0, 16)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.LEG050632', N'12', N'12 FA', N'Fiche triplette', 2.82, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.LEG052042', N'12', N'12 FA', N'Fiche droite hypra 2P+T 16A 220V PLAST BLEU', 12.54, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.LEG052084', N'12', N'12 FA', N'Prise mobile 3P+N+T 16A 220V PLAST BLEU', 14.015, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.LEG052744', N'12', N'12 FA', N'Fiche 3P+N+T 32A 220V PLASTIQUE BLEU', 12.47, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.LEG052784', N'12', N'12 FA', N'Fiche 3P+N+T 220V PLASTIQUE BLEU', 16.36, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.LEG052944', N'12', N'12 FA', N'Fiche 3P+N+T 32A rouge male', 20.06, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.LEG055637', N'12', N'12 FA', N'Fiche 3P+N+T 20A grise IP44', 4.74, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.LEG056477', N'12', N'12 FA', N'Fiche mobile coude 32A 3P+T', 15.78, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.LEG056478', N'12', N'12 FA', N'Fiche mobile coude 32A 3P+N+T', 16.51, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.LEG056808', N'12', N'12 FA', N'Fiche de tableau 16A incline 3P+N+T', 18.528, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.LEG057438', N'12', N'12 FA', N'Fiche 3P+N+T 16A rouge femelle IP44 400V', 3.75, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.LEG057440', N'12', N'12 FA', N'Fiche inverseur de phases 16A 3P+N+T', 34.15, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.MCA920850', N'12', N'12 FA', N'Fiche  RJ45 8/8 CAT6 blinds par sachet de 10 pices', 6.2, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.REM.F', N'12', N'12 FA', N'Fiche femelle rallonge remorque', 6.145334, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.SCH81771', N'12', N'12 FA', N'Fiche mobile coude 32A 3P', 33.44, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.SCH83913', N'12', N'12 FA', N'Fiche mobile invers phase', 32.65, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.TBLANC', N'17', N'17FC', N'Fiche planning BLANC dimensions 15/92/120/80 BOITE DE 100 PIECES', 1.37, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.TBLEU', N'17', N'17FC', N'Fiche planning bleu dimensions 15/92/120/80 BOITE DE 100 PIECES', 1.37, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.TJAUNE', N'17', N'17FC', N'Fiche planning JAUNE dimensions 15/92/120/80 BOITE DE 100 PIECES', 1.37, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.TROSE', N'17', N'17FC', N'Fiche planning ROSE dimensions 15/92/120/80 BOITE DE 100 PIECES', 1.37, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FICH.TROUGE', N'17', N'17FC', N'Fiche planning ROUGE dimensions 15/92/120/80 BOITE DE 100 PIECES', 1.37, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_BRASER', N'07', N'07FA', N'Fil a braser tendre sans plomb etain / cuivre 3% D2 250g', 32.28, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_DEB2.4X261', N'14', N'14FC', N'Fil debroussailleuse orange 261ml/2.4mm', 32.27, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_DEB2.4X275C', N'14', N'14FC', N'Fil debroussailleuse orange carr 275ml/2.4mm', 35.57, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_DEB2.4X70CARBO', N'14', N'14FC', N'Fil debroussailleuse carbone CF3 PRO', 17.6, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_DEB3X280', N'14', N'14FC', N'Rouleau fil debroussailleuse jaune 280ml/3mm', 39.54, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_H07VU1.5BRUN', N'12', N'12 FA', N'Fil lectrique 1,5 brun 100ml H07V-U rigide', 0.1125, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_H07VU2.5BRUN', N'12', N'12 FA', N'Fil lectrique 2,5 brun 100ml H07V-U rigide', 0.1862, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_H07VU2.5NOIR', N'12', N'12 FA', N'Fil lectrique 2,5 noir 100ml H07V-U rigide', 0.2524753, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_H07VU2.5ORAN', N'12', N'12 FA', N'Fil lectrique 2,5 orange 100ml H07V-U rigide', 8.2322, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_H07VU4BLEU', N'12', N'12 FA', N'Fil lectrique 4 bleu 100ml H07V-U rigide', 120.7396, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_H07VU4BRUN', N'12', N'12 FA', N'Fil lectique 4 brun 100ml H07V-U rigide', 120.7396, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_H07VU4NOIR', N'12', N'12 FA', N'Fil lectrique 4 noir 100ml H07V-U rigide', 120.7396, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_H07VU4ROUG', N'12', N'12 FA', N'Fil lectrique 4 rouge 100ml H07V-U rigide', 120.7396, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_H07VU4VJ', N'12', N'12 FA', N'Fil lectrique 4 vert - jaune 100ml H07V-U rigide', 120.7396, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_HO7VK1.5BLANC', N'12', N'12 FA', N'Fil 1,5mm2 blanc souple 100ml', 0.2204, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_HO7VK1.5MAR', N'12', N'12 FA', N'Fil 1,5mm2 marron souple', 22.04, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_HO7VK1.5NOIR', N'12', N'12 FA', N'Fil 1,5mm2 noir souple', 22.04, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_RECUIT1.5', N'26', N'26FD', N'fil de fer 1.5 mm recuit', 21.93, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_RECUIT2.7', N'26', N'26FD', N'fil de fer recuit 2.7mm', 19.73833, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_SCIE_UNI.', N'26', N'26MA', N'FIL au carbure de tungstene 300mm', 31.2, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_SOUD10/10', N'26', N'26FD', N'Fil  souder 10/10 Reparmag 15/16kgs', 117.767, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_SOUDURE_HC10/10', N'22', N'22MD', N'Filtech haute capacitee 805AG 10/10', 480, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_SOUDURE_HC12/10', N'22', N'22MD', N'Filtech haute capacitee 805AG 12/10', 457.52, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_TEND3.2GALV', N'05', N'05FA', N'Fil tendeur dia:3,2 5kgs galva', 8.8497, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIL_TENDPV2.4', N'05', N'05MA', N'Fil tendeur plastifi 2,4mm 100ml', 9.45, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILA.', N'26', N'26FD', N'Bobine de filasse pour devidoir', 8, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILE.DPECHE', N'14', N'14FA', N'filet de pche sur cadre primaire en acier', 13, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILM_ETIR.', N'26', N'26FD', N'Rouleau de film etirable WINRAP + 300mm', 6.85, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.ABEK/1', N'18', N'18MB', N'Cartouche filtrante ABEK1 pour 1/2 masque', 5.227829, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.BOB1B6678034', N'14', N'14FC', N'filtre  air', 59.085, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.BRI272490', N'14', N'14FC', N'Prefiltre a air Attila', 6.7, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.BRI394018', N'14', N'14FC', N'Filtre a air Attila', 24.7, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.BRI491588', N'14', N'14FC', N'Filtre a air briggs', 9.8231, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HIFSO404', N'33', N'33FC', N'Filtre a huile pour PMF', 9.18, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HIFSO8013', N'22', N'22FA', N'Filtre a huile pour tracteur SAME', 24.18, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HIFT3142', N'22', N'22FA', N'Filtre  a huile pelle atlas', 13.57, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HON330150405', N'22', N'22FA', N'Filtre a air pour moteur pompe a eau  honda', 19.88, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HUS503895301', N'14', N'14FC', N'Filtre a air', 27.9048, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.KAR66612170', N'22', N'22FA', N'Filtre anti parasite', 19.61, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.KAW11013-2151', N'14', N'14FC', N'Filtre a air TAK 30-323', 21.1902, 2, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.KAW11013-2152', N'14', N'14FC', N'Prefiltre a air pour tondeuse wolf', 3.63, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.LOM2175040', N'14', N'14FC', N'Filtre  a huile', 14.79, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.LOM2175048', N'14', N'14FC', N'Filtre  a air variante:SA17017', 28.29, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.LOM2175107', N'14', N'14FC', N'Filtre a huile', 13.815, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.LOM5976005', N'22', N'22FA', N'filtre reniflard pour pompe a eau genelec', 2.97, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.LOM75044', N'14', N'14FC', N'Filtre  a huile', 21.56, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.DESDC2', N'22', N'22FA', N'filtre a air a particule', 128.75, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.DON30801011201', N'22', N'22FA', N'filtre a air pour groupe 16K electrogene', 58.765, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.DON330510018', N'22', N'22FA', N'filtre a G-O pour groupe 16K electrogene', 18.83333, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.DON330510019', N'22', N'22FA', N'filtre a huile pour groupe 16K electrogene', 17.53062, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.ECH13031006230', N'14', N'14FC', N'Filtre a air grille acier pour  ECHO', 13.18, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.ECHA226000220', N'14', N'14FC', N'Filtre a air debroussailleuse', 10.3312, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.ECHA226000360', N'14', N'14FC', N'Filtre a air debroussailleuse a dos', 19.9921, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HAT849401', N'22', N'22FA', N'Filtre 849401 HATZ  a G-O/poste a souder', 5.29, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HIF17974', N'22', N'22FA', N'Filtre/compress.chantier variante:SA17974', 65.54, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.PALEA1392', N'33', N'33FB', N'filtre pour grue du camion', 72.69, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.PALEA1412', N'33', N'33FB', N'filtre pour grue du camion', 63.28, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.PERK2654403', N'33', N'33FC', N'Filtre a huile pour PMF', 10.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.PERK26561117', N'33', N'33FC', N'Filtre a Gazole pour PMF', 7.65, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.PERKULPK0002', N'33', N'33FC', N'Filtre de pompe pour PMF', 0, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.PRE01172', N'26', N'26MA', N'Filtre pour entonnoir', 2.2604, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.PREVKTM_SM3', N'26', N'26MA', N'Filtre rgulateur  filetage femelle BSPP = G 1/2', 85.45, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.PURC112', N'33', N'33FA', N'Filtre C112 G-O', 5.38, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.PURC113', N'22', N'22FA', N'Filtre C113 G-O Purflux', 10.584, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.PURC460', N'33', N'33FB', N'Filtre  pour Master MANNP733/1', 8.082, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.PURC496', N'33', N'33FB', N'Filtre  G-O pour MASTER 4595TQ62', 19.152, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.PURCS155', N'33', N'33FB', N'Filtre CS155 G-O Purflux Express', 6.93, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.PURCS178A', N'33', N'33FB', N'Filtre CS178A G-O Purflux', 7.21, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.PURL270', N'33', N'33FB', N'Filtre a huile / Master 4595TQ62', 11.4, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.PURL331', N'33', N'33FA', N'Cartouche de filtre  huile', 16.6029, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.STH11391201602', N'14', N'14FC', N'Filtre a air STIHL 020', 13.15, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.STH41341410300', N'14', N'14FC', N'Filtre a air', 8.33, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.STH41471410300C', N'14', N'14FC', N'Filtre a air', 5.2624, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.STH42291201800', N'14', N'14FC', N'Filtre a air', 1.3024, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.WILT20P2', N'18', N'18MB', N'Filtre X2P2 pour 1/2 masque', 2.403636, 19, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIOU.1ER', N'33', N'33FF', N'Fioul premier', 0.7209, 0.4900017, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIOU.CHAUF', N'33', N'33FF', N'Fioul de chauffage', 0.74167, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIOU.CHAUF_CMR', N'33', N'33FF', N'Fioul de chauffage CMR', 0.71666, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FIXA.WC', N'05', N'05MA', N'Fixation WC et bidet 6/80', 4.38, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FLAC.STH0000881182', N'26', N'26FD', N'Flacon doseur pour mlange', 6.66, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FLAS.CLA6000149631', N'14', N'14FC', N'flasque de roue pour pales', 404.33, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FLAS.ECH61031307132', N'14', N'14FC', N'Flasque', 24.0668, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FLAS.ECH61031407130', N'14', N'14FC', N'Flasque dbroussailleuse SRM 4600', 17.47587, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FLASQ.NOR100511', N'14', N'14FC', N'Flasque de poulie MAGISTRA', 11.93, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FLEA.KUHA5407231', N'14', N'14FC', N'fleau pour broyeur', 2.42, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FLEA.NOR103052', N'14', N'14FC', N'Fleau Y', 1.01, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FLEA.NOR103059', N'14', N'14FC', N'Fleau Y/ MAGISTRA', 1.055103, 141, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FLEA.NOR103070', N'14', N'14FC', N'Fleau LN 1600 et Elenia', 2.267997, 79, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FLEX.+T1000', N'26', N'26MA', N'Flexible + tresse 1000mm pompe a graisse', 25, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FLEX.+T300', N'26', N'26MA', N'Flexible + tresse 300mm pompe a graisse', 9.260667, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FLEX.BOB1B6576386', N'22', N'22FA', N'Flexible', 4.59, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FLEX.HP.SM', N'22', N'22FA', N'Flexible HP suivant modle pour nettoyeur', 198.46, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FLEX.HYDSM', N'22', N'22FA', N'flexible hydraulique suivant modele', 67.67, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FLEX.KAR44406530', N'24', N'24FA', N'flexible d''aspiration pour aspirateur NT361', 82.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FLEX.STH41287103000', N'14', N'14FC', N'Flexible complet FS 350/450', 186.22, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FLUO.15GR', N'05', N'05FL', N' Fluoricine pot de 15gr', 95.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FLUO.1L', N'05', N'05FL', N' Fluoricine', 92.84, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FLUX_S39', N'05', N'05FI', N'Flux S39 pour decapage lors de soudure 340ml', 14.45, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.COB3.5', N'26', N'26FD', N'Foret au cobalt diametre 3,5', 10.75, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.COB4', N'26', N'26FD', N'Foret au cobalt diametre 4', 12.1, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.COB6', N'26', N'26FD', N'Foret au cobalt diametre 6', 4.9, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.PILOTE_SC6', N'26', N'26FD', N'Foret centreur pour trpan SC 6 cm', 5.12, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+05A12', N'26', N'26FD', N'Jeu de forets beton 5a12mm SDS plus', 52.98, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+05X110', N'26', N'26FD', N'Foret SDS plus 5x110', 3.659, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+05X160', N'26', N'26FD', N'Fort SDS plus 5x160', 11.13, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+06.5X260', N'26', N'26FD', N'Fort SDS plus 6.5x260', 14.48, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+06X110', N'26', N'26FD', N'Foret SDS plus 6x110', 3.825, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+06X160', N'26', N'26FD', N'foret SDS plus 6x160', 6.94636345, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+06X260', N'26', N'26FD', N'Fort SDS plus 6x260', 9.58, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+08X110', N'26', N'26FD', N'Foret SDS plus 8x110', 5.82, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+08X160', N'26', N'26FD', N'Foret SDS plus 8x160', 8.122759, 17, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+08X210', N'26', N'26FD', N'Fort SDS plus 8x210', 7.360806, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+10X110', N'26', N'26FD', N'Foret SDS plus 10x110', 8.22132, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+10X160', N'26', N'26FD', N'Fort SDS plus 10x160', 8.018357, 21, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+12X160', N'26', N'26FD', N'Fort SDS plus 12x160', 10.63, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+12X210', N'26', N'26FD', N'Foret SDS + trio drill 12x210', 21.5261, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+12X260', N'26', N'26FD', N'Foret SDS + 12x260', 21.0417, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+14X160', N'26', N'26FD', N'Foret SDS + 14x160', 14.0287, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+14X210', N'26', N'26FD', N'Foret SDS + 14x210', 17.44, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+14X260', N'26', N'26FD', N'Foret SDS plus trio drill 14x250', 20.84, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+16X160', N'26', N'26FD', N'Foret SDS + 16x160', 42.14, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+16X210', N'26', N'26FD', N'Foret SDS + 16x210', 41.52, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+16X260', N'26', N'26FD', N'Foret SDS + 16x260', 64.8067, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+16X450', N'26', N'26FD', N'Foret SDS + 16x450/400mm', 63.54, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+18X250', N'26', N'26FD', N'Foret SDS + 18x250', 23.23, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+20X250', N'26', N'26FD', N'Foret SDS + 20/250/200', 67.05, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+20X450', N'26', N'26FD', N'Foret SDS + 20/450', 49.3, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+22X250', N'26', N'26FD', N'Foret SDS + 22/250/200', 82.25, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+22X450', N'26', N'26FD', N'Foret SDS + 22/450/400 xtron', 107.2, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDS+25X200', N'26', N'26FD', N'Foret SDS + 25/250/200', 65.69, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDSM16X200', N'26', N'26FD', N'Foret SDS MAX 16x200', 54.975, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDSM18X200', N'26', N'26FD', N'Foret SDS MAX 18x200', 61.97, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDSM20X200', N'26', N'26FD', N'Foret SDS MAX 20x200', 66.9333, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDSM20X400', N'26', N'26FD', N'Fort SDS MAX 20x400', 57.65, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDSM22X200', N'26', N'26FD', N'Fort SDS MAX 22x200', 42.06875, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDSM25X200', N'26', N'26FD', N'Fort SDS MAX 25x200', 88.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDSM28X400', N'26', N'26FD', N'Foret SDS MAX 28X400x520', 110, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDSM32X920', N'26', N'26FD', N'Foret SDS MAX 32x920', 150.4, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDSM35X920X800', N'26', N'26FD', N'Foret SDS MAX 35x800 longueur utile', 250.12, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDSM40X800', N'26', N'26FD', N'Foret SDS MAX 40x800', 242.3333, 1, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDSM45X990', N'26', N'26FD', N'Foret SDS MAX 45x990 longueur utile mega-tron', 258.17, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDSM65X310', N'26', N'26FD', N'Foret trepan monobloc SDS MAX 65x310', 321.16, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDSM65X550', N'26', N'26FD', N'Foret trepan monobloc SDS MAX 65x550', 270.05, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FORE.SDSM65X900', N'26', N'26FD', N'Foret trepan monobloc SDS MAX 65x900', 300.29, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FOUR.FUM', N'26', N'26MA', N'Fourche  fumier manche frne', 34.2676, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FOUR.PVC100', N'28', N'28MA', N'Fourreau pvc largeur totale 100mm pour sangle plate 3Tonne', 6.65, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FOUR.PVC70', N'28', N'28MA', N'Fourreau pvc  largeur totale 70mm, pour sangle plate 2 tonne', 5, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FOUR.RVI5005030702', N'33', N'33FB', N'Fourrure  DR8', 0.69, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FOUR.S47', N'05', N'05FA', N'Fourrure S47 pour plafond suspendu 20x5.300ml', 0.87, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FOUR.STH41387117300', N'14', N'14FC', N'Fourreau pour HT75', 16.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FOUR_MINI', N'22', N'22MF', N'Mini four', 120, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FOYE.SEA_C069', N'12', N'12 MC', N'Optiques leds rouge avec lentille fume  PVC diamtre 200 12/24V', 123.25, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FOYE.SEA_C071', N'12', N'12 MC', N'Optiques leds vertes dn5mm avec lentille fume  PVC diamtre 200 12/24V NF EN 12368', 131.75, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FOYE.TRA020204_LR', N'12', N'12 MC', N'Circuit 95 leds rouge alim 24V cable 1M lentille polycarbonate + siliconage complet', 180, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.PURLS235', N'33', N'33FB', N'Filtre a huile LS 235 pour Master', 19.47, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.PURLS309', N'33', N'33FA', N'Filtre  huile LS309', 9.639, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.PURLS924', N'33', N'33FA', N'Filtre  a huile', 9.0588, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.PURLS932', N'33', N'33FA', N'filtre a huile kangoo diesel', 17.699, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.PURLS933', N'33', N'33FA', N'filtre a huile kangoo 2 diesel', 10.884, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.REN164038513R', N'33', N'33FB', N'Filtre  G-O pour MASTER', 24.0162, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.REN7701472321', N'33', N'33FB', N'Filtre  gas-oil pour MASTER 4595TQ62', 10.42, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.REN7701478538', N'33', N'33FB', N'Filtre  huile pour MASTER L2H2', 7.518, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.RIT3172100', N'12', N'12 FA', N'Filtre de rechange SK3240/41', 13.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.SOL40', N'14', N'14FC', N'Filtre SOLO', 0.95, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.SPIT644006', N'22', N'22FA', N'set de 2 filtres aspirateur spit AC1600', 41.19, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.STAUFFSFC5710E', N'33', N'33FD', N'Element filtrant pour PMF Denise', 0, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.STH00001201653', N'14', N'14FC', N'Filtre a air mtallique MS880', 22.0792, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HIFEN13150AASL13150', N'22', N'22FA', N'Filtre liquide pour nettoyeur HP DIMACO 50microns', 24.9, 15, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HIFRT7', N'33', N'33FD', N'Prefiltre a carburant moteur HATZ ( le Sarre)', 2.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HIFSA10126', N'33', N'33FD', N'filtre a air moteur HATZ ( le Sarre)', 17.795, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HIFSA12922', N'14', N'14FC', N'Filtre a air pour pompe a eau genelec', 13.32, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HIFSA16302', N'22', N'22FA', N'Filtre a air tracteur SAME', 37.54, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HIFSA17099', N'22', N'22FA', N'Filtre a air / poste a souder SDMO', 15.919, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HIFSA6001', N'14', N'14FC', N'Filtre a air pourles moteurs BERNARD des pompes a eau DN200', 17.3, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HIFSC40003', N'14', N'14FC', N'Filtre air cabine / ERGOS', 36.46, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HIFSC60008', N'22', N'22FA', N'Filtre a air cabine tracteur Pales', 60.82, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HIFSH52933', N'33', N'33FC', N'Filtre hydraulique pour PMF', 44.94, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HIFSH56236', N'14', N'14FC', N'Filtre hydraulique pour tracteur renault', 19.99, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HIFSH56411', N'22', N'22FA', N'Filtre hydraulique pour tracteur SAME', 29.76, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HIFSH61153', N'14', N'14FC', N'Filtre hydraulique pour tracteur Renault', 38.37201, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HIFSH66124', N'22', N'22FA', N'Filtre hydraulique pour mini pelle de Sarreguemines', 54.38, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HIFSN039', N'33', N'33FC', N'Filtre a Gazole pour grue atlas', 11.91, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HIFSN327', N'33', N'33FD', N'filtre a carburant moteur HATZ ( le Sarre) et tracteur SAME', 14.32, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.HIFSN555', N'22', N'22FA', N'Filtre a GO / poste a souder SDMO', 16.88, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELEC.RUT.2.5', N'22', N'22MD', N'Electrode rutile 2,5x350mm type 54', 67.98, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELEC.RUT.3.2', N'22', N'22MD', N'Electrode rutile dn  3,2mm 160 pieces', 64.1391, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELEM.FILT/EAU', N'11', N'11FC', N'Elment filtrant pour conduite d''eau', 18.523, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELEM.PERSAB33062', N'33', N'33FD', N'Element air mousse', 11.75, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELEM.TAR83', N'26', N'26FD', N'element final arriere aiguille 9mm', 36.54, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELIN.AC12/25M', N'22', N'22MB', N'Cable acier DN 12mm long.25M avec boucle manchonne de 800mm a une extremite', 192.75, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELIN.AC12/3M', N'22', N'22MB', N'Cable acier DN 12mm long.3M CMU 1,5To Extr.manch.', 11, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELIN.AC14/3M', N'22', N'22MB', N'Cable acier DN 14mm long.3ml extr.manch. CMU 2T200', 15.1, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELIN.AC14/5M', N'22', N'22MB', N'Elingue acier dia:14mm lg 5ml', 20.28, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELIN.AC20/6M', N'22', N'22MB', N'Elingue acier DN20mm LG6m CMU 4T35', 80.7, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELIN.AC22/6M', N'22', N'22MB', N'Elingue acier DN22mm LG6m CMU 5T200', 50.44, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELIN.CH2X1.3ML8MM', N'22', N'22MB', N'Eling.chane 2 brins 1.3ml DN 6mm extremite +racourcisseur+crochet automatique', 92, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELIN.CH4X1.3ML8MM', N'22', N'22MB', N'Elingue chane 4 brins - longueur totale 1.3ml - DN 8mm - extremite crochets + linguets', 128, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELIN.EL2T1M', N'22', N'22MB', N'Elingue ELRO 2 tonnes 1ml verte', 4.2, 0, 0, 0, 4)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELIN.EL2T2M', N'22', N'22MB', N'Elingue ELRO 2 tonnes 2ml verte', 4.6, 0, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELIN.EL2T3M', N'22', N'22MB', N'Elingue ELRO 2 tonnes 3ml verte', 7.8, 0, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELIN.EL3T1.5M', N'22', N'22MB', N'Elingue ELRO 3 tonnes 1,5ml JAUNE', 5.1, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELIN.EL3T1M', N'22', N'22MB', N'Elingue ronde polyester 1m 3To', 7.285714, 1, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELIN.EL3T2M', N'22', N'22MB', N'Elingue ronde 3To 2ml Rf:ECM3/2 jaune', 6.3, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELIN.EL3T3M', N'22', N'22MB', N'Elingue ronde CMU 3T 3M jaune', 12.88571, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELIN.EL3T3MR', N'22', N'22MB', N'Elingue renforce CMU 3 T LG 3M couture au milieu', 16, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELIN.EL3T4M', N'22', N'22MB', N'Elingue ELRO jaune  3TO 4ml', 14, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELIN.EL4T4M', N'22', N'22MB', N'Elingue ELRO grise  4TO 4ml', 24.75, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELIN.EL5T3M', N'22', N'22MB', N'Elingue ronde CMU 5T LG 3ml rouge', 18.3, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBA.', N'05', N'05FC', N'Emballage produits inox ou alu', 9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBA.JMC_BASELINE_01ALV', N'12', N'12MB', N'Embase', 29, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBA.LEG031950', N'12', N'12 FA', N'Embase a visser Legrand 031950', 19.38, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBA.LEG031955', N'12', N'12 FA', N'Embase  Legrand 031955', 20.01, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBA.SCHABE7P08T330', N'12', N'12MB', N'Embase de sortie equipe de relais electromagnetique debrochable ABR 7S33', 87, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.614176717', N'26', N'26MA', N'Embout 6 pans creux 1/4 6P 10mm / vis PIASTA', 14.89, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.A_COL40', N'11', N'11FC', N'Embout a coller droit DN40 male pour flexible', 1.56, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.AW10', N'26', N'26MA', N'Embout / vis ASSY AW 10 25mm', 7.06, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.AW25', N'26', N'26MA', N'Embout / vis ASSY AW 25 25mm', 6.26, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.AW25*', N'26', N'26MA', N'Embout / vis ASSY AW 25 25mm', 10.43, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.AW30', N'26', N'26MA', N'Embout / vis ASSY AW 25 30mm', 8.15, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.BORNPH1', N'26', N'26FD', N'embout de vissage pour bornier ph1', 7.1314, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.BORNPH2', N'26', N'26FD', N'embout de vissage pour bornier ph2', 7.1314, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.BORNPZ1', N'26', N'26FD', N'embout de vissage pour bornier pz1', 1.876, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.BORNPZ2', N'26', N'26FD', N'embout de vissage pour bornier pz2', 3.31, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.BORNPZ3', N'26', N'26FD', N'embout de vissage pour bornier pz3', 1.77, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.CAB1.5MM', N'12', N'12 FA', N'Embout de cablage 1.5 mm', 0.0131, 200, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.CAB1.5MM D', N'12', N'12 FA', N'Embout de cablage 1.5 mm double noir', 46.74, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.CAB10MM', N'12', N'12 FA', N'Embout de cablage 10mm', 0.1568, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.CAB1MM', N'12', N'12 FA', N'Embout de cablage 1mm', 0.0175, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.CAB2.5MM', N'12', N'12 FA', N'Embout  de cablage 2.5mm', 0.0278, 300, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.CAB4MM', N'12', N'12 FA', N'Embout de cablage 4mm', 0.12, 300, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.CAB6MM', N'12', N'12 FA', N'Embout de cablage 6mm', 0.1366, 300, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.DP_N4', N'26', N'26FD', N'Embout double pointes N4 longueur 25mm', 7.67, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.DP_N6L90', N'26', N'26FD', N'Embout double pointes N6 longueur 90mm', 8.67, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.EH1-3-25', N'26', N'26MA', N'Embout pour vis six pans creux lg 25mm N3', 2.8857, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.EH1-4-25', N'26', N'26MA', N'Embout pour vis six pans creux long.25mm N4', 2.9286, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.EH1-5-25', N'26', N'26MA', N'Embout pour vis six pans creux long.25mm N5', 2.9231, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.EH1-6-25', N'26', N'26MA', N'Embout pour vis six pans creux long.25mm N6', 2.27, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.EH3-2.5-50', N'26', N'26MA', N'Embout pour vis six pans creux long.50mm N2.5', 3.38, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.EH3-2-50', N'26', N'26MA', N'Embout pour vis six pans creux long.50mm N2', 3.38, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.EH3-3-50', N'26', N'26MA', N'Embout pour vis six pans creux long.50mm N3', 3.38, 3, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.EH3-4-50', N'26', N'26MA', N'Embout pour vis six pans creux long.50mm N4', 3.38, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.EH3-5-50', N'26', N'26MA', N'Embout pour vis six pans creux long.50mm N5', 3.38, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.EH3-6-50', N'26', N'26MA', N'Embout pour vis six pans creux long.50mm N6', 3.38, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.EH3-8-50', N'26', N'26MA', N'Embout pour vis six pans creux long.50mm N8', 5.5, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.FACEB32', N'26', N'26MA', N'Embout / massette a embout adaptable rouge', 3.15, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.FACEC32', N'26', N'26MA', N'Embout / massette a embout adaptable blanc', 3.13, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.FT0.8X5.5L25', N'26', N'26MA', N'Embout fente 5,5mm L25mm', 3.415, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.FT1.2X6.5L50', N'26', N'26MA', N'Embout fente 6,5mm L50mm', 9.1327, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.FT1.2X8L50', N'26', N'26MA', N'Embout fente 8mm L50mm', 9.299, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.FT1X5.5L25', N'26', N'26MA', N'Embout fente 1x5,5 L25mm', 2.7314, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.FT1X6L50', N'26', N'26MA', N'Embout fente 6mm L50mm0614177972', 8.4165, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.FT3.5X70', N'26', N'26MA', N'Embout plat 3.5mm lg 70mm', 7.714, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.FT3X70', N'26', N'26MA', N'Embout plat 3mm lg 70mm', 6.975, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.FT4.5X45', N'26', N'26MA', N'Embout/vis fente long.2,5cm larg.4,5', 3.26, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.FT4X70', N'26', N'26MA', N'Embout plat 4mm lg 70mm', 7.5457, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.HAG221771', N'12', N'12MB', N'Embout pour plinthe SL20115 PALOMA', 4.34, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.KRA2671', N'26', N'26MA', N'Embout tri-wing 1/4" 25mm N1', 1.03, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EPON.MG', N'24', N'24FB', N'Eponge magic gomme 110 x 66 x 30 mm', 2.1, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EPON.VEG.N6', N'24', N'24FB', N'Eponge vegetale N6', 0, 13, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EPON.VEG.N8', N'24', N'24FB', N'Eponge vegetale N8 150x116x50', 2.7788, 22, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EQUA.14PCE', N'26', N'26MA', N'pochette d''quarissoir 14 pieces pour chalumeau', 41.3, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EQUA.4PCE', N'26', N'26MA', N'pochette d''quarissoirs 4 pieces pour buse de chalumeau', 25, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.KRA2672', N'26', N'26MA', N'Embout tri-wing 1/4" 25mm N2', 1.03, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.KRA2673', N'26', N'26MA', N'Embout tri-wing 1/4" 25mm N3', 1.03, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.KRA2674', N'26', N'26MA', N'Embout tri-wing 1/4" 25mm N4', 1.03, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.PHN1L25', N'26', N'26MA', N'Embout philips N1 25mm', 1.944615, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.PHN2L50', N'26', N'26MA', N'Embout philips 1/4 N2 L50mm', 5.61, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.PZN1L25', N'26', N'26MA', N'Embout PZ N1 L25mm', 3.06, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.PZN1L90', N'26', N'26MA', N'Embout pozidrive N1 L90mm', 9.585, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.PZN2L25', N'26', N'26MA', N'Embout pozidriv N2 L25mm', 1.2, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.PZN2L90', N'26', N'26MA', N'Embout pozidrive N2 L90 mm', 9.585, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.PZN3L25', N'26', N'26MA', N'Embout pozidriv N3 L25mm', 3.575, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.PZN3L90', N'26', N'26MA', N'Embout pozidrive N3 L90mm', 9.585, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.SOL50', N'26', N'26MA', N'Embout vissable SOLO', 8.5, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.TS2.5', N'26', N'26MA', N'Embout spherique pour vis six pans creux 2.5 mm x 25', 6.05, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.TS3', N'26', N'26MA', N'Embout spherique pour vis six pans creux 3 mm x 25', 6.05, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.TS4', N'26', N'26MA', N'Embout spherique pour vis six pans creux 4 mm x 25', 6.05, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.TS5', N'26', N'26MA', N'Embout spherique pour vis six pans creux 5 mm x 25', 6.05, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.TX10', N'26', N'26MA', N'Embout torx N10', 2.8, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.TX20', N'26', N'26MA', N'Embout torx 20', 3.046, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.TX30', N'26', N'26MA', N'Embout torx de 30', 2.9025, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.TX40', N'26', N'26MA', N'Embout torx N40', 2.68467, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.TX50', N'26', N'26MA', N'Embout torx N50', 12.6, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.TX9', N'26', N'26MA', N'Embout torx N9 L26mm 1/4', 7.522, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.TXC10', N'26', N'26MA', N'Embout torx creux N10', 3.6, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.TXC15', N'26', N'26MA', N'Embout torx creux N15', 3.6, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.TXC20', N'26', N'26MA', N'Embout torx creux N20', 3.6, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.TXC25', N'26', N'26MA', N'Embout TORX creux 25mm 1/4', 3.615, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.TXC30', N'26', N'26MA', N'Embout torx creux N30', 3.6, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.TXC40', N'26', N'26MA', N'Embout torx creux TX 40', 4.437, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.TXZIN110X25', N'26', N'26MA', N'Embout torx creux ZINT 110x25 L', 5.7, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.TXZIN110X40', N'26', N'26MA', N'Embout torx creux ZINT 110x40 L', 5.7, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBO.TXZIN30X40', N'26', N'26MA', N'Embout torx creux ZINT   30x40 L', 3.7, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EMBR.ECHP021016610', N'14', N'14FC', N'Embrayage complet', 39.66, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENDU.SB25', N'05', N'05FA', N'Enduit de lissage special bande 25kgs', 20.01, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENJO.HAGWXD100B', N'12', N'12 FA', N'Enjoliveur WXD100B', 0.69, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENJO.LEG068001', N'12', N'12 FA', N'Enjoliveur blanc coupure simple', 1.0002, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENJO.LEG068002', N'12', N'12 FA', N'Enjoliveur blanc coupure double', 3.691, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENJO.LEG068111', N'12', N'12 FA', N'Enjoliveur 2P+T FB surface blanc', 0.9773, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENJO.LEG068251', N'12', N'12 FA', N'Enjoliveur blanc prise RJ45 simple', 2.5254, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENLE.DIND', N'09', N'09SC', N'enlevements de dechets industriels non dangereux', 1275.68, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENRE.SVER-48-217345', N'31', N'31MA', N'Enregistreur IP 100 ips 4TB H264 HDMI VGA-PNR-5304/4TB', 230.85, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENRO.', N'05', N'05FA', N'Fournitures d''enrochements', 25, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENRO.3G2.5-25', N'12', N'12 FA', N'Enrouleur electrique 25m 3G2,5', 126.4, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENRO.3G2.5-40', N'12', N'12 FA', N'Enrouleur electrique 40m 3G2.5', 151.49, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENRO.A_FR.', N'05', N'05FG', N'Enrobe a froid seau de 25kgs', 33.3, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENRO.AUT.AC8MM', N'22', N'22MA', N'enrouleur automatique air comprime passage 8mm', 296.944, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENRO.SANGL', N'05', N'05MA', N'Enrouleur de sangle blanc pour volet roulant diametre du  boitier 120mm', 13.33, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENSE.FAC.325', N'26', N'26MA', N'Ensemble ebavurage - chanfreinage', 81.54, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENSE.FACR151RN', N'26', N'26MA', N'Ensemble entretien pour cliquet PM', 5.48, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENSE.PF_SANDIEGO3559782', N'12', N'12 MC', N'Ensemble applique san diego 1191/265 cle I 7x70 F1', 10.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENSE.PF_SANDIEGO3782001', N'12', N'12 MC', N'Ensemble applique san diego 1191/265 cle I 7x70 F1', 10.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENSE.PF_VENISE', N'05', N'05MA', N'Ensemble Venise argent 190x40mm cle L', 7.12, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENSE.PLUIE_L', N'18', N'18MB', N'Ensemble de pluie a capuche L', 3.3987, 19, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENSE.PLUIE_M', N'18', N'18MB', N'Ensemble de pluie a capuche M', 3.4221, 18, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENSE.PLUIE_XXL', N'18', N'18MB', N'Ensemble de pluie a capuche XXL', 4.7, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENSE.PLUIEXL', N'18', N'18MB', N'Ensemble de pluie a capuche XL', 3.5321, 17, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENSE.PREKTBSM1', N'22', N'22FA', N'Ensemble filtre , rducteur et lubrificateur', 62.61, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENTO.PR160', N'26', N'26FD', N'Entonnoir plastique rond  contenu 1.2 litres lg du bec d''ecoulement coud 200mm', 6.78, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENTO.PR250', N'26', N'26FD', N'Entonnoir plastique rond  contenu 3.2 litres HT 255mm dn sortie 27mm', 7.4, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENTO.PREC4L', N'26', N'26FD', N'Entonnoir plastique rectangulaire avec tamis 4 litres', 11.13, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENTR.7X150L30', N'26', N'26FD', N'Entretoise cylindrique bichromatee M7x150 30mm', 0.27, 95, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.MANC14210/2', N'14', N'14FC', N'Fltre a air grand model pales', 26.35, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.MANC17337/2', N'14', N'14FC', N'Fltre a air grand model ergos', 30.21, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.MANC23440/1', N'33', N'33FB', N'Filtre a air camion C23440/1-echanger BOUR RVPS', 44.34, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.MANCF1800', N'22', N'22FA', N'Filtre air MANN CF1800', 20.95, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.MANCF850/2', N'14', N'14FC', N'Fltre a air petit model pales', 17.17, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.MANP917X', N'14', N'14FC', N'Filtre G-O-Renault 006005007409', 5.15, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.MANPF1190X', N'33', N'33FD', N'Filtre  huile  pour bateau le Sarre', 12.56, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.MANTB1374-3X', N'33', N'33FB', N'Filtre du circuit pneumatique / camion MIDLUM', 39.07, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.MANW11102/36', N'33', N'33FB', N'Filtre a huile pour camion Sarreguemines', 12.78, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.MANW1160/2', N'33', N'33FB', N'Filtre a huile Mann camion', 13.73, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.MANW7053', N'22', N'22FA', N'Filtre / poste a souder SDMO', 8.97, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.MANW75/3', N'33', N'33FA', N'Filtre a huile clio', 5, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.MANW77', N'14', N'14FC', N'Filtre a huile MANN  attila', 8.477333, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.MANW925', N'14', N'14FC', N'Filtre a huile', 13.72, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.MANW936/4', N'14', N'14FC', N'Filtre a huile tracteur ergos', 6.482399, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.MANW940', N'14', N'14FC', N'Filtre a huile tracteur', 7.93, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.MANW940/5', N'14', N'14FC', N'Filtre a huile tracter pales', 9.99, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.MANWK731', N'14', N'14FC', N'Filtre a gas-oil /pales', 6.700227, 2, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FILT.MANWK8100', N'14', N'14FC', N'Filtre a gas-oil ergos', 21.77333, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENTR.ECHC536000030', N'14', N'14FC', N'Entretoise plastique  SRM4600+4605', 14.8471, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENTR.ECHV353000020', N'14', N'14FC', N'Entretoise', 6.424, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENTR.KUHA5411834', N'14', N'14FC', N'Bague manille pour broyeur', 2.25, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENTR.NOR102870', N'14', N'14FC', N'Entretoise lisse', 17.52, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENTR.NOR103037', N'14', N'14FC', N'Entretoise lisse LN 1600', 0.64, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENTR.NOR103072', N'14', N'14FC', N'Entretoise LN 1600 Ref:103072', 0.66, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENTR.NOR103076', N'14', N'14FC', N'Entretoise pour MAGISTRA', 0.6782156, 113, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENTR.NOR27266', N'14', N'14FC', N'entretoise pour fixation corps de lame', 1.02, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENVE.BL110.X220 PB', N'17', N'17FC', N'Post bloc de 50 enveloppes blanche prcases bande protectrice 110x220', 1.135714, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENVE.K162.X229', N'17', N'17FC', N'Enveloppe kraft bande protectrice gamme environnement 162x229-90 grammes', 11.885, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENVE.KS30X260X330', N'17', N'17FC', N'Enveloppe kraft 260x330 soufflet de 30mm 120 gramme', 6.15, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ENZI.1L', N'05', N'05FI', N'Nettoyant aux enzymes', 26.6, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EPIN.TAB.AFFICH', N'17', N'17FA', N'Epingles pour tableau d''affichage', 0.47, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EQUE.FAC.819.200CLO', N'26', N'26MA', N'Equerre a chapeau 200mm', 178.08, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EQUE.LCM586058', N'12', N'12MB', N'Equerre de fixation pour chemin de cable boite de 50 pieces IN304L', 80, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ESSU.MAIN_KIM6763', N'24', N'24FB', N'Essuie main kimberly ultra super soft format 21.5x41.5 30x96 feuilles - 2880', 4.92512035, 271, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ESSU.TOUT', N'24', N'24FB', N'Lot de 24 Essuie-tout ouate blanc 50 formats 23x24.5', 0.5850625, 192, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ETAG.DEX755523', N'20', N'20MC', N'Etagre fixe universelle pour baie professionnel', 77, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ETAI.ARGENT', N'22', N'22MD', N'etain argent sans plomb D.15/10 ame decap. en bobine', 95.35, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ETAI_CLA6005012666', N'14', N'14FC', N'Etai', 0.71, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ETAI_CLA6005012696', N'14', N'14FC', N'Etai', 0.79, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ETAI_CLA6005012737', N'14', N'14FC', N'Etai', 0.9399999, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ETAU_125MM', N'26', N'26MA', N'Etau de 125mm avec base tournante', 111.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ETIQ.A210X297', N'17', N'17FC', N'Lot de 100 etiquettes autocollantes', 8.9, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ETIQ.A45.7X21', N'17', N'17FC', N'Etiquettes laser A4 resistantes  l''humidit pour milieu hostile 45.7x21mm blanches coins arrondis', 58, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ETIQ.A70X25', N'17', N'17FC', N'Etiquettes adresses autocollantes coin carre 70x25mm blanches', 4.02, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ETIQ.A70X32ROUGE', N'17', N'17FC', N'Etiquettes rouge 70x32mm multi usages', 14.65, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ETIQ.A70X37', N'17', N'17FC', N'Etiquettes adresses autocollantes coin carre 70x37mm blanches multi usages', 4.34, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ETIQ.A99.1X33.9', N'17', N'17FC', N'1600 etiquettes autocollantes adresses - blanc laser -16 etiquettes par planche', 28.22, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ETIQ.DYMMANAGER160', N'17', N'17MA', N'Etiqueteuse LABELMANAGER 160 ruban 6.9 et 12mm clavier AZERTY/NUMERIQUE', 27.17, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ETIQ.MAG30X100', N'17', N'17FC', N'Lot de 50 etiquettes magnetiques 30x100 mm blanc', 64, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ETIQ.PEPIQC21-30', N'20', N'20MC', N'Lot de 25 tiquettes electro', 66.98, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ETUI_12.5"', N'20', N'20FB', N'Etui de protection pour pC 12.5"', 13.7, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ETUI_P.CEINTURE', N'18', N'18MB', N'Etui combine PVC pour ceinture Husqvarna', 12.32, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EVEN.ECHA356000030', N'14', N'14FC', N'Event complet ECHO', 7.146, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EVEN.ECHA356000031', N'14', N'14FC', N'Event complet ECHO', 5.53, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EXTE.COOEXP-PSU', N'28', N'28MB', N'Extension bus 10 Z filaire + alimentation12V 3A', 192.57, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EXTE.EWO_FLB3202', N'20', N'20FB', N'Extension flexy modem 3G +', 245, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EXTE.EWO_FLX3101', N'20', N'20FB', N'Extension flexy port ethernet WAN (10/100 base T)', 178, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EXTR.FUME', N'22', N'22ME', N'Extracteur  fume FUA 1800', 2010.3, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FANI.K1', N'28', N'28MA', N'Fanion rouge K1', 16.56, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FARD.', N'28', N'28MA', N'Fardier cylindre charge lourde', 25, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FAUC.', N'26', N'26MA', N'fauchard', 21.66, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FAUS.EQU.FAC817.25', N'21', N'21MA', N'Fausse querre 250mm', 65.41, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEME.ACO523304', N'11', N'11FC', N'Femelle fixe Dia:16-1/2', 2.3, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_AD.WEL_DSX80', N'26', N'26FA', N'Fer a dessouder electronique 80 watts24V avec station de dessoudage WDD81X temperature de la pointe de soudage 450', 259, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_AS.WEL_WSP80', N'26', N'26FA', N'Fer a souder electronique 80 watts 24V temperature d''utilisation max +450 mini +150', 177, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_AS20-40W', N'26', N'26MA', N'Pistolet  souder 230V-20-40W', 33.9, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_CARRE10', N'05', N'05FC', N'Fer carre de 10mm E24 6,1ml', 0.51, 18.3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_CARRE12', N'05', N'05FC', N'Fer carre de 12mm E24 6,1ml', 0.6144, 24.4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_IPN80', N'05', N'05FC', N'IPN 80mm', 7.201142, 36.6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_P020X06', N'05', N'05FC', N'Fer plat 20x6x6,2ml', 0.3964, 36.6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_P025X04', N'05', N'05FC', N'Fer plat 25/4', 2.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_P025X05', N'05', N'05FC', N'Fer plat 25/5', 0.4589, 24, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_P030X05', N'05', N'05FC', N'fer plat 30x5-6ml', 1.539731, 36, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_P030X08', N'05', N'05FC', N'fer plat 30x8-6ml', 1.1815, 30, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_P035X05', N'05', N'05FC', N'Fer plat 35/5 E24 barre de 6,10ml', 1.23, 24.4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_P035X08A2', N'05', N'05FC', N'Inox plat 35/8 barre de 6ml', 13.125, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_P040X05', N'05', N'05FC', N'Fer plat 40x5x6,2ml', 0.5946, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_P040X05A2', N'05', N'05FC', N'Fer plat inox 40x5x6,2ml', 10.748, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_P040X06', N'05', N'05FC', N'Fer plat 40x6x6,2ml', 3.88, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_P050X06', N'05', N'05FC', N'Fer plat 50x6x6,2ml', 2.73, 24.4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_P050X08', N'05', N'05FC', N'Fer plat 50x8-6ml', 2.57, 24.4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_P050X15', N'05', N'05FC', N'Fer plat 50x15 long.6,15ml', 11.86, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_P060X08', N'05', N'05FC', N'Fer plat 60x8    6,00 ml', 2.7996, 42, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_P070X08', N'05', N'05FC', N'Fer plat 70X8', 8.5165, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_P080X08', N'05', N'05FC', N'Fer plat 80x8 longueur 6,15ml', 4.5744, 24.6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_P080X10', N'05', N'05FC', N'Fer plat 80x10 longueur 6,15ml', 12.7, -3.88751E-09, 0, 3.88751E-09, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_P090X10', N'05', N'05FC', N'Fer plat 90x10 longueur de 6,15ml', 22.9, 3.387658E-14, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_P120X 6', N'05', N'05FC', N'Fer plat 120x6 6,15ml', 11.915, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_R06MM', N'05', N'05FC', N'Fer rond de serrurier dia:6mm', 0.254, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_R06MMINOX', N'05', N'05FC', N'Fer rond inox dia:6mm barre de 3ml', 1.71, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_R08MM', N'05', N'05FC', N'Fer rond de serrurier 8mm', 0.3049, 30, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_R08MMINOX', N'05', N'05FC', N'Fer rond inox dia:8mm barre de 3ml', 2.985, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_R10MM', N'05', N'05FC', N'Fer rond de serrurier 10mm', 0.4269, 30, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_R10MMINOX', N'05', N'05FC', N'Fer rond inox dia:10mm barre de 3ml', 4.635, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_R12MM*', N'05', N'05FC', N'fer rond de serrurier 12mm', 1.122507, 18, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_R16MM', N'05', N'05FC', N'Fer rond de serrurier DN:16mm S235JRG2', 2.519292, 30, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_R18MM', N'05', N'05FC', N'Fer rond de serrurier 18mm / ml', 4.754, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_R20MM', N'05', N'05FC', N'Fer rond de serrurier DN:20mm', 3.211673, 24, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_R25MM', N'05', N'05FC', N'fer rond de serrurier dn 25mm', 2.99, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_T30X4', N'05', N'05FC', N'Fer T 30X30x4 barre de 6,15ml prix /ml', 2.65, 18, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_TOR08', N'05', N'05FC', N'Fer tor de 8mm barre de 6ml', 3.074, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_TOR10', N'05', N'05FC', N'Fer tor de 10mm barre', 4.601, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_TOR12', N'05', N'05FC', N'Fer tor de 12mm barre de 6ml', 9.44, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_TOR14', N'05', N'05FC', N'Fer tor de 14mm barre de 6ml', 12.7, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_UAC50X25X5', N'05', N'05FC', N'Fer UAC 50x25 p:5 E24', 2.4742, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_UPN080MM', N'05', N'05FC', N'Fer UPN 80mm 6,1ml', 17.08507, 12.2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FER_UPN100MM', N'05', N'05FC', N'Fer UPN 100 S275JR', 14.006, 12.2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FERM.12.5/260/120', N'05', N'05FA', N'Plaque de Fermacell 12.5mm/2.600x1.200', 11.15, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FERM.6.5X6.5X0.07_25ML', N'26', N'26FD', N'fermette galvanise maille de 6.5x6.5x0.07 hauteur 1m longueur 25ml', 85.96, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FERU.', N'26', N'26MA', N'Frule pour manche de fourche', 2.16, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEU_00000000601', N'33', N'33FB', N'feu de position rond dn 80mm direction+stop', 11.81, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEU_4 FONC.REM', N'33', N'33FC', N'Feu arrire de remorque 4 fonctions', 2.344, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEU_BABORD', N'33', N'33FD', N'Feu babord corps noir grand modle', 52.0665, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEU_CLA7701026757', N'14', N'14FC', N'Feu avant complet tracteur', 14.3, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEU_GUE.502-2', N'33', N'33FD', N'Feu projecteur blanc 24V DC', 496, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEU_HEL2SD002514161', N'33', N'33FC', N'Feu arrire de remorque', 8.84, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEU_INF2231', N'33', N'33FC', N'Feu de remorque blanc pour remorque', 12.18, 0, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEU_MARIL46237', N'33', N'33FD', N'Feu projecteur orientable  blanc 24V DC  tlcommande', 308.25, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEU_POUPE', N'33', N'33FD', N'Feu de poupe corps noir grand modle', 69.55, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEU_ROUGE_AV88', N'33', N'33FC', N'Feu rouge arrire mobylette AV88', 44.607, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'FEU_RVI5021136890', N'33', N'33FC', N'Feu rond de position avant cristal + CA', 9.253, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DECA.2000W', N'22', N'22MF', N'Decapeur thermique 2000W 2temp.45', 82.68, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DECA.PV5', N'05', N'05FI', N'Decapant PV gel 5L', 67, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DECA.SOUDER', N'05', N'05FI', N'Decapant a souder', 9.85, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DECL.SCHGVAX385', N'12', N'12 FA', N'Declencheur Tesys CVAX pour GV2ME', 31.77, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DECO.BOS06012331004', N'22', N'22ME', N'Decoupeur -ponceur  GOP 40-30 3 lames', 233.17, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DEGR.HD2', N'05', N'05FI', N'Degraissant industriel biologique pour fontaine bio chauffante bidon de 20l', 179.8, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DEMA.CLA05111613360', N'14', N'14FC', N'Demarreur', 381.89, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DEMA.CLA11320110', N'14', N'14FC', N'Demarreur Ergos', 362.77, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DEMA.SCHLE1M35P706', N'12', N'12 FA', N'Dmarreur 0.18kw 3P 230V50 60', 75.68, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DEMI_CYL30X10', N'05', N'05MA', N'demi cylindre 30x10 3 cls PG/PP', 32.76, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DEMI_RAC.ALU.2"', N'22', N'22FA', N'Demi raccord Alu Sym.2"', 21.6889, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DEMI_RAC.ALU.40', N'22', N'22FA', N'Demi raccord Alu Sym 1"1/2  dn40mm gaz verrou', 27.07, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DEMI_RAC.ALU25', N'22', N'22FA', N'Demi raccord express cannelee 25', 5.83, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DEMI_RAC.ALU32F', N'22', N'22FA', N'Demi raccord symetrique 2416 femelle 32 alu sans verrou cannelee', 5.83, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DEMI_RAC.ALU50/51', N'22', N'22FA', N'Demi raccord symetrique 2411  50/51 cannel alu', 16.7233, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DEMO.750ML', N'05', N'05FI', N'Spray 750ML dmoustiqueur pour vhicules gamme bio', 10.4, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DENT_1B7107330_PACK', N'22', N'22FA', N'Dent avec support pack de 10', 312.282, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DENU.CABLE', N'26', N'26MA', N'Denude cable jokari', 32.06, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DEPL.', N'32', N'32SB', N'deplacement pour  prestation', 40, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DESH.BIO5L', N'14', N'14FB', N'Dsherbant vgtal non phyto', 38.55, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DESO.CLIP_MEL.', N'24', N'24FB', N'Desodorisant clip melon concombre', 10.73, 30, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DESO.COQ.MELON', N'24', N'24FB', N'Desodorisant coque concombre - melon', 18.53, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DESO.MECHE', N'24', N'24FB', N'Desodorisant a meche', 5.12574625, 29, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DETE.BANQS303E', N'12', N'12 FA', N'detecteur expert emet.barrage 213', 119, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DETE.BANQS30ARXQ', N'12', N'12 FA', N'detecteur expert recept.barrage 213', 179, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DETE.BANQS30EXQ', N'12', N'12 FA', N'detecteur expert emet.barrage 213', 176.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DETE.BANQS30VR3R', N'12', N'12 FA', N'detecteur expert recepteur barrage 213', 178, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DETE.MVTS', N'12', N'12 FA', N'Detecteur de mouvements 180 + 360 noir', 38.61333, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DETE.OXY10M3', N'26', N'26FD', N'detendeur pour bouteille d''oxygene 10m3 chantier', 80.77, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DETE.RX40QZPT', N'28', N'28MB', N'Detecteur IR passif intrieur 12M/90', 27, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DETE.SCHXUX0ARCTT16', N'12', N'12MB', N'Detecteur Osiconcept XUX 0 infrarouge de type barrage (rcepteur)', 97.96, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DETE.SCHXUX0ARCTT16T', N'12', N'12MB', N'Detecteur Osiconcept XUX 0 de type barrage (transmetteur)', 51.54, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DETE.STARNET', N'24', N'24FB', N'Detergent degraissant bidon de  5 litres', 45.3, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DETE.STE034702', N'12', N'12 FA', N'Detecteur IS 2180 eco noir', 30, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DEVI.ESCARGOT', N'17', N'17FC', N'Devidoir escargot pour ruban adhesif', 0.465, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DEVI.FILASSE', N'26', N'26FD', N'Dvidoir pour filasse', 29.2, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DIAB.M.ESCALIER', N'22', N'22MB', N'Diable monte escalier en acier 200kgs  dim.590x645x1300 pelle 320x250 diametre roue 260x85', 320, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DIAB.PLIANT300KGS', N'22', N'22MB', N'Diable pliant - roue gonflable - capacit 300kgs - bavette 450x595', 149, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DIAP.ECH12311215030', N'14', N'14FC', N'Membrane pour ECHO 4600', 5.449, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DIAP.ECH12314103930', N'14', N'14FC', N'Diaphragme pour ECHO 4600', 12.597, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DIFF.SAF12189', N'22', N'22FA', N'Diffuseur gaz noir', 4.1, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DILU.5L_BIO', N'05', N'05FI', N'Diluant pour travaux de nettoyage biodegradable', 103.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DILU.CELLULOSIQ.', N'05', N'05FI', N'Diluant cellulosique', 5.982, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DILU.N5L', N'05', N'05FI', N'Diluant pour pnettoyage', 37.275, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DILU.P5L', N'05', N'05FI', N'Diluant pour peinture D2420', 54.65, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DILU.TEX30', N'05', N'05FI', N'DILUANT TEX 30  POUR PEINTURE COMUS PISCINE', 9.82, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DIOD./LUNET', N'18', N'18MB', N'Paire de diodes avec piles au lithium fournies pour lunettes', 11.75, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISJ.FG261140', N'12', N'12 FA', N'Disjoncteur 10A', 5.6, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISJ.FG261150', N'12', N'12 FA', N'Disjoncteur 16A', 5.6, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISJ.MG21407', N'12', N'12 FA', N'DT40 tri+neutre pdc 10ka 20A courbe c', 57.79074, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISJ.SCHA9F74201', N'12', N'12 FA', N'Disjoncteur 1A courbe C 2P IC60N', 65.71, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISJ.SCHA9F74202', N'12', N'12 FA', N'Disjoncteur 2A courbe C 2P IC60N', 67.26, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISJ.SCHA9F75402', N'12', N'12 FA', N'Disjoncteur 2A COURBE D 4P IC60N', 168.48, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISJ.SCHA9F77220', N'12', N'12 FA', N'Disjoncteur bipolaire 20A courbe C', 36.66, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISJ.SCHA9F77432', N'12', N'12 FA', N'Disjoncteur magnetothermique acti9  32A C 4P iC60 N courbe C', 80.86, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISJ.SCHA9F77440', N'12', N'12 FA', N'Disjoncteur IC60N  4P 40A courbe C', 125.42, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISJ.SCHA9N21020', N'12', N'12 FA', N'DT40N 1P+N 2A C', 18.16, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISJ.SCHA9N21025', N'12', N'12 FA', N'DT 40 1P+N C16 6KA', 77.24, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISJ.SCHA9N21361', N'12', N'12 FA', N'DT40N 1P+N 2A C 10KA', 55.95, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISJ.SCHA9N21366', N'12', N'12 FA', N'DT40N 1P+N C16 10KA RE', 22.73, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISJ.SCHA9N61522', N'12', N'12 FA', N'Disjoncteur 2A COURBE C 2P C60H-DC', 81.79, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISJ.SCHA9N61526', N'12', N'12 FA', N'Disjoncteur 6A COURBE C 2P C60H-DC', 80.73, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISJ.SCHA9N61528', N'12', N'12 FA', N'Disjoncteur 10A COURBE C 2P C60H-DC', 81.05, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISJ.SCHA9P24616', N'12', N'12 FA', N'Disjoncteur modulaire ACTI 9 1P+N C  IDT40N', 32.97, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISJ.SCHA9Q11440', N'12', N'12 FA', N'Disjoncteur', 185.02, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISJ.SCHGV2ME07', N'12', N'12 FA', N'Disjoncteur magntothermique tesys GV2 triphas, AC3, 400VAC, 0.75KW, 2.5A,', 43.02, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISJ.SCHNLSN10C', N'12', N'12 FA', N'Disjoncteur divisionnaire SCHUPA 16A  NLSN 10-C', 6.8602, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISP.HYDROCARBURES', N'05', N'05FI', N'Traitement dispersant des ecoulements accidentels d''hydrocarbures et d''huiles', 70.25, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISP.PHOTCMGUARDRS40004GVPN', N'20', N'20MC', N'dispositif de securit mobile 4G 10 tunnels VPN pare feu intelligent', 1400.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.115DIAM', N'26', N'26FD', N'Disque diamant dia 115 universel', 49.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.115DIAMCA', N'26', N'26FD', N'Disque diamant Diametre 115 mm', 43.68, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.115EB', N'26', N'26FD', N'Disque 115x6,4x22 a ebarber acier', 5.025556, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.115F1', N'26', N'26FD', N'Disque a trononner acier 115x1,0xx22', 3.25, 0, 0, 0, 50)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.115TR', N'26', N'26FD', N'Disque a trononner acier 115x2,5x22', 3.131467, 37, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.125DIAM', N'26', N'26FD', N'Disque diamant dia 125 mm', 52.674, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.125DIAM/CH', N'26', N'26FD', N'Disque diamant dia 125 mm  chanfreiner', 188, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.125DIAMCA', N'26', N'26FD', N'Disque diamant carrelage Diametre 125mm', 49.88, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.125EB', N'26', N'26FD', N'Disque a ebarber acier 125x6,4x22', 5.728148, 22, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.125F1', N'26', N'26FD', N'Disque a trononner acier 125x1,0xx22', 2.74818, 62, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.125MULTICUT', N'26', N'26FD', N'Disque a trononner multicut 125x22.2mm', 19.9, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.125TR2.5', N'26', N'26FD', N'Disque a trononner acier 125x2.5x22,2', 2.8607, 48, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.150DIAM', N'26', N'26FD', N'Disque diamant coupe a sec pour rainureuse dn 150mm x 22.2mm', 52.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.180DIAMCA', N'26', N'26FD', N'Disque diamant a eau carrelage Diametre 180x1.6x30', 49, 2, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.230DIAM', N'26', N'26FD', N'Disque diamant 230x2.4x22.23', 127.9486, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.230DIAMU', N'26', N'26FD', N'Disque diamant unicut 230x2.4x22.23', 130.49, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.230EB', N'26', N'26FD', N'Disque a ebarber 230x6x22mm acier', 9.69835, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.230TR.EP2.5', N'26', N'26FD', N'Disque 230x2,5x22 a tronconner acier', 8.15, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.230TR.EP3', N'26', N'26FD', N'Disque 230x3x22 a tronconner acier', 8.15, 40, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.300DIAM', N'26', N'26FD', N'Disque diamant 300 alesage de 20mm', 153.5444, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.63TR', N'26', N'26FD', N'Disque  trononner TYROA 63X1', 1.3, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.65TR', N'26', N'26FD', N'Disque  trononner 65 EP 1.8 - 3.2', 1.3, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.BLEU', N'26', N'26FD', N'Disque de stationnement rglementaire', 6.24, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.D.WEST2TO_BLACK', N'20', N'20FB', N'Western digital disque dur 2 TO SATA 3  Western digital WDblack', 166.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.D1TO', N'20', N'20FB', N'Western digital disque dur 1 TO 3.5" RED', 67, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.D4TO', N'20', N'20FB', N'Disque dur 4 TO WD40PURZ', 145, 0, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.DSVHK-50-303800458', N'20', N'20FB', N'Disque dur 6TB WD60PURZ', 213.4, 0, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.KM25', N'33', N'33FB', N'Disque 25km/h adhesif', 3.96, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.LAM110X40', N'26', N'26FD', N'Disque  lamelles 110 gr40', 8.5, 34, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.LAM110X80', N'26', N'26FD', N'Disques  lamelles 110 Gr.80', 4.43, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.LAM125X40', N'26', N'26FD', N'Disques  lamelles 125 Gr.40', 4.703077, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.LAM125X80', N'26', N'26FD', N'Disques  lamelles 125 Gr.80', 8.5, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.LAM180X40', N'26', N'26FD', N'Disque  lamelles Gr.40 DN180 au zirconium', 10.94333, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.REN7701206339', N'33', N'33FA', N'Disque de frein  Kangoo', 79.8355, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.REN7701209839', N'33', N'33FA', N'Disque de frein  Kangoo', 82.739, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.SSD1TO', N'31', N'31MA', N'Disque dur SSD 1TO interne SATA3', 192.3, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.STH41197133100', N'14', N'14FC', N'Disque porteur FS86', 7.612, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.SVAX-11-217659', N'31', N'31MA', N'Disque dur 4 TB, SATA, HDD-400SATA purple - 217659', 323.292, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.TACHY125', N'33', N'33FB', N'Disque /D KOMBI 125-24 EC4K-FLIFE165A', 10.2617, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DISQ.TACHY140', N'33', N'33FB', N'Disque /D KOMBI 140KM/H -24 EC4K-FLIFE165A', 17.76, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DIST.PT_MX', N'24', N'24FB', N'Distributeur ABS blanc pour papier toilette maxi bobine', 49.349, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DIST.PT900F', N'24', N'24FB', N'Distributeur papier toilette 900 feuilles compact', 6.337, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DIST.RHEA', N'22', N'22ME', N'Distributeur de 30 telecommandes', 24966, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DIST.SAV350ML', N'24', N'24FB', N'Distributeur savon anti goutte 350 ml lotus', 40.81, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DIST_PHOPTFIX6/18X2.5-NS35BU', N'20', N'20FB', N'Bloc distributeur 19 connections, section 0.14-4mm,  larg:28.6 haut 28.7 bleu', 5.3619, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DIST_PHOPTFIX6/18X2.5-NS35RD', N'20', N'20FB', N'Bloc distributeur 19 connections, section 0.14-4mm,  larg:28.6 haut 28.7 rouge', 5.3619, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DIVE', N'26', N'26FD', N'Divers petites fournitures', 0.58, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOCK.HORC738144', N'20', N'20MC', N'docking station double sata 3.5/2.5 USB 3.0 5GB', 69, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOCK.HORC738148', N'20', N'20MC', N'Dock USB 3.0 SATA/IDE pour 2 SSD/HDD 2.5 ou 3.5', 61, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOLI.1G', N'25', N'25FA', N'Boite de doliprane 1g', 2.024103, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOMI.10MM', N'12', N'12MB', N'Barrette de domino noir 10mm', 1.66771853, 17, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOMI.16MM', N'12', N'12MB', N'Barrette de domino 16mm', 2.976, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOMI.6MM', N'12', N'12MB', N'Barrette de domino 6mm', 0.9404, 14, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DORS.', N'26', N'26FD', N'COUSSIN D''ASSISE', 0, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOSE_NET.SOL', N'24', N'24FB', N'Dose nettoyant sol', 0.99, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOSS.SUSP30', N'17', N'17FC', N'Boite de 4 dossiers suspendus 30mm coloris assortis', 41.02, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOUI.FAC17H', N'26', N'26MA', N'Douille FACOM 17H pour cliquet', 2.691, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOUI.FACEF6DM8L', N'26', N'26MA', N'Douille FACOM magnetique pour vis six pans creux', 9.07, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOUI.FACK55B', N'26', N'26MA', N'Douille FACOM 3/4 12 pans mtrique 55mm', 24.61, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOUI.FACNM.50A', N'26', N'26MA', N'Douille FACOM impact 16 PT 50mm', 47.29, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOUI.FACNS27LA', N'26', N'26MA', N'Douille FACOM longue impact 1/2 - 27mm', 16.35, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOUI.FACNS29LA', N'26', N'26MA', N'Douille FACOM longue impact 1/2 - 29mm', 19.51, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOUI.FACNS30LA', N'26', N'26MA', N'Douille FACOM longue impact 1/2 - 30mm', 0, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOUI.FACNS32LA', N'26', N'26MA', N'Douille FACOM longue impact 1/2 - 32mm', 0, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOUI.FACS21', N'26', N'26MA', N'Douille 12 pans  19mm 1/2', 3.23, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOUI.FACS32L', N'26', N'26MA', N'Douille FACOM longue - 32mm 12 pans', 14.16, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOUI.FACSTM.8', N'26', N'26MA', N'Douille tournevis', 8.25, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOUI.KRA301100', N'26', N'26MA', N'Douille  longue 10 1/2', 7.32, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOUI.KRA301130', N'26', N'26MA', N'Douille  longue 13 1/2', 7.32, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOUI.KRA301170', N'26', N'26MA', N'Douille  longue 17 1/2', 7.32, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOUI.KRA301190', N'26', N'26MA', N'Douille  longue 19 1/2', 7.32, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOUI.SAMSH14', N'26', N'26MA', N'Douille 14 standard', 3.82, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DOUI.STH11297925500', N'14', N'14FC', N'Douille', 0.94, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DRAI.AGRIJ100X50', N'05', N'05FA', N'Rouleau de drain agricole jaune dia:100 50ml', 1.63, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DRAI.AGRIJ65X50', N'05', N'05FA', N'Rouleau de drain agricole jaune dia:65mm  50ml', 0.77, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DURI.PER26481', N'33', N'33FD', N'Durite eau', 5.72, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DVD_+R', N'20', N'20FB', N'DVD+R 16x boitier slim case', 1.82, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EASY_CLIP', N'28', N'28MA', N'Clip de controle pour vrification des engins et matriels', 120, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EAU_0.5', N'01', N'01FB', N'Eau  pack de 24 x 50cl', 3.39, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EAU_0.5/12', N'01', N'01FB', N'Eau  pack de 12 x 50cl', 3.56, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EAU_1.5L', N'01', N'01FB', N'Eau  pack de 6 x 1,5l', 3.52, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECHA.TRIANGULAIRE', N'25', N'25FA', N'Echarpe triangulaire', 4.75, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECHE.WOLORM', N'26', N'26MA', N'Elagueur POUR MANCHE ZMT1 et ZMT2', 33.822, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECLA.RVI5021186039', N'33', N'33FA', N'eclaireur de plaque d''immatriculation pour remorque', 11.151, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECLI.CAB558288', N'12', N'12MB', N'Eclisses  IN304L', 5.4, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECO_TAXE', N'09', N'09SC', N'Eco taxe', 0.16, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRA.CENS54CE', N'18', N'18MB', N'Ecran polycarbonate incolore pour support CENTURION S54CE', 11.5, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRA.CENS59CE', N'18', N'18MB', N'Ecran grillage forestier', 18.754, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRA.DEL_P2719H', N'20', N'20MC', N'Ecran 27" de 68.6cm noir', 195, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRA.ELEC.135X180', N'31', N'31MD', N'Ecran electrique  fixation plafond 135x180', 765, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRA.MURAL', N'17', N'17FC', N'Ecran mural ou plafond 150x150 s''ajuste a tous les standards', 71.48, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRA.PLEX107X52', N'18', N'18MB', N'ECR.PLEX.107X52 pour masque a souder', 4.606, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRA.PLEX108X88', N'18', N'18MB', N'ECR.PLEX.108X88 pour masque a souder', 1.8, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRA.PLEXI.EXT9000', N'18', N'18MB', N'masque a souder exterieur SPEED 9000', 5.62, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRA.PLEXI.EXT9100', N'18', N'18MB', N'masque a souder exterieur SPEED 9100', 4.79, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRA.PLEXI.INT9000', N'18', N'18MB', N'masque a souder interieur SPEED 9000', 4.08, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRA.PLEXI.INT9100V', N'18', N'18MB', N'masque a souder interieur SPEED 9100V', 1.94, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRA.POLY108X51', N'18', N'18MB', N'ECR.polycarbonate108X51 pour masque a souder', 1.89, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRA.STH00008840511', N'18', N'18MB', N'visiere integrale grillag sans casque pour debroussaillage', 34.45, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRA.SVHK-40-3025001992', N'20', N'20MC', N'Ecran LED 50" VGA/HDMI DS-1005KI', 843.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRA.TREPIED', N'17', N'17FC', N'Ecran trpied 150x150 en toile rglable en hauteur. s''adapte a tous les standards.', 104, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.08ETCAOL1290', N'14', N'14FC', N'Ecrou tournant hydraulique 12 - 90', 5.44, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.12L-INOX', N'22', N'22FA', N'Ecrou M12 inox', 2.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.AIL06', N'26', N'26FD', N'Ecrous papillon M6 AC ZI 4.6', 0.328, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.AIL08', N'26', N'26FD', N'Ecrous  ailettes M8 AC ZI 4.6', 0.433, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.AIL10', N'26', N'26FD', N'Ecrous  ailettes M10 AC ZI 4.6', 0.768, 41, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.AIL12', N'26', N'26FD', N'Ecrous  ailettes M12 AC ZI 4.6', 0.909, 13, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.BN04', N'26', N'26FD', N'Ecrou frein bague nylon M4', 0.073, 139, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.BN05', N'26', N'26FD', N'Ecrou frein bague nylon M5', 0.03, 200, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.BN06', N'26', N'26FD', N'Ecrou frein bague nylon M6', 0.0308, 242, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.BN08', N'26', N'26FD', N'Ecrou frein bague nylon M8', 0.022, 56, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.BN10', N'26', N'26FD', N'Ecrou frein bague nylon M10', 0.1122351, 118, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.BN10A2', N'26', N'26FD', N'Ecrou frein bague nylon M10 inox A2 10.9', 0.1825, 67, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.BN12', N'26', N'26FD', N'Ecrou frein bague nylon M12', 0.1293796, 96, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.BN1210.9', N'26', N'26FD', N'Ecrou frein bague nylon M12 10.9', 0.2179, 34, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.BN14', N'26', N'26FD', N'Ecrou frein bague nylon M14', 0.38, 84, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.BN16', N'26', N'26FD', N'Ecrou frein bague nylon M16', 0.2903, 46, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.BN18', N'26', N'26FD', N'Ecrou frein bague nylon M18', 0.46, 53, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.BN20', N'26', N'26FD', N'Ecrou bague nylon frein M20', 0.37, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.CAGE_M6', N'26', N'26FD', N'Ecrou cage M6', 0.189, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.CAOS 12', N'14', N'14FC', N'Ecrou tournant hydraulique', 3.23, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.CAOS12-90', N'14', N'14FC', N'Ecrou tournant hydraulique 90', 5.35, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.CLA11363160', N'14', N'14FC', N'Ecrou pour roue AR tracteur PalesM18 X 1.50 Classe 10 en I', 0.8415, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.CLA11570060', N'14', N'14FC', N'Ecrou', 1.42, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.CLA6005000461', N'14', N'14FC', N'Ecrou pour roue AR tracteur Pales', 1.581, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.CU06', N'26', N'26FD', N'Ecrou cuivre M6', 0.6, 81, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.ECH61032052130', N'14', N'14FC', N'Ecrou  pour ECHO 4605', 8.5285, 4, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.ECH90010605020', N'14', N'14FC', N'vis', 1.8216, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.ECH90050200006', N'14', N'14FC', N'Ecrou iso bas', 0.09, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.ECH90050200008', N'14', N'14FC', N'Ecrou hexagonal bas AC ZI  Dia 8 Echo', 0.03, 103, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.ECH90051100010', N'14', N'14FC', N'Ecrou a gauche Dia10 Echo', 1.59045, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.EUT27368', N'14', N'14FC', N'Ecrou 27368 ATTILA AV95', 4.3067, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.FTG', N'22', N'22FA', N'Ecrou filetage trapeze a gauche suivant modele', 368.5, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.GCU06', N'26', N'26FD', N'Ecrou laiton brut M6', 0.6, 91, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.H04', N'26', N'26FD', N'Ecrou H AC ZI M4', 0.0203, 708, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.H05', N'26', N'26FD', N'Ecrou H M5 AC ZI 8,8', 0.0156, 438, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.H05A2', N'26', N'26FD', N'Ecrou H M5 inox A2', 0.0239, 150, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.H06', N'26', N'26FD', N'Ecrou H M6 AC ZI 8,8', 0.0195683, 387, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.H07', N'26', N'26FD', N'Ecrous H AC ZI M7', 0.0355, 242, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.H08', N'26', N'26FD', N'Ecrou H M 8,8 AC.ZI 8,8', 0.03234199, 390, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.H08A2', N'26', N'26FD', N'Ecrous Hex Hu Inox A2 934 M8', 0.067, 177, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.H10', N'26', N'26FD', N'Ecrou H M10 AC ZI 8,8', 0.06679355, 558, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.H10A2', N'26', N'26FD', N'Ecrous Hex Hu Inox A2 M10', 0.1113787, 86, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.H12', N'26', N'26FD', N'Ecrou H M12 AC ZI 8,8', 0.09875498, 381, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.H12A2', N'26', N'26FD', N'Ecrous Hex Hu Inox A2  M12', 0.11, 85, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.H14', N'26', N'26FD', N'Ecrou H M14 AC ZI 8,8', 0.21, 175, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.H16', N'26', N'26FD', N'Ecrou H M16 8.8 AC ZI', 0.1873736, 145, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.H16_10.9', N'26', N'26FD', N'Ecrou H M16 10.9 AC BRUT', 0.2157143, 175, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.H16A2', N'26', N'26FD', N'Ecrou H M16 AC inox A2', 0.44, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.H18', N'26', N'26FD', N'Ecrou H M18 AC ZI 8,8', 0.307515562, 232, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.H20', N'26', N'26FD', N'Ecrou H M20 AC ZI 8,8', 0.4754789, 36, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.H20_10.9', N'26', N'26FD', N'Ecrou H M20 AC ZI 10.9', 0.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.H22', N'26', N'26FD', N'Ecrou H M22 AC ZI 8,8', 0.4323, 24, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.H22A2', N'26', N'26FD', N'Ecrou H M22 AC inox A2', 1.68, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.H24', N'26', N'26FD', N'Ecrou H M24 AC BR 8,8', 0.9056926, 96, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.H27', N'26', N'26FD', N'Ecrous H AC ZI 8.8 M27', 1.04, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.H30', N'26', N'26FD', N'Ecrous H AC ZI M30 8.8', 1.01, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.KUH80201241', N'14', N'14FC', N'Ecrou HEX AUTO  / manille pour broyeur', 0.24, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.M12L', N'14', N'14FC', N'Ecrou M12L - EO hydraulique', 0.64, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.M16S', N'14', N'14FC', N'Ecrou M16S', 2.021, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.M52EP26', N'22', N'22FA', N'Ecrou M52 x5.00  droite paisseur 26 suivant modle', 52, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.NOR103018', N'14', N'14FC', N'ecrou de securite', 0.3049081, 118, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.NOR103019', N'14', N'14FC', N'Ecrou H M14 10.9 / MAGISTRA', 0.3009966, 93, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.NOR103022', N'26', N'26FD', N'Ecrou H Dia11 LN 1600', 0.2232468, 104, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.NOR103690', N'14', N'14FC', N'Ecrou de securite', 1.03, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.NOR103691', N'14', N'14FC', N'Ecrou de securite M18 cl.8 ZN', 0.38, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.ROND06', N'26', N'26FD', N'Ecrou rondelle type twolok M6', 0.0513, 200, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.ROU11105010', N'14', N'14FC', N'Ecrou de racleur', 0.48, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.ROUE', N'33', N'33FC', N'Ecrou de roue compresseur de chantier', 1.36, 0, 0, 0, 8)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.RVI5005030013', N'33', N'33FB', N'Ecrou raccord 2 A 10', 3.87, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.SER230', N'22', N'22FA', N'Ecrou de serrage rapide pour  meuleuse dn 230mm', 42.35, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COMM.HIR_SPIDER5TX', N'20', N'20MC', N'Commutateur ethernet 5 ports RJ45', 152.85, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COMM.LEG27510', N'12', N'12 FA', N'Commutateur triphas inverseur de phase', 37.25, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COMM.YNM7263502000', N'33', N'33FC', N'commande de frein avant pour mobylette club', 9.552, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COMP.24LNUAIR', N'22', N'22ME', N'Compresseur 24l  FC2/24 CMZ S CE', 260, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COMP.FACDELA1901.08', N'26', N'26MA', N'Compas a pointe seche 250mm', 13.12, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COMP.PRES23285P', N'21', N'21MA', N'Compteur digital / citerne mobile', 298, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COMP.STER10X10', N'25', N'25FA', N'Boite de 10 compresses steriles de gaz hydrophile 10x10', 2.030925, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONC.0/31.5', N'05', N'05FA', N'Concasse calcaire 0/31,5', 16.18, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONC.10/14', N'05', N'05FA', N'Concasse calcaire 10/14 a la tonne', 16.25, 0, 0, 0, 12)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONN.SEA099', N'12', N'12 MC', N'Connecteurs etanches 2x1 rouge 2 voies femelle', 6.72, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONN.SEA101', N'12', N'12 MC', N'Connecteurs etanches 2x1 vert 2 voies femelle', 6.72, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONN.STA6030003263-FI-G-30S-W3', N'22', N'22FA', N'Connectique raccord STAUFF', 12.82, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONN.STA6030003829-FI-M-30S-W3', N'22', N'22FA', N'Connectique raccord STAUFF', 5.67, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONN.TH.BLEU1.5-2.5', N'12', N'12MB', N'Connecteur thermofusible  section cable 1.5 - 2.5 mm', 1.576, 65, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONN.TH.ROUG0.5-1.5', N'12', N'12MB', N'Connecteur thermofusible  section cable 0.5 - 1.5 mm', 1.508, 85, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONN.W1963590000', N'12', N'12 FA', N'Connecteur SNAP IN CAT6 avec protection anti coudage', 1.9344, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONS.MA', N'14', N'14FC', N'Petits consommables materiel agricole', 7.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONT.AUMZ032.068', N'22', N'22FA', N'Contact FDC/LDC simple 1os/Ag-250V-0.5A-220-SA/Sn REP.560.1', 48, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONT.CHA6460', N'21', N'21MA', N'Controleur de terre + valise', 682, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONT.HAGETC225', N'12', N'12 FA', N'Contacteur J/N 25A 2F 230V', 57.32, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONV.AIRA691315', N'22', N'22MF', N'Convecteur 6 ordres de telecommande triphas 1500W', 286.88, 0, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONV.AIRA693817', N'22', N'22MF', N'Convecteurnoveo 2 digital programmable H 2000W B', 446.55, 0, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONV.AIRA693887', N'22', N'22MF', N'Convecteur digital 2000W Horizontal B', 282.75, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONV.AIRA693895', N'22', N'22MF', N'Convecteur digital 1500W Vertical', 244.4, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONV.AR1', N'05', N'05FL', N'Convertissuer de rouille 1L', 22.96, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONV.ATL520215', N'22', N'22MF', N'Convecteur F18 PASSAGE BAS blanc 1500W', 150.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONV.DEXC127424', N'12', N'12MB', N'Convertisseur actif displayport 1.2 VE', 30.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONV.JMC_JK0030A1', N'12', N'12MB', N'Convertisseur analogique', 119, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COQU.CENTS42CE', N'18', N'18MB', N'Paire de coquille SNR30db aegan centurion', 23.94333, 1, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COQU.TELEPHONE', N'31', N'31FA', N'Coque de protection pour telephone', 24, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORB.MURALE', N'17', N'17FC', N'Corbeille cristal transparent  pour documents L25.4xP26xH10.5cm', 3.39, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.DEXC128146', N'31', N'31FA', N'Cordon display port 1.2 M vers HDMI 2.0 male', 33.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.DEXC128921', N'31', N'31FA', N'Cordon HDMI  / ETHERNET haute vitesse', 8.4, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.DEXC852512', N'12', N'12 FA', N'Rallonge RJ45 CAT6 F/UTP 0.5ml gris', 2.3, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.POLY10', N'26', N'26FD', N'Cordage polypropilne dia:10mm couronne de 100ml', 0.1865, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.POLY12', N'26', N'26FD', N'Corde polypropilne Dia:12mm', 0.29, 0, 0, 0, 100)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.POLY14', N'26', N'26FD', N'Corde polypropilne Dia:14mm', 0.3, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.POLY16', N'26', N'26FD', N'Cordage polypropilne DN:16mm', 0.48, 88, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.POLY18', N'26', N'26FD', N'Cordage polypropilne DN18mm', 0.576, 0, 0, 0, 100)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.POLY20', N'26', N'26FD', N'Cordage polypropilne dia:20mm  3torons', 0.62, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.POLY22', N'26', N'26FD', N'Cordage polypropilne dia:22mm  3torons', 1.2, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.POLY24', N'26', N'26FD', N'Cordage polypropilne dia:24mm  3torons', 1.07, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.POLY6', N'26', N'26FD', N'Cordage polypropilne dia:6mm', 0.09, 0, 0, 0, 100)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.POLY8', N'26', N'26FD', N'Cordage polypropilne dia:8mm', 0.117, 85, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.RJ45CAT6-10M', N'12', N'12 FA', N'Rallonge RJ45 CAT6 blind 10ml', 6.647619, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.RJ45CAT6-1M', N'12', N'12 FA', N'Rallonge RJ45 CAT6 blind 1ml', 3.462963, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.RJ45CAT6-20M', N'12', N'12 FA', N'Cordon ethernet RJ45 CAT6 blind 20ml', 18, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.RJ45CAT6-30M', N'12', N'12 FA', N'Cordon ethernet RJ45 CAT6 blind 30ml', 15.2, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.RJ45CAT6-3M', N'12', N'12 FA', N'Rallonge RJ45 CAT6 blind 3ml', 3.7, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.RJ45CAT6-3MBL', N'12', N'12 FA', N'Rallonge RJ45 CAT6 UTP 3ml blanc', 8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.RJ45CAT6-3MBLEU', N'12', N'12 FA', N'Rallonge RJ45 CAT6 UTP 3ml bleu', 8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.RJ45CAT6-3MGR', N'12', N'12 FA', N'Rallonge RJ45 CAT6 UTP 3ml gris', 8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.RJ45CAT6-3MJAU', N'12', N'12 FA', N'Rallonge RJ45 CAT6 UTP 3ml jaune', 8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.RJ45CAT6-3MROUG', N'12', N'12 FA', N'Rallonge RJ45 CAT6 UTP 3ml rouge', 8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.RJ45CAT6-3MVERT', N'12', N'12 FA', N'Rallonge RJ45 CAT6 UTP 3ml vert', 8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.RJ45CAT6-5M', N'12', N'12 FA', N'Rallonge RJ45 CAT6 blind 5ml', 3.791736, 2, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.RJ45CAT6-7M', N'12', N'12 FA', N'Rallonge RJ45 CAT6 blind 7ml', 7.4, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.RJ45CAT7-10M', N'12', N'12 FA', N'Rallonge RJ45 CAT7 blind 10ml', 27.72, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.RJ45CAT7-15M', N'12', N'12 FA', N'Rallonge RJ45 CAT7 blind 15ml', 35.06, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.RJ45CAT7-20M', N'12', N'12 FA', N'Cordon ethernet RJ45 CAT7 blind 20ml', 49.66, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.RJ45CAT7-3M', N'12', N'12 FA', N'Rallonge RJ45 CAT7 blind 3ml', 10.49, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.RJ45CAT7-5M', N'12', N'12 FA', N'Rallonge RJ45 CAT7 blind 5ml', 15.86, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.RJ45CAT7-7M', N'12', N'12 FA', N'Rallonge RJ45 CAT7 blind 7ml', 20.96, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.SCHBMXFCC201', N'12', N'12MB', N'Cordon automate simple', 37.39, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.SCHBMXFCC203', N'12', N'12MB', N'Cordon automate simple', 59.84, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.BPL-D16', N'33', N'33FB', N'Cosse de batterie PL - fut dn 16mm', 5.46, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.CFB', N'12', N'12MB', N'Cosse bleu cylindrique F 8,2-1,5 3,5mm', 0.02, 16, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.CFB4', N'12', N'12MB', N'Cosse F cylindrique bleu D4mm ampliversal 141454/1', 0.1, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.CMB4', N'12', N'12MB', N'Cosse cylindrique male bleu dn 4mm', 0.278, 319, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.COEUR13', N'26', N'26FD', N'Cosse coeur 13mm / cable 12 mm', 0.98, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.COEUR18', N'26', N'26FD', N'Cosse coeur 18mm', 2.38, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.OB5', N'12', N'12MB', N'Cosse ronde il bleu blister DN 5mm', 0.208, 20, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.OB6', N'12', N'12MB', N'Cosse a oiel bleu  isolee M6 1-2,5mm', 0.4018812, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.OB8', N'12', N'12MB', N'Cosse a oiel bleu  isolee M8', 0.4489286, 55, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.OJ6', N'12', N'12MB', N'Cosse a oeil jaune M 6mm section cable 4 - 6 mm', 0.2121, 53, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.OJ8', N'12', N'12MB', N'Cosse a oeil jaune M 8mm section cable 4 - 6 mm', 0.1241, 155, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.PFIB6.3', N'12', N'12MB', N'Cosses plates Femelle tout isolee bleu 6,3/1,5-2,5mm2', 0.19, 15, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.PFIR2.8', N'12', N'12MB', N'Cosse plate femelle isole rouge 2.8mm', 0.29, 65, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.PFIR6.3/0.25', N'12', N'12MB', N'Cosse plate Femelle tout isolee rouge 6,3/0,25 1mm2', 0.24, 150, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.PMR2.86/0.5', N'12', N'12MB', N'Cosse plate rouge male 2,86x0,5', 0.15, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.PRB', N'12', N'12MB', N'Cosse prolongateur bleu', 0.5, 48, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.REST6646', N'26', N'26FD', N'Cosse F blister 35pces  6,35x08mm section 2,6 a 6mm', 6.75, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.SOUD10X6.8', N'12', N'12 FA', N'cosse a souder 10x6.8', 1.817, 30, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.SOUD12X6.8', N'12', N'12 FA', N'cosse a souder 12x6.8', 1.5203, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.SOUD8X6.8', N'12', N'12 FA', N'cosse a souder 8x6.8', 1.5775, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.TH.OB8', N'12', N'12MB', N'Cosse thermofusible a oeil bleu 8mm section cable 1.5 - 2.5 mm', 1.168, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.TH.PFB1.5-2.5', N'12', N'12MB', N'Cosse thermofusible plate bleu femelle etanche section cable 1.5 - 2.5 mm larg.6.3mm', 1.932, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.TH.PFR0.5-1.5', N'12', N'12MB', N'Cosse thermofusible plate rouge femelle etanche section cable 0.5 - 1.5 mm larg.6.3mm', 1.68, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.TH.PMB1.5-2.5', N'12', N'12MB', N'Cosse thermofusible plate bleu etanche male section cable 1.5 - 2.5 mm larg.6.3mm', 0.908, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.TH.PMR0.5-1.5', N'12', N'12MB', N'Cosse thermofusible plate rouge etanche Male section cable 0.5 - 1.5 mm larg.6.3mm', 0.892, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.TUB.10-10', N'12', N'12MB', N'Cosse tubulaire cuivre W-CT section 10mm bornage M10 percage 10.3 mm', 0.1866, 85, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO.STH11241418300', N'14', N'14FC', N'Ecrou fendu', 4.607, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ECRO_BOB1B95D6', N'22', N'22FA', N'Ecrou pour dent avec support pack de 10 pices', 24.624, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EFFA.', N'17', N'17FA', N'Stylo pointe correcteur', 1.44, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EFFA.FEUTRE', N'17', N'17FA', N'Stylo pointe correcteur + FEUTRE', 0.46, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EFFA.FLUO', N'17', N'17FA', N'Stylo effaceur stabylo', 2.2, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'EGOU.VAISSELLE', N'24', N'24FB', N'Egouttoir pour vaisselle', 39.85, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELAG.WOLOR750', N'26', N'26MA', N'Elagueur confort avec enclume 45mm', 50.23, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELAG.WOLOS83', N'26', N'26MA', N'Elagueur confort', 108, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELAG.WOLOS84V', N'26', N'26MA', N'Elagueur confort', 65.48, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELAG.WOLOS900T', N'26', N'26MA', N'Elagueur confort', 54.19, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELEC.24V19W', N'12', N'12 FA', N'electroaimant forme D action tirer, course 24mm 19W, 24V', 155.77, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELEC.AHRPE3-063Z11', N'22', N'22FA', N'Electrovalve RPE3-063Z11 + bobines + connecteurs', 158.1333, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELEC.DS2000S', N'22', N'22MD', N'Electrode 2000S pour sour soudure Aluminium', 318.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELEC.DS670_4', N'22', N'22MD', N'Electrode DS 670 dia:4mm lg:350', 604.6, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELEC.DS800_2,5', N'22', N'22MD', N'Electrode DS 800 DN2,5mm / 5kgs BASIC', 209.965, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ELEC.DS800_3.2', N'22', N'22MD', N'Electrode DS 800  DN 3,2mm', 185.2, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.EW6L_NU', N'14', N'14FC', N'Coude EW 6L orientable nu', 6.97, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.F_PE32', N'11', N'11FC', N'Coude PE 32 TOF PUSH femelle pe32 26x34 ref 10070006PFB', 8.99, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.GALV.F1"', N'11', N'11FC', N'Coude 1" F galva', 1.3888, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.GALV.F1/2', N'11', N'11FC', N'Coude galva F 1/2', 0.3796, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.GCU12-3/8F', N'11', N'11FC', N'Coude laiton 12-3/8 F', 2.1, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.ISI32X32', N'11', N'11FC', N'Coude isiflo 120 32x32', 66.03, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.PER1/2X16', N'11', N'11FC', N'Coude PER 1/2x16 crou tournant ACOME 523330', 5.6803, 13, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUP.19GCU', N'11', N'11FC', N'Coupleur eau 19mm laiton aquastop', 11.9, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUP.AC_F1/2PAS6', N'22', N'22FA', N'COUPLEUR SEC.FEM.FILETE F 1/2 GAZ PASS.6', 19.98, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUP.AC_F1/4PAS6', N'22', N'22FA', N'COUPLEUR SEC.FEM.FILETE F 1/4 GAZ PASS.6', 24.441, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUP.AC_M1/4PAS6', N'22', N'22FA', N'COUPLEUR SEC.male FILETE M 1/4 GAZ PASS.6', 27.285, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUP.AC_M3/8PAS6', N'22', N'22FA', N'Coupleur air comprime F filete 3/8 gaz pass.6mm', 22.73, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUP.AC_PAS10', N'22', N'22FA', N'COUPLEUR SEC.FEM.A BARBE PASS.10MM', 21.22, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUP.AC_PAS6', N'22', N'22FA', N'COUPLEUR SEC.FEM.A BARBE  6A7MM PASS.6', 22.73, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUP.BOB1B6672960', N'22', N'22FA', N'Coupleur plat F G mod', 40.374, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUP.CIR_RVI26524137', N'33', N'33FB', N'Poigne coupe circuit en acier rouge', 119.97, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUP.CIRCUIT100A', N'33', N'33FB', N'Poigne coupe circuit rouge 100A', 16.18, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUP.CIRCUIT150A', N'33', N'33FB', N'Poigne coupe circuit en acier rouge 150A 2 bornes 48 V maximale', 18.48, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUP.ECH69922956830', N'14', N'14FC', N'Coupelle pour ECHO 4600', 10.9032, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUP.GROM1/2F', N'14', N'14FC', N'Coupleur 1/2 GROM femelle', 25.705, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUP.GROM3/4F', N'14', N'14FC', N'Coupleur 3/4 GROM femelle', 57.45, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUP.GROM3/8M', N'14', N'14FC', N'Coupleur 3/8 GROM male', 8.750667, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUP.STH69922956830', N'14', N'14FC', N'Coupelle pour debroussailleuse Stihl', 10.9032, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUP.TUB_SAM620-12', N'26', N'26MA', N'Coupe tube telescopique', 72, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUP.WOLRMM', N'26', N'26MA', N'Coupe bordure 22.5cm pour manche multistar', 14.2296, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUR.DIA_DET9-062', N'26', N'26FA', N'Couronne diamant  62mm 400mm 1"1/4 6 segments hauteur 9mm', 178, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUR.DIA_DET9-132', N'26', N'26FA', N'Couronne diamant  132mm 400mm 1"1/4 11 segments hauteur 9mm', 274, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUR.GAL104', N'22', N'22FA', N'Courroie 323023 GALLIA 104 ppe  eau maisons clus', 14.4827, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUR.LB39', N'14', N'14FC', N'Courroie LB 39 pour OREC', 13.99, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUR.NOR101697', N'14', N'14FC', N'Courroie crantee pour MAGISTRA', 54.6, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUR.NOR103637', N'14', N'14FC', N'Courroie jeu de 3 LN 1600 Ref:103637', 93.314, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUR.NOR109488', N'14', N'14FC', N'Courroie ARGOS', 35.92, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUR.REN8200830182', N'33', N'33FA', N'courroie alternateur pour kangoo', 6.7287, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUR.REN8200830187', N'33', N'33FA', N'courroie striee pour kangoo', 7.297, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUR.REST16263', N'33', N'33FB', N'Couronne', 44.13, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUR.WOL42005', N'14', N'14FC', N'Courroie varidur', 17.0896, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUR.WOL42009', N'14', N'14FC', N'Courroie ax25 13x8x660', 12.144, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUS.ECH13192311120', N'14', N'14FC', N'Coussinet  ECHO 4600', 2.4024, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUT. ASTEACK', N'24', N'24FB', N'Couteaux a steack', 5.37, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUT. OPINEL8', N'24', N'24FB', N'Couteau', 7.63, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUT.AENDI12', N'26', N'26MA', N'Couteau a enduire inox N12', 4.1, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUT.AENDI14', N'26', N'26MA', N'Couteau a enduire inox N14', 3.88, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUT.COL1X200', N'26', N'26MA', N'Couteau  colle 200mm denture 1mm', 2, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUT.COL2X1', N'26', N'26MA', N'Couteau a colle lame acier denture 2x1 larg,12cm', 1.829, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUT.COL2X200', N'26', N'26MA', N'Couteau  colle larg.200mm dent.2mm larg', 2, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUT.ECH69901654530', N'14', N'14FC', N'Couteau fil nylon', 12.774, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUT.GRIGNOT', N'26', N'26FD', N'Couteau de rechange pour grignoteuse', 13.73, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUT.MAROUF', N'26', N'26MA', N'Couteau a maroufler polyetilene souple', 1.89, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUT.PEINT6', N'26', N'26MA', N'Couteau de peintre amricain', 5.02, 1, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUT.PEINT7', N'26', N'26MA', N'Couteau de peintre amricain', 5.73, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUT.PEINT8', N'26', N'26MA', N'Couteau de peintre americain N8', 5.94, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUT.PEINTI10', N'26', N'26MA', N'Couteau de peintre inox N10', 7.1, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUT.PEINTI12', N'26', N'26MA', N'Couteau de peintre inox N12', 3.995, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUT.PEINTI8', N'26', N'26MA', N'Couteau de peintre inox N8', 5.81, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUT.SN300', N'14', N'14FC', N'Couteaux  taillis SN300', 19.8, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUT.STH40017133801', N'14', N'14FC', N'Couteau a herbe 4 dts pour debroussailleuse', 11.6, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUT.STH40017133803', N'14', N'14FC', N'Couteau a herbe 8dts pour debroussailleuse', 12.5083, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUT.STH41127134100', N'14', N'14FC', N'Couteau taillis', 25.96, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUT.STH41197134100', N'14', N'14FC', N'Couteau taillis', 28.58667, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.30', N'05', N'05FA', N'Couvertine 30cm grise', 7.86, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.600X400X220', N'26', N'26FD', N'Couvercle pour bac plastique', 20.384, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.600X400X320', N'26', N'26FD', N'Couvercle pour bac plastique', 20.384, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.A4-CI', N'17', N'17FC', N'Paquet de 100 couvertures cristal incolore A4', 4.176, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.AUM500.0', NULL, NULL, N'Couvercle pour boitier de commande', 41, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.AUM507.0', N'22', N'22FA', N'Couvercle de prise', 41, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.BET30X30', N'05', N'05FA', N'Couvercle bton 30x30 hauteur 4cm', 7.3, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.BET50X50', N'05', N'05FA', N'Couvercle bton 50/50', 19.98, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.BET600', N'05', N'05FA', N'Couvercle beton DN600', 22.13, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.ECH13031306230', N'14', N'14FC', N'Couvercle pour filtre a air 4605', 13.0064, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.ECH13132840630', N'14', N'14FC', N'Couvercle event echo', 0.5225, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.ECH14587143130', N'14', N'14FC', N'Couvercle echappement SRM 4600-4605 ECHO', 22.5324, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.ECH61027542230', N'14', N'14FC', N'Couvercle caoutchouc noir echo', 5.51, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.ECH61027627631', N'14', N'14FC', N'Couvercle caoutchouc noir echo', 5.148, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.ECHA160000241', N'14', N'14FC', N'Couvercle de cylindre en plastique SRM5000', 36.7048, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.ECHA162000020', N'14', N'14FC', N'Couvercle', 14.6784, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.ECHA320000080', N'14', N'14FC', N'Couvercle de pot en plastique SRM5000', 16.5264, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.F700X700/125', N'05', N'05FC', N'Couvercle fonte 700x635x45 classe 125', 80, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.HAG853781', N'12', N'12MB', N'Couvercle pour  plinthe SL20115 PALOMA blanc', 5.18, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.LCM646014', N'12', N'12MB', N'Couvercle CP50 IN316L', 24.3, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.P1P2', N'26', N'26FD', N'Couvercle pour filtre P1/P2 pour 1/2 masque', 0.9208333, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.STH11296401702', N'14', N'14FC', N'Couvercle de pignon pour MS200', 53.56, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.STH11296487700', N'14', N'14FC', N'Couvercle 020T', 6.47, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUV.STH11356401703', N'14', N'14FC', N'Couvercle de pignon', 48.08, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CRAI.BLEU_GRAS', N'26', N'26FD', N'Craie bleu grasse', 0.445, 15, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CRAI.DE_BRIANC', N'26', N'26FD', N'Craie blanche de Brianon pour fer', 0.2329, 20, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CRAI.JAU.N_GRAS', N'26', N'26FD', N'Craie jaune non grasse', 0.445, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CRAI.JAU.SURF.LIS', N'26', N'26FD', N'Craie jaune pour surfaces lisses', 0.445, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CRAI.PNEU', N'26', N'26FD', N'Craie blanche pour pneu S4305', 1.57, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CRAI.ROU.GRAS', N'26', N'26FD', N'Craie rouge grasse', 0.445, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CRAM.ANTI_DERAP', N'18', N'18MB', N'crampon homme anti derapant  attacher sous la chaussure', 11.71105, 17, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CRAY.ANIL.', N'26', N'26FD', N'Crayon aniline', 2.744, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CRAY.CHARP', N'26', N'26MA', N'crayon de charpentier', 1.512089, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CRAY.MAC', N'26', N'26MA', N'Crayon de macon', 1.93, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CREM.HYD.', N'25', N'25FA', N'creme hydratante et regeneratrice pour les mains', 12, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CREP.HIFSH63585', N'14', N'14FC', N'Crepine d''aspiration pour Renault Ergos 100', 34.16, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CROC.1.5T', N'22', N'22MB', N'Crochet CLO SEC/Verrouillage 1,5T', 49.5105, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CROC.CTRVT7X200', N'05', N'05FA', N'Crochet contrevent 7x200 ZI', 1.53, 20, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CROC.CTRVT7X250', N'05', N'05FA', N'Crochet contrevent 7x250 ZI', 1.53, 19, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CROC.SORC95007', N'33', N'33MC', N'Crochet de grenouillre pour remorque SOREL percage 46mm L125mm x l 31mm', 2.8864, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CROC.STH00003530605', N'14', N'14FC', N'Crochet', 1.078, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CROC.WOLRTM', N'26', N'26MA', N'Crochet pour manche multistar', 10.56, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CROC_FUM4DTS', N'26', N'26MA', N'Croc a fumier avec manche', 27.88, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CROC_PLAST16590', N'26', N'26FD', N'Croc de rechange Plastimo / gaffe manche bois', 4.24, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CUIS.T40', N'18', N'18MB', N'Cuissarde CAOUTCHOUC T40', 132.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CUIS.T41', N'18', N'18MB', N'Cuissarde  CAOUTCHOUC T41', 73.1, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CUIS.T42', N'18', N'18MB', N'Cuissarde CAOUTCHOUC T42', 90, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CUIS.T43', N'18', N'18MB', N'Cuissardes caoutchouc T43', 90, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CUIS.T44', N'18', N'18MB', N'Cuissarde CAOUTCHOUC T44', 84.9, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CUIS.T45', N'18', N'18MB', N'Cuissardes  CAOUTCHOUC T45', 142, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CUIV.ECROUI08', N'11', N'11FC', N'Barre de cuivre 08mm X 5ml', 4.68, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CUIV.ECROUI14', N'11', N'11FC', N'Barre de cuivre 14mm X 3ml', 4.09, 0, 0, 0, 12)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CUIV.NUD25', N'12', N'12 FA', N'Cuivre recuit nu 25 T500 pour mise a la terre', 2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CULO.100PVC45F', N'11', N'11FC', N'Y PVC dia:100 F 45', 3.4628, 5, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CULO.100PVC45MF', N'05', N'05FA', N'Culotte Y simple PVC 45 MFF D100', 3.238818, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CULO.100PVC45MF*', N'11', N'11FC', N'Y PVC dia:100 MF', 2.722, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CULO.110PVC45F', N'11', N'11FC', N'Culotte PP dia:110mm 45femelle', 5.07, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CURA.D.1LTC3', N'05', N'05FI', N'Traitement curatif du circuit carburant diesel', 42.39, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CURA.DTC3_300ML', N'05', N'05FI', N'Traitement curatif du circuit carburant diesel', 26.07, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CURA.MEC133005', N'05', N'05FI', N'Traitement curatif HIVERS du circuit carburant diesel BILUGAZOIL vehicules en bidon de 5 litres', 30, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CURA.MEC157005', N'05', N'05FI', N'Traitement curatif du circuit ESSENCE TC1', 28.33, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CURA.MEC174005', N'05', N'05FI', N'Bactericide pour cuve a fioul de chauffage', 27.46, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CUTT.DEP', N'26', N'26MA', N'Cutter de poche', 5.47, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CUTT.PROF', N'26', N'26MA', N'Cutter professionnel a lame autoblocante', 16.9336357, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CUTT.SECURIT', N'26', N'26MA', N'Cutter professionnel de scurit a lame trapze rtractable', 28.4, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CUVE_CLA6005033220', N'14', N'14FC', N'Cuve en verre pour filtre G-O PALES', 5.825, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CYLI.30X30', N'26', N'26FD', N'Cylindre 30x30', 14.97, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CYLI.30X30/PG', N'26', N'26FD', N'Cylindre de porte double DOM  SIGMA+ 30x30 3 cles sur PG', 35.44, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CYLI.30X40/PG', N'26', N'26FD', N'Cylindre de porte double DOM  SIGMA+ 30x40 3 cles sur PG', 46.732, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CYLI.30X45/PG', N'26', N'26FD', N'Cylindre de porte double DOM  SIGMA+ 30x45 3 cles sur PG', 43.88, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CYLI.30X50/PG', N'26', N'26FD', N'Cylindre de porte double DOM  SIGMA+ 30x50 3 cles sur PG', 46.7, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CYLI.30X60/PG', N'26', N'26FD', N'Cylindre de porte double DOM  SIGMA+ 30x60 3 cles sur PG', 55.81, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CYLI.30X65/PG', N'26', N'26FD', N'Cylindre de porte double DOM  SIGMA+ 30x65 3 cles sur PG', 58.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CYLI.40X40/PG', N'26', N'26FD', N'Cylindre de porte double DOM  SIGMA+ 40x40 3 cles sur PG', 46.7, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CYLI.40X45/PG', N'26', N'26FD', N'Cylindre de porte double DOM  SIGMA+ 40x45 3 cles sur PG', 49.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CYLI.45X50/PG', N'26', N'26FD', N'Cylindre de porte double DOM  SIGMA+ 45x50 3 cles sur PG', 55.13, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DALL.ACOUST4MM', N'05', N'05MA', N'Dalle acoustique 4mm 22db pour pose de revetement sol', 38.35, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DALL.BET100/35/8', N'05', N'05FA', N'Dalles beton arme 100/35/8 poids 72kgs', 23.12, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DALL.OSB12MM', N'05', N'05FA', N'Dalle OSB3 12MM milieu humide 2.5 * 0.675 * 12.0', 4.59, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DALL.OSB18MM', N'05', N'05FA', N'Dalle OSB3 18MM milieu humide 2.5 * 0.675 * 18.0', 6.78, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DATE.AUTO', N'17', N'17FC', N'Dateur a encrage automatique 4mm avec cassette d''ancrage', 4.04, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'DEBO.1L', N'24', N'24FB', N'Deboucheur gel express', 16.46, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_ART.FAC467F-13', N'26', N'26MA', N'Cle articule mixte  cliquet dn 13mm', 12.82, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_DPG', N'26', N'26FD', N'Cle de passe general livre avec le cylindre', 4.14, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_DPPP1', N'26', N'26FD', N'Cle de passe general livre avec le cylindre PP1', 10.86, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_DPPP2', N'26', N'26FD', N'Cle de passe general livre avec le cylindre PP2', 12.36, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_DPPP3', N'26', N'26FD', N'Cle de passe general livre avec le cylindre PP3', 12.36, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_DPPP4', N'26', N'26FD', N'Cle de passe general livre avec le cylindre PP4', 12.52, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_ECH13X19', N'26', N'26MA', N'Clef multiple 13*19 pour dbroussailleuse', 9.594, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_ECH89751801131', N'26', N'26MA', N'Cle ECHO pour blocage tete de debroussailleuse', 1.14, 3, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_ECKRA2585', N'26', N'26MA', N'Cle en croix KRA2585-12', 12.48, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_FACCMSFAC82H.5', N'26', N'26MA', N'Cle coudee male spherique 5mm', 1.22, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_GAZ', N'26', N'26FD', N'Cle plastique pour raccord tournant bouteille de gaz 13 kgs', 3.2608, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_IR476185PPG', N'26', N'26FD', N'Cle passe de Sarreguemines', 11.31, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_MIXCFAC67F.10', N'26', N'26MA', N'Cle mixte a cliquet de 10', 10.73, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_MOL.FAC101.10G', N'26', N'26MA', N'Cle a molette serie 10 ajust rapide plastique', 20.15, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_MOL.FAC101.8GPB', N'26', N'26MA', N'Cle a molette serie 101 chrome gaine', 16.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_MOL.FAC113A.12CG', N'26', N'26MA', N'Cle a molette chrom gaine longueur 310mm', 26.44, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_ROB394013', N'26', N'26MA', N'Cl universelle 9 embouts CM9', 32.87, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_ST14"', N'26', N'26MA', N'cle a tube master grip 14"', 69, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_STH11298903401', N'26', N'26MA', N'Clef multiple pour TRONCONNEUSE', 3.6256, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_TRIA32X50', N'26', N'26MA', N'Cl tricoise articule 32x50', 54.56, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_TRIACIER', N'26', N'26MA', N'Cl tricoise acier', 13.56, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_TRIANGLE11MM', N'26', N'26MA', N'Cl triangle 11mm EDF', 44.12, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_TRIANGLE5MM', N'26', N'26MA', N'Cl triangle 5mm', 17.89, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_USB04G+LOG', N'20', N'20FB', N'Cle usb 4 giga avec marquage logo VNF R+V quadri dme epoxy selon BAT', 16.92, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_USB08G', N'20', N'20FB', N'Cle usb 8 giga', 4.884957, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_USB32G', N'20', N'20FB', N'Cle usb 32 giga avec securisation des donnes', 7.934165, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_USB32GMF', N'20', N'20FB', N'Cle usb 32 giga metal fusion pour connection permanente', 18.445, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLIP.BIZ710241', N'26', N'26FD', N'Boite de 100 clipeo pour tube IRL de 20mm', 49.255, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLIP.SPIT011203', N'12', N'12 FA', N'Clip electrique pour spit', 12.35, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.AGI221001', N'26', N'26MA', N'Coffret 9 outils isols 1000V', 97.2, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.BOS2608664131', N'26', N'26FA', N'Coffret lames best for cutting 5 lames', 39.01, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.BOS2608664624', N'26', N'26FA', N'Coffret starlock spcial rnovation', 60.09, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.CLIMULTI1/2', N'26', N'26MA', N'Coffret de douilles multi 1/2"', 100.64, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.DIADRILL6-68MM', N'26', N'26MA', N'Coffret diadrill ceramic 6  68mm', 383.7, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.EMBMIXT', N'26', N'26MA', N'Coffret RECA maxi mixte', 12.08, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.EMBMIXTMIDI', N'26', N'26MA', N'Coffret empreintes plat-pz-philips RECA 10 pieces', 38.48, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.EMBMIXTMINI', N'26', N'26MA', N'Coffret empreintes plat-pz-philips RECA', 92.36, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.EMBPOZI', N'26', N'26MA', N'Coffret empreintes pozidrive bitorsion avec porte embout rapidaptor', 56.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.EMBTX', N'26', N'26MA', N'Coffret d''embouts torx', 58.708, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.FACR2NANO', N'26', N'26MA', N'Coffret radio cliquet 1/4 6 pans + embouts de vissage', 124.02, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.FACSL.DBOX1PB', N'26', N'26MA', N'Coffret cliquet etanche + douille', 135.27, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.FRT', N'26', N'26MA', N'Coffret forets  0,5-13', 40, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.FRTULTRA', N'26', N'26MA', N'Coffret forets RECA + ultraspibo 2,5-13', 88.96, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.FRTULTRA_INOX', N'26', N'26MA', N'Coffret forets RECA  ultra inox 2,5-13', 299, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.IMPAKTOR', N'26', N'26MA', N'Coffret 30 EMBOUTS pour usage extreme', 148.598, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.JCL2000', N'12', N'12 FA', N'Coffret M6 avec plat 6106 pour lampe terre plein d''ecluses', 244.68, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.KRA4900-47K', N'26', N'26MA', N'Coffret cl mixte  cliquet', 224.88, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COIN_D''EMMENCH', N'26', N'26FD', N'Coins d''emmanchage sachets de 4 pieces diffrentes', 6.7584, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COIN_ECLAT.', N'26', N'26MA', N'Coin eclateur', 25.7515, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COIN_PL23', N'26', N'26MA', N'Coin plastique anti ret.23cm', 14.6344, 0, 0, 0, 4)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COIN_PL25', N'26', N'26MA', N'Coin plastique anti ret.25cm', 9.24, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COIN_PL30', N'26', N'26MA', N'Coin plastique anti ret.30cm', 14.256, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.AT14', N'26', N'26FD', N'Collier ATLAS DN14mm', 0.03, 68, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.AT18', N'26', N'26FD', N'Collier ATLAS DN18mm', 0.04, 58, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.AT22', N'26', N'26FD', N'Collier ATLAS DN22mm', 0.04, 82, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.AT28', N'26', N'26FD', N'Collier ATLAS DN28mm', 0.05, 59, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.BATONNET', N'05', N'05FI', N'Batonnet de colle pour pistolet', 14.49, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.BDE08-12', N'26', N'26FD', N'Colliers 8-12  a bande acier inoxydable largeur 7.5mm', 0.524, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.BDE08-16', N'26', N'26FD', N'Colliers 8-16  a bande acier inoxydable largeur 9mm', 2.29, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.BDE10-16', N'26', N'26FD', N'Colliers 10-16 reglable a bande inox largeur 7.5mm', 0.4097474, 133, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.BDE12-20', N'26', N'26FD', N'Colliers 12-20 a bande inoxydble largeur 9mm', 0.011, 34, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.BDE16-25', N'26', N'26FD', N'Collier 16-25 bande inoxydable largeur 9mm', 1.0617, 17, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.BDE20-32', N'26', N'26FD', N'Collier 20-32 bande inoxydable largeur 6mm', 1.1717, 17, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.BDE25-40', N'26', N'26FD', N'Collier 25-40 bande inoxydable  CE 940-CT', 1.17, 18, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.BDE30-45', N'26', N'26FD', N'Collier 30-45 bande inoxydable largeur 9mm', 1.233, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.BDE32-50', N'26', N'26FD', N'Colliers 32-50 bande inoxydable largeur 9mm', 1.233, 14, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.BDE40-60', N'26', N'26FD', N'Collier 40-60 bande inoxydable largeur 9mm', 1.36, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.BDE50-70', N'26', N'26FD', N'Collier 50-70 bande inoxydable largeur 7mm', 1.23, 14, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.HERHAUTE_SECU', N'28', N'28MA', N'Collier haute securit qui relie les clotures de chantier', 1.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.INTISSE20', N'05', N'05FA', N'Colle murale pour papier intisse 20kg', 21, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.INTISSE5', N'05', N'05FA', N'Colle murale pour intisse 5kg', 8.42, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.LEG031920', N'12', N'12 FA', N'Collier colson long.498', 54.12, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.LEG032031', N'12', N'12 FA', N'Collier COLRING 3.5/140 33 / 100 pieces', 4.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.LEG032032', N'12', N'12 FA', N'Collier COLRING 3.5/180 33 / 100 pieces', 6.7, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.NOR101729', N'14', N'14FC', N'Collier pour tuyau hydraulique', 13.61, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.OET13-15', N'26', N'26FD', N'Collier Oetiker AC BI ZI 13-15', 0.18, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.OET15-18', N'26', N'26FD', N'Collier Oetiker AC BI ZI 15-18', 0.753, 14, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.PVC250', N'24', N'24FB', N'Colle PVC 250ml', 6.51, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.PVC32', N'11', N'11FC', N'Collier monoclip DN32 taraude 7x150', 1, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.PVC32HP', N'11', N'11FC', N'Collier monoclip DN32 taraude 7x150 / tuyau HP', 1.9, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.PVC40', N'11', N'11FC', N'Collier monocbloc DN40 taraude 7x150', 1.14, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.PVC500', N'24', N'24FB', N'Colle pour raccord PVC 500ml', 10.03, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.REST598', N'26', N'26FD', N'sachet de collier', 8.78, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.REST599', N'26', N'26FD', N'sachet de collier', 9.83, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.REST949', N'26', N'26FD', N'sachet de collier', 16.46, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.SCHENN46966', N'12', N'12 FA', N'Collier de cablage CINTURA 4.8x200', 10.47, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.SCHENN47930', N'12', N'12 FA', N'Collier de fixation pour tube a froid DN 20mm', 26.4740257, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.SCHENN47942', N'12', N'12 FA', N'Collier polyamide L194', 10.18, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_ACIR', N'22', N'22MD', N'Cle a choc  1/2  "fort couple" IQ20V 2 batterie W7150EU K22', 489, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.BDE60-80', N'26', N'26FD', N'Collier 60-80 bande inoxydable largeur 7mm', 1.217, 37, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.SCHENN47962', N'12', N'12 FA', N'Collier SAREL 273 mm 47962', 14.75, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONC.PORPHYRE0/25', N'05', N'05FA', N'Concasse porphyre 0/25', 28.98, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.DEXC852533', N'12', N'12 FA', N'Rallonge RJ45 CAT6 F/UTP 1ml vert', 2.94, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.SPIR7.5M', N'14', N'14FC', N'Cordon spirale 7.5m prise gyrophare', 16.99, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.TUB.10-6', N'12', N'12MB', N'Cosse tubulaire cuivre W-CT section 10mm bornage M6 percage 6.4 mm', 0.184, 65, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.32PVC45F', N'11', N'11FC', N'Coude PVC DN32 F 45', 0.5371, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.32PVC45MF', N'11', N'11FC', N'Coude PVC MF DN32 45', 0.98, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.32PVC87F', N'11', N'11FC', N'Coude dia,32 F 8730', 0.43, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.33.7X2.6', N'05', N'05FC', N'coude acier S/S 33,7x2,6 3D', 0.686, 34, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.40PVC45MF', N'11', N'11FC', N'Coude DN40 PVC 45 MF', 1.39, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.BOB1B6598908', N'22', N'22FA', N'Coude pack de 5', 86.895, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.CU12', N'11', N'11FC', N'Coude cuivre DN 12mm', 0.2, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.CU14', N'11', N'11FC', N'Coude cuivre DN 14mm', 0.91, 0, 0, 0, 10)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.CU16', N'11', N'11FC', N'Coude cuivre DN 16mm 90', 0.8767, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.EW15L_NU', N'14', N'14FC', N'Coude EW 15L orientable nu', 10.46, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_MIXCFAC67F.13', N'26', N'26MA', N'Cle mixte a cliquet de 13', 11.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_MIXCKRA3410', N'26', N'26MA', N'Cle mixte a cliquet de 10', 9.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_MIXCKRA3421', N'26', N'26MA', N'Cle mixte a cliquet de 21', 22, 0, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLE_MIXFAC40.13', N'26', N'26MA', N'Cl mixte de 13', 4.24, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLIP_ECH12312703930', N'14', N'14FC', N'Clip pour debroussailleuse ECHO', 1.75, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLIP_ECH13201326630', N'14', N'14FC', N'Clip ECHO', 0.44, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLIP_ECHP022007890', N'14', N'14FC', N'Clip ECHO M+F pour harnais debroussailleuse RM4000', 11.0352, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLIQ.ART1/2', N'26', N'26MA', N'Cliquet 1/2 articul', 60.31, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLIQ.STH11241957200', N'14', N'14FC', N'Cliquet STIHL  064', 2.4464, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLIQ.STH11251957200', N'14', N'14FC', N'Cliquet / STIHL 020', 2.96, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLIQ.STH17721840630', N'14', N'14FC', N'Cliquet blanc echo', 4.4172, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLIQ.WER160785/8100SA/SC2', N'26', N'26MA', N'Cliquet 1/4 + 1/2 zyclop', 488, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLOC.BL04238910', N'14', N'14FC', N'Cloche  de filtre', 7.84, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLOC.ECHA556000181', N'14', N'14FC', N'Cloche d''embrayage', 57.01, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLOC.HUS503143204', N'14', N'14FC', N'Cloche d''embrayage trononneuse', 51.5504, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLOU.3.1/100', N'26', N'26FD', N'Clous 3.1/100 torsad clair boite de 3600 pieces', 131.3, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLOU.STRI3.5/45', N'26', N'26FD', N'Clous acier stri 3.5x45', 11.39, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLOU.STRIE4.5/70', N'26', N'26FD', N'Clous acier stri 4.5x70', 25.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.LEG058951', N'12', N'12 FA', N'Coffret de chantier 16A', 484.99, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.LEG058954', N'12', N'12 FA', N'Coffret de chantier  quiper', 484.26, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.LEG058957', N'12', N'12 FA', N'Coffret de chantier  quiper', 164.4, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.RCAC-12-000606', N'21', N'21MA', N'Coffret mural fixe P400 - 6U', 325.729, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.SCHGV3MCK04', N'12', N'12 FA', N'Coffret tesys vide pour GV2ME avec BP arrt d''urgence coup de poing d''urgence', 34.47, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COFF.SERM48639111', N'12', N'12 FA', N'Coffret de chantier 64A IP44 4NF+CEE 2x16A5P + 32A5P', 489.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COIF.ECH15901203433', N'14', N'14FC', N'Coiffe SRM4605', 8.27, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.BDE70-90', N'26', N'26FD', N'Collier 70-90 lbande inoxydable largeur 13mm', 0.524, 24, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.BDE80-100', N'26', N'26FD', N'Collier 70-90 bande inoxydable largeur 9mm', 2.01, 24, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.BOB1B42HS04', N'22', N'22FA', N'Collier de serrage', 3.258, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.BOB1B6616213', N'22', N'22FA', N'Colliers pack de 5', 35.244, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.BOISINTEXT', N'24', N'24FB', N'Colle bois D4  interieur et exterieur', 10.89, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.CP25', N'05', N'05FA', N'Sac de colle carreau de platre 25kgs big mat', 13.89, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.CYANO', N'05', N'05FI', N'Colle super rapide', 19.965, 2, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.DBGEL', N'17', N'17FC', N'Colle gel de bureau 30ml', 0.4666667, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.DBSTICK8.2', N'17', N'17FC', N'Colle gel de bureau 8.2g', 0.5130769, 13, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.DOUB25', N'05', N'05FA', N'Sac de colle doublage 25kgs big mat', 11.29, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.ECHA172000150', N'14', N'14FC', N'Collier', 69.78, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.ETTR', N'05', N'05FA', N'Colle de fixation 310ml translucide', 22.12253, 23, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.ETTR100ML', N'05', N'05FA', N'Colle de fixation 100ml', 10.68, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.GAL80X40', N'28', N'28MA', N'Collier galva 80x40 + boulons', 2.504545, 9, 0, 0, 36)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.SCHENN47992', N'12', N'12 FA', N'Collier SAREL 370mm 47992', 0.266691536, 200, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.SERRAGE50', N'26', N'26FD', N'Collier de serrage de 50mm', 4.25, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.STASP321.3/21.3PAGDASINOX', N'22', N'22FA', N'Collier de fixation STAUFF pour tuyauterie', 10.46, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.STASP430PADPAASINOX', N'22', N'22FA', N'Collier de fixation STAUFF', 12.44, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.STH11231605400', N'14', N'14FC', N'Collier de frein / STIHL 020T', 13.09, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.TOUR32-35', N'26', N'26FD', N'Collier  tourillon diametre de serrage 32-35', 1.31, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLL.TOUR40-43', N'26', N'26FD', N'Collier  tourillon diametre de serrage 40-43', 1.44, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COLO.NOIR', N'05', N'05FI', N'Colorant 250cc noir', 10.01, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COMB.JET2', N'18', N'18MB', N'Combinaison jetable T2/M non tisse avec capuche', 5.7, 20, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COMB.JET3', N'18', N'18MB', N'Combinaison jetable T3/L non tisse  blanche avec capuche', 5.577551, 49, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COMB.JET4', N'18', N'18MB', N'Combinaison jetable T4/XL non tisse blanche avec capuche', 5.12803268, 76, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COMB.JET5', N'18', N'18MB', N'Combinaison jetable T5/XXL non tisse blanche avec capuche', 5.434919, 46, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COMB.PLUIE_M', N'18', N'18MB', N'Combinaison de pluie T2 jmarine', 80.96, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COMB.PLUIE_TL', N'18', N'18MB', N'Combinaison de pluie TL marine', 106.46, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COMB.PLUIE_XL', N'18', N'18MB', N'Combinaison de pluie TXL marine', 117.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONC.RAON0.20', N'05', N'05FA', N'Raon 0/20', 20.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONE_DC30CM', N'28', N'28MA', N'Cone de chantier hauteur 30cm', 7.97, 13, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONE_DC50CM', N'28', N'28MA', N'Cone de chantier hauteur 50cm', 8.86, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONE_DC50CM_TELESC', N'28', N'28MA', N'Cone de chantier telescopique hauteur 50cm', 12.25, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONF.', N'28', N'28SC', N'Mise en conformit', 300, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONN.AUM51.0', N'22', N'22FA', N'Connecteur femelle muni completement', 105, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONN.AUMN1', N'22', N'22FA', N'Connecteur males avec 2 fiches N1', 41, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONN.AUMREP.502.0', N'22', N'22FA', N'Connecteur males sans fiches', 41, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONN.DEX418060', N'20', N'20MC', N'Connecteur RJ45 CAT6/EA sans outil KS-T', 5.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONN.GGMPLUGIT10G', N'20', N'20FB', N'Fiel plug 10G class EA STP', 6.8268, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONN.LINK_CON_EZSLC6F', N'12', N'12 FA', N'Connecteur RJ45 CAT6 STP EZ GOLD PLATED H', 0.649, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONN.MUR11598100', N'12', N'12 FA', N'Connecteur 230 AC/DC IP 65  Pas metrique', 1.625, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONN.NEX420.666', N'12', N'12 FA', N'Connecteur SNAP IN CAT6', 6.559, 19, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONN.PEPV1-G-2M-PVC', N'12', N'12 FA', N'Connecteur', 7.85, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONN.PEPV1-W-2M-PUR', N'12', N'12 FA', N'Connecteur', 8.69, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONN.PHO1414394', N'12', N'12 FA', N'Connecteur RJ45', 6.1, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONN.PHOCUC_IND_CIZNI_S/R4IE8', N'20', N'20FB', N'Connecteur RJ45 IP20 pour FO', 8.31, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONN.POU980535', N'12', N'12 FA', N'Boite de 100 connecteurs 0.4mm  0.9mm UR2', 27, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONT.NOVI15', N'05', N'05FA', N'Contre plaque novipro film combi exterieur collage WBP 15mm 1.25 x 2.5', 15.1, 4.65, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONT.NOVI18', N'05', N'05FA', N'Contre plaque novipro film combi exterieur collage WBP 18mm 1.25 x 2.5', 17.73, 4.685, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONT.OK10WBP', N'05', N'05FA', N'CP d''asie extrieur10mm feuille de 2.5mx1,22m  collage WBP', 9.41, 2.579999, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONT.OK5WBP', N'05', N'05FA', N'CP Okoum cd''asie extrieur 5mm feuille de 2.5mx1,22m collage WBP', 7.0111, 3.05, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONT.PERAPPARAU', N'02', N'02SC', N'controle priodique des appareils de levage, tirfors, pinces, etc', 1380, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONT.PERECHEL', N'02', N'02SC', N'controle annuel des echelles et escabeaux', 466, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONT.PERENGLEVAGE', N'02', N'02SC', N'controle priodique des engins de levage', 1600, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONT.PERHARNAI', N'02', N'02SC', N'Controle des harnais anti chute', 20, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONT.PERPORTESEC', N'02', N'02SC', N'controle portes sectionnelle', 350, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONT.PM5', N'12', N'12 FA', N'Contacteur manometrique PM5 J/M', 24.35, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONT.SCHA9C24732', N'12', N'12 FA', N'Contact modulaire bipolaire 230V AC 25A 2F standard CT', 40.75, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONT.TACHY', N'33', N'33SF', N'controle annuel du tachygraphe', 139, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONT.TECHCAM', N'33', N'33SF', N'controle technique camion', 82.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CONV.AIRA687485', N'22', N'22MF', N'Convecteur TACTIC ET 15BL', 89.96, 0, 0, 0, 7)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.DEXC852542', N'12', N'12 FA', N'Rallonge RJ45 CAT6 F/UTP 0.5ml bleu', 2.3, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.DEXC852572', N'12', N'12 FA', N'Rallonge RJ45 CAT6 F/UTP 0.5ml blanc', 2.3, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.DEXC854182', N'12', N'12 FA', N'Rallonge RJ45 CAT6 U/UTP 0.5ml gris', 1.52, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.DEXC854193', N'12', N'12 FA', N'Rallonge RJ45 CAT6 U/UTP 1ml jaune', 1.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.DEXC854203', N'12', N'12 FA', N'Rallonge RJ45 CAT6 U/UTP 1ml vert', 1.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.DEXC854222', N'12', N'12 FA', N'Rallonge RJ45 CAT6 U/UTP 0.5ml rouge', 1.52, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.DEXC854243', N'12', N'12 FA', N'Rallonge RJ45 CAT6 U/UTP 1ml blanc', 1.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.DEXC856830', N'12', N'12 FA', N'Rallonge RJ45 CAT6 S/FTP 0.5ml vert', 2.4, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.DEXC856847', N'12', N'12 FA', N'Rallonge RJ45 CAT6 S/FTP 1m rouge', 3.1, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.DEXC856852', N'12', N'12 FA', N'Rallonge RJ45 CAT6 S/FTP 1m noir', 3.1, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.DISP_HDMI5M', N'31', N'31FA', N'Cordon display port M vers HDMI male 5M', 34.75, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.DLANC3', N'26', N'26FD', N'Corde de lanceur', 0.315551, 46, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.DLANC3.5', N'26', N'26FD', N'Cordelette DN 3,5mm en fut de 100m', 0.27, 31, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.DLANC4', N'26', N'26FD', N'Corde polyamide DN 4mm rl de 100ml blanc', 2.345, 80, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.DLANC4.5', N'26', N'26FD', N'Corde polyamide DN 4.5mm rl de 100ml blanc', 0.16, 32, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.ERC4404000205', N'20', N'20FB', N'Cordon DATA AUDIO pour GENPRO 25e', 19, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.EWO4PORTS', N'20', N'20FB', N'cordon  alimentation flexy base 4 ports 10/1000', 178, 0, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.FLETL75', N'26', N'26MA', N'Jeu de cordons pointes de touche 2mm standard', 23, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.HDMI-20M', N'31', N'31FA', N'Cordon HDMI 20ml', 81.6, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.HDMI-2M', N'31', N'31FA', N'Cordon HDMI 2ml', 3.64, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.HDMI-5M', N'31', N'31FA', N'Cordon HDMI 4K 5ml', 11.396, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.LEG078730', N'12', N'12 FA', N'Rallonge RJ11 1ml pour Mosaic', 8.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.LUNET', N'18', N'18MB', N' Cordelette', 0.833, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.MAC1.5', N'26', N'26MA', N'Ficelle de maon  dia 1.5mm', 3.8, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.MAC1.5 PINCK', N'26', N'26MA', N'Ficelle de maon  dia 1.5mm rose 200ml', 15.5057144, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.MAC2', N'26', N'26MA', N'Ficelle de maon  dia 2mm x 40ml', 4.48, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.PJP6036', N'21', N'21FA', N'Cordon de mesure de securit mle 4mm - banane mle 1M ; rouge', 4.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.STH11221902900', N'26', N'26FD', N'Cordelette de lanceur ELASTOSTAR', 3.92, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.STH11281902900', N'26', N'26FD', N'Cordelette elastostar DN 3,5mm', 4.24, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.VGA/HDMI-1.5M', N'31', N'31FA', N'Cordon USB male/HDMI femelle 1.5m', 39.4, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.VGA/USB-1.5M', N'31', N'31FA', N'Cordon USB male/VGA femelle 1.5m', 19.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.VOL_SET10PIECES', N'21', N'21FA', N'Set de 10 cordons de mesures (pinces crocodiles) 0.28 noir, rouge, vert, jaune, blanc', 21.99, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.VOL1MM_NOIR', N'21', N'21FA', N'Cordon de mesure banane 1mm noir', 5.59, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORD.VOL1MM_ROUGE', N'21', N'21FA', N'Cordon de mesure banane 1mm rouge', 5.49, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORN.AC120X12', N'05', N'05FC', N'Fer cornire 120x120x12 6ml', 21.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORN.AC150X15', N'05', N'05FC', N'Cornire de 150x150x15', 25.459, 6.15, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORN.AC20X3', N'05', N'05FC', N'Fer cornire 20x20x3x6,2ml', 0.7, 37.2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORN.AC30X3', N'05', N'05FC', N'Fer cornire 30x3x6,2ml', 1.0519, 6.2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORN.AC40X4', N'05', N'05FC', N'Fer cornire 40x40x4 6ml', 2.129649, 18.6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORN.AC50X5', N'05', N'05FC', N'Fer cornire 50x50x5 6ml', 6.068371, 24, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORP.EUT27332', N'14', N'14FC', N'Corps de lame ATTILA AV85', 81.09, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORP.NOR102832', N'14', N'14FC', N'Corps de rouleau palpeur pour XP2000', 461.1, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CORP.SCHZC2JC1', N'12', N'12 FA', N'CORPS D''INTERRUPTEUR DE POSITION FIXE 1O/F', 43.83, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.B7701393251', N'33', N'33FB', N'Cosse de batterie VL +', 5.43, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.BPL+D13', N'33', N'33FB', N'Cosse de batterie PL + fut 13mm', 2.683, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.BPL+D16', N'33', N'33FB', N'Cosse de batterie PL +fut dn 16mm', 5.46, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.BPL-D13', N'33', N'33FB', N'Cosse de batterie PL - fut dn 13mm', 2.717, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CADE.S''ENTR40', N'26', N'26FD', N'Cadenas ABUS s''entrouvrant 40mm avec 2 cles', 8.24, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CADE/PG', N'26', N'26FD', N'Cadenas 777 a cylindre DOM SIGMA+ 3 cles sur PG', 63.7033, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CADR.LEG080280', N'12', N'12MB', N'Cadre PRG MOSAIC 2 MOD H30mm', 2.44, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAFE.DOSE', N'22', N'22MF', N'Cafetiere noir avec doses de caf 5 tasses 1450W reservoir 0.75 litre', 79.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAFE.DOSE_NG', N'22', N'22MF', N'Cafetiere noir nouvelle generation avec doses de caf 5 tasses 1450W reservoir 0.75 litre', 138, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAFE.ELEC', N'22', N'22MF', N'Cafetiere electrique filtre 100', 45, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAFE_DOSE48', N'01', N'01FB', N'cafe en 48 doses pour senseo', 12.11, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAFE_MOULU', N'01', N'01FB', N'cafe moulu', 6.72, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAGE_ECH17721041030', N'14', N'14FC', N'cage a cliquet', 8.2122, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAGE_STH95129332380', N'14', N'14FC', N'Cage  aiguille 10-16-12', 7.7, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAGO.SOUDURE', N'18', N'18MB', N'Cagoule de soudage aspirante eutexair complte', 984.54, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAHI.A4', N'17', N'17FC', N'Cahier a seyes A4 21x29.7', 0.5433334, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAHI.ACTIV', N'17', N'17FC', N'Cahier organiseur activboock avec pochette et carreaux 5x5', 6.050064, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAHI.MEET', N'17', N'17FC', N'Cahier meeting boock ave elastique', 8.556111, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAHI.SPIRA4', N'17', N'17FC', N'Cahier a spirale seyes A4 21x29.7 180 pages', 1.1676, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAHI.SPIRA5', N'17', N'17FC', N'Cahier a spirale seys petit format 17x22 180 pages', 0.8133, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAIL.AD1000X2000X18', N'28', N'28MA', N'Caillebotis industriel anti drapant 1000x2000 epaisseur 18mm', 327.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAIS.DB', N'26', N'26FD', N'Caisse de brouette peinte', 23.59, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAIS.PALETTE', N'26', N'26FD', N'Caisse palette cots ajours 680 litres', 370, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALC', N'17', N'17FC', N'Calculatrice', 21.01, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALC.12_CHIFFRES', N'17', N'17FC', N'Calculatrice 12 chiffres', 21.77, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE.12M', N'17', N'17FC', N'Calendrier mural cartonn 12 mois', 1.66, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE.2X6M', N'17', N'17FC', N'Calendrier semestriel mural cartonn', 0.6075586, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE_1MM', N'26', N'26FD', N'Cale plate blanche 100x24', 0.062, 815, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE_2MM', N'26', N'26FD', N'Cale plate bleu 100x24', 0.068, 805, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE_3MM', N'26', N'26FD', N'Cale plate rouge 100x24', 0.071, 775, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE_4MM', N'26', N'26FD', N'Cale plate jaune 100x24', 0.08, 814, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE_5MM', N'26', N'26FD', N'Cale plate vert 100x24', 0.082, 799, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE_6MM', N'26', N'26FD', N'Cale plate noir 100x24', 0.08, 825, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE_8MM', N'26', N'26FD', N'Cale plate gris 100x24', 0.103, 860, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE_APAP', N'26', N'26MA', N'Cale  poncer auto agrippante', 6.016, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE_BIS.BR', N'26', N'26FD', N'Cale plastique biseaute brune', 0.09, 120, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE_BIS.VERT', N'26', N'26FD', N'Cale plastique biseaute verte', 0.07, 130, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE_FCH.30X40', N'26', N'26FD', N'Cale fourchette 30x40 par 10cales condit.1000pces', 0.037, 210, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE_FCH.30X80', N'26', N'26FD', N'Cale fourchette 30x80 par 10pces condit.1000pces', 0.05, 400, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE_M1000G', N'26', N'26FD', N'Cale ronde pour manche bois', 1.05, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE_M140.200G', N'26', N'26FD', N'Cale ronde pour manche bois', 0.3, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE_M1500G', N'26', N'26FD', N'Cale ronde pour manche bois', 1.2, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE_M230.320G', N'26', N'26FD', N'Cale ronde pour manche bois', 0.4, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE_M450.520G', N'26', N'26FD', N'Cale ronde pour manche bois', 0.6, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE_M600G', N'26', N'26FD', N'Cale ronde pour manche bois', 0.7, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE_M800G', N'26', N'26FD', N'Cale ronde pour manche bois', 0.9, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE_UNI16X50', N'26', N'26FD', N'Cale universelle 16x50 par 10pces condit.1000 pces', 0.029, 340, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALE_UNI20X50', N'26', N'26FD', N'Cale universelle 20x50 par 10 pces condit.1000pces', 0.034, 420, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALI.ADEL-H718', N'21', N'21MA', N'Calibreur / recepteur 1/20MA 0/10V 0/100MV', 486.6, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALI.STH11108934000', N'26', N'26MA', N'Calibre  de chaine', 7.31, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CALO.GAL461007', N'22', N'22FA', N'Calotte de piston pour pompe GALLIA 104', 4, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAME.SAMQNV-7080R', N'31', N'31MD', N'Camera dme2.8-12mm IR', 300, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAME.SVCR-03-213011', N'31', N'31MD', N'Camera IP 1/3",2 MP, JN, WDR, 5.1-51mm,IR,ext-IPB-72A0010M0A', 658.35, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAME.SVHK-30-301311213', N'31', N'31MD', N'Camera AN SOL 8" 2MP 36xIR PTZ 24VAC & PoE DS 2DF8236IX-AEL', 1503.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAMI.7L+RECH.', N'26', N'26FD', N'Camion plastique 7l + recharges', 14.86, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAPA.PEPCBB8-18GS75-E2-V1', N'12', N'12 FA', N'Detecteur capacitif', 91.96, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAPT.NIV1052', N'21', N'21MA', N'Capteur de vitesse avec hauteur intgre 20m', 4070, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAPU.VIS_ETERNIT', N'26', N'26FD', N'Capuchon plastique noir pour vis eternit', 0.15, 15, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CARB.ECHA021000341', N'14', N'14FC', N'Carburateur DEBROUSSAILLEUSE SRM4605 ECHO', 101.7456, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CARB.ECHA021001030', N'14', N'14FC', N'Carburateur DEBROUSSAILLEUSE SRM4605 ECHO', 146.5464, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CARN.DE_CONSTAT', N'17', N'17FA', N'Carnet de constat 50 liasse de 3 feuillets autocopiants 21x29.7', 29.27, 15, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CARR.8MM', N'26', N'26FD', N'Carr de 8mm pour bquille de porte', 1.34, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CARR.ECH61002007131', N'14', N'14FC', N'Carre pour ECHO  a dos', 0.53, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.BOB1MIC', N'11', N'11FC', N'Cartouche bobine 1micron 10"PA5 / conduit eau pot', 12, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.BRO', N'20', N'20FB', N'Cartouche imprimante', 29.62, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.BROLC1280C', N'20', N'20FB', N'Cartouche d''encre XL cyan pour Brother MFC J6710 DW', 14.73, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.BROLC1280M', N'20', N'20FB', N'Cartouche d''encre magenta XL pour Brother MFC J6710 DW', 14.73, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.BROLC1280NP', N'20', N'20FB', N'Cartouche d''encre noir XL pour Brother MFC J6710 DW pack de 2 pieces', 24.33, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.BROLC1280Y', N'20', N'20FB', N'Cartouche d''encre jaune XXL pour Brother MFC J6710 DW', 14.73, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.BROLC3217BK', N'20', N'20FB', N'Cartouches d''encre noir pour Brother MFC J 57300 W', 13.11, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.BROLC3217C', N'20', N'20FB', N'Cartouches d''encre cyan pour Brother MFC J 57300 W', 9.54, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.BROLC3217M', N'20', N'20FB', N'Cartouches d''encre Magenta pour Brother MFC J 57300 W', 9.54, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.BROLC3217Y', N'20', N'20FB', N'Cartouches d''encre Yellow pour Brother MFC J 57300 W', 9.54, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.BROLC3219XLBK', N'20', N'20FB', N'Pack de 2 cartouches d''encre noir pour Brother MFC J 5730 DW 3000 pages', 25.39, 0, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.BROLC3219XLC', N'20', N'20FB', N'Cartouches d''encre cyan pour Brother MFC J 5730 DW 1500 pages', 16.82, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.BROLC3219XLM', N'20', N'20FB', N'Cartouches d''encre magenta pour Brother MFC J 5730 DW 1500 pages', 16.82, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.BROLC3219XLY', N'20', N'20FB', N'Cartouches d''encre yellow pour Brother MFC J 5730 DW 1500 pages', 16.82, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.BROLC980CN', N'20', N'20FB', N'Cartouche d''encre noir pour Brother MFC 295 CN', 12.46, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.BROTN2000', N'20', N'20FB', N'Cartouche grande capacit laser noir pour fax BROTHER 2825', 58.13, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.BROTN241BK', N'20', N'20FB', N'Cartouche d''encre noir pour MFC-9140CDN 2200 copies', 50.4035, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.BROTN241C', N'20', N'20FB', N'Cartouche d''encre cyan pour MFC-9140CDN 2200 copies', 49.86815, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.BROTN241M', N'20', N'20FB', N'Cartouche d''encre magenta pour MFC-9140CDN 2200 copies', 49.86115, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.BROTN241Y', N'20', N'20FB', N'Cartouche d''encre yellow pour MFC-9140CDN 2200 copies', 49.86115, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.BROTN3060', N'20', N'20FB', N'cartouche laser noir pour brother HL5150D grande capacit', 64.4567, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.BUT+PROP', N'11', N'11FB', N'Cartouche butane + propane gaz pour lampe express', 13.5, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.CANFX10', N'20', N'20FB', N'Cartouche grande capacit laser noir pour FAX CANON L100', 50.03, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.ENCRE_N', N'17', N'17FC', N'Boite de 8 cartouches d''encre noir', 2.2, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.EPST1301', N'20', N'20FB', N'cartouche d''encre noir XL pour imprimante epson WF-3530 DTWF', 21.291172, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.EPST1306', N'20', N'20FB', N'Multipack de cartouche d''encre couleur pour imprimante epson WF-3530 DTWF', 41.0078, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.HP3HZ52AE', N'20', N'20FB', N'Lot de 4 cartouches HP office jet pro 8710', 92.79, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.HPHC920XLKIT', N'20', N'20FB', N'Kit de 4 cartouche d''encre hp pour offiejet 7000 wide format', 58.45333, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.MEM.4GO', N'08', N'08MB', N'Carte memoire 4go pour appareil photo numrique', 13.03, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.MSI_GT720', N'20', N'20MC', N'Carte graphique MSI GeFORCE GT720 1GO DDR3', 73, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.NOR101510', N'14', N'14FC', N'Cartouche filtrante pour MAGISTRA', 46.4, 2, 0, 0, -2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.RES6962', N'33', N'33FB', N'Carte interrupteur', 14.71, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.REST6945', N'33', N'33FB', N'Carte interrupteur', 16.54, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.RICGC21C', N'20', N'20FB', N'Cartouche d''encre cyan pour ricoh aficio GX2500', 30.87, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.RICGC21K', N'20', N'20FB', N'Cartouche d''encre noir pour ricoh aficio GX2500', 24.76, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.RICGC21M', N'20', N'20FB', N'Cartouche d''encre magenta pour ricoh aficio GX2500', 30.87, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.RICGC21Y', N'20', N'20FB', N'Cartouche d''encre jaune pour ricoh aficio GX2500', 30.87, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.ROU4102541', N'14', N'14FC', N'Cartouche filtrante reservoir pour rousseau', 67.37, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.ROU4102543', N'14', N'14FC', N'Cartouche filtrante gavage pour rousseau', 51.11, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.SAM_MLTD203LEL', N'20', N'20FB', N'Cartouche laser proxpress M3820 ND', 101.25, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.SAMMLT-D250E', N'20', N'20FB', N'Cartouche noir pour imprimante Samsung ML-3710ND', 121.9, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.SCHBMXAMI0410', N'12', N'12MB', N'carte de 4 entree analogiques pour automate M340', 377.93, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.SCHBMXCPS2000', N'12', N'12MB', N'Carte alimentation automate', 206.515, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.SCHXUZX2004', N'12', N'12 FA', N'Carter de protection avec rotule pour detecteur photoelectrique osiconcept XUX 0', 7.74, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.SDHC32GO', N'08', N'08MB', N'Carte mmoire micro SDHC 32 GO', 9.6, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.SDHC64GO', N'08', N'08MB', N'Carte mmoire micro SDHC 64 GO', 41, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CART.STH11290801806', N'14', N'14FC', N'Carter de ventilateur', 28.75, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CASQ.C1', N'18', N'18MB', N'Casque anti-bruit 30DB CLARITY C1', 14.7, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CASQ.C3', N'18', N'18MB', N'Casque anti bruit CLARITY C3', 23.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CASQ.CHT.BLC', N'18', N'18MB', N'Casque de chantier blanc', 37.68394, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CASQ.HUS562413', N'18', N'18MB', N'Casque de bucheronnage', 42.8333, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CASQ.INTEGRA', N'18', N'18MB', N'Casque de bucheronnage', 47.59, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CASQ.STEREO', N'20', N'20FB', N'Casque fiche jack 2.1m de cable', 2.73, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CASS.SIGN', N'17', N'17FC', N'Cassette d''encrage pour tampon de marque sign', 9.9, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CASS.TIMB.4911', N'17', N'17FC', N'Cassette d''encrage pour timbre 4911', 4.34, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CATA_RVI5010096738', N'33', N'33FB', N'Catadioptre rouge ARD fix sur le support du feu AR', 6.76, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CAVA.NOR104455', N'14', N'14FC', N'Cavalier XL1600', 36.83, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CEIN.PORTE_OUT.', N'18', N'18MB', N'Ceinture porte outil de bucheronnage', 27.28, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAI.AC2.5', N'22', N'22MB', N'Chane dia:2,5mm ZI DIN 5685', 1.1558, 19, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAI.AC3', N'22', N'22MB', N'Chane dia:3.0mm ZI DIN 5685', 1.918, 23, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAI.AC6', N'22', N'22MB', N'Chaine zinguee diametre 6mm', 2.1, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAI.AC6INOX', N'26', N'26FD', N'Chaine inox en fut 6mm', 14, 14, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAI.ORE91VXL055E', N'14', N'14FC', N'Chaine SEMI CHISEL 3/8 LTP', 12.5, 2, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAI.STH36100030044', N'14', N'14FC', N'Chaine P3/8 1,1 30CM HT pour elagueuse', 12.5, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAI.STH36290030067', N'14', N'14FC', N'Chaine 325 1,6  1/2 ronde 40CR   26RMC 67T 40cm', 16.7064, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAI.STH38680030072', N'14', N'14FC', N'Chaine 3/8 1,6 50CC Carr   36RM 72TCR', 16.02347, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAI.STH39460000091', N'14', N'14FC', N'Chaine tronconneuse MS880 404-1.6-91C', 32.9296, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAI.STH39700030074', N'14', N'14FC', N'Chaine tronconneuse 325 1,6 45CR 74T', 16.67489, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAI.STH39910030060', N'14', N'14FC', N'Chaine 3/8 40cm', 15.62625, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAI.STH39910030066', N'14', N'14FC', N'Chaine 3/8 1,6 45CR', 15.0495, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAI.STH39910030084', N'14', N'14FC', N'Chaine 3/8 1,6 84T', 18.8127, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAI.STH39970030050', N'14', N'14FC', N'Chaine 1,1 3/8  63PM 50T 35cm pour 020 ou MS200', 12.54341, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAM.11.2/10-24', N'14', N'14FC', N'Chambre  air AV. tracteur 6432QR62', 28.0003, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAM.11.5/12-5X15', N'14', N'14FC', N'Chambre a air 11,5/12-5x15', 25.58, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAM.13.6/24', N'14', N'14FC', N'Chambre a air 13,6/24', 38, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAM.15E13', N'14', N'14FC', N'145A180-15 155A185/70-15 560-15/roulotte de chanti', 14.43, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAM.16.9-34', N'14', N'14FC', N'Chambre  air AR tracteur ergos 95', 137, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAM.2"1/4-17', N'33', N'33FC', N'Chambre  air de mobylette', 8.88, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAM.2"3/4-18', N'33', N'33FC', N'Chambre  air pour mobylette AV 88', 8.25, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAM.350X4.00-8', N'14', N'14FC', N'Chambre a air pour brouette', 12.3, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAM.EUT28353', N'14', N'14FC', N'Chambre  air arriere pour Attila', 22.3916, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAM.L2T', N'05', N'05FA', N'Chambre de tirage avec fond', 143, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAP.+P110', N'05', N'05MA', N'Chapeau + plomb dia:110', 74.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAP.CERC.INOX', N'26', N'26FD', N'Chape pour cerclage', 15.625, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAP.PALPZZR450R-68', N'22', N'22MB', N'Chape entre rotator DN68', 388.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAP.SAKRET40', N'05', N'05FA', N'Sac de beton pret a l''emploi 40kgs 0/7', 4.96, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAR.BOS12V3AH', N'22', N'22MD', N'Chargeur pour visseuse Bosch', 16.27, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAR.BOSC7', N'22', N'22FA', N'Chargeur de batterie compact C1 C3et C7 12V et 24V', 89.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAR.CROSSCALL_SPIDER X5', N'31', N'31FA', N'Chargeur portable crosscall spider X5', 45.1, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAR.PIANO40MM', N'05', N'05FA', N'Charnire piano 14mm 1980mmm', 2.9697, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAR.TRO870-C', N'22', N'22MA', N'Chariot retention mobile', 641.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAS.CLA6005014627', N'14', N'14FC', N'Chassis', 206.7, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAS.CLOU_CONE', N'26', N'26MA', N'Chasse clou conique', 2.2715, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAS.FAC249.GJ5', N'26', N'26MA', N'Jeu de 5 chasse goupille gain', 34.83, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAS.LEG057743', N'12', N'12MB', N'Chassis pliable', 104.22, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAU.BIZ700217', N'26', N'26MA', N'Kit de 4 chaussetes acier 6-32mm', 121.39, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.12X60', N'26', N'26FD', N'Cheville nylon 12x60', 4.73, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.12X66', N'26', N'26FD', N'Chevilles a collerette fine S12X66 50 pces', 18.76, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.12X71', N'26', N'26FD', N'Cheville Schark sans collerette 12x71', 15.98, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.14X75*', N'26', N'26FD', N'Cheville Schark sans collerette 14x75', 2.757, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.6X30', N'26', N'26FD', N'Cheville nylon 6x30', 5.876636, 17, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.8X46', N'26', N'26FD', N'Cheville nylon 8x46', 7.113175, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.B12/10', N'26', N'26FD', N'Cheville mtallique de scurit 12/10 B avec ecrou', 1.692, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.B14/10', N'26', N'26FD', N'Chevilles mtalliques type B WHL m10 14/10 B lg 113mm', 3.2848, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.B14/25', N'26', N'26FD', N'Cheville mtallique type B WHL14/25B', 3.08, 15, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.B18/15', N'26', N'26FD', N'Cheville mtalliques type B W-HL18/15B', 4.33, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.BASC', N'26', N'26FD', N'Cheville  bascule Fischer duotec', 21.86, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.COL10X62', N'26', N'26FD', N'Chevilles  collerette S10X62 50pces', 7.224, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.COL14X76', N'26', N'26FD', N'Cheville SHARK a collerette rouge 14X76 / 20 pces', 10, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.COL7X37', N'26', N'26FD', N'Cheville Schark a collerette 7x37', 0.1, 900, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.COL8X40', N'26', N'26FD', N'chevilles  collerette S8X40', 5.35, 3, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.COL8X52', N'26', N'26FD', N'Cheville Schark avec collerette 8x52', 0.0621, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.FRAP.FK5X25', N'26', N'26FD', N'cheville a frapper type FK sans collerette 5x25', 23.81, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.FRAP.FK6X40', N'26', N'26FD', N'cheville sans collerette type FK 6x40', 6.74, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.FRAP.FK6X60', N'26', N'26FD', N'cheville a frapper type FK sans collerette 6x60', 15.3, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.FRAP.FK6X80', N'26', N'26FD', N'cheville a frapper type FK sans collerette 6x80', 19.32, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.FRAP.SK6X60', N'26', N'26FD', N'cheville a frapper type sk collerette fraisee 6x60', 15.23, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.FRAP.SK6X80', N'26', N'26FD', N'cheville a frapper type SK collerette fraisee 6x80', 20.65, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.MACON250', N'26', N'26FD', N'Chevillette de maon 250mm tige ronde', 3.48, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.PARCR16X24', N'26', N'26FD', N'Chevilles paroies creuses 16x24mm AC ZI', 0.1858, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.PARCR4X32', N'26', N'26FD', N'Chevilles paroies creuses 4x32 AC ZI', 0.15874, 500, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.PARCR4X9', N'26', N'26FD', N'Chevilles paroies creuses 4x9 AC ZI', 0.1836, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.PARCR5X12', N'26', N'26FD', N'Chevilles paroies creuses 5x12mm + vis AC ZI', 0.2192, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.PARCR5X32', N'26', N'26FD', N'chevilles paroies creuses 5x32 AC ZI  S/Vis', 0.2223529, 160, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.PARCR5X37', N'26', N'26FD', N'Chevilles paroies creuses 5x37 + vis AC ZI', 0.3905, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.PARCR6X52', N'26', N'26FD', N'Chevilles paroie creuse 6x52 AC ZI', 0.6200027, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.PARCR8X65', N'26', N'26FD', N'Chevilles paroie creuse 8x65 AC ZI avec vis', 0.278, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.PARCRNYL8X45', N'26', N'26FD', N'Cheville paroi creuse PLASTIQUE 8x45', 0.722, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.POLYFIX6X28', N'26', N'26FD', N'Cheville POLYFIX 6x28 grise / 125pces', 7.5, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.POLYFIX8X33', N'26', N'26FD', N'Cheville polyfix bleu  bte de 125 pces', 9.45, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.S12/10', N'26', N'26FD', N'Cheville de scurit type S 12/10', 1.392, 64, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.S12/40', N'26', N'26FD', N'Chevilles mtallique type S WHL 12/40 S', 3.02, 20, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.S12/50', N'26', N'26FD', N'Chevilles mtallique type S WHL 12/50 S 90561250', 1.9235, 21, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.S8/55/10', N'26', N'26FD', N'Cheville metallique WHL type S M8/55/10', 1.901, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.WMAX', N'26', N'26FD', N'Chevilles W MAX plastique / 200pces', 0.21, 200, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHIF.BLANC', N'26', N'26FD', N'Chiffon blanc coton 10kgs', 34.9041672, 11, 0, 0, 5)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CIME.CE25', N'05', N'05FA', N'Ciment 25KGS CE', 3.19, 0, 0, 0, 10)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CIME.PROMPT25', N'05', N'05FA', N'Ciment prompt 25 kgs', 22.65, 0, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CIME.SCBE25', N'05', N'05FA', N'Mortier a maonner 25KGS', 4.96, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CIRC.ECH90070100012', N'14', N'14FC', N'Circlips ext.pour ECHO4605', 0.77, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CIRC.ECHP022002100', N'14', N'14FC', N'Circlips ext.pour ECHO4605', 1.9, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CIRC.EXT08', N'26', N'26FD', N'Circlip extrieur 8x0,8', 0.0388, 115, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CIRC.EXT12', N'26', N'26FD', N'Circlips extrieur de 12', 0.0332, 105, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CIRC.EXT16', N'26', N'26FD', N'circlips extrieur de 16', 0.044, 105, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CIRC.EXT17', N'26', N'26FD', N'Circlip extrieur 17x1', 0.0553, 115, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CIRC.EXT30', N'26', N'26FD', N'Circlip extrieur 30', 2.14, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CIRC.NOR103135', N'14', N'14FC', N'circlip', 0.45, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CIRC.STH94606241001', N'26', N'26FD', N'Circlips 10x1.5', 0.572, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CIRC.TRA020202', N'28', N'28MA', N'Circuit 95 leds orange alim 24V cable 1M lentille polycarbonate + siliconage complet', 180, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CIRC.TRA020204', N'28', N'28MA', N'Circuit 95 leds rouge alim 24V cable 1M lentille polycarbonate + siliconage complet', 180, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CISE.BOIS10MM', N'26', N'26MA', N'Ciseaux  bois 10 mm', 16.25, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CISE.BOIS8MM', N'26', N'26MA', N'Ciseaux  bois 8mm', 16, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CISE.BUREAU', N'17', N'17FC', N'Ciseaux de bureau', 2.51, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLAP.AR_F1/2HP', N'22', N'22FA', N'Clapet anti retour taraud F/F R1/2 HP', 23.4, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLAP.GAL461003', N'22', N'22FA', N'Clapet caoutchouc Gallia 104', 4.116, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLAP.S10A05', N'22', N'22FA', N'Clapet anti retour S1005', 180, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLAS.10N', N'17', N'17FC', N'Classeur jumbo dos 10 cm noir', 8.7, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLAS.5BL', N'17', N'17FC', N'Classeur dos 5 cm bleu', 1.59, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLAS.5N', N'17', N'17FC', N'Classeur dos 5 cm noir', 1.45, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLAS.5RG', N'17', N'17FC', N'Classeur dos 5 cm rouge', 1.45, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLAS.5V', N'17', N'17FC', N'Classeur dos 5 cm vert clair', 1.59, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLAS.8BL', N'17', N'17FC', N'Classeur dos 8 cm bleu', 1.65, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLAS.8RG', N'17', N'17FC', N'Classeur dos 8 cm rouge', 1.45, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLAS.8VM', N'17', N'17FC', N'Classeur dos 8 cm vert moyen', 1.59, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLAS.DOSLARG', N'17', N'17FC', N'Classeur a levier dos large format A4 dos 7cm', 2.443478, 20, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLAS.DOSLIT', N'17', N'17FC', N'Classeur dos large  l''italienne', 2.82, 18, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLAV.+SOURIS', N'20', N'20FB', N'Pack clavier + souris laser sans fil', 19.9, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLAV.6X6X13.8', N'22', N'22FA', N'Clavette parrallle 6x6x13.8', 2.64, 40, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLAV.6X6X32', N'22', N'22FA', N'Clavette parrallle 6x6x32 avec usinage rayon de 3 aux 2 extrmits', 2.74, 46, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLAV.8X7X55.8', N'22', N'22FA', N'Clavette parrallle 8x7x55.8', 2.86, 40, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLAV.ECH90032303014', N'14', N'14FC', N'Clavette', 1.1352, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLAV.MOB.847215', N'33', N'33FC', N'Clavette de mobylette dakota', 1.2, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLAV.NOR103460', N'14', N'14FC', N'clavette velo', 5.285, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CLAV.SVHK-40-302600066', N'20', N'20MC', N'Clavier USB pour DVR / NVR DS-1005KI', 193.03, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.LEG089125', N'12', N'12 FA', N'Bote d''encastrement 1P 65x65x38 089125 LEGR', 0.5107, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.LEG089224', N'12', N'12 FA', N'Bote d''encastrement ronde D.60 prof.40  vis vert', 0.26, 14, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.LEG089281', N'12', N'12 FA', N'Bote de maonnerie  derivation 165x110x40', 1.356, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.LEG089337', N'12', N'12 FA', N'Bote d''enc.pour luminaire centre DCL batibox seche', 4.9945, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.LEG089341', N'12', N'12 FA', N'Bote d''enc.1 poste prof.40 mixte 089341 LEGR', 0.52, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.LEG089401', N'12', N'12 FA', N'Bote d''encastrement 85x85x40 089401 LEGR', 1.28, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.LEG092094', N'12', N'12 FA', N'Bote de derivation plexo 360x270x124mm', 96, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.OUT4PL', N'26', N'26FD', N'Boite de rangement 4 plateaux', 36.24, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.OUTFACBP.C19N', N'26', N'26MA', N'Boite a outil 19 inch', 16.19, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.OUTFACBS.T20', N'26', N'26FD', N'Boite  outils textile', 52.65, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.OUTFACBT13GPB', N'26', N'26MA', N'Boite a outils 5 cases  longue', 36.24, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.OUTFACCBT.11GPB', N'26', N'26MA', N'Boite a outil 5 compartiments 53x20x20', 39.06, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.PW12042', N'12', N'12 FA', N'Bote de derivation pose en saillie 76x76x37', 0.9, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.SAR04508', N'12', N'12 FA', N'Boite murabox  80x80x30 couvercle 78x78', 1.6353, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.SAR04509', N'12', N'12 FA', N'Boite a encastrer  pour luminaire', 1.85, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.SAR04511', N'12', N'12 FA', N'Boite cloison seche  120x120x40', 2.85, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.SAR04513', N'12', N'12 FA', N'Bote  sceller 135x135x40 04513', 3.03, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.SAR04516', N'12', N'12 FA', N'Bote  sceller 165x165x45 04516', 3.68, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.SAR04517', N'12', N'12 FA', N'Boite cloison seche 175x175x45', 4.64, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.SCH03350', N'12', N'12 FA', N'Boite etanche SAREL ref:03350 164/99/67', 6.7, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.SCHENN05004', N'12', N'12 FA', N'Boite etanche 80x80x45', 2.41461539, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.SCHENN05005', N'12', N'12 FA', N'Boite de derivation etanche 105x105x55 EVABOX', 4.05, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.SCHENN05007', N'12', N'12 FA', N'Boite de derivation etanche 150x105x80 EVABOX', 10.68, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.SCHENN05010', N'12', N'12 FA', N'Boite SAREL tanche 175x150x80', 13.49, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.SCHNSYTBS342912', N'12', N'12 FA', N'Boite avec couvercle 341x291x128 ABS', 55.99, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.SOD03200', N'12', N'12 FA', N'Boite etanche IP 55 60X60X45', 2.77, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.SVAX.08-202888', N'31', N'31MD', N'Boitier de connex series medium et small candid large AK 4', 100.89, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOLL.DN100', N'28', N'28MA', N'Bollard DN100  sceller matire fonte', 183, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BONN.S/CASQUE', N'28', N'28MA', N'Bonnet sous casque de chantier universel', 8.48, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOOS.KS550.1810', N'22', N'22MA', N'Car booster 12V', 362.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BORN.BIZ300444', N'12', N'12 FA', N'Bornes de connection cristal 4 entrees', 16.234, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BORN.BLM475120', N'12', N'12 FA', N'Bornes individuelles  SOUPLE 2x2.5 a 4mm 100 pieces', 34, 0, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BORN.BLM475130', N'12', N'12 FA', N'Bornes individuelles  SOUPLE 3 entrees 75 pces', 30.75, 0, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BORN.BLM475150', N'12', N'12 FA', N'Bornes individuelles   levier 5x2.5  4mm 50 pieces', 32.5, 0, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BORN.CES040032', N'12', N'12 FA', N'Borne de mise a la terre TRL avec rondelle et vis 6 X 10 serrage 12 a 6mm', 14, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BORN.PHO.PTCBEI24DC/1-8ANO', N'20', N'20FB', N'Borne disjoncteur electronique 24 VDC rglable de 1  8 - NO', 22.57, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BORN.WAG221415', N'12', N'12 FA', N'Bornes individuelles   levier 5x2.5  4mm', 74.5, 0, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BORN.WAG222412', N'12', N'12 FA', N'Bornes individuelles  SOUPLE 2x2.5 a 4mm', 25.96166, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BORN.WAG222413', N'12', N'12 FA', N'Bornes individuelles  SOUPLE 3 cond.0.08-4mm', 14.21, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BORN.WAG2273203', N'12', N'12 FA', N'Bornes individuelles 3x0,5  2', 13.99, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BORN.WAG2273204', N'12', N'12 FA', N'Bornes individuelles 4 x0,5  2', 19.12, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BORN.WAG2273208', N'12', N'12 FA', N'Borne de raccordement 8 trous 0.5-2.5mm', 14.66, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BORN.WAG273101', N'12', N'12 FA', N'Bornes individuelles  5x0,75  1,5', 11.3, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BORN.WAG273103', N'12', N'12 FA', N'Borne de raccordement 8x1 a 1,5 2,5mm', 22.29, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BORN.WAG273104', N'12', N'12 FA', N'Bornes individuelles 3x0,75 a 2,5', 15.55, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BORN.WAG273105', N'12', N'12 FA', N'Bornes individuelles  5x0,75  2,5', 9.35, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOTT.FOURRET40_S3', N'18', N'18MB', N'Bottes de securit fourr  S3 pour femme', 95, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOTT.SIPT41', N'18', N'18MB', N'Bottes de tronconnage + semelle anti perforation pt41', 74.11, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOTT.T37', N'18', N'18MB', N'Bottes CAOUTCHOUC T37 SAS', 89.9, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOTT.T40', N'18', N'18MB', N'Bottes CAOUTCHOUC T40 SAS', 144, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOTT.T41', N'18', N'18MB', N'Bottes CAOUTCHOUC T41 SAS', 80, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOTT.T42', N'18', N'18MB', N'Bottes CAOUTCHOUC T42 SAS', 67.4, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOTT.T43', N'18', N'18MB', N'Bottes  CAOUTCHOUC T43 SAS', 67.4, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOTT.T44', N'18', N'18MB', N'Bottes CAOUTCHOUC T44 SAS', 87.93333, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOTT.T47', N'18', N'18MB', N'Bottes  CAOUTCHOUC T47 SAS', 89.9, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.1/2RAC100', N'22', N'22FA', N'bouchon demi-raccord 1092.531 symetrique a poignee 100 alu avec chainette', 25.8, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.BIL303L20', N'18', N'18MB', N'Bouchon BILSOM 200pces 303L20', 26.03555, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.BIL656SML', N'18', N'18MB', N'Bouchon NST 656 small', 2.48, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.BM303286', N'22', N'22FA', N'bouchon de reservoir essence pompe a eau', 3.91, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.CD1000L', N'26', N'26FD', N'Bouchon plastique femelle diametre 153 mm  pour cuve 1000l', 18, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.CU14F', N'11', N'11FC', N'Bouchon cuivre femelle de diametre 14', 0.67, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.DEL23331', N'22', N'22FA', N'Bouchon filet pour H2S', 13, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.DNABLE', N'33', N'33FD', N'Bouchon de nable pour new matic', 8.9, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.ECH13100455530', N'14', N'14FC', N'bouchon reservoir echo', 9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.ECH13160009861', N'14', N'14FC', N'Bouchon reservoir a essence echo', 23.246, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.ECH61043450030', N'14', N'14FC', N'Bouchon pour 4605 ECHO', 0.78, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.ECH61051001930', N'14', N'14FC', N'Bouchon pour ECHO', 3.57, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.GAL.M1"', N'11', N'11FC', N'Bouchon M galva 1"', 0.7348, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.GAL.M3/4', N'11', N'11FC', N'Bouchon M galva 3/4', 0.625, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.HONSMART_FIT', N'18', N'18MB', N'Bouchon d''oreille boite de 50 paires avec cordelette et adaptable sur mesure', 52.62, 0.5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.HUS537215202', N'14', N'14FC', N'Bouchon huile essence', 8.2632, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.HUS537215207', N'14', N'14FC', N'Bouchon huile essence', 8.2632, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.HYDC3/8F', N'14', N'14FC', N'Bouchon coupleur hydraulique 3/8 GROM femelle', 8.04, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.LAIT.M3/8', N'11', N'11FC', N'Bouchon laiton M 3/8 pour pompe Gallia', 0.122, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.MOULE', N'18', N'18MB', N'Bouchon moule audipack en kit avec malette', 104.8, 0, 0, 0, 13)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.MPVC100', N'11', N'11FC', N'Bouchon M PVC 100', 4.75, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.PER34150', N'33', N'33FD', N'Bouchon 0.4 bars', 46.02, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.ROU205602', N'14', N'14FC', N'Bouchon de reniflard', 30.94, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.ROV12L', N'14', N'14FC', N'Bochon hydraulique ROV 12 L', 4.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.RS817-8855', N'26', N'26FD', N'Bouchon obturateur  lisse noir en nylon 12.7mm', 0.356, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.STH00003500510', N'14', N'14FC', N'Bouchon huile STIHL', 14.07, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.STH00003500520', N'14', N'14FC', N'Bouchon de reservoir complet STIHL', 10.26, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.STH00003500521', N'14', N'14FC', N'Bouchon huile STIHL', 6.732, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.STH00003500530', N'14', N'14FC', N'Bouchon de reservoir complet STIHL', 7.2336, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUC.STH11241409500', N'14', N'14FC', N'Bouchon d''obturation', 6.13, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUE_BICO.V600NM', N'28', N'28MA', N'Boue bicone verte 40cm/64cm non mousse ht:600 14 kgs', 50.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUE_COUR+LIGNE', N'28', N'28MA', N'Boue couronne solas + 30 metres ligne de jet diametre 8mm', 43.166, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUE_CYL.R740NM', N'28', N'28MA', N'Boue cylindrique  rouge ht:74cm x dn 40cm x dn sup 25cm 14 kgs', 50.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUG.CHARC12YC', N'14', N'14FC', N'Bougie Champion RC12YC', 5.4333, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUG.CHARCJ6Y', N'14', N'14FC', N'Bougie Champion RC12YC', 6.11, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUG.EY42LJS3', N'33', N'33FA', N'Bougie EYQUEM C42LJS3', 2.3239, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUG.NGKB6HS', N'33', N'33FA', N'Bougie champion L82C ou NGK B6HS', 2.0927, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUG.NGKBCP5ES', N'33', N'33FA', N'Bougie Champion C9YCX ou NGK BCP5ES', 2.03, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUG.NGKBK5ESZ', N'33', N'33FA', N'Bougie NGK BK5ESZ', 2.06, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUG.NGKBKR5EK', N'33', N'33FA', N'Bougie NGK BKR5EK', 3.4855, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUG.NGKBKR6E', N'33', N'33FA', N'Bougie Champion RC9YCC ou NGK BKR6E', 2.59, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUG.NGKBP6ES', N'33', N'33FA', N'Bougie Champion N281YC ou NGK BP6ES', 2.04, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUG.NGKBPMR6A', N'14', N'14FC', N'Bougie pour debroussailleuse et tronconeuse NGKBPMR6A', 4.91, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUG.NGKBPR5ES', N'14', N'14FC', N'Bougie', 2.71, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUG.NGKLFR6A', N'33', N'33FD', N'Bougie NGK', 12.42, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUG.QL77JC4', N'33', N'33FD', N'Bougie champion pour bateau CAP CAMARAT', 3.32, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUG.REN7701040208', N'33', N'33FB', N'Bougie de prchauffage', 17.28, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUG.REN8200490950', N'33', N'33FB', N'Bougie de prchauffage pour kangoo 2', 20.64, 16, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUG.REN8671004853', N'33', N'33FA', N'Bougies de prchauffage pour kangoo et autres', 9.2684, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUG.REN8671017928', N'33', N'33FA', N'Lot de bougies d''allumage pour kangoo - twingo et clio', 70.992, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUI.ELEC', N'24', N'24FB', N'bouilloire electrique', 22.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUL.1ERG12X50', N'14', N'14FC', N'Boulon de charrue 1ergot acier brut 6.8 12x50', 0.6, 81, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUL.NOR110162', N'14', N'14FC', N'Boulon (vis+ecrou) / patin MAGISTRA', 1.25, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUL.P05X40', N'26', N'26FD', N'Boulon polier 5x40 AC ZI 4.8', 0.267, 47, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUL.P06X30', N'26', N'26FD', N'Boulon polier 6x30 AC ZI 4.8', 0.05, 138, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUL.P06X40', N'26', N'26FD', N'Boulon polier 6x40 AC ZI 4,8', 0.0659, 194, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUL.P08X40', N'26', N'26FD', N'Boulon polier 8x40 AC ZI 4.8', 0.691, 53, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUL.P08X70', N'26', N'26FD', N'Boulon polier 8x70 AC ZI 4.8', 0.82, 58, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUL.P10X40', N'26', N'26FD', N'Boulon polier 10x40 AC ZI 4.8', 1.288, 65, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUL.P10X60', N'26', N'26FD', N'Boulon polier 10x60 AC ZI 4.8', 1.57, 65, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUL.STH11201625200', N'22', N'22FA', N'Boulon', 1.94, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUL.TAR81/82', N'26', N'26FD', N'Boule nylon avant complete diametre 20mm', 30.46, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOUT.LEG057745', N'12', N'12 FA', N'Bouton de coupure d''urgence OSMOZ pour coffret P17', 38.18, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOX_SVHK-50-302701355', N'20', N'20MC', N'Box support pour  dme DS-1604ZJ', 42.68, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BP_LEG067031', N'12', N'12MB', N'Poussoir INVERSEUR 6A', 7.9335, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BP_LEG080505', N'12', N'12MB', N'Poussoir NEPT 2 10a LEGR 080505', 2.21, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BP_LEG080552', N'12', N'12MB', N'Poussoir + inter Nept2', 3.6893, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BP_SCHA9E180328', N'12', N'12MB', N'IPB bouton poussoir simple gris NO 20A 230VCA', 12.09, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.TUB.10-8', N'12', N'12MB', N'Cosse tubulaire cuivre W-CT section 10mm bornage M8 percage 8.3 mm', 0.182, 65, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.TUB.16-10', N'12', N'12MB', N'Cosse tubulaire cuivre W-CT section 16mm bornage M10 percage 10.3 mm', 0.254, 65, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.TUB.16-6', N'12', N'12MB', N'Cosse tubulaire cuivre W-CT section 16mm bornage M6 percage 6.4 mm', 0.252, 85, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COSS.TUB.16-8', N'12', N'12MB', N'Cosse tubulaire cuivre W-CT section 16mm bornage M8 percage 8.3 mm', 0.253, 72, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COTT.FOR.ORE295453/L', N'18', N'18MB', N'Pantalon de tronconnage  Taille L Yukon', 93.58, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COTT.FOREST.M', N'18', N'18MB', N'Cotte  bretelles forestire M 1SGZ vert sapin orange  EN385-5', 82.9188, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COTT.FOREST.XL', N'18', N'18MB', N'Cotte  bretelles forestire taille XL 1SG2 vert sapin orange  EN385-5', 69.8, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COTT.FOREST.XS', N'18', N'18MB', N'Cotte  bretelles forestire XS 1SG2 vert sapin orange  EN385-5', 64.18, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COTT.ORE295454/L', N'18', N'18MB', N'Cotte  bretelles forestire taille L yukon + type A', 93.58, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.1/2MF', N'22', N'22FA', N'Coude hydraulique 1/2 MF', 10.26, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.100PVC20MF', N'11', N'11FC', N'Coude PVC DN100 20 MF', 4.22, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.100PVC45F', N'11', N'11FC', N'Coude PVC dia:100 FF', 3.416, 12, 0, 0, 5)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.100PVC45MF', N'11', N'11FC', N'Coude PVC  45 dia:100 MF', 2.591518, 25, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.100PVC87F', N'05', N'05FA', N'Coude PVC dia:100 FF', 3.906, 7, 0, 0, 4)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.100PVC87MF', N'11', N'11FC', N'Coude PVC gris dia:100 MF 8730', 2.439, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'COUD.110PVC45F', N'05', N'05FA', N'Coude PVC 110 45', 2.453333, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BP_SCHXB4BA21', N'12', N'12MB', N'Bouton poussoir', 8.19, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BRAC.ETROIT200', N'17', N'17FC', N'Bracelets blonds etroit 200mm boite de 100 grammes', 0.49, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BRAN.ECH35101052931', N'14', N'14FC', N'Brancard G pour debroussailleuse ECHO 5000', 53.0024, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BRAS.PLASTORM150N', N'18', N'18MB', N'Brassiere STORM + 70kgs 150N', 19.39, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BRET.ORE537804', N'18', N'18MB', N' Bretelle  pour pantalon de bucheronnage', 12.7668352, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BRET.SOL4300334', N'22', N'22FA', N'Bretelle / pulverisateur SOLO', 10, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BRID.', N'22', N'22FA', N'Bride de refoulement pompe hydraulique', 14.42, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BRID.ECH69901140430', N'14', N'14FC', N'bride de rpotection echo', 17.9, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROC_VERS1L', N'26', N'26FD', N'Broc verseur plastique translucide 1L avec couvercle bec flexible et capuchon', 10.8, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROC_VERS5L', N'26', N'26FD', N'Broc verseur plastique translucide 5L avec bec flexible', 20.32125, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROD.T40', N'18', N'18MB', N'Brodequin de securit', 123.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.200X20X20', N'26', N'26FD', N'Brosse circulaire pour touret a meuler', 26.74, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.A_ENCOLLER', N'26', N'26MA', N'Brosse a encoller', 22.25, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.A_TAPISSER', N'26', N'26MA', N'Brosse a tapisser', 3.59, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.B2025', N'14', N'14FC', N'Brosse mtallique pour debroussailleuse 230x050x25.4mm', 44.93, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.BOUGIE', N'26', N'26MA', N'Brosse a bougie laiton 3 rgs', 0.762, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.CHIEND', N'24', N'24FB', N'Brosse de nettoyage chiendent', 4.93, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.ETRIER', N'26', N'26MA', N'Brosse etrier', 2.98, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.MET4RG', N'26', N'26MA', N'Brosse mtallique 4 rangs laiton', 3.52, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.MET5RG', N'26', N'26MA', N'Brosse mtallique 5 ranges', 1.99, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.PEINT20', N'26', N'26MA', N'Brosse  vernir N20', 1.1967, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.PEINT25', N'26', N'26MA', N'Brosse de peintre N25', 4.11, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.PEINT30', N'26', N'26MA', N'Brosse de peintre N30', 2.01268, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.PEINT40', N'26', N'26MA', N'Brosse de peintre N40', 2.815857, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.PEINT50', N'26', N'26MA', N'Brosse de peintre N50', 3.7529, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.PEINT60', N'26', N'26MA', N'Brosse de peintre N60', 4.732857, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.PEINT70', N'26', N'26MA', N'Brosse de peintre N70', 5.671036, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.PEINT8', N'26', N'26MA', N'Brosse a  peindre N8', 11.27, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.PEINT80', N'26', N'26MA', N'Brosse de peintre N80', 8.594, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.PEINTRAD35', N'26', N'26MA', N'Brosse radiateur N35', 3.088, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.PEINTRAD40', N'26', N'26MA', N'Brosse radiateur N40 coudee', 5.997067, 14, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.REPUL0.5M', N'24', N'24FB', N'Brossol anti rongeur longueur 0.5m / 7.842.8553', 10.95, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.REPUL1M', N'24', N'24FB', N'Brossol anti rongeur longueur 1m / 7.842.8554', 16.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.ROT.CIRC115', N'24', N'24FB', N'Brosse rotative circulaire DN 115mm - fil 0.5 - alesage 22.2mm', 15.39573, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.ROT.CIRC125', N'24', N'24FB', N'Brosse rotative circulaire DN 125mm/13/28 - fil 0.5 - alesage 22.2mm', 15.6, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.ROT.FC', N'24', N'24FB', N'Brosse rotative forme coupe fil,14x2 65x0,5', 26.20667, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.ROT100', N'24', N'24FB', N'Brosse rotative pour meuleuse 2 rangs acier 0.30', 21.9, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.VEHICUL', N'26', N'26MA', N'Brosse de nettoyage pour vehicules', 31.26, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BROS.WC+R.', N'24', N'24FB', N'Brosse WC + rceptacle 1ER PRIX', 9.092857, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BUFF_THERMAL', N'18', N'18MB', N'Buff thermal chaleur froid', 1.92, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BURI.AC263.25', N'26', N'26MA', N'Burin a profil constant 263.25', 10.69, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BURI.BOS1618661000', N'26', N'26FA', N'Burin beche 400*80 MM HEX 28MM', 80.78, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BURI.FAC259', N'26', N'26MA', N'Burin extra plat 259 Facom', 9.83, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BURI.MAC300X24', N'26', N'26MA', N'Burin de maon 300x24mm', 13.6, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BURI.MAC400X28', N'26', N'26MA', N'Burin de maon 400x28mm', 18.03, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BURI.PLAT250SDS+', N'26', N'26FD', N'Burin plat SDS + L250', 25.35, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BURI.PLATMAX400', N'26', N'26FD', N'Burin SDS MAX plat lg 400mm', 25.35, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BUSE_12/10', N'22', N'22MD', N'Buse 12/10 pour chalumeau coupe 25/50mm 3cones ad', 20.826, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BUSE_16/10', N'22', N'22MD', N'Buse SAF 16/10 pour chalumeau coupe 30/70mm 3cones ad', 20.05, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BUSE_CONIQUE', N'22', N'22MD', N'Buse conique pour chalumeau', 3.9, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BUSE_DEBOU17-3/8', N'22', N'22FA', N'Buse de canalisation  inox R3/8M dn17 6 jets arriere + 1 jet avant', 36, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BUSE_WEL_DX113', N'26', N'26FD', N'Buse pour fer a souder', 9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BUTE.COUD7X02,2', N'26', N'26FD', N'Butee coudee BICHROMATE 7x02,2 pour arret de volet', 1.53, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BUTE.STH11291626600', N'14', N'14FC', N'Butee pour MS200', 2.6752, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BUTO.STH11147909600', N'14', N'14FC', N'Butoir annulaire 020T STIHL', 10.8944, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BUTO.STH11167909600', N'14', N'14FC', N'Butoir annulaire', 8.9122, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BUTO.STH11227909900', N'14', N'14FC', N'Butoir annulaire', 7.84, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BUTO.STH11227909905', N'14', N'14FC', N'Butoir annulaire', 6.525, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BUTO.STH11227909920', N'14', N'14FC', N'Butoir annulaire', 6.23, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BUTO.STH11257909904', N'14', N'14FC', N'Butoir annulaire', 5.18, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BUTO.STH11257912805', N'14', N'14FC', N'Butoir d''arret 034', 4.31, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BUTO.STH11297909900', N'14', N'14FC', N'Butoir annulaire', 10.2696, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BUTO.STH11297909902', N'14', N'14FC', N'Butoir annulaire', 8.2537, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BUTO.STH11297909903', N'14', N'14FC', N'Butoir annulaire', 7.9904, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.AC10X20M', N'22', N'22MB', N'Cable acier 10mm longueur 20m avec  une extrmit  1 crochet + linguet', 72, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.AC12MM', N'22', N'22MB', N'Cable acier dia:12mm au ml', 2.927, 15, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.AC3MM-A2', N'22', N'22MB', N'Cable INOX dia:3mm au ml', 1.02, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.AC6MM', N'22', N'22MB', N'Cable acier dia:6mm au ml', 1.0367, 45, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.BANMQDC1-530RA', N'12', N'12 FA', N'Cable recepteur emetteur', 78.4, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.CAT5', N'12', N'12 FA', N'Cable PATCH U/FTP categorie 5 multi brins 100ml', 69, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.CAT6', N'12', N'12 FA', N'cable pour reseaux locaux 4 paires, categorie 6, blinde', 0.547272742, 50, 0, 0, 100)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.CICO-32-712002', N'31', N'31FA', N'Cable outdoor 1x4p S-FTP cat.7 gaine PE touret 500m', 1.668, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.ECH17800143230', N'14', N'14FC', N'Cable gaz SRM4600 NM', 16.4472, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.ECHV430000390', N'14', N'14FC', N'Cable gaz', 25.83, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.ECHV430000960', N'14', N'14FC', N'Cable gaz RM4000', 27.5352, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.EUT27203*', N'14', N'14FC', N'Cable  ATTILA', 37.36, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.HO5VV5F5X0.75', N'12', N'12 FA', N'Cable 5x0.75HO5VV5F gris', 0.5615, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.LIYCY19X0,5', N'12', N'12 FA', N'Cable LIYCY 19x0,5 BLIN CU S/T 1000M', 1.3492, 20, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.PEPV1SD-G-5M-PUR-ABG-V1-W', N'20', N'20FB', N'Cable interface vers tete de lecture RFID', 30.38, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.PEPV1SD-G-5M-PUR-ABG-V45-G', N'20', N'20FB', N'Cable interface vers RJ45', 53.94, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.PHO.FLSM_PATCH1.0LCLC', N'20', N'20FB', N'Cable FO prconfectionn pour la pose dans les armoires long.1m', 48.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.R2V37G1.5', N'12', N'12 FA', N'Cable R2V CU 37G1,5', 0, 0, 0, 0, 50)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.R2V3G1.5', N'12', N'12 FA', N'Cable U 1000 R2V 3G1,5', 0.482322246, 300, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.R2V3G2.5', N'12', N'12 FA', N'Cable R2V U1000 3G2,5', 0.6805373, 195, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.R2V4G10', N'12', N'12 FA', N'Cable R2V 4G10 sans terre', 4.98, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.R2V5G1.5', N'12', N'12 FA', N'Cable R2V CU 5G1,5 AV V/J', 0.78, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.R2V5G2.5', N'12', N'12 FA', N'Cable R2V CU 5G2,5', 1.1, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.R2V5G6', N'12', N'12 FA', N'Cable R2V CU 5G6 TGL', 2.7035, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.RES16263', N'33', N'33FB', N'25 m de cable 2x1.5 multi conducteurs automobile', 45.45, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.RES16264', N'33', N'33FB', N'25 m de cable 3x1.5 multi conducteurs automobile', 59.83, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.RNF12G1.5', N'12', N'12 FA', N'Cable RNF 12G1,5', 3.63, 0, 0, 0, 100)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.RNF2G1.5', N'12', N'12 FA', N'H07 Cable RNF 2G1,5', 0.653, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.RNF2G2.5', N'12', N'12 FA', N'Cable souple 2Gx2,5mm H07RN-F', 0.9044, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.RNF3G1.5', N'12', N'12 FA', N'Cable souple 3x1,5mm H07RN-F', 0.8735782, 610, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.RNF3G2.5', N'12', N'12 FA', N'Cable H07 RNF 3G2,5 T500 souple', 0.7580479, 220, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.RNF5G4', N'12', N'12 FA', N'Cable 5G4 H07 RNF', 2.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.RNFTGL5G6', N'12', N'12 FA', N'Cable 5G6 TGL', 3.992, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.STH41287113300', N'14', N'14FC', N'Cable flexible stihl FR350/450', 33.4798, 1, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.TIRF3T200', N'22', N'22MB', N'Cable tirfor 3TO200', 468.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.USB/MICRO_USB', N'31', N'31FA', N'Cable de synchronisation a double connectiques USB et micro USB', 11.75, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.USB2A/A3', N'20', N'20FB', N'Cable usb2 a/a longueur 3m', 2.4, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.USB2A/B5', N'20', N'20FB', N'Cable usb2 a/b longueur 5m', 2.06, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.USBC/HDMI', N'20', N'20FB', N'Cable usb-C vers HDMI pour tablette', 52.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABL.YNY126311AS00', N'33', N'33FC', N'Cable d''accelerateur pour mobylette dakota', 16.68, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABO.6FONCTIONS', N'33', N'33FC', N'Cabochon pour lanterne 6 fonctions', 7.21, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABO.RVI5000808166', N'33', N'33FC', N'3762 Cabochon', 29.205, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABO.RVI5021136902', N'33', N'33FB', N'Cabochon cristal feu antenne', 6.035, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABO.RVI5021136903', N'33', N'33FB', N'Cabochon rouge feu antenne', 6.262667, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABO.RVI7484553916', N'33', N'33FC', N'Cabochon lanterne (grand feu)', 30.32, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABO.SOR3425', N'33', N'33FC', N'Cabochon gauche de remorque routiere', 17.16, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CABO.SOR3426', N'33', N'33FC', N'Cabochon droit de remorque routiere', 17.16, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CACH.CLA7700003354', N'14', N'14FC', N'Cache ecrou M6', 1.33, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CACH.DB1L+DAT', N'17', N'17FC', N'Cachet de bureau 1 lignes + dateur', 42, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CACH.EUT27235', N'14', N'14FC', N'Cache pour roue d''ATTILA', 9.24, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CADE.30', N'26', N'26FD', N'Cadenas laiton 30mm', 6.26, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CADE.38ZENITH', N'26', N'26FD', N'Cadenas zenith 38 anse acier  fabrication spciale', 24.96, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CADE.40', N'26', N'26FD', N'Cadenas laiton 40mm', 10.6, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CADE.50', N'26', N'26FD', N'Cadenas laiton 50mm', 14.54, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CADE.50 DE_SECURITE', N'26', N'26FD', N'Cadenas de securit 50mm avec 3 cls', 65.45, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CADE.6ASI', N'26', N'26FD', N'Cadenas anti sciage intgr', 22.98, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CADE.COMB40', N'26', N'26FD', N'Cadenas combinaison 40 mm', 19.95, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CADE.COMB50', N'26', N'26FD', N'Cadenas combinaison 50 mm', 27.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ARMO.PROD.DANG113L', N'28', N'28MB', N'Armoire de securit pour produits dangereux ventile 1118mmx1013mmx378mm', 1350, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ARMO.PROD.DANGEREUX', N'28', N'28MB', N'Armoire de securit pour produits dangereux ventile 1950mmx950mmx500', 1350, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ARRE.MOTEUR', N'22', N'22FA', N'Arret moteur', 77.92, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ARRE.REN7704000989', N'33', N'33FA', N'Arret pene noir pour ceinture de securite', 3.86, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ARRE.STH11146567705', N'14', N'14FC', N'Arret de chaine', 4.12, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ARRE.STH11226567700', N'14', N'14FC', N'Arret de chaine', 1.448, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ARRE.STH11256507700', N'14', N'14FC', N'Arret de chaine avec vis 036', 1.9096, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ARRE.STH11296567701', N'14', N'14FC', N'Arret de chaine Stihl MS200', 2.016, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASPE.2T', N'33', N'33FF', N'Carburant en bidon de 5L destin aux moteur 2T prt  l''emploi', 18.0266, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASPE.4T', N'33', N'33FF', N'Carburant en bidon de 5L destin aux moteur 4T prt  l''emploi', 18.0266, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASPI.DIM/E21L', N'24', N'24FA', N'Aspirateur poussiere 21 Litres', 241, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASPI.NILAERO21-01', N'22', N'22MF', N'Aspirateur eau et poussiere cuve inox  aero PC 21-01 inox', 229, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASPI.NILVL200', N'22', N'22MF', N'Aspirateur eau et poussiere cuve 20 litres pro', 299, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSI.', N'31', N'31MD', N'Assistance Hotline par le fabricant du logiciel', 1275, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSI.125DIAM', N'26', N'26FD', N'Assiette a poncer diamant dia 125 mm', 154, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSI.180DIAM', N'26', N'26FD', N'Assiette a poncer diamant dia 180 mm', 187.9, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSO.ABIHV3000', N'12', N'12 FA', N'Assortiment de 300 fusibles verre 5x20 dmarrage rapide et lent', 88, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSO.COLLIER', N'26', N'26FD', N'assortiment colliers attache cable noir', 70.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSO.SCIE_CLOCHE', N'26', N'26FA', N'Assortiment de scies cloche universelle', 270.21, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSO.SILICONE', N'26', N'26FD', N'Assortiment ncessaire pour la pose de silicone', 111.43, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSO.VIS_AP', N'26', N'26FD', N'Assortiment de vis au perceuse tete cylindrique bombe cruciforme zingu', 157.47, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSO.VISTCB/TCC', N'26', N'26FD', N'Assortiment de vis a tole cruciforme tete cylindrique et tete fraisee bombee', 80.7, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSO.VISTTCBAP', N'26', N'26FD', N'Assortiment de vis a tole tete cruciforme bombe autoperforante', 212.23, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSY_C10X140', N'26', N'26FD', N'Vis ASSY COMBI TH AW40 AC.ZI 10x140', 1.06, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSY_C10X60', N'26', N'26FD', N'Vis ASSY combi FT TH AW 10x60', 0.26, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSY_C8X 60', N'26', N'26FD', N'Vis ASSY combi FT TH AW 8x50', 0.251, 49, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSY_C8X120', N'26', N'26FD', N'Vis ASSY KOMBI AW40 AC ZI 8X120', 0.2, 55, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSY_C8X50', N'26', N'26FD', N'Vis ASSY combi FT TH AW 8x50', 0.32, 46, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSY_E4.5X 35', N'26', N'26FD', N'Vis ASSY ECOFAST TF BI 4,5X35 AW20', 26.6, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSY_E4.5X40', N'26', N'26FD', N'Vis ASSY ECOFAST TF BI 4,5X40 AW20', 26.05, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSY_E4.5X50', N'26', N'26FD', N'Vis ASSY ECOFAST TF BI 4,5X50 AW20', 9.07, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSY_E4X35', N'26', N'26FD', N'Vis ASSY ECFAST BI  4X35 AW20', 17.29, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSY_E4X45', N'26', N'26FD', N'Vis ASSY ECOFAST TF BI 4X45 AW20', 22.775, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSY_E4X60', N'26', N'26FD', N'Vis ASSY ECOFAST TF BI 4x60 AW20', 27.155, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSY_E5X50', N'26', N'26FD', N'Vis ASSY ECOFAST TF BI 5x50 AW20', 21.09, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSY+FPTF4.5X50', N'26', N'26FD', N'Vis ASSY + FP TF AW20 AC BI 4,5x50 016524550', 43.49, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSY+FPTF4X30', N'26', N'26FD', N'Vis ASSY + FP TF AW20 AC BI 4x30 016524030', 25.7, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ASSY+FPTF4X40', N'26', N'26FD', N'Vis ASSY + FP TF AW20 AC BI 4x40 016524040', 27.15, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ATTA.53X47', N'17', N'17FC', N'Attaches geantes 53x47 (trombone)', 2.65, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ATTA.CAPOT_GM', N'14', N'14FC', N'Attache capot tracteur grand model', 2.543967, 11, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ATTA.CAPOT_PM', N'14', N'14FC', N'Attache capot tracteur petit model', 5.3, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ATTA.CASE3S', N'17', N'17FC', N'Attache case 3 soufflets', 38.8, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ATTA.CLA6005023804', N'14', N'14FC', N'Attache', 0.37, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AUGM.FACNS232B', N'26', N'26MA', N'Augmentateur impact 1/2  3/4', 18.47, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AXE_1200P707', N'33', N'33FD', N'Axe de basculement tige', 70.7, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AXE_ALLONGE', N'26', N'26FD', N'Axe filet de rechange pour allonge', 15.5, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AXE_BOB6806971', N'22', N'22FA', N'Axe de godet pour bob cat', 107.955, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AXE_D30XL132', N'22', N'22MA', N'Axe diamtre 30 long.132  5ZN Gamme F88', 35.26, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AXE_D52XL120D', N'22', N'22MA', N'Axe diamtre 52 long.240 filet M52x5.00 sur 120 de long', 80.08, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AXE_D52XL120G', N'22', N'22MA', N'Axe diamtre 52 long.240 filet M52x5.00  gauche sur 120 de long', 91.52, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AXE_ECH12311705020', N'14', N'14FC', N'Axe de gaz  pour debroussailleuse ECHO', 8.11, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AXE_ECH61001149931', N'14', N'14FC', N'Axe de transmission pour SRM 5000', 38.63, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AXE_ECH61031007130', N'14', N'14FC', N'Axe d''outil', 55.66, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AXE_ECH61031056930', N'14', N'14FC', N'Axe d''outil', 72.305, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AXE_ECHJ485000030', N'14', N'14FC', N'Axe pour levier capot filtre a air SRM 5000', 7.0488, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AXE_NOR100764', N'14', N'14FC', N'Axe plat d''orientation du pivot/balancier', 49.75, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AXE_NOR100766', N'14', N'14FC', N'Axe d''articulation bielle', 12.16, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AXE_NOR102868', N'14', N'14FC', N'Axe plat d''arret', 27, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AXE_NOR102876', N'14', N'14FC', N'Axe lisse', 32.34, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AXE_NOR102878', N'14', N'14FC', N'Axe plat d''arret', 27, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AXE_NOR107648', N'14', N'14FC', N'Axe plat d''arret', 48.58, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AXE_NOR107649', N'14', N'14FC', N'Axe', 54.63, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AXE_ROU3858145', N'14', N'14FC', N'Kit axe + visserie verin de renversement HERA 43', 130, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AZOT.M20', N'11', N'11FB', N'Azote en bouteille M20', 81.39, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BA_5.3X47', N'26', N'26FD', N'Baguette d''angle pin 2 arrondis 5.3x47', 2.608, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BA_CP2.5M', N'26', N'26FD', N'Baguette d''angle special carreaux de platre 2.5ml', 0.7, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BA13_2.5/0.6', N'05', N'05FA', N'Plaque de pltre BA13 2.5x0.6', 4.81, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAC_600X400X220P', N'26', N'26FD', N'Bac plastique plein', 37.6285, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAC_600X400X240A', N'26', N'26FD', N'Bac plastique  gerbable  ouverture', 29.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAC_600X400X320+C', N'26', N'26FD', N'Caisse plastique bleu anti statique avec couvercle', 46, 0, 0, 0, 4)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAC_600X400X320P', N'26', N'26FD', N'Bac plastique plein', 23.933, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAC_BEC_METAL28L', N'26', N'26FD', N'Bac de rangement  bec mtallique 28 litres', 46.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAC_BEC0.25J', N'26', N'26FD', N'Bac de rangement 0.25 litres jaune dim:90/80 - 102/97', 33.488, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAC_BEC0.7V', N'26', N'26FD', N'Bac de rangement 0.7 litres vert dim:164/150 - 105/97', 25.389, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAC_BEC3.2R', N'26', N'26FD', N'Bac de rangement 3.2 litres assemblables en polystirene rouge', 83.083, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAC_RETENTION150L', N'28', N'28MA', N'Bac de retention pour petits volumes 1250mm X 850mm 16kgs', 186, 0, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAC_T3GRIS', N'26', N'26FD', N'bac de rangement gris T3', 6.75, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAC_T3ROUGE', N'26', N'26FD', N'Bac de rangement rouge T3 230x150x125 - 3 litres', 4.9385, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAC_T4BLEU', N'26', N'26FD', N'Bac de rangement T4 bleu', 2.8858, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAC_T4GRIS', N'26', N'26FD', N'Bac de rangement gris T4', 3.31, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAC_T4ROUGE', N'26', N'26FD', N'bac de rangement rouge T4', 3.1514, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAC_T4VERT', N'26', N'26FD', N'Bac de rangement vert T4', 3.071, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BACH.2X3NYLON', N'26', N'26FD', N'Bache 2x3 nylon de protection', 6.345, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BACH.3X4CAMION', N'26', N'26FD', N'Bache de camion avec oeillet tous les 50cm dimensions 3x4', 315.25, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BACH.3X4NYLON', N'26', N'26FD', N'Bache 3x4 nylon de protection', 11.13, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BACH.3X5NYLON', N'26', N'26FD', N'Bache 3x5 nylon de protection', 20.85555, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BACH.4X5NYLON', N'26', N'26FD', N'Bache 4x5 nylon de protection', 18.775, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BACH.6X10NYLON', N'26', N'26FD', N'bache nylon de protection', 103.7, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BACH.PROSILO', N'26', N'26FD', N'Bache larg 6m PRO SILO 210m epaisseur 150 ape contribue au recyclage', 83, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BACT.MECBCR100ML', N'05', N'05FI', N'traitement bactericide et fongicide curatif des reservoirs', 15.31, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.AUTOC16', N'33', N'33FA', N'Bague d''etancheite autocentre / vidange  0469 016', 1.62, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.AUTOC24.7X32X2', N'33', N'33FA', N'Bague d''etancheite autocentre pour vidange camion', 1.63, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.BOB1B6553411', N'22', N'22FA', N'Bague pour BOBCAT 0.5" pack de 5', 28.656, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.BOB1B6803213', N'22', N'22FA', N'Bague pour BOBCAT', 36.927, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.BSA-BSP1/2', N'22', N'22FA', N'bague acier autocentre BSA-BSP 1/2', 0.52, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.CLA6005012695', N'14', N'14FC', N'Bague etanche PALES', 3.15, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.CLA6005012725', N'14', N'14FC', N'Bague etanche PALES', 2.06, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.CLA6005012726', N'14', N'14FC', N'Bague etanche PALES', 3.82, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.DPR12-L/S', N'14', N'14FC', N'Bague progressive DPR 12 L/S', 0.27, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.ECH10021227930', N'14', N'14FC', N'Bague tanche', 11.787, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.ES2-12L/SINOX', N'14', N'14FC', N'Bague progressive DPR 12 L/S inox', 4.13, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.ES2-16S', N'14', N'14FC', N'Bague progressive ES2-16S', 1.067, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.KAR63624800', N'22', N'22FA', N'Bague d''etancheite pour nettoyeur HD1050B', 1.3183, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.KAR63632730', N'22', N'22FA', N'Bague pour nettoyeur HP KARCHER HD650 electrique', 1.01, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.NOR100653', N'14', N'14FC', N'Bague de frottement balancier', 9.56, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.NOR101685', N'14', N'14FC', N'Bague de frottement balancier', 18.39, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.NOR101686', N'14', N'14FC', N'Bague de frottement', 9.54, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.NOR103568', N'14', N'14FC', N'Bague d''usure', 6.03, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.NOR103599', N'14', N'14FC', N'Bague d''usure', 7.72, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.ORE22273', N'14', N'14FC', N'Bague  d''entrainement 3/8 8DTS', 9.36, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.ORE68210', N'14', N'14FC', N'Bague  d''entrainement 3/8 7DTS', 8.3188, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.P/TOUR.32A16', N'26', N'26FD', N'Bague de reduction pour touret a meuler', 2.395, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.PER33053', N'33', N'33FD', N'Bague', 3.01, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.RELIER_3MM', N'17', N'17FC', N'baguette  relier 3mm 25 feuilles boite de 25', 2.16, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.RELIER_6MM', N'17', N'17FC', N'baguette  relier 297x6mm  capacit noir', 1.97, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.RELIER_9MM', N'17', N'17FC', N'baguette  relier 297x9mm  capacit noir', 2.44, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.RVI5005030003', N'33', N'33FA', N'Bague de sertissage 10', 0.76, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.STH00006421207', N'14', N'14FC', N'Bague d''entranement 404 7Dents pour MS880', 10.032, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.STH00006421216', N'14', N'14FC', N'Bague  d''entrainement', 9.152, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.STH00006421223', N'14', N'14FC', N'Bague  d''entrainement / 036 STIHL', 10.07, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.STH61041307130', N'14', N'14FC', N'Bague tanche', 4.54, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.TEF35/28D25LG21.5/1.5', N'22', N'22FA', N'Bague tflon pour cric de vanne', 3.85, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAGU.TYPEC-CS75/95/10DC_NBR', N'22', N'22FA', N'bgue type C-CS 75x95x10 DC  NBR', 25.96, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAIE_DEX755418', N'20', N'20MC', N'Baie serveur 42U 800x1000 noir 1/2 port', 1147, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BALA.CANT.', N'24', N'24FB', N'Balai de cantonnier', 12.22, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BALA.COCO38', N'24', N'24FB', N'Balai coco 38 cm vis intgr', 8.74, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BALA.COCO60', N'24', N'24FB', N'Balai coco largeur 60cm', 8.138, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BALA.COMPTEUSE3KG', N'21', N'21MA', N'Balance compteuse 3kgs precision 0.1g porte 3kgs modle N 9860', 342.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BALA.EG600MM', N'33', N'33FB', N'Essuie-glace TIR 600 / master', 13.8744, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BALA.EG600MM+GICL', N'33', N'33FB', N'Essuie-glace + gicleur TIR 600 / master', 13.498, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BALA.EGREN7701068753', N'33', N'33FA', N'Essuie-glace 580mm kangoo 2 av grand model', 21.4533, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BALA.EGREN7701068755', N'33', N'33FA', N'Essuie-glace 530mm kangoo 2 av petit model', 18.698, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BALA.EGRVI5001865594', N'33', N'33FB', N'Essuie-glace TIR 600 pour camion', 20.28, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BALA.FIBRE60', N'24', N'24FB', N'Balai fibre rouge 60cm', 13.88, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BALA.ISK79019316', N'33', N'33FD', N'Balai de demarreur Val De Sarre', 5.06, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BALA.MCOURT', N'24', N'24FB', N'Balayette coco manche court', 2.4, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BALA.MLONG', N'24', N'24FB', N'Balayette coco manche long', 3.953333, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BALA.NILSW250', N'24', N'24MA', N'Balayeuse mecanique', 409, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BALA.REN7711421795', N'33', N'33FA', N'Essuie-glace 400mm + 600mm twingo 2', 21.797, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BALA.SOIE', N'24', N'24FB', N'Balai  soie sorties 52mm', 42.6, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BALA.WOLUAM50', N'26', N'26MA', N'balai a feuille pour manche multistar', 24.98427, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BALA.WOLUBM25', N'26', N'26MA', N'balai multi star 25', 11.5896, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BALA.WOLUBM40', N'26', N'26MA', N'balai de terrasse de 40cm', 15.0198, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BANC_2000/420/400GCH', N'23', N'23MA', N'Banc de vestiaire L2000 HxP 420x400 gris clair/hetre', 194.71, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAND.ABRP100', N'26', N'26FD', N'Bande sf de toile abrasive 110x620 P100', 66.68, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAND.ABRP120', N'26', N'26FD', N'Bande de toile abrasive 110x620 P120', 66.68, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAND.HJN51MM', N'28', N'28MB', N'Bande hachur en silice jaune et noir largeur 51mm x 18.3 metre', 60.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAND.HUS503137802', N'14', N'14FC', N'Bbande de frein', 13.24, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAND.JT_ARM', N'05', N'05FA', N'Bande armee p/plaque de platre 30m', 14.59, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAND.MOUS40X10', N'05', N'05FA', N'Bande de relev mousse EPDM adhsive largeur 40 - epaisseur 10mm', 2.3, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAND.MOUS40X4MM', N'05', N'05FA', N'Bande de relev mousse EPDM adhsive largeur 40 - epaisseur 4mm', 3.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAND.PERF12', N'12', N'12 FA', N'Bande perforee 12mmx0.8mmx10ml', 8.31, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAND.PERF17', N'12', N'12 FA', N'Bande perforee 17mm x0.8mmx10ml', 8.85, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAND.RCAA-10-000108', N'21', N'21FA', N'Bandeau alu 8 PC 19" + voyant -1U', 59.021, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAND.REFLEC.G+D10M', N'33', N'33FB', N'Bande reflectoris de 10m G+D pour vhicules classe 2', 263.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAND.STH11216486610', N'14', N'14FC', N'Bande de glissement', 2.135, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAND.STH11236486600', N'14', N'14FC', N'Bande de glissement', 1.96, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAND_PARA.EP10', N'05', N'05MA', N'Bande para ep,10mm-larg,80mm-long,5000mm', 59.8744, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BANJ.14-8MM', N'14', N'14FC', N'banjo oeil int. de 14mm et tube de 8mm', 6.04, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BANJ.HA06B17', N'14', N'14FC', N'banjo  droit  oeil', 6.04, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BANJ.NOR102112', N'14', N'14FC', N'Magistra', 15.02, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BARR.INSECT.', N'05', N'05FI', N'Barrage a insectes 750l', 29.1707, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BARR.LG34388', N'12', N'12MB', N'Barrette de coupure  haute', 7.5157, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BARR.LG34389', N'12', N'12MB', N'Barrette de coupure  basse', 12.43, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BARR.MINE2M', N'26', N'26MA', N'Barre a mine de 2m avec pout plat et pointu', 92.28, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BARR.OR1X50', N'28', N'28MA', N'Barrire de signalisation orange 1ml x 50ml', 58.57, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BASE_DELL_PRECISION3930', N'20', N'20MA', N'Base XCTO rack prcision 3930', 1600, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BASE_EWOFLEXY-201', N'20', N'20FB', N'Base FLEXY 4 ports 10/100 routage 4 emplacements cartes', 437.5, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BATT.12V12AH', N'33', N'33FD', N'batterie  au plomb 12V 12ah', 36.79, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BATT.12V45AH', N'33', N'33FD', N'Batterie  12V 190 amperes 45 AH -210 de large, 135 de profond, 200 de haut', 81, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BATT.AMP9068', N'12', N'12 FA', N'Batterie  plomb 12V 140 ah etanche gel', 386, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BATT.AP.PHOTO', N'08', N'08MB', N'Batterie pour appareils photo numrique', 113, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BATT.COOSCA00003', N'28', N'28MB', N'Batterie 12 volts 17AH', 61.82, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BATT.FUL31', N'33', N'33FB', N'Batterie 140AH D04 513x189x223', 117, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BATT.FUL32', N'33', N'33FB', N'Batterie 180AH D05 513x223x223', 110, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BATT.FUL33', N'33', N'33FB', N'Batterie 210AH D05 518x279x240', 175, 0, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BATT.FULA770', N'33', N'33FB', N'Batterie PSL AM CARB 12', 110, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BATT.PC', N'20', N'20FB', N'Batterie PC portable 11.1V 7800mAh', 79.17, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BATT.STARN4', N'33', N'33FB', N'batterie 66ah 278x175x190', 66, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BATT.STARN5', N'33', N'33FB', N'batterie 88AH 353x175x190', 93, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BATT.STARN6', N'14', N'14FC', N'Batterie 12V110AH', 146, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BATT.STARN8', N'33', N'33FB', N'Batterie 140AH 800A 12V pour camion Renault S160 - SGS', 144, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BATT.Y60N30LAKR', N'14', N'14FC', N'Batterie pour Attila', 99.86, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAVE.NOR104408', N'14', N'14FC', N'Bavette (1 piece) / MAGISTRA', 35.28, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAVE.NOR104410', N'14', N'14FC', N'Bavette LN1600', 6.021, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BAVE.NOR110198', N'14', N'14FC', N'Bavette (7 pieces) pour MAGISTRA', 13.2295, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BEC_HUSQ505598002', N'26', N'26FD', N'Bec verseur essence HUSQVARNA bidon essence', 11.1672, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BEC_HUSQ505598003', N'26', N'26FD', N'Bec verseur essence HUSQVARNA bidon d''huile', 2.9392, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BEC_MELANG', N'26', N'26FD', N'Buse pour mortier chimique +crou', 26.16, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BEC_VERSEUR2279B', N'26', N'26FD', N'Bec verseur pour jerrican 2279(ZIMMER)', 2.5, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BECH.', N'26', N'26MA', N'Beche avec manche en frne', 31.39345, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BETO.C25/30', N'05', N'05FA', N'Beton C25/30 XF1 S3 D15', 93.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BETO.LES165L', N'22', N'22ME', N'Betonniere electrique Lescha 165 litres 220V', 479.92, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BIEL.NOR100778', N'14', N'14FC', N'Bielle', 141.31, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BLOC.0471210705', N'12', N'12 FA', N'Bloc alimentation15W 220 VAC 12VDC 1.25A', 23.8, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BLOC_BEH20-9585', N'31', N'31MA', N'Bloc d''alimentation pour des installations sspcifiques 15V= 1.2A', 36, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BLOC_BRE1152821', N'12', N'12 FA', N'Bloc prolongateur 6 prises 2p+t et cordon 1.5m', 9.09, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BLOC_BRE1159321018', N'12', N'12 FA', N'Bloc prolongateur 8 prises 2p+t et cordon 1.5m', 17.41, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BLOC_COF20/20/50', N'05', N'05FA', N'Bloc coffrant 20/20/50', 1.63, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BLOC_DBA4', N'17', N'17FC', N'Bloc de bureau 80 feuilles A4 detache  315x21cm 80g quadrille 5x5', 0.7712499, 13, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BLOC_DBA5', N'17', N'17FC', N'Bloc de bureau 80 feuilles A5 detache  14.8x21cm 80g quadrille 5x5', 0.4116349, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BLOC_DBA7', N'17', N'17FC', N'Bloc de bureau 80 feuilles A7 detache  7.4X10.5cm 80g quadrille 5x5', 0.4346, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BLOC_DE_CHANT', N'12', N'12 FA', N'Bloc de chantier 6 prises bleu + 5m de cble + fiche', 243.18, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BLOC_EPHE8.2X12DG', N'17', N'17FC', N'Bloc ephemeride date a gauche 8x12.5', 0.84, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BLOC_LEG050083', N'12', N'12 FA', N'Bloc prolongateur 6 prises 2p+t et cordon 1.5m', 15.82, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BLOC_LEG50097', N'12', N'12 FA', N'Bloc prolongateur 6 prises 2p+t + parafoudre et cordon 1.5m', 22.15, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BLOC_P204/83H88P', N'05', N'05MA', N'Bloque porte pre peint 204/83 H88', 35.39, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BLOC_SCHA9N21492', N'12', N'12 FA', N'Bloc differentiel VIGI-TG40 3P+N 40A 30MA', 143.2202, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BLOC_SCHR9PRC240', N'12', N'12 FA', N'Bloc differentiel XE 2P  30MA  40A  AC', 41.6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BLOC_SCHR9PRC610', N'12', N'12 FA', N'Disjoncteur XE 1P+N 10A   30MA  40A  AC', 8.43, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BLOC_SCHR9PRC616', N'12', N'12 FA', N'Disjoncteur XE 1P+N 16A   30MA  40A  AC', 8.43, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BLOC_SCHZBVBG1', N'12', N'12 FA', N'Bloc lumineux harmony XB4-XB5 DEL 24V  120VAC', 9.71, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AB50', N'05', N'05MA', N'Absorbant 50L', 66.44, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ABRA.115X50P100', N'26', N'26FD', N'Abrasif brun 115mm x 50ml P100', 59.1, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ABRA.115X50P60', N'26', N'26FD', N'Abrasif brun 115mmx50ml P60', 78.6, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ABRA.115X50P80', N'26', N'26FD', N'Abrasif brun 115mm x 50ml P80', 77.4, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ABRA.D150P100', N'26', N'26FD', N'Abrasif D150   P100  pour pnceuse orbitale', 1.21, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ABRA.D150P80', N'26', N'26FD', N'Abrasif D150   P80 pour pnceuse orbitale', 0.7024, 130, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ABRA.ROLOCP80', N'26', N'26FD', N'Disques a poncer P80 a fixation rapide s''utilise avec un support', 2.5, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ABRA.SEC 150', N'26', N'26FD', N'Feuille de papier de verre a sec P150', 2.31, 36, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ABRA.SEC120', N'26', N'26FD', N'Feuille de papier de verre a sec P120', 1.26, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ABRA.SEC220', N'26', N'26FD', N'Feuile de papier de verre a sec P220', 2.58, 73, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ABRA.SEC80', N'26', N'26FD', N'Feuille de papier de verre a sec P80', 2.3, 20, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ABSO.30L', N'05', N'05FI', N'Terre de diatomee', 76.2, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ABSO.FEUIL', N'05', N'05FI', N'Feuilles de papier absorbant en bobine de 100 feuilles', 194.5, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ACCO.BASE_GROUPE', N'22', N'22FA', N'Accouplement complet base groupe', 580, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ACCO.SAD', N'23', N'23MA', N'Accotoir  de siege assis debout rglage 2D', 40, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ACCO.SPIDEX_A28/38', N'22', N'22FA', N'Accouplement complet spidex A28/38 28H7', 675, 0, 0, 0, 2)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BLOC_URA111013', N'12', N'12 MC', N'Bloc de secours evacuation sati a leds', 69.74, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BLOC_W102038', N'12', N'12 FA', N'bloc de jonction  WDU 10 bleu', 0.714, 48, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BLOC_W102898', N'12', N'12 FA', N'Bloc de jonction WDU 16/ZA bleu 16mm', 1.026, 48, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BLOC_WC', N'24', N'24FB', N'Bloc nettoyant et desinfectant pour WC', 2.324966, 155, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOBI.ECH69621406830', N'14', N'14FC', N'Bobine', 7.1637, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.AUX_LETTRES', N'26', N'26FD', N'Boite aux lettres avec pied', 58.44, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.BLM515309', N'12', N'12 FA', N'Boite etanche 80x80x45', 1.87, 0, 0, 0, 5)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.CD-TR', N'17', N'17FA', N'Boitier DVD ou CD slim transparant', 5.8, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.CLPR40', N'17', N'17FA', N'Boite de classement polypropilene rigide a pression largeur 40mm', 28.18, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.ECH3030747533', N'14', N'14FC', N'Boitier filtre a air pour SRM 4600', 28.73, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.LEG069672', N'12', N'12 FA', N'Boitier 2 PH gris composite', 7.08, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.LEG080051', N'12', N'12 FA', N'Bote cloison sche 1 poste P.50mm', 0.8046, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.LEG080052', N'12', N'12 FA', N'Bote cloison sche 2 poste P.50mm', 3.463, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'BOIT.LEG080053', N'12', N'12 FA', N'Bote cloison sche 3 poste P.50mm', 4.39398, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ACCU.NOR100643', N'14', N'14FC', N'Accumulateur', 213.67, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ACCU_12V-2AH', N'26', N'26FD', N'Batterie de visseuse 12V 2AH', 63, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ACCU_12V-3AH', N'26', N'26FD', N'Batterie de visseuse 12V 3AH', 162.09, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ACCU_18V', N'26', N'26FD', N'Batterie de visseuse 18V', 82.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ACCU_18V4.0AH', N'22', N'22FA', N'Accu pour cle a choc BOSCH 4.0 AH  Li-lon 18V', 135, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ACCU_CARPOWER', N'26', N'26FD', N'Accu chargeur pour informatique et vehicules', 88, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ACCU_MIL4933451423', N'12', N'12 FA', N'Pack de 3 accus M18 NRG 503 18V', 254.15, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ACET.3M3', N'11', N'11FB', N'Actylene 3m3', 95, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ACET.6M3', N'11', N'11FB', N'Acetylene  6m3', 153, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ACTI.BIO_1KG', N'24', N'24FB', N'Boite de 1kg pour remise en marche de la fosse septique', 27.97154, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ACTI.BIO_1L', N'24', N'24FB', N'Liquide bio pour activateur de fosse septique', 14.75, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ACTI.COLLE', N'26', N'26FD', N'Activateur de colle', 23.84, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ADAP.12CANELURES', N'26', N'26MA', N'Adaptateur 12 canelures pour  sds max', 120, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ADAP.13PL/7PL.F', N'33', N'33FC', N'Adaptateur rallonge vehicule 13 prises males sur 7 prises femelles 115BL', 17.96, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ADAP.13PL/7PL.M', N'33', N'33FC', N'Adaptateur rallonge vehicule 13 prises males sur 7 prises fMale inf115BL', 17.96, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ADAP.DVI/VGA', N'31', N'31FA', N'Adaptateur DVI VGA', 6, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ADAP.ENIXSXQ6004', N'12', N'12 FA', N'Adaptateur de mat sxq6002', 123.05, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ADAP.LEG050382', N'12', N'12 FA', N'Adaptateur 2P+T shuko/fiche Fancaise', 4.056, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ADAP.MBSPCT1/2', N'22', N'22FA', N'Adaptateur MBSPCT 1/2 x MBSPCT 1/2', 2.14, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ADAP.NOR102099', N'14', N'14FC', N'Adaptateur droit', 5.13, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ADAP.NOR102112', N'14', N'14FC', N'Adaptateur banjo', 15.85, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ADAP.NOR102122', N'14', N'14FC', N'Adaptateur droit', 2.98, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ADAP.PD1/4', N'26', N'26MA', N'Embout porte douille carre 1/4- entrainement 1/4', 8.16, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ADAP.PHODT-LAN-CAT6+', N'12', N'12MB', N'Adaptateur parafoudre RJ45 pour ethernet CAT6+', 92.8096, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ADAP.SDS+MAX', N'26', N'26FD', N'Adaptateur pour meches sds+ sur emmmenchement sds max', 84.35, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ADAP.SVAX-08-202641', N'31', N'31FA', N'Adaptateur fixation mat candid S M L W3 WB1 AK-5 AK-4 PM-42A', 45.315, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ADAP.VGAFF', N'31', N'31FA', N'Adaptateur VGA FF', 5.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ADBL.5L', N'05', N'05FI', N'Additif ADBLUE', 3.68, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAU.COF.TECHNICAL-S3-SRC', N'18', N'18MB', N'Chaussure de securit COFRA technical S3 SRC', 64.09, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAU.ORTHO', N'18', N'18MB', N'Chaussures orthopediques', 79.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAU.TR43', N'18', N'18MB', N'Chaussures de  de tronconnage T43', 130, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAU.TR44', N'18', N'18MB', N'Chaussures de  de tronconnage T44', 130, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAU.TR45', N'18', N'18MB', N'Chaussures de  de tronconnage T45', 130, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAU.YUKT37', N'18', N'18MB', N'Chaussures de  de tronconnage T37', 102.17, 0, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAU.YUKT39', N'18', N'18MB', N'Chaussures de  de tronconnage T39', 102.17, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAU.YUKT40', N'18', N'18MB', N'Chaussures de  de tronconnage T40', 102.16, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAU.YUKT41', N'18', N'18MB', N'Chaussures de  de tronconnage T41', 102.16, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAU.YUKT42', N'18', N'18MB', N'Chaussures de  de tronconnage T42', 102.17, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAU.YUKT43', N'18', N'18MB', N'Chaussures de  de tronconnage T43', 102.16, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAU.YUKT44', N'18', N'18MB', N'Chaussures de  de tronconnage T44', 102.16, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAU.YUKT45', N'18', N'18MB', N'Chaussures de  de tronconnage T45', 102.17, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAU.YUKT46', N'18', N'18MB', N'Chaussures de  de tronconnage T46', 118.07, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAUX_25KGS', N'05', N'05FA', N'Chaux de crepissage 25kgs', 11.21, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHAUX_35KGS', N'05', N'05FA', N'Chaux de crepissage 35kgs', 9.21, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEM.250GR', N'17', N'17FC', N'Chemises 250gr coloris assortis', 1.4821, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEM.CAB000068', N'12', N'12MB', N'Chemin de cable inox 304L CF 54 largeur 50mm  longueur 3000', 19.3, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.00008810400', N'26', N'26MA', N'Chevalet d''affutage', 26.7966, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'CHEV.10X60', N'26', N'26FD', N'Cheville nylon 10x60', 6.593333, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AFFU.STH52032000008', N'14', N'14MA', N'Affuteuse USG complet pour chane de trononneuse', 296.07, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AGEN.CT', N'17', N'17FC', N'Agenda carre travers', 1.31, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AGEN.MINIST.SP', N'17', N'17FC', N'Agenda ministre a spirale', 11.82, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AGGL.20/20/50', N'05', N'05FA', N'Agglos 20x20x50', 1.31, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AGIT.ACAFE', N'26', N'26FD', N'agitateur plastique x200 pieces', 6.79625, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AGRA.23/12/1000', N'17', N'17FC', N'La boite de 1000 agrafe 23/12 galvanis', 0.85, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AGRA.24/6/500', N'17', N'17FC', N'La boite de 5000 agrafe 24/6 galvanis', 1.2, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AGRA.26/6/1000', N'17', N'17FC', N'La boite de 1000 agrafe 26/6 galvanis', 1.17, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AGRA.400X80X400', N'05', N'05SA', N'Agraphes pour la fibre optique 400x80x400 U plis 90 en HA8', 0.42, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AGRA.48/6', N'17', N'17FC', N'Agraphe de bureau 48/6 optima 19 boite de 3600 agrafes', 2.49, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AGRA.CL40', N'26', N'26FD', N'boite de 1000 agrafes pour stone box', 47.68, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AGRA.DB10', N'17', N'17FC', N'AGRAPHEUSE de bureau pour agrafes N10', 2.6054, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AGRA.DB24/26', N'17', N'17FC', N'Agrapheuse de bureau pour agrafes N24/26', 3.42, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AGRA.DB24/26-40F', N'17', N'17FC', N'Agrapheuse de bureau pour agrafes N24/26 40 feuilles', 11.17, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AGRA.EPR', N'14', N'14FA', N'agraphe epr pour filet de pche', 0.15, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AGRA.HPG', N'26', N'26MA', N'Agrafe hydraulique Pres12631 pour ppe a graisse', 3.928, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AGRA.N4_14MM', N'26', N'26FD', N'Agraphe N4 14mm  HT34 / ST11 galva boite de 5000 pieces', 20.2, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AGRA.N5_10MM', N'26', N'26FD', N'Boite de 1000 agraphes materiaux durs 10mm', 60, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AGRA.VR22/1100', N'26', N'26FD', N'Agrafes plastifiees vert VR 22 bote de 1100', 15.08, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AIGU.STH11181953500', N'14', N'14FC', N'Aiguille de cliquet', 0.62, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AILE.EUTMC85', N'14', N'14FC', N'Jeu ailette pour attila AV85', 63.6504, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AIMA.15F', N'17', N'17FC', N'Aimant inox carr 10mm x10mm blister de 8 pieces', 6.11, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AIMA.B22(6)', N'17', N'17FC', N'Blister de 6 aimants bleu 22mm', 0.72, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AIMA.N22(6)', N'17', N'17FC', N'Blister de 6 aimants noir 22mm', 0.6766667, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AIMA.R22(6)', N'17', N'17FC', N'Blister de 6 aimants rouge 22mm', 0.72, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AIMA.SCHBP20', N'12', N'12MB', N'Aimant  BP20 pour Automatisation', 26, 0, 0, 0, 35)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ALAR.SDR', N'14', N'14FC', N'Alarme sonore de recul / engins', 40, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ALIM.HPVAN90C-480B-1A', N'20', N'20FB', N'Alimentation switch HP 2520-8-POE', 89, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ALIM.IDE151006', N'20', N'20FB', N'Alimentation navitek NT PRO verificateur', 284, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ALIM.J9562ACC', N'12', N'12 FA', N'Alimentation  redresse format HP commutateur', 408, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ALIM.PHO2866763', N'12', N'12MB', N'Alimentation a dcoupage 24VCC 10A', 375, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ALIM.PHO2903147', N'20', N'20FB', N'Le FL DIN RA est mont sur rack norm 19 pouces qui permet de monter en rack des equipements electriques', 40.06, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ALIM.PHO2903148', N'12', N'12MB', N'Alimentation trio - PS - entree mono 230 VAC Sortie 24 VDC 5A', 55.8914, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ALIM.TDKLAMDSP10-24', N'12', N'12MB', N'Alim rail 24v 0.42a', 39, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ALIM.VEGA', N'21', N'21FA', N'Alimentation sonde', 148.28, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ALIM.VEL_LABPS6005', N'21', N'21MA', N'Alimentation de laboratoire rglable 30V DCA 5  150W', 86.99, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ALLO.280', N'26', N'26FD', N'allonge spiralee pour augmenter la profondeur de percage', 141.89, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ALLU.GAZ_FL', N'24', N'24FB', N'Allume gaz flamme', 15.03, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ALUM.C50X5', N'05', N'05FC', N'Aluminium cornire alu 50x50x5 6ml', 8.32, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ALUM_P050X05', N'05', N'05FC', N'Aluminium plat 50/5', 4.59, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ALUM_U50X80X50X5', N'05', N'05FC', N'Aluminium U angles vifs 50X80X50 paisseur 5mm', 10.91, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ALVE.FORET', N'26', N'26FD', N'Alveole pour le rangement des forets', 6.67, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMARRE 24X6000', N'22', N'22MB', N'Amarre pour bateau DN 24mm et longueur 6ml', 79.01, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMO_3 7.5X102', N'26', N'26FD', N'Vis AMO 3 7,5x102 Tete large 0234 330102  200pces', 0.72, 140, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMO_3 7.5X132', N'26', N'26FD', N'Vis AMO 3 7,5x132 Tete large 0234 330132  200pces', 0.83, 140, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMOR.CLA6005012542', N'14', N'14FC', N'Amortisseur', 34.21, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMOR.CLA6005012549', N'14', N'14FC', N'Amortisseur', 34.28, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPL.BEH20-0054', N'31', N'31MA', N'Amplificateuer de puissance 7W', 100.8, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.114215', N'14', N'14FC', N'Ampoule pour MAGISTRA', 1.61, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.11W_B22', N'05', N'05MA', N'Ampoule 11W B22 microtwist 18W remplace ampoule traditionnelle 60w', 9.8146, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.150W_E40', N'05', N'05MA', N'Ampoule NAV-T 150W super 4Y E40', 19, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.15W_E27', N'05', N'05MA', N'Ampoule conomique traditionnelle 15W E27 equivaut a une 70W traditionnelle', 7.0325, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.18W_B22', N'05', N'05MA', N'Ampoule 18W B22 microtwist 18W remplace ampoule traditionnelle 100w', 5.5072, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.18W_E27', N'05', N'05MA', N'Ampoule tube conomique 18W E27 equivaut a une 100W traditionnelle', 11.45, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.2W', N'05', N'05MA', N'Ampoule 2W 12516 12V', 2.5, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.40W_B22', N'05', N'05MA', N'Ampoule 40W B22', 1.29, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.40W_E14_R50', N'05', N'05MA', N'Ampoule 40W E14 R50', 9.92, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.42W_E27', N'05', N'05MA', N'Ampoule halogene 42W  vis E27 230V nouvelle generation', 2.54, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.53W_E27', N'05', N'05MA', N'Ampoule halogene 53W vis E27 230V nouvelle generation', 2.5, 15, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.60W_E27', N'05', N'05MA', N'Ampoule spot 60W  vis E27 diametre 80mm', 5.1, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.60W_E27*', N'05', N'05MA', N'Ampoule 60W  vis E27', 0.946, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.60W_E27/24V', N'05', N'05MA', N'Ampoule 60W  vis E27 BCR 24V A60 CL 1CT', 3.8, 18, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.70W_E27', N'05', N'05MA', N'Ampoule  vis 70W E27', 1.2452, 18, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.8W_E27', N'05', N'05MA', N'Ampoule LEDS spot 8W E27 650 lumens 4000K', 14.38, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.92W_B22', N'05', N'05MA', N'Ampoule baonnette B22 92W', 1.69, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.BAI4.8V0.75A', N'05', N'05MA', N'Ampoule krypton 4,8V 0,75A baionnette pour lampe de poche', 4.66, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.CHIM20', N'05', N'05FI', N'Ampoule pour scellement chimique M20', 6.925, 18, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.CHIM24', N'05', N'05FI', N'Ampoule pour scellement chimique M24', 1.449, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.COFF.', N'33', N'33FA', N'Coffret d''ampoules pour dpannage', 14.61, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.E14POIRE15W', N'05', N'05MA', N'Ampoule / frigidaire PC ecluse N1 POIRE 220V 15W 26X54', 1.89, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.FEU24V25W', N'33', N'33SC', N'Ampoule radium feu 24V 25W ergots dcals pour matriel flottant', 17.2, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.GRAIS12V10W', N'33', N'33FA', N'ampoule graisseur 10W 12V', 0.8, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.GRAIS12V5W', N'33', N'33FA', N'Ampoule graisseur 5W12V', 0.705, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.GRAIS24V5W', N'33', N'33FB', N'Ampoule graisseur 24V 5W', 1.14, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.H35W', N'05', N'05MA', N'Ampoule halogene starlite 12V 35W GY6 35A', 1.28, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.HALO.H1', N'14', N'14FC', N'Ampoule halogene H1 12V 55W', 3.833513, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.HALO.H3', N'14', N'14FC', N'Ampoule halog, H3 12V55W+fil', 5.78, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.HALO.H4', N'33', N'33FA', N'Ampoule halogene H4 blanc', 4.63, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.HALO.H4EC', N'33', N'33FA', N'Ampoule H4 avec culot euro code blanc', 6.3, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.HALO.H7', N'33', N'33FA', N'Ampoule halogene H7', 7.667, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.HALO.H7PR', N'33', N'33FA', N'Presentoir pour ampoule halogene H7', 9.546, 16, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.HALO12V21W', N'33', N'33FA', N'Ampoule pour girophare nouvelle gnration 12V 21W halogne', 5.8245, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.IODEH1-24V', N'33', N'33FB', N'Ampoule H1 iode 24V', 6.082, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.LED5W', N'05', N'05MA', N'Ampoule leds 5w R50 830 E14', 8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.LED6W', N'05', N'05MA', N'Ampoule leds 6w 230V  GU 10', 7.714286, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.MINIWATT3W', N'33', N'33FA', N'Ampoule temoin culot verre 12V3W', 0.595, 10, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.MINIWATT5W', N'33', N'33FA', N'Ampoule temoin culot verre 12V5W', 0.71, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.MINIWATT5W24V', N'33', N'33FA', N'Ampoule temoin culot verre 24V5W', 0.78, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.NAVE12V10W', N'33', N'33FA', N'Ampoule navette 10W 12V', 0.9, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.NAVE12V10W8X30', N'33', N'33FA', N'Ampoule navette 10W 12V dimensions 8x30', 5.62, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.NAVE12V5W', N'33', N'33FA', N'Ampoule navette 5W 12V', 0.78, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.ORB130188', N'05', N'05MA', N'Ampoule E40 38x220 230V 500W B.LI', 29, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.STOP_AMB.', N'33', N'33FA', N'Ampoule stop ambre 1 fil 12W21W', 1.62, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.STOP_BA15S', N'33', N'33FB', N'Ampoule stop 24V 21W BA15S', 0.852, 27, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.STOP_BLANC*', N'33', N'33FA', N'Ampoule stop 1 fil blanc 21W', 0.85, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.STOP12V21/5W', N'33', N'33FA', N'Ampoule stop 2 fil 12V21/5W', 1.19, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.STOP16W', N'33', N'33FA', N'Ampoule stop feu additionnel culot en verre', 1.92, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.STOP24V21/5W', N'33', N'33FB', N'Ampoule stop 24V 21/5W BAY15D', 1.666, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.TEM24V4W', N'33', N'33FA', N'Ampoule temoin C15W 4W 24V feu de gabarit', 0.671, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.TEMO24/2W', N'33', N'33FB', N'Ampoule tmoin 24V/2W', 1.05, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'AMPO.TEMO4W', N'33', N'33FA', N'Ampoule temoin 12V 4W', 0.5914, 28, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ANGL.HAG896054', N'12', N'12MB', N'Angle exterieur variable pour plinthe SL20115 PALOMA', 4.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ANGL.HAG896078', N'12', N'12MB', N'Angle intrieur variable pour plinthe SL20115 PALOMA', 4.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ANNE.CLE_DN18', N'26', N'26FD', N'Anneau pour porte cle DN 18mm', 0.4, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ANNE.DL1.3TO_ARTEON', N'26', N'26FD', N'Anneau de levage type arteon 1.300  tonne', 39, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ANNE.ECH30121004630', N'14', N'14FC', N'Anneau ECHO pour fixation harnais tube', 3.59, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ANNE.STH1287918400', N'14', N'14FC', N'Anneau', 2, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ANOD.PLA177524', N'26', N'26FD', N'Anodes a souder magnesium 290x150x40', 116, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ANOD.PLA38390', N'26', N'26FD', N'Anodes a souder magnesium   - 1.8 kg', 79.9, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ANTE.GSM5DBIM', N'20', N'20MC', N'Antenne magnetique bi-bande GSM equip de cable faible perte de 2m gain 5dbi', 37.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ANTE.RHEA_AL', N'31', N'31FA', N'Antenne pour recepteur d''alarme rhea type MU7-CXP4/1 avec 4m de cable', 50, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ANTE.RHEA_AN', N'31', N'31FA', N'Antenne pour recepteur d''annonceaval et amont rhea type HX70 + adaptateur BNC coud', 30, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ANTI_CREVAISON1L', N'05', N'05FI', N'Anti crevaison pour pneu EUTESIA 1L', 15.2768, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ANTI_FOURMIS', N'14', N'14FB', N'Botes d''appt anti fourmis', 5.75, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ANTI_GRAFFITI', N'05', N'05FI', N'Nettoyant graffiti', 148.2, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ANTI_RET.FGCT6 10', N'22', N'22FA', N'Anti retour quickmatic femelle GC (rouge) T6 10', 62.2062, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ANTI_TRABLOCFOR10', N'18', N'18MB', N'Anti chute tractel cable acier 10m coque abs poids 4.5kgs + M46', 357.28, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ANTIGEL20', N'05', N'05FI', N'antigel 20 litres', 3.25, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'APPA.PHOTO', N'08', N'08MB', N'Appareil photo numerique zoom optique', 472, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ARBR.ROH14899', N'26', N'26FD', N'Arbre pour mandrin', 3.85, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ARBR.STH41287113300', N'14', N'14FC', N'Arbre', 21.46, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ARBR.STH41377113200', N'14', N'14FC', N'Arbre d''entrainement FS85', 38.9224, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ARBR.STH41387103203', N'14', N'14FC', N'Arbre de commande pour HT75', 83.5032, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ARBU.', N'14', N'14FA', N'Arbuste d''ornement', 125, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ARCA.11.5M3', N'11', N'11FB', N'11,5m3-Air liquide - ARCAL MAG SMARTOP', 138, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ARMO.AT1950/120/500', N'23', N'23MA', N'Armoire d''atelier 1950/120/500 gris clair ral 7035 4 tablettes 3 tiroirs', 999.53, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ARMO.BOTT', N'23', N'23MA', N'Armoire charge lourde H2000 X L1050 X P650mm NU', 539.08, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ARMO.H198X120', N'23', N'23MA', N'Armoire a rideaux htre plaquage gris fonc haut.198xlarg.120xprof.43cm', 351, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ARMO.H198X120SD', N'23', N'23MA', N'Armoire a rideaux gris clair SD SD 198xlarg.120xprof.43cm', 331, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ARMO.OUTIL1000X1000', N'23', N'23MA', N'Armoire  outil H1000x1000xprof.500 colori gris', 409, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ARMO.OUTIL1000X500', N'23', N'23MA', N'Armoire  outil H1000xlarg.500xprof.500 colori bleu gentiane 1 tiroir', 241.8, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP10X180', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 10x180', 0.282, 45, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP10X40', N'26', N'26FD', N'Vis TH AC ZI filetage partiel 10x40', 0.1791427, 73, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP10X40A2', N'26', N'26FD', N'Vis TH - filetage partiel A2 10x40', 0.372, 61, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP10X50', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 10x50', 0.14, 37, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP10X50A2', N'26', N'26FD', N'Vis TH filetage partiel inox A2 8.8 10x50', 0.56808, 125, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP10X50A4', N'26', N'26FD', N'Vis TH filetage partiel inox A4 8.8 10x50', 0.548, 24, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP10X60', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 10x60', 0.1571, 33, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP10X60A2', N'26', N'26FD', N'Vis TH filetage partiel A2 10x60', 0.6058, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP10X70', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 10x70', 0.163, 159, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP10X70A2', N'26', N'26FD', N'Vis TH filetage partiel A2 10x70', 0.56, 45, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP10X80', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 10x80', 0.2138, 98, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP10X80A2', N'26', N'26FD', N'Vis TH filetage partiel A2', 0.595, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP10X90', N'26', N'26FD', N'Vis TH filetage partiel AC ZI  10x90', 0.191, 123, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP12X100', N'26', N'26FD', N'Vis TH filetage partiel 12X100 AC.ZI. 8.8', 0.5626465, 70, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP12X120', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 12x120', 0.784, 65, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP12X130', N'26', N'26FD', N'Vis TH AC ZI filetage partiel 8.8 12X130', 2.54, 19, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP12X50', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 12x50', 0.21, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP12X60', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 12x60', 0.3627, 83, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP12X60A2', N'26', N'26FD', N'Vis TH filetage partiel AC A2 12x60', 0.733, 35, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP12X70', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 12x70', 0.4957895, 35, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP12X80', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 12x80', 0.357, 140, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP12X90', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 12x90', 0.739, 76, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP14X100', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 14x100', 1.1881, 43, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP14X110', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 14x110', 0.8063, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP14X50', N'26', N'26FD', N'Vis TH filetage partiel 14X50 AC.ZI. 8.8', 0.317, 19, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP14X60', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 14x60', 0.442, 70, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP14X70', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 14x70', 0.906, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP14X80', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 14x80', 1.044, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP14X90', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 14x90', 0.44, 18, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP16X100', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 16x100', 1.167542, 107, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP16X140', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 16x140', 0.677, 23, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP16X160', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 16x160', 0.957, 23, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP16X50', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 16x50', 0.474, 12, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP16X50_10.9', N'26', N'26FD', N'Vis TH filetage partiel AC BI 10.9 16x50', 3.392, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP16X60', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 16x60', 0.4358, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP16X60A2', N'26', N'26FD', N'Vis TH filetage partiel AC inox A2 16x60', 1.4, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP16X70', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 16x70', 0.506, 26, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP16X80', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 16x80 8.8', 0.7729682, 13, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP16X80_10.9', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 16x80 10.9', 0.9739999, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP16X90', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 16x90', 0.86514, 109, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP18X100', N'26', N'26FD', N'Vis TH AC ZI filetage partiel 8.8 18X100', 2.5, 21, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP18X70', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 18x70', 0.94, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP18X80', N'26', N'26FD', N'Vis TH filetage partiel 18X80 AC.ZI 8.8', 1.3, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP20X 80', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 20x80', 1.28, 5, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP20X 90_10.9', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 10.9 20x90', 1.65, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP20X100', N'26', N'26FD', N'Vis TH filetage partiel 20x100 AC ZI 8.8', 0.77, 22, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP20X120', N'26', N'26FD', N'Vis TH filetage partiel 20x120 8.8 AC ZI', 1.29, 30, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP20X130', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 20x130', 2.184762, 19, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP20X140_10.9', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 10.9 20x140', 5.2712, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP20X180', N'26', N'26FD', N'Vis TH filetage partiel AC ZI 8.8 20x180', 3.58, 39, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP20X200', N'26', N'26FD', N'Vis TH filetage partiel 20x200 8.8 zinguee', 4.6, 15, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THP22X80A2', N'26', N'26FD', N'Vis TH filetage partiel 22x80 inox A2', 0.396, 62, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THPAB12X110', N'26', N'26FD', N'Vis TH filetage partiel ACIER BRUT 8.8 12x110', 0.364, 58, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THPAB12X80', N'26', N'26FD', N'Vis TH filetage partiel ACIER BRUT 8.8 12x80', 0.238, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THPAB14X120', N'26', N'26FD', N'Vis TH filetage partiel 14x120 ACIER BRUT 8.8', 2.203, 34, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THPAB16X110', N'26', N'26FD', N'Vis TH filetage partiel ACIER BRUT 8.8 16x110', 0.595, 143, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THPAB16X300', N'26', N'26FD', N'Vis TH filetage partiel ACIER BRUT 8.8 16x300', 3.7, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THPAB18X120', N'26', N'26FD', N'Vis TH filetage partiel ACIER BRUT 8.8 18x120', 1.3213, 24, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THPAB18X320', N'26', N'26FD', N'Vis TH filetage partiel  ACIER BRUT 8.8 18x320', 8.65, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THPAB18X70', N'26', N'26FD', N'Vis TH filetage partiel  ACIER BRUT 8.8 18x70', 0.668, 15, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THPAB20X150', N'26', N'26FD', N'Vis TH filetage partiel ACIER BRUT 8.8 20x150', 1.345, 47, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THPAB20X220', N'26', N'26FD', N'Vis TH filetage partiel ACIER BRUT 8.8 20x220', 9.63, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THPAB22X110', N'26', N'26FD', N'Vis TH filetage partiel ACIER BRUT 8.8 22x110', 1.194, 9, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THPAB24X120', N'26', N'26FD', N'Vis TH filetage partiel 8.8 ACIER BRUT 24X120', 2.043, 14, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THPAB24X150', N'26', N'26FD', N'Vis TH filetage partiel ACIER BRUT 8.8 24x150', 4.0436, 53, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THPAB24X80', N'26', N'26FD', N'Vis THfiletage partiel ACIER BRUT 8.8 24x80', 1.139, 8, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THPAB27X100', N'26', N'26FD', N'Vis TH filetage partiel ACIER BRUT 8.8 27x100', 3.485, 15, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THPAB30X80', N'26', N'26FD', N'Vis TH filetage partiel ACIER BRUT 8.8 30x80', 1.74, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT04X10', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 4x10', 0.04, 160, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT04X25', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 4x25', 0.0367, 555, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT04X35', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 4x35', 0.07, 186, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT05X20', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 5x20', 0.021, 168, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT05X30', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 5x30', 0.066, 164, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT05X40', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 5x40', 0.07, 184, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT06X16', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 6x16', 0.0334, 438, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT06X20', N'26', N'26FD', N'Vis TH FT 6x20 AC ZI 8.8', 0.029, 190, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT06X25', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 6x25', 0.036, 494, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT06X30', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 6x30', 0.104, 200, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT06X40', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 6x40', 0.088, 107, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT06X50', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 6x50', 0.0621, 57, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT06X60', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 6x60', 0.17, 169, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT08X16', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 8x16', 0.032, 196, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT08X20', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 8x20', 0.0633, 200, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT08X25', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 8x25', 0.0561, 150, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT08X30', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 8x30', 0.07783332, 96, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT08X35', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 8x35', 0.064, 63, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT08X35A2', N'26', N'26FD', N'Vis TH FT A2 8x35', 0.195, 90, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT08X40', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 8x40', 0.0789, 109, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT08X50', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 8x50', 0.093, 29, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT08X50A2', N'26', N'26FD', N'Vis TH FT A2 8x50', 0.3296, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT08X60', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 8x60', 0.119, 34, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT08X70', N'26', N'26FD', N'Vis TH 8x70 AC ZI 8.8', 0.281, 270, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT08X80', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 8x80', 0.47, 79, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT08X90A2', N'26', N'26FD', N'Vis TH FT inox A2 8x90', 0.586, 58, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT10X100', N'26', N'26FD', N'VisTH FT AC ZI 8.8 10x100', 0.204, 24, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT10X110', N'26', N'26FD', N'VisTH FT AC ZI 8.8 10x110', 0.606, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT10X20', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 10x20', 0.078, 49, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT10X25', N'26', N'26FD', N'Vis TH AC ZI 10x25 FT 8.8', 0.118, 106, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT10X30', N'26', N'26FD', N'Vis 10x30 THT AC ZI 8.8', 0.151408, 177, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT10X35', N'26', N'26FD', N'Vis 10x35 THT AC ZI 8.8', 0.243, 93, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT10X40', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 10x40', 0.1701, 208, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT10X50', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 10x50', 0.125, 20, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT10X50A4', N'26', N'26FD', N'Vis TH FT inox A4 10x50 0091 10 50', 1.29, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT10X60', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 10x60', 0.136, 41, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT10X60A2', N'26', N'26FD', N'Vis TH FT inox A2 10x60', 3.5, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT10X60A4', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 10x60 inox A4', 0.136, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT10X70', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 10x70', 0.156, 93, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT10X70A2', N'26', N'26FD', N'Vis TH FT A2 10x70 - 0096 10 70', 0.56, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT10X80', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 10x80', 0.418, 111, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT10X90', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 10x90', 0.314, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT12X100', N'26', N'26FD', N'Vis TH 12x100 AC ZI 8.8 FT', 0.753, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT12X120', N'26', N'26FD', N'Vis TH FT AC ZI 8,8 12x120', 0.982, 36, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT12X25', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 12x25', 0.09, 94, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT12X30', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 12x30', 0.1625, 71, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT12X30A2', N'26', N'26FD', N'Vis TH FT A2 12x30', 1.31, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT12X35', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 12x35', 0.131, 84, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT12X40', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 12x40', 0.166, 22, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT12X50', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 12x50', 0.3707792, 154, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT12X60', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 12x60', 0.223, 95, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT12X70', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 12x70', 0.654, 46, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT12X80', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 12x80', 0.797, 46, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT12X90', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 12x90', 0.391, 46, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT14X120', N'26', N'26FD', N'Vis TH 14X120 AC ZI 8.8 FT', 2.204, 21, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT14X35', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 14x35', 0.307, 21, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT14X40', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 14x40', 0.36, 94, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT14X50', N'26', N'26FD', N'Vis TH 14X50 AC ZI 8,8 FT', 0.317, 82, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT14X60', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 14x60', 0.29, 62, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT14X80', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 14x80', 1.262, 21, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT16X 60PF', N'26', N'26FD', N'Vis TH FT AC ZI pas fin 10.9 16x60 pour DELMAG', 1.134, 20, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT16X100', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 16x100', 1.646, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT16X40', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 16x40', 0.8288428, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT16X40A2', N'26', N'26FD', N'Vis TH FT AC inox A2 8.8 16x40', 1.0508, 30, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT16X45', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 16x45', 0.88, 46, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT16X50', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 16x50', 0.403, 20, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT16X60', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 16x60', 0.453, 105, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT18X40', N'26', N'26FD', N'Vis TH 18x40 AC ZI 8.8 FT', 0.63, 10, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT18X50', N'26', N'26FD', N'Vis TH 18x50 AC ZI 8.8 FT', 1.4081, 7, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT18X70', N'26', N'26FD', N'Vis TH 18x70 AC ZI 8.8 FT', 2.064, 13, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT18X80', N'26', N'26FD', N'Vis TH 18x80 AC ZI 8.8 FT', 2.06, 21, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT20X40', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 20x40', 1.46, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT20X50', N'26', N'26FD', N'Vis TH FT AC ZI 8.8 20x50', 0.49, 111, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT20X60', N'26', N'26FD', N'Vis TH AC ZI 8.8 20x60', 0.56, 43, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_THT24X60', N'26', N'26FD', N'Vis TH FT AC ZI 10.9 24x60', 2.87, 21, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC06X30Z', N'26', N'26FD', N'Vis TRCC 6x30 Zingu', 0.0656, 120, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC06X40Z', N'26', N'26FD', N'Vis TRCC 6x40 Zingu', 0.0701, 169, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC06X50Z', N'26', N'26FD', N'Vis TRCC 6x50 Zingu', 0.0823, 146, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC06X60Z', N'26', N'26FD', N'Vis TRCC 6x60 Zingu', 0.0899, 342, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC06X70N', N'26', N'26FD', N'Vis TRCC 6x70 Noir', 0.0945, 48, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC06X70Z', N'26', N'26FD', N'VIs TRCC 6x70 Zingu', 0.0945, 279, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC08X100N', N'26', N'26FD', N'Vis TRCC 8x100 Noir', 0.1936, 198, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC08X100Z', N'26', N'26FD', N'Vis TRCC 8x100 Zingu', 0.1936, 96, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC08X110N', N'26', N'26FD', N'Vis TRCC 8x110 Noir', 0.2302, 42, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC08X110Z', N'26', N'26FD', N'Vis TRCC 8x110 Zingu', 0.2302, 48, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC08X160Z', N'26', N'26FD', N'Vis TRCC 8x160 Zingu', 0.3537, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC08X40Z', N'26', N'26FD', N'Vis TRCC 8x40 Zingu', 0.1174, 42, 0, 0, 0)
GO
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC08X60N', N'26', N'26FD', N'Vis TRCC 8x60 Noir', 0.1296, 95, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC08X60Z', N'26', N'26FD', N'Vis TRCC 8x60 Zingu', 0.1296, 76, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC08X70Z', N'26', N'26FD', N'Vis TRCC 8x70 Zingu', 0.1585, 193, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC08X80Z', N'26', N'26FD', N'Vis TRCC 8x80 Zingu', 0.1296, 382, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC08X90Z', N'26', N'26FD', N'Vis TRCC 8x90 Zingu', 0.1296, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC10X100Z', N'26', N'26FD', N'Vis TRCC 10x100 Zingu', 0.2851, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC10X120Z', N'26', N'26FD', N'Vis TRCC 10x120 Zingu', 0.58, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC10X140Z', N'26', N'26FD', N'Vis TRCC 10x140 Zingu', 3.66, 18, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC10X160Z', N'26', N'26FD', N'Vis TRCC 10x160 Zingu', 0.6266, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC10X60Z', N'26', N'26FD', N'Vis TRCC 10x60 Zingu', 0.2302, 358, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC10X70Z', N'26', N'26FD', N'Vis TRCC 10x70 Zingu', 0.247, 99, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC10X80Z', N'26', N'26FD', N'Vis TRCC 10x80 Zingu', 0.2653, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC12X100Z', N'26', N'26FD', N'Vis TRCC 12x100 Zingu', 1.32, 90, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC12X110Z', N'26', N'26FD', N'Vis TRCC 12x110 Zingu', 0.5516, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC12X120Z', N'26', N'26FD', N'Vis TRCC 12x120 Zingu', 0.97, 25, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC12X160Z', N'26', N'26FD', N'Vis TRCC 12x160 Zingu', 0.7927, 20, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC12X200Z', N'26', N'26FD', N'Vis TRCC 12x200 Zingu', 0.9589, 14, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC12X250Z', N'26', N'26FD', N'Vis TRCC 12x250 Zingu', 1.0824, 6, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC12X50Z', N'26', N'26FD', N'Vis TRCC 12x50 Zingu', 0.375, 50, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC12X70Z', N'26', N'26FD', N'Vis TRCC 12x70 Zingu', 0.3994, 23, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC12X80Z', N'26', N'26FD', N'Vis TRCC 12x80 Zingu', 0.4288, 32, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC12X90Z', N'26', N'26FD', N'Vis TRCC 12x90 Zingu', 0.4522529, 51, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC14X120Z', N'26', N'26FD', N'Vis TRCC 14x120 Zingu', 2.4971, 13, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TRCC14X160Z', N'26', N'26FD', N'Vis TRCC 14x160 Zingu', 1.3934, 18, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TTCB4.2X38', N'26', N'26FD', N'Vis a tole TCB AC ZI 4.2x538', 0.11, 60, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TTCB4.8X45', N'26', N'26FD', N'Vis a tole TCB AC ZI 4.8x45', 0.11, 95, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TTH08X19', N'26', N'26FD', N'Vis  tole TH AC BI 8x19 KOMBI', 0.375, 29, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TTH4.8X16', N'26', N'26FD', N'Vis  tole TH AC BI 4,8x16 KOMBI', 0.25, 60, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TTH5.5X16', N'26', N'26FD', N'Vis tole TH AC BI 5,5x16 KOMBI', 0.276, 96, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TTH6.3X16', N'26', N'26FD', N'Vis  tole TH AC BI 6,3x16 KOMBI', 0.595, 100, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TTH6.3X22', N'26', N'26FD', N'Vis  tole TH AC ZI 6,3x22', 0.274, 80, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VIS_TTH6.5X16', N'26', N'26FD', N'Vis  tole TH AC BI 6,5x16 KOMBI', 0.317, 80, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VISI.STH00008840565', N'18', N'18MB', N'Visiere plexi courte quip de coquilles anti bruit', 52.34, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VISS.BOSGSB18V-60C', N'22', N'22MD', N'Visseuse Solo', 219, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VISS.BOSGSB18V-85C', N'22', N'22MD', N'Visseuse a percussion avec coffret GSB 18 V-85C', 479, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VISS.BOSGSR18VLI', N'22', N'22MD', N'Visseuse a percussion avec coffret  4AH li + toolbox', 299, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VITR.CLA113008110', N'14', N'14FC', N'Vitre', 30.11, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VITR.CLA6005014581', N'14', N'14FC', N'Vitre de portiere PALES', 372.52, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VITR.CLA6005014584', N'14', N'14FC', N'Vitre hayon arriere PALES', 111.62, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VITR.INCASSABLE', N'31', N'31FA', N'Vitre incassable pour telephone', 24, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VITRINE EXT.1000', N'23', N'23MA', N'Vitrine exterieure alu anodis 1000x1050 avec 2 verins', 480, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VOYA.SCHXB4BVB3', N'12', N'12 FA', N'Voyant lumineux vert TELE', 10.54, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VOYA.SCHXB4BVB4', N'12', N'12 FA', N'Voyant lumineux rougeTELE', 10.54, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'VULC.50ML', N'05', N'05FI', N'vulvanisant pour pneu', 3.896, 1, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'WADE.T43', N'18', N'18MB', N'Waders caoutchouc semelle+coquille securite T43', 228.625, 4, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'WADE.T44', N'18', N'18MB', N'Waders caoutchouc semelle+coquille securite T44', 217.5, 3, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'WADE.T45', N'18', N'18MB', N'Waders caoutchouc semelle+coquille securiteT45', 255.9, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'WC_BLANC', N'05', N'05MA', N'WC blanc avec pied', 119.5, 0, 0, 0, 1)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'WHIT.SPIRIT1', N'05', N'05FL', N'White spirit 1litre desaromatis', 15.93, 0, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'WHIT.SPIRIT5', N'05', N'05FL', N'White spirit 5l', 15.9353848, 13, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'XENO.TRA252133', N'12', N'12 MC', N'Xenon rouge rtb-5 base 10j24v', 173, 2, 0, 0, 0)
INSERT [dbo].[PIECES] ([ID_PIECE], [ID_GRFP], [ID_FP], [DES_PIECE], [PRIX], [QTE_STOCK], [SEUIL], [QT_DA], [QT_CDE]) VALUES (N'ZCO_20', N'22', N'22FA', N'Zco 20 - 17-20 acier collier 2 oreilles', 0.44, 0, 0, 0, 0)
GO 

INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-0006', N'CC206', N'LOGICO', CAST(N'2018-01-05T00:00:00.000' AS DateTime), CAST(N'2018-01-05T00:00:00.000' AS DateTime), 5, 2080.032)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-0007', N'CC206', N'BEYO', CAST(N'2018-01-05T00:00:00.000' AS DateTime), CAST(N'2018-01-05T00:00:00.000' AS DateTime), 5, 1752)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-0027', N'CC206', N'KUTZ', CAST(N'2018-01-10T00:00:00.000' AS DateTime), CAST(N'2018-01-11T00:00:00.000' AS DateTime), 5, 313.2036)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-0029', N'CC206', N'ACM DIFFUSION', CAST(N'2018-01-09T00:00:00.000' AS DateTime), CAST(N'2018-01-13T00:00:00.000' AS DateTime), 5, 326.58)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-0052', N'CC206', N'CCARM', CAST(N'2018-01-10T00:00:00.000' AS DateTime), CAST(N'2018-02-11T00:00:00.000' AS DateTime), 5, 505.9)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-0053', N'CC206', N'FUCKLER', CAST(N'2018-01-11T00:00:00.000' AS DateTime), CAST(N'2018-02-08T00:00:00.000' AS DateTime), 5, 694.883)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-0101', N'CC206', N'SM BO', CAST(N'2018-01-15T00:00:00.000' AS DateTime), CAST(N'2018-01-15T00:00:00.000' AS DateTime), 5, 851.49)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-0249', N'CC206', N'AVGE', CAST(N'2018-01-09T00:00:00.000' AS DateTime), CAST(N'2018-03-10T00:00:00.000' AS DateTime), 5, 746.93)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-0250', N'CC206', N'AMPLI SERVICE', CAST(N'2018-01-16T00:00:00.000' AS DateTime), CAST(N'2018-03-18T00:00:00.000' AS DateTime), 5, 2933.88)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-0251', N'CC206', N'LEMEUR', CAST(N'2018-01-09T00:00:00.000' AS DateTime), CAST(N'2018-01-24T00:00:00.000' AS DateTime), 5, 998.99)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-0252', N'CC206', N'BEYO', CAST(N'2018-01-24T00:00:00.000' AS DateTime), CAST(N'2018-01-24T00:00:00.000' AS DateTime), 5, 461.368)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-0253', N'CC206', N'CCARM', CAST(N'2018-01-15T00:00:00.000' AS DateTime), CAST(N'2018-01-16T00:00:00.000' AS DateTime), 5, 994)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-0254', N'CC206', N'RUDOL', CAST(N'2018-01-10T00:00:00.000' AS DateTime), CAST(N'2018-03-12T00:00:00.000' AS DateTime), 5, 385.84)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-0255', N'CC206', N'BIGREAL', CAST(N'2018-01-11T00:00:00.000' AS DateTime), CAST(N'2018-01-12T00:00:00.000' AS DateTime), 5, 437.58)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-0342', N'CC206', N'CRA SF', CAST(N'2018-01-30T00:00:00.000' AS DateTime), CAST(N'2018-02-19T00:00:00.000' AS DateTime), 5, 1718.29)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-0348', N'CC206', N'INTERF', CAST(N'2018-01-31T00:00:00.000' AS DateTime), CAST(N'2018-02-07T00:00:00.000' AS DateTime), 5, 1282.6)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-0450', N'CC206', N'CAT AX', CAST(N'2018-02-07T00:00:00.000' AS DateTime), CAST(N'2018-02-08T00:00:00.000' AS DateTime), 5, 445.3)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-0568', N'CC206', N'EQUILEX', CAST(N'2018-01-30T00:00:00.000' AS DateTime), CAST(N'2018-03-02T00:00:00.000' AS DateTime), 5, 7254.62)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-0772', N'CC206', N'RUDOL', CAST(N'2018-02-05T00:00:00.000' AS DateTime), CAST(N'2018-03-18T00:00:00.000' AS DateTime), 5, 970.6072)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-0886', N'CC206', N'BIGREAL', CAST(N'2018-02-05T00:00:00.000' AS DateTime), CAST(N'2018-03-09T00:00:00.000' AS DateTime), 5, 987.0932)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1193', N'CC201', N'AUMALE', CAST(N'2018-03-13T00:00:00.000' AS DateTime), CAST(N'2018-03-14T00:00:00.000' AS DateTime), 5, 7104)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1194', N'CC206', N'LOGICO', CAST(N'2018-03-13T00:00:00.000' AS DateTime), CAST(N'2018-03-13T00:00:00.000' AS DateTime), 5, 3008)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1195', N'CC206', N'LEMEUR', CAST(N'2018-01-31T00:00:00.000' AS DateTime), CAST(N'2018-03-26T00:00:00.000' AS DateTime), 5, 1563.8)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1196', N'CC206', N'ALSA NOVOS', CAST(N'2018-03-13T00:00:00.000' AS DateTime), CAST(N'2018-03-13T00:00:00.000' AS DateTime), 5, 586.07)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1201', N'CC206', N'AVGE', CAST(N'2018-03-19T00:00:00.000' AS DateTime), CAST(N'2018-04-20T00:00:00.000' AS DateTime), 5, 848.74)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1203', N'CC206', N'AMPLI SERVICE', CAST(N'2018-03-22T00:00:00.000' AS DateTime), CAST(N'2018-04-22T00:00:00.000' AS DateTime), 5, 2822.47)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1205', N'CC206', N'CCARM', CAST(N'2018-03-28T00:00:00.000' AS DateTime), CAST(N'2018-05-03T00:00:00.000' AS DateTime), 5, 1273.2)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1222', N'CC206', N'AVGE', CAST(N'2018-01-31T00:00:00.000' AS DateTime), CAST(N'2018-03-11T00:00:00.000' AS DateTime), 5, 765.12)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1266', N'CC206', N'THOMYS', CAST(N'2018-03-16T00:00:00.000' AS DateTime), CAST(N'2018-03-17T00:00:00.000' AS DateTime), 5, 956)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1267', N'CC201', N'LEMEUR', CAST(N'2018-02-21T00:00:00.000' AS DateTime), CAST(N'2018-02-22T00:00:00.000' AS DateTime), 5, 4043.02)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1360', N'CC206', N'CCARM', CAST(N'2018-02-15T00:00:00.000' AS DateTime), CAST(N'2018-03-23T00:00:00.000' AS DateTime), 5, 1049.7)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1368', N'CC206', N'MABEOX', CAST(N'2018-03-07T00:00:00.000' AS DateTime), CAST(N'2018-03-09T00:00:00.000' AS DateTime), 5, 1373.67)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1395', N'CC206', N'FUCKLER', CAST(N'2018-03-15T00:00:00.000' AS DateTime), CAST(N'2018-06-15T00:00:00.000' AS DateTime), 5, 2469.759)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1432', NULL, N'ELTYCH', CAST(N'2018-03-22T00:00:00.000' AS DateTime), CAST(N'2018-03-22T00:00:00.000' AS DateTime), 5, 294.78)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1606', N'CC206', N'BEYO', CAST(N'2018-04-04T00:00:00.000' AS DateTime), CAST(N'2018-04-04T00:00:00.000' AS DateTime), 5, 1747.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1641', N'CC206', N'SM BO', CAST(N'2018-03-22T00:00:00.000' AS DateTime), CAST(N'2018-05-17T00:00:00.000' AS DateTime), 5, 1410.42)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1642', N'CC206', N'HAPPY', CAST(N'2018-04-04T00:00:00.000' AS DateTime), CAST(N'2018-04-04T00:00:00.000' AS DateTime), 5, 679.4)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1716', N'CC206', N'BILLIAUX', CAST(N'2018-04-09T00:00:00.000' AS DateTime), CAST(N'2018-04-10T00:00:00.000' AS DateTime), 5, 196.09)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1717', N'CC206', N'EUROPE BN', CAST(N'2018-04-09T00:00:00.000' AS DateTime), CAST(N'2018-04-10T00:00:00.000' AS DateTime), 5, 1213.47)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1729', N'CC201', N'NOREM', CAST(N'2018-04-09T00:00:00.000' AS DateTime), CAST(N'2018-04-10T00:00:00.000' AS DateTime), 5, 6145)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1731', N'CC201', N'RUDOL', CAST(N'2018-04-09T00:00:00.000' AS DateTime), CAST(N'2018-04-09T00:00:00.000' AS DateTime), 5, 2401.667)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1805', N'CC206', N'LEMEUR', CAST(N'2018-03-13T00:00:00.000' AS DateTime), CAST(N'2018-03-14T00:00:00.000' AS DateTime), 5, 1830.3)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1806', N'CC206', N'CRA SF', CAST(N'2018-04-11T00:00:00.000' AS DateTime), CAST(N'2018-04-12T00:00:00.000' AS DateTime), 5, 47)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1807', N'CC201', N'LEMEUR', CAST(N'2018-04-11T00:00:00.000' AS DateTime), CAST(N'2018-04-12T00:00:00.000' AS DateTime), 5, 3660)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1834', N'CC206', N'BALDER', CAST(N'2018-04-12T00:00:00.000' AS DateTime), CAST(N'2018-04-12T00:00:00.000' AS DateTime), 5, 2167.84)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1835', N'CC206', N'CRA SF', CAST(N'2018-04-12T00:00:00.000' AS DateTime), CAST(N'2018-04-13T00:00:00.000' AS DateTime), 5, 155.6)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1937', N'CC206', N'RUDOL', CAST(N'2018-03-16T00:00:00.000' AS DateTime), CAST(N'2018-04-26T00:00:00.000' AS DateTime), 5, 1317.122)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-1995', N'CC206', N'NOREM', CAST(N'2018-04-18T00:00:00.000' AS DateTime), CAST(N'2018-04-19T00:00:00.000' AS DateTime), 5, 387.94)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-2005', N'CC206', N'CCARM', CAST(N'2018-04-19T00:00:00.000' AS DateTime), CAST(N'2018-05-10T00:00:00.000' AS DateTime), 5, 3062)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-2006', N'CC206', N'GUERN', CAST(N'2018-04-13T00:00:00.000' AS DateTime), CAST(N'2018-05-10T00:00:00.000' AS DateTime), 5, 155.493)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-2041', N'CC206', N'EUTEXIA', CAST(N'2018-04-19T00:00:00.000' AS DateTime), CAST(N'2018-04-20T00:00:00.000' AS DateTime), 5, 318.8)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-2042', N'CC206', N'RUDOL', CAST(N'2018-05-14T00:00:00.000' AS DateTime), CAST(N'2018-07-14T00:00:00.000' AS DateTime), 5, 1025.106)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-2465', N'CC206', N'SM BO', CAST(N'2018-05-14T00:00:00.000' AS DateTime), CAST(N'2018-06-11T00:00:00.000' AS DateTime), 5, 60.52)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-2553', N'CC206', N'GUERN', CAST(N'2018-05-17T00:00:00.000' AS DateTime), CAST(N'2018-05-18T00:00:00.000' AS DateTime), 5, 96.65)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-2554', N'CC206', N'BIGREAL', CAST(N'2018-03-16T00:00:00.000' AS DateTime), CAST(N'2018-04-28T00:00:00.000' AS DateTime), 5, 1534.82)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-2560', N'CC206', N'BEYO', CAST(N'2018-05-17T00:00:00.000' AS DateTime), CAST(N'2018-05-17T00:00:00.000' AS DateTime), 5, 11638)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-2562', N'CC206', N'BIGREAL', CAST(N'2018-05-28T00:00:00.000' AS DateTime), CAST(N'2018-07-05T00:00:00.000' AS DateTime), 5, 1815.931)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-2798', N'CC206', N'LEMEUR', CAST(N'2018-04-12T00:00:00.000' AS DateTime), CAST(N'2018-05-14T00:00:00.000' AS DateTime), 5, 4134.248)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-2846', N'CC206', N'LORRAINE NATICA', CAST(N'2018-05-30T00:00:00.000' AS DateTime), CAST(N'2018-06-03T00:00:00.000' AS DateTime), 5, 193.497)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-2859', N'CC206', N'CCARM', CAST(N'2018-05-31T00:00:00.000' AS DateTime), CAST(N'2018-06-01T00:00:00.000' AS DateTime), 5, 329.54)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-2861', N'CC206', N'AVGE', CAST(N'2018-06-04T00:00:00.000' AS DateTime), CAST(N'2018-07-13T00:00:00.000' AS DateTime), 5, 463.98)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-2968', N'CC201', N'LEMEUR', CAST(N'2018-06-04T00:00:00.000' AS DateTime), CAST(N'2018-06-05T00:00:00.000' AS DateTime), 5, 1718.84)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3035', N'CC206', N'BILLIAUX', CAST(N'2018-06-08T00:00:00.000' AS DateTime), CAST(N'2018-06-09T00:00:00.000' AS DateTime), 5, 15.47)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3037', N'CC304', N'NISSEM', CAST(N'2018-06-11T00:00:00.000' AS DateTime), CAST(N'2018-06-12T00:00:00.000' AS DateTime), 5, 785.77)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3063', N'CC206', N'SM BO', CAST(N'2018-06-11T00:00:00.000' AS DateTime), CAST(N'2018-06-11T00:00:00.000' AS DateTime), 5, 1062.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3064', N'CC304', N'AVGE', CAST(N'2018-06-12T00:00:00.000' AS DateTime), CAST(N'2018-07-14T00:00:00.000' AS DateTime), 5, 214.65)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3175', N'CC201', N'EUTEXIA', CAST(N'2018-06-18T00:00:00.000' AS DateTime), CAST(N'2018-06-19T00:00:00.000' AS DateTime), 5, 2767.8)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3216', N'CC206', N'LEMEUR', CAST(N'2018-02-21T00:00:00.000' AS DateTime), CAST(N'2018-02-22T00:00:00.000' AS DateTime), 5, 1553.14)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3217', N'CC206', N'TRAFIV', CAST(N'2018-05-31T00:00:00.000' AS DateTime), CAST(N'2018-05-31T00:00:00.000' AS DateTime), 5, 960)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3218', N'CC206', N'CRA SF', CAST(N'2018-06-18T00:00:00.000' AS DateTime), CAST(N'2018-06-19T00:00:00.000' AS DateTime), 5, 377.07)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3219', N'CC206', N'BEYO', CAST(N'2018-06-12T00:00:00.000' AS DateTime), CAST(N'2018-06-12T00:00:00.000' AS DateTime), 5, 5183.525)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3225', N'CC206', N'NOREM', CAST(N'2018-06-18T00:00:00.000' AS DateTime), CAST(N'2018-06-19T00:00:00.000' AS DateTime), 5, 78.56)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3245', N'CC206', N'GUERN', CAST(N'2018-06-19T00:00:00.000' AS DateTime), CAST(N'2018-07-16T00:00:00.000' AS DateTime), 5, 178.494)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3248', N'CC206', N'CCARM', CAST(N'2018-06-22T00:00:00.000' AS DateTime), CAST(N'2018-06-23T00:00:00.000' AS DateTime), 5, 1783.6)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3249', N'CC206', N'FRANK', CAST(N'2018-06-25T00:00:00.000' AS DateTime), CAST(N'2018-07-11T00:00:00.000' AS DateTime), 5, 1460.39246)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3250', N'CC206', N'CCARM', CAST(N'2018-06-25T00:00:00.000' AS DateTime), CAST(N'2018-06-26T00:00:00.000' AS DateTime), 5, 94)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3334', N'CC206', N'CCARM', CAST(N'2018-06-19T00:00:00.000' AS DateTime), CAST(N'2018-06-20T00:00:00.000' AS DateTime), 5, 1083.56)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3334bis', N'CC206', N'CCARM', CAST(N'2018-04-12T00:00:00.000' AS DateTime), CAST(N'2018-06-23T00:00:00.000' AS DateTime), 5, 2264.8)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3373', N'CC206', N'AMPLI SERVICE', CAST(N'2018-06-22T00:00:00.000' AS DateTime), CAST(N'2018-06-22T00:00:00.000' AS DateTime), 5, 2870.506)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3374', N'CC206', N'ELTYCH', CAST(N'2018-06-27T00:00:00.000' AS DateTime), CAST(N'2018-06-27T00:00:00.000' AS DateTime), 5, 474.89)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3377', N'CC206', N'BIGREAL', CAST(N'2018-07-03T00:00:00.000' AS DateTime), CAST(N'2018-08-04T00:00:00.000' AS DateTime), 5, 786.17)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3469', N'CC206', N'RHEAM', CAST(N'2018-07-02T00:00:00.000' AS DateTime), CAST(N'2018-07-02T00:00:00.000' AS DateTime), 5, 658.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3470', N'CC201', N'RHEAM', CAST(N'2018-07-02T00:00:00.000' AS DateTime), CAST(N'2018-07-02T00:00:00.000' AS DateTime), 5, 1280)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3471', N'CC206', N'CRA SF', CAST(N'2018-07-03T00:00:00.000' AS DateTime), CAST(N'2018-07-04T00:00:00.000' AS DateTime), 5, 772.26)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3473', N'CC206', N'EQUILEX', CAST(N'2018-07-03T00:00:00.000' AS DateTime), CAST(N'2018-08-03T00:00:00.000' AS DateTime), 5, 1141.03)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3474', N'CC206', N'LEMEUR', CAST(N'2018-07-09T00:00:00.000' AS DateTime), CAST(N'2018-08-09T00:00:00.000' AS DateTime), 5, 1439.41)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3476', N'CC304', N'AMPLI SERVICE', CAST(N'2018-07-11T00:00:00.000' AS DateTime), CAST(N'2018-07-11T00:00:00.000' AS DateTime), 5, 120.99)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3478', N'CC206', N'RUDOL', CAST(N'2018-07-11T00:00:00.000' AS DateTime), CAST(N'2018-07-11T00:00:00.000' AS DateTime), 5, 651.7232)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3479', N'CC206', N'AMPLI SERVICE', CAST(N'2018-07-11T00:00:00.000' AS DateTime), CAST(N'2018-07-22T00:00:00.000' AS DateTime), 5, 309.56)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3480', N'CC206', N'AMPLI SERVICE', CAST(N'2018-07-11T00:00:00.000' AS DateTime), CAST(N'2018-08-11T00:00:00.000' AS DateTime), 5, 756.27)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3730', N'CC206', N'SM BO', CAST(N'2018-07-09T00:00:00.000' AS DateTime), CAST(N'2018-07-09T00:00:00.000' AS DateTime), 5, 1053)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3731', N'CC201', N'FRANK', CAST(N'2018-07-03T00:00:00.000' AS DateTime), CAST(N'2018-07-03T00:00:00.000' AS DateTime), 5, 999.53)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3884', N'CC206', N'MGSYS', CAST(N'2018-07-17T00:00:00.000' AS DateTime), CAST(N'2018-07-18T00:00:00.000' AS DateTime), 5, 216.48)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-3911', N'CC206', N'NOREM', CAST(N'2018-07-17T00:00:00.000' AS DateTime), CAST(N'2018-07-18T00:00:00.000' AS DateTime), 5, 586.18)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4028', N'CC206', N'CRA SF', CAST(N'2018-08-07T00:00:00.000' AS DateTime), CAST(N'2018-08-08T00:00:00.000' AS DateTime), 5, 1423.27)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4029', N'CC206', N'AVGE', CAST(N'2018-08-07T00:00:00.000' AS DateTime), CAST(N'2018-09-08T00:00:00.000' AS DateTime), 5, 1304.12)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4321', N'CC206', N'NOREM', CAST(N'2018-08-07T00:00:00.000' AS DateTime), CAST(N'2018-08-08T00:00:00.000' AS DateTime), 5, 426.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4322', N'CC206', N'BORFLE', CAST(N'2018-08-08T00:00:00.000' AS DateTime), CAST(N'2018-08-08T00:00:00.000' AS DateTime), 5, 981)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4324', N'CC206', N'JO CORNE', CAST(N'2018-08-16T00:00:00.000' AS DateTime), CAST(N'2018-08-16T00:00:00.000' AS DateTime), 5, 98)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4325', N'CC206', N'RUDOL', CAST(N'2018-08-16T00:00:00.000' AS DateTime), CAST(N'2018-09-26T00:00:00.000' AS DateTime), 5, 1490.796)
GO
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4326', N'CC206', N'HERRMO', CAST(N'2018-08-17T00:00:00.000' AS DateTime), CAST(N'2018-08-18T00:00:00.000' AS DateTime), 5, 657.1012)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4437', N'CC206', N'AUTO SYS', CAST(N'2018-08-13T00:00:00.000' AS DateTime), CAST(N'2018-08-13T00:00:00.000' AS DateTime), 5, 82.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4487', N'CC206', N'AVGE', CAST(N'2018-08-20T00:00:00.000' AS DateTime), CAST(N'2018-08-21T00:00:00.000' AS DateTime), 5, 239)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4524', N'CC206', N'LEMEUR', CAST(N'2018-07-11T00:00:00.000' AS DateTime), CAST(N'2018-08-11T00:00:00.000' AS DateTime), 5, 1934.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4525', N'CC206', N'BILLIAUX', CAST(N'2018-08-21T00:00:00.000' AS DateTime), CAST(N'2018-08-22T00:00:00.000' AS DateTime), 5, 142.17)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4528', N'CC206', N'BEYO', CAST(N'2018-08-22T00:00:00.000' AS DateTime), CAST(N'2018-08-22T00:00:00.000' AS DateTime), 5, 9798.16)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4530', N'CC206', N'LEMEUR', CAST(N'2018-08-23T00:00:00.000' AS DateTime), CAST(N'2018-08-24T00:00:00.000' AS DateTime), 5, 288.25)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4534', N'CC206', N'AVGE', CAST(N'2018-08-30T00:00:00.000' AS DateTime), CAST(N'2018-10-01T00:00:00.000' AS DateTime), 5, 623.1804)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4538', N'CC206', N'FIPRO', CAST(N'2018-09-05T00:00:00.000' AS DateTime), CAST(N'2018-09-25T00:00:00.000' AS DateTime), 5, 1440.34)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4573', N'CC206', N'GUERN', CAST(N'2018-08-22T00:00:00.000' AS DateTime), CAST(N'2018-08-23T00:00:00.000' AS DateTime), 5, 360.53)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4574', N'CC206', N'AMPLI SERVICE', CAST(N'2018-08-23T00:00:00.000' AS DateTime), CAST(N'2018-09-03T00:00:00.000' AS DateTime), 5, 297.6)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4575', N'CC206', N'SM BO', CAST(N'2018-08-21T00:00:00.000' AS DateTime), CAST(N'2018-09-18T00:00:00.000' AS DateTime), 5, 309.42)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4772', N'CC206', N'NOREM', CAST(N'2018-08-30T00:00:00.000' AS DateTime), CAST(N'2018-08-31T00:00:00.000' AS DateTime), 5, 1464.18)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4839', N'CC206', N'AMPLI SERVICE', CAST(N'2018-08-07T00:00:00.000' AS DateTime), CAST(N'2018-09-07T00:00:00.000' AS DateTime), 5, 949.138)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4840', N'CC206', N'AMPLI SERVICE', CAST(N'2018-08-30T00:00:00.000' AS DateTime), CAST(N'2018-09-30T00:00:00.000' AS DateTime), 5, 933.62)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4841', N'CC206', N'EUTEXIA', CAST(N'2018-09-05T00:00:00.000' AS DateTime), CAST(N'2018-09-06T00:00:00.000' AS DateTime), 5, 662.91)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4842', N'CC206', N'NOREM', CAST(N'2018-09-06T00:00:00.000' AS DateTime), CAST(N'2018-09-07T00:00:00.000' AS DateTime), 5, 137.3)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4843', N'CC206', N'GUERN', CAST(N'2018-09-06T00:00:00.000' AS DateTime), CAST(N'2018-09-07T00:00:00.000' AS DateTime), 5, 436.8)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4846', N'CC201', N'SEAR', CAST(N'2018-09-06T00:00:00.000' AS DateTime), CAST(N'2018-09-06T00:00:00.000' AS DateTime), 5, 1175.76)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-4847', N'CC206', N'ELTYCH', CAST(N'2018-09-11T00:00:00.000' AS DateTime), CAST(N'2018-09-11T00:00:00.000' AS DateTime), 5, 831.008)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-488', N'CC206', N'HAPPY', CAST(N'2018-02-08T00:00:00.000' AS DateTime), CAST(N'2018-02-08T00:00:00.000' AS DateTime), 5, 691.24)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-489', N'CC206', N'XL ME', CAST(N'2018-02-08T00:00:00.000' AS DateTime), CAST(N'2018-02-10T00:00:00.000' AS DateTime), 5, 580)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-491', N'CC206', N'EQUILEX', CAST(N'2018-02-13T00:00:00.000' AS DateTime), CAST(N'2018-02-23T00:00:00.000' AS DateTime), 5, 3099.8)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5028', N'CC201', N'LEMEUR', CAST(N'2018-09-12T00:00:00.000' AS DateTime), CAST(N'2018-10-14T00:00:00.000' AS DateTime), 5, 1500.3)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5029', N'CC201', N'BEHN', CAST(N'2018-09-13T00:00:00.000' AS DateTime), CAST(N'2018-09-13T00:00:00.000' AS DateTime), 5, 246.3)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5043 et 5044', N'CC206', N'EQUILEX', CAST(N'2018-09-03T00:00:00.000' AS DateTime), CAST(N'2018-10-03T00:00:00.000' AS DateTime), 5, 5121.8)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5080', N'CC206', N'RECAM', CAST(N'2018-09-14T00:00:00.000' AS DateTime), CAST(N'2018-09-15T00:00:00.000' AS DateTime), 5, 780.72)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5104', N'CC206', N'NOREM', CAST(N'2018-09-17T00:00:00.000' AS DateTime), CAST(N'2018-09-18T00:00:00.000' AS DateTime), 5, 998.01)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5116', N'CC206', N'AVGE', CAST(N'2018-09-17T00:00:00.000' AS DateTime), CAST(N'2018-09-18T00:00:00.000' AS DateTime), 5, 693)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5117', N'CC206', N'CRA SF', CAST(N'2018-09-17T00:00:00.000' AS DateTime), CAST(N'2018-09-18T00:00:00.000' AS DateTime), 5, 30.11)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5122', N'CC206', N'BILLIAUX', CAST(N'2018-09-18T00:00:00.000' AS DateTime), CAST(N'2018-09-19T00:00:00.000' AS DateTime), 5, 1878.11)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5125', N'CC206', N'RUDOL', CAST(N'2018-09-20T00:00:00.000' AS DateTime), CAST(N'2018-10-31T00:00:00.000' AS DateTime), 5, 389.224)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5141', N'CC206', N'SM BO', CAST(N'2018-08-22T00:00:00.000' AS DateTime), CAST(N'2018-09-19T00:00:00.000' AS DateTime), 5, 1053.02)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5141bis', N'CC206', N'SM BO', CAST(N'2018-09-18T00:00:00.000' AS DateTime), CAST(N'2018-11-13T00:00:00.000' AS DateTime), 5, 363.8)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5142', N'CC206', N'RECAM', CAST(N'2018-08-31T00:00:00.000' AS DateTime), CAST(N'2018-09-10T00:00:00.000' AS DateTime), 5, 1604.3)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5143', N'CC206', N'NOREM', CAST(N'2018-09-18T00:00:00.000' AS DateTime), CAST(N'2018-09-19T00:00:00.000' AS DateTime), 5, 1872.77)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5152', N'CC201', N'ALVAXYS', CAST(N'2018-09-20T00:00:00.000' AS DateTime), CAST(N'2018-09-20T00:00:00.000' AS DateTime), 5, 1510)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5153', N'CC206', N'EQUILEX', CAST(N'2018-09-24T00:00:00.000' AS DateTime), CAST(N'2018-09-24T00:00:00.000' AS DateTime), 5, 761)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5170', N'CC206', N'FUCKLER', CAST(N'2018-09-28T00:00:00.000' AS DateTime), CAST(N'2018-12-29T00:00:00.000' AS DateTime), 5, 2099.8)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5206', N'CC201', N'SM BO', CAST(N'2018-09-24T00:00:00.000' AS DateTime), CAST(N'2018-09-24T00:00:00.000' AS DateTime), 5, 765)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5254', N'CC201', N'PHOENYX', CAST(N'2018-09-26T00:00:00.000' AS DateTime), CAST(N'2018-09-26T00:00:00.000' AS DateTime), 5, 40903.14)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5272', N'CC206', N'PNEUSS', CAST(N'2018-09-17T00:00:00.000' AS DateTime), CAST(N'2018-09-28T00:00:00.000' AS DateTime), 5, 2302.64)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5311', N'CC206', N'NOREM', CAST(N'2018-09-28T00:00:00.000' AS DateTime), CAST(N'2018-09-29T00:00:00.000' AS DateTime), 5, 368.54)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5317', N'CC201', N'TETRADEC', CAST(N'2018-09-27T00:00:00.000' AS DateTime), CAST(N'2018-10-27T00:00:00.000' AS DateTime), 5, 36186.46)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-532', N'CC206', N'CCARM', CAST(N'2018-02-02T00:00:00.000' AS DateTime), CAST(N'2018-03-10T00:00:00.000' AS DateTime), 5, 880.9)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5345', N'CC206', N'POMPI', CAST(N'2018-10-01T00:00:00.000' AS DateTime), CAST(N'2018-10-02T00:00:00.000' AS DateTime), 5, 72.7)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5391', N'CC206', N'STRAM', CAST(N'2018-10-02T00:00:00.000' AS DateTime), CAST(N'2018-10-02T00:00:00.000' AS DateTime), 5, 173.42)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5392', N'CC201', N'ELTYCH', CAST(N'2018-10-03T00:00:00.000' AS DateTime), CAST(N'2018-10-03T00:00:00.000' AS DateTime), 5, 3443.75)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5424', N'CC206', N'FOULER', CAST(N'2018-10-03T00:00:00.000' AS DateTime), CAST(N'2018-10-03T00:00:00.000' AS DateTime), 5, 709.43)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5442', N'CC206', N'EQUILEX', CAST(N'2018-10-04T00:00:00.000' AS DateTime), CAST(N'2018-10-04T00:00:00.000' AS DateTime), 5, 883.704)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5485', N'CC206', N'BIGREAL', CAST(N'2018-08-30T00:00:00.000' AS DateTime), CAST(N'2018-10-01T00:00:00.000' AS DateTime), 5, 473.33)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5486', N'CC206', N'CCARM', CAST(N'2018-09-27T00:00:00.000' AS DateTime), CAST(N'2018-09-28T00:00:00.000' AS DateTime), 5, 683.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5514', N'CC206', N'BEYO', CAST(N'2018-10-03T00:00:00.000' AS DateTime), CAST(N'2018-10-09T00:00:00.000' AS DateTime), 5, 7654.967)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5579', N'CC206', N'RECAM', CAST(N'2018-10-08T00:00:00.000' AS DateTime), CAST(N'2018-10-09T00:00:00.000' AS DateTime), 5, 1016.58)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5620', N'CC206', N'NOREM', CAST(N'2018-10-09T00:00:00.000' AS DateTime), CAST(N'2018-10-10T00:00:00.000' AS DateTime), 5, 85.54)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5621', N'CC206', N'RUDOL', CAST(N'2018-10-09T00:00:00.000' AS DateTime), CAST(N'2018-10-09T00:00:00.000' AS DateTime), 5, 625.8576)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5622', N'CC206', N'BILLIAUX', CAST(N'2018-10-10T00:00:00.000' AS DateTime), CAST(N'2018-10-11T00:00:00.000' AS DateTime), 5, 540.54)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5780', N'CC206', N'BIGREAL', CAST(N'2018-10-03T00:00:00.000' AS DateTime), CAST(N'2018-10-04T00:00:00.000' AS DateTime), 5, 3234)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5781', N'CC206', N'BIGREAL', CAST(N'2018-09-25T00:00:00.000' AS DateTime), CAST(N'2018-10-26T00:00:00.000' AS DateTime), 5, 18249.54)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5782', NULL, N'BIGREAL', CAST(N'2018-09-25T00:00:00.000' AS DateTime), CAST(N'2018-09-26T00:00:00.000' AS DateTime), 5, 4046.58)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5783', N'CC206', N'MGSYS', CAST(N'2018-09-25T00:00:00.000' AS DateTime), CAST(N'2018-11-24T00:00:00.000' AS DateTime), 5, 2456.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5784', N'CC206', N'LEJEUNE', CAST(N'2018-09-25T00:00:00.000' AS DateTime), CAST(N'2018-09-25T00:00:00.000' AS DateTime), 5, 2897.66)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5785', N'CC206', N'CCARM', CAST(N'2018-09-25T00:00:00.000' AS DateTime), CAST(N'2018-09-26T00:00:00.000' AS DateTime), 5, 4000)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5787', N'CC206', N'LEMEUR', CAST(N'2018-09-26T00:00:00.000' AS DateTime), CAST(N'2018-11-19T00:00:00.000' AS DateTime), 5, 1935.418)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5788', N'CC206', N'TPDO', CAST(N'2018-10-12T00:00:00.000' AS DateTime), CAST(N'2018-10-12T00:00:00.000' AS DateTime), 5, 5000)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5809', N'CC206', N'AMPLI SERVICE', CAST(N'2018-09-17T00:00:00.000' AS DateTime), CAST(N'2018-10-03T00:00:00.000' AS DateTime), 5, 1601.33)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5812', N'CC206', N'LEMEUR', CAST(N'2018-09-25T00:00:00.000' AS DateTime), CAST(N'2018-09-26T00:00:00.000' AS DateTime), 5, 1660.78)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5818', N'CC206', N'BIGREAL', CAST(N'2018-10-12T00:00:00.000' AS DateTime), CAST(N'2018-10-13T00:00:00.000' AS DateTime), 5, 2398.99)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5893', N'CC206', N'LEMEUR', CAST(N'2018-10-03T00:00:00.000' AS DateTime), CAST(N'2018-10-17T00:00:00.000' AS DateTime), 5, 877.64)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5895', N'CC201', N'AUMALE', CAST(N'2018-10-12T00:00:00.000' AS DateTime), CAST(N'2018-10-13T00:00:00.000' AS DateTime), 5, 7368)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5896', N'CC201', N'LEMEUR', CAST(N'2018-10-12T00:00:00.000' AS DateTime), CAST(N'2018-10-13T00:00:00.000' AS DateTime), 5, 5101.2)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5897', N'CC206', N'CRA SF', CAST(N'2018-10-16T00:00:00.000' AS DateTime), CAST(N'2018-10-17T00:00:00.000' AS DateTime), 5, 507.32)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5898', N'CC206', N'SEAR', CAST(N'2018-10-16T00:00:00.000' AS DateTime), CAST(N'2018-10-16T00:00:00.000' AS DateTime), 5, 605.88)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5899', N'CC206', N'KLEINNE', CAST(N'2018-10-16T00:00:00.000' AS DateTime), CAST(N'2018-10-16T00:00:00.000' AS DateTime), 5, 474.93)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5904', N'CC206', N'LOXOM', CAST(N'2018-10-18T00:00:00.000' AS DateTime), CAST(N'2018-10-18T00:00:00.000' AS DateTime), 5, 94.27)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5926', N'CC206', N'EQUILEX', CAST(N'2018-09-25T00:00:00.000' AS DateTime), CAST(N'2018-10-05T00:00:00.000' AS DateTime), 5, 5180)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5941', N'CC206', N'XL ME', CAST(N'2018-10-15T00:00:00.000' AS DateTime), CAST(N'2018-10-15T00:00:00.000' AS DateTime), 5, 678)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5942', N'CC206', N'BEHN', CAST(N'2018-10-18T00:00:00.000' AS DateTime), CAST(N'2018-10-18T00:00:00.000' AS DateTime), 5, 738.9)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5944', N'CC206', N'CCARM', CAST(N'2018-10-17T00:00:00.000' AS DateTime), CAST(N'2018-10-30T00:00:00.000' AS DateTime), 5, 1243.6)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5968', N'CC206', N'LEMEUR', CAST(N'2018-10-16T00:00:00.000' AS DateTime), CAST(N'2018-11-17T00:00:00.000' AS DateTime), 5, 3897.1)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5969', N'CC206', N'CARRIE', CAST(N'2018-10-18T00:00:00.000' AS DateTime), CAST(N'2018-10-19T00:00:00.000' AS DateTime), 5, 1018.8)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5970', N'CC206', N'LEMEUR', CAST(N'2018-10-18T00:00:00.000' AS DateTime), CAST(N'2018-10-19T00:00:00.000' AS DateTime), 5, 6936)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5971', N'CC201', N'AVGE', CAST(N'2018-10-18T00:00:00.000' AS DateTime), CAST(N'2018-10-19T00:00:00.000' AS DateTime), 5, 13105)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5992', N'CC206', N'SEAR', CAST(N'2018-10-18T00:00:00.000' AS DateTime), CAST(N'2018-10-18T00:00:00.000' AS DateTime), 5, 8232)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-5993', N'CC206', N'AMPLI SERVICE', CAST(N'2018-10-22T00:00:00.000' AS DateTime), CAST(N'2018-10-22T00:00:00.000' AS DateTime), 5, 150.2)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6075', N'CC206', N'BEYO', CAST(N'2018-10-22T00:00:00.000' AS DateTime), CAST(N'2018-10-22T00:00:00.000' AS DateTime), 5, 1326)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6082', N'CC201', N'RHEAM', CAST(N'2018-10-23T00:00:00.000' AS DateTime), CAST(N'2018-10-23T00:00:00.000' AS DateTime), 5, 24966)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6085', N'CC206', N'BIGREAL', CAST(N'2018-10-24T00:00:00.000' AS DateTime), CAST(N'2018-10-24T00:00:00.000' AS DateTime), 5, 3996.18)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6133', N'CC206', N'CRA SF', CAST(N'2018-10-23T00:00:00.000' AS DateTime), CAST(N'2018-11-23T00:00:00.000' AS DateTime), 5, 2364.31)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6136', N'CC206', N'EQUILEX', CAST(N'2018-10-24T00:00:00.000' AS DateTime), CAST(N'2018-11-24T00:00:00.000' AS DateTime), 5, 604.23)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6137', N'CC206', N'BIGREAL', CAST(N'2018-10-24T00:00:00.000' AS DateTime), CAST(N'2018-11-23T00:00:00.000' AS DateTime), 5, 1541.76)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6139', N'CC206', N'CCARM', CAST(N'2018-10-24T00:00:00.000' AS DateTime), CAST(N'2018-10-25T00:00:00.000' AS DateTime), 5, 4200)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6180', N'CC206', N'BEYO', CAST(N'2018-10-24T00:00:00.000' AS DateTime), CAST(N'2018-10-30T00:00:00.000' AS DateTime), 5, 577.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6186', N'CC206', N'CARRIE', CAST(N'2018-10-24T00:00:00.000' AS DateTime), CAST(N'2018-10-24T00:00:00.000' AS DateTime), 5, 915.12)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6187', N'CC206', N'SM BO', CAST(N'2018-10-25T00:00:00.000' AS DateTime), CAST(N'2018-12-20T00:00:00.000' AS DateTime), 5, 1865.21)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6188', N'CC206', N'LEMEUR', CAST(N'2018-10-31T00:00:00.000' AS DateTime), CAST(N'2018-11-01T00:00:00.000' AS DateTime), 5, 437.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6482', N'CC206', N'CCARM', CAST(N'2018-11-05T00:00:00.000' AS DateTime), CAST(N'2018-11-06T00:00:00.000' AS DateTime), 5, 237.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6495', N'CC206', N'PHOENYX', CAST(N'2018-11-05T00:00:00.000' AS DateTime), CAST(N'2018-11-05T00:00:00.000' AS DateTime), 5, 907.2)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6538', N'CC201', N'RUDOL', CAST(N'2018-11-06T00:00:00.000' AS DateTime), CAST(N'2018-12-17T00:00:00.000' AS DateTime), 5, 1338.17)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6551', N'CC206', N'BEYO', CAST(N'2018-11-06T00:00:00.000' AS DateTime), CAST(N'2018-11-06T00:00:00.000' AS DateTime), 5, 995.808)
GO
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6586', N'CC206', N'LEMEUR', CAST(N'2018-11-09T00:00:00.000' AS DateTime), CAST(N'2018-12-11T00:00:00.000' AS DateTime), 5, 724)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6637', N'CC206', N'XL ME', CAST(N'2018-11-09T00:00:00.000' AS DateTime), CAST(N'2018-11-09T00:00:00.000' AS DateTime), 5, 1010)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6638', N'CC206', N'SM BO', CAST(N'2018-11-09T00:00:00.000' AS DateTime), CAST(N'2018-11-09T00:00:00.000' AS DateTime), 5, 71.48)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6651', N'CC206', N'AMPLI SERVICE', CAST(N'2018-11-07T00:00:00.000' AS DateTime), CAST(N'2018-11-07T00:00:00.000' AS DateTime), 5, 1942.404)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6652', N'CC206', N'EQUILEX', CAST(N'2018-11-09T00:00:00.000' AS DateTime), CAST(N'2018-11-09T00:00:00.000' AS DateTime), 5, 1061.6)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6787', N'CC206', N'CCARM', CAST(N'2018-11-14T00:00:00.000' AS DateTime), CAST(N'2018-11-15T00:00:00.000' AS DateTime), 5, 963.09)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6799', N'CC206', N'PNEUSS', CAST(N'2018-11-15T00:00:00.000' AS DateTime), CAST(N'2018-11-16T00:00:00.000' AS DateTime), 5, 137)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6846', N'CC206', N'AVGE', CAST(N'2018-10-16T00:00:00.000' AS DateTime), CAST(N'2018-11-06T00:00:00.000' AS DateTime), 5, 996.55)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6857', N'CC206', N'BIGREAL', CAST(N'2018-11-15T00:00:00.000' AS DateTime), CAST(N'2018-12-17T00:00:00.000' AS DateTime), 5, 226.58)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6933', N'CC206', N'AMPLI SERVICE', CAST(N'2018-11-19T00:00:00.000' AS DateTime), CAST(N'2018-11-19T00:00:00.000' AS DateTime), 5, 902)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-6982', N'CC206', N'CCARM', CAST(N'2018-11-19T00:00:00.000' AS DateTime), CAST(N'2018-11-20T00:00:00.000' AS DateTime), 5, 1324.15)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-7063', N'CC206', N'SNEA', CAST(N'2018-11-23T00:00:00.000' AS DateTime), CAST(N'2018-11-23T00:00:00.000' AS DateTime), 5, 212.95)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-7427', N'CC206', N'AMPLI SERVICE', CAST(N'2018-11-28T00:00:00.000' AS DateTime), CAST(N'2018-12-29T00:00:00.000' AS DateTime), 5, 431.8)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-762', N'CC206', N'BERNATO', CAST(N'2018-02-21T00:00:00.000' AS DateTime), CAST(N'2018-02-21T00:00:00.000' AS DateTime), 5, 4670)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-913', N'CC206', N'CAT AY', CAST(N'2018-02-27T00:00:00.000' AS DateTime), CAST(N'2018-02-27T00:00:00.000' AS DateTime), 5, 389.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-951', N'CC206', N'AUMALE', CAST(N'2018-03-01T00:00:00.000' AS DateTime), CAST(N'2018-03-02T00:00:00.000' AS DateTime), 5, 2961)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-978', N'CC206', N'BEYO', CAST(N'2018-03-05T00:00:00.000' AS DateTime), CAST(N'2018-03-11T00:00:00.000' AS DateTime), 5, 1400)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-997', N'CC206', N'CCARM', CAST(N'2018-03-05T00:00:00.000' AS DateTime), CAST(N'2018-03-26T00:00:00.000' AS DateTime), 5, 3638)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2018-998', N'CC206', N'GUERN', CAST(N'2018-03-06T00:00:00.000' AS DateTime), CAST(N'2018-03-07T00:00:00.000' AS DateTime), 5, 56.48)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-001', N'CC204', N'RUDOL', CAST(N'2019-01-02T00:00:00.000' AS DateTime), CAST(N'2019-01-31T00:00:00.000' AS DateTime), 5, 602.1256)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-002', N'CC204', N'AVGE', CAST(N'2019-01-02T00:00:00.000' AS DateTime), CAST(N'2019-03-03T00:00:00.000' AS DateTime), 5, 654.89)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-003', N'CC204', N'LEMEUR', CAST(N'2019-01-02T00:00:00.000' AS DateTime), CAST(N'2019-12-31T00:00:00.000' AS DateTime), 5, 1203.84)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-00358', N'CC204', N'LOGICO', CAST(N'2019-01-18T00:00:00.000' AS DateTime), CAST(N'2019-01-18T00:00:00.000' AS DateTime), 5, 3075.244)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-005', N'CC204', N'BIGREAL', CAST(N'2019-01-02T00:00:00.000' AS DateTime), CAST(N'2019-01-31T00:00:00.000' AS DateTime), 5, 876.31)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-006', N'CC204', N'AMPLI SERVICE', CAST(N'2019-01-01T00:00:00.000' AS DateTime), CAST(N'2019-02-17T00:00:00.000' AS DateTime), 5, 342.3)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-011', N'CC203', N'RUDOL', CAST(N'2019-02-04T00:00:00.000' AS DateTime), CAST(N'2019-03-05T00:00:00.000' AS DateTime), 5, 459.044)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-013', N'CC202', N'BIGREAL', CAST(N'2019-02-07T00:00:00.000' AS DateTime), CAST(N'2019-03-09T00:00:00.000' AS DateTime), 5, 747.43)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-014', N'CC204', N'BIGREAL', CAST(N'2019-02-07T00:00:00.000' AS DateTime), CAST(N'2019-03-24T00:00:00.000' AS DateTime), 5, 442.31)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-02028-30', N'CC202', N'LEMEUR', CAST(N'2019-02-04T00:00:00.000' AS DateTime), CAST(N'2020-02-02T00:00:00.000' AS DateTime), 5, 4782.94)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1019', N'CC203', N'ALSA NOVOS', CAST(N'2019-02-25T00:00:00.000' AS DateTime), CAST(N'2019-02-25T00:00:00.000' AS DateTime), 5, 460.76)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1020', N'CC204', N'ALSA NOVOS', CAST(N'2019-02-21T00:00:00.000' AS DateTime), CAST(N'2019-03-04T00:00:00.000' AS DateTime), 5, 333.16)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1198', N'C1000', N'BEYO', CAST(N'2019-03-06T00:00:00.000' AS DateTime), CAST(N'2019-03-12T00:00:00.000' AS DateTime), 5, 1666.039)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1199', N'CC204', N'BEYO', CAST(N'2019-03-11T00:00:00.000' AS DateTime), CAST(N'2019-03-11T00:00:00.000' AS DateTime), 5, 1222.88647)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1200', N'CC204', N'RSO', CAST(N'2019-03-06T00:00:00.000' AS DateTime), CAST(N'2019-03-07T00:00:00.000' AS DateTime), 5, 93.1)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1326', N'CC202', N'LEJEUNE', CAST(N'2019-03-06T00:00:00.000' AS DateTime), CAST(N'2019-04-06T00:00:00.000' AS DateTime), 5, 8197)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1327', N'CC203', N'CCARM', CAST(N'2019-02-20T00:00:00.000' AS DateTime), CAST(N'2019-04-22T00:00:00.000' AS DateTime), 5, 1597.7)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1328', N'CC204', N'MANUO', CAST(N'2019-03-07T00:00:00.000' AS DateTime), CAST(N'2019-03-07T00:00:00.000' AS DateTime), 5, 1379.308)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1349', N'CC202', N'SEAR', CAST(N'2019-03-06T00:00:00.000' AS DateTime), CAST(N'2019-03-06T00:00:00.000' AS DateTime), 5, 1073.76)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1350', N'CC202', N'TRAFIV', CAST(N'2019-03-06T00:00:00.000' AS DateTime), CAST(N'2019-03-06T00:00:00.000' AS DateTime), 5, 2720)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1351', N'CC202', N'AUMALE', CAST(N'2019-03-13T00:00:00.000' AS DateTime), CAST(N'2019-03-13T00:00:00.000' AS DateTime), 5, 1719)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1352', N'C1000', N'CAT BK', CAST(N'2019-03-13T00:00:00.000' AS DateTime), CAST(N'2019-03-14T00:00:00.000' AS DateTime), 5, 474)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1353', N'CC204', N'CCARM', CAST(N'2019-03-14T00:00:00.000' AS DateTime), CAST(N'2019-04-19T00:00:00.000' AS DateTime), 5, 589.9)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1354', N'CC204', N'BIGREAL', CAST(N'2019-03-15T00:00:00.000' AS DateTime), CAST(N'2019-04-19T00:00:00.000' AS DateTime), 5, 310.97)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1357', N'CC202', N'BIGREAL', CAST(N'2019-03-20T00:00:00.000' AS DateTime), CAST(N'2019-04-21T00:00:00.000' AS DateTime), 5, 1235.52)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1418', N'CC202', N'MGSYS', CAST(N'2019-03-06T00:00:00.000' AS DateTime), CAST(N'2019-03-07T00:00:00.000' AS DateTime), 5, 2587.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1618', N'CC204', N'STRAM', CAST(N'2019-03-25T00:00:00.000' AS DateTime), CAST(N'2019-03-25T00:00:00.000' AS DateTime), 5, 529.92)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1619', N'CC301', N'DALLIER', CAST(N'2019-02-25T00:00:00.000' AS DateTime), CAST(N'2019-02-25T00:00:00.000' AS DateTime), 5, 1855)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1628', N'CC301', N'CNSO', CAST(N'2019-01-02T00:00:00.000' AS DateTime), CAST(N'2019-01-31T00:00:00.000' AS DateTime), 5, 8675)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1630', N'CC301', N'AUMALE', CAST(N'2019-03-06T00:00:00.000' AS DateTime), CAST(N'2019-03-07T00:00:00.000' AS DateTime), 5, 7448)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1631', N'CC301', N'LEMEUR', CAST(N'2019-02-19T00:00:00.000' AS DateTime), CAST(N'2019-03-23T00:00:00.000' AS DateTime), 5, 1814.59)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1670', N'CC202', N'TPDO', CAST(N'2019-03-28T00:00:00.000' AS DateTime), CAST(N'2019-03-28T00:00:00.000' AS DateTime), 5, 530)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1671', N'CC202', N'BIGREAL', CAST(N'2019-03-26T00:00:00.000' AS DateTime), CAST(N'2019-03-27T00:00:00.000' AS DateTime), 5, 835.55)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1673', N'CC204', N'MANUO', CAST(N'2019-04-03T00:00:00.000' AS DateTime), CAST(N'2019-04-03T00:00:00.000' AS DateTime), 5, 794.55)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1735', N'CC204', N'LEMEUR', CAST(N'2019-02-20T00:00:00.000' AS DateTime), CAST(N'2019-03-24T00:00:00.000' AS DateTime), 5, 1850.06)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1736', N'CC301', N'LEMEUR', CAST(N'2019-03-06T00:00:00.000' AS DateTime), CAST(N'2019-03-07T00:00:00.000' AS DateTime), 5, 7320)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1760', N'CC204', N'AMPLI SERVICE', CAST(N'2019-03-25T00:00:00.000' AS DateTime), CAST(N'2019-05-25T00:00:00.000' AS DateTime), 5, 2274.4)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1765', N'CC202', N'TETRADEC', CAST(N'2019-04-03T00:00:00.000' AS DateTime), CAST(N'2019-04-03T00:00:00.000' AS DateTime), 5, 140)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1766', N'C1000', N'SM BO', CAST(N'2019-04-02T00:00:00.000' AS DateTime), CAST(N'2019-04-21T00:00:00.000' AS DateTime), 5, 562.66)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1966', N'CC204', N'NICOLI', CAST(N'2019-04-09T00:00:00.000' AS DateTime), CAST(N'2019-04-10T00:00:00.000' AS DateTime), 5, 1250)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-1975', N'CC204', N'NICOLI', CAST(N'2019-04-09T00:00:00.000' AS DateTime), CAST(N'2019-04-09T00:00:00.000' AS DateTime), 5, 470)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2012', N'CC204', N'HERRMO', CAST(N'2019-04-10T00:00:00.000' AS DateTime), CAST(N'2019-04-10T00:00:00.000' AS DateTime), 5, 384.3532)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-2029', N'CC301', N'DALLIER', CAST(N'2019-04-10T00:00:00.000' AS DateTime), CAST(N'2019-04-10T00:00:00.000' AS DateTime), 5, 1770.73)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2030', N'CC301', N'LEMEUR', CAST(N'2019-04-11T00:00:00.000' AS DateTime), CAST(N'2019-04-12T00:00:00.000' AS DateTime), 5, 1144.09)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-2031', N'CC204', N'RUDOL', CAST(N'2019-02-25T00:00:00.000' AS DateTime), CAST(N'2019-04-07T00:00:00.000' AS DateTime), 5, 756.5592)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2077', N'CC202', N'LEMEUR', CAST(N'2019-04-12T00:00:00.000' AS DateTime), CAST(N'2019-05-14T00:00:00.000' AS DateTime), 5, 3049.76)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2080', N'CC204', N'AMPLI SERVICE', CAST(N'2019-04-15T00:00:00.000' AS DateTime), CAST(N'2019-04-25T00:00:00.000' AS DateTime), 5, 1299.72)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2162', N'CC202', N'ELTYCH', CAST(N'2019-04-15T00:00:00.000' AS DateTime), CAST(N'2019-04-15T00:00:00.000' AS DateTime), 5, 1405.103)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2163', N'CC204', N'AMPLI SERVICE', CAST(N'2019-04-12T00:00:00.000' AS DateTime), CAST(N'2019-04-23T00:00:00.000' AS DateTime), 5, 471.29)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2228', N'CC204', N'LOGICO', CAST(N'2019-04-17T00:00:00.000' AS DateTime), CAST(N'2019-04-29T00:00:00.000' AS DateTime), 5, 3364.6)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2229', N'CC303', N'ACM DIFFUSION', CAST(N'2019-04-17T00:00:00.000' AS DateTime), CAST(N'2019-04-18T00:00:00.000' AS DateTime), 5, 2540.83)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2234', N'CC204', N'BEYO', CAST(N'2019-04-17T00:00:00.000' AS DateTime), CAST(N'2019-04-17T00:00:00.000' AS DateTime), 5, 7213)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--22897', N'CC204', N'BEYO', CAST(N'2019-05-20T00:00:00.000' AS DateTime), CAST(N'2019-05-28T00:00:00.000' AS DateTime), 5, 3084.99)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2314', N'CC204', N'RECAM', CAST(N'2019-04-26T00:00:00.000' AS DateTime), CAST(N'2019-05-04T00:00:00.000' AS DateTime), 5, 3161.755)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2315', N'CC203', N'CCARM', CAST(N'2019-04-26T00:00:00.000' AS DateTime), CAST(N'2019-04-27T00:00:00.000' AS DateTime), 5, 296.06)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2315bis', N'CC204', N'CCARM', CAST(N'2019-04-26T00:00:00.000' AS DateTime), CAST(N'2019-04-27T00:00:00.000' AS DateTime), 5, 439)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2316', N'CC204', N'LEMEUR', CAST(N'2019-04-26T00:00:00.000' AS DateTime), CAST(N'2019-05-27T00:00:00.000' AS DateTime), 5, 1343.72)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2317', N'CC204', N'AMPLI SERVICE', CAST(N'2019-04-29T00:00:00.000' AS DateTime), CAST(N'2019-05-30T00:00:00.000' AS DateTime), 5, 1580.03)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2318', N'CC204', N'RUDOL', CAST(N'2019-04-30T00:00:00.000' AS DateTime), CAST(N'2019-06-10T00:00:00.000' AS DateTime), 5, 171.532)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-2319', N'CC301', N'RHEAM', CAST(N'2019-03-20T00:00:00.000' AS DateTime), CAST(N'2019-07-20T00:00:00.000' AS DateTime), 5, 3821)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2319', N'CC203', N'RUDOL', CAST(N'2019-04-30T00:00:00.000' AS DateTime), CAST(N'2019-04-30T00:00:00.000' AS DateTime), 5, 83.1666)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-2319bis', N'CC301', N'RHEAM', CAST(N'2019-03-20T00:00:00.000' AS DateTime), CAST(N'2019-07-20T00:00:00.000' AS DateTime), 5, 27225)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2320', N'CC204', N'AVGE', CAST(N'2019-05-02T00:00:00.000' AS DateTime), CAST(N'2019-05-14T00:00:00.000' AS DateTime), 5, 907.35)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2467', N'CC204', N'AMPLI SERVICE', CAST(N'2019-05-02T00:00:00.000' AS DateTime), CAST(N'2019-05-02T00:00:00.000' AS DateTime), 5, 1405)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2468', N'CC204', N'HAPPY', CAST(N'2019-05-02T00:00:00.000' AS DateTime), CAST(N'2019-05-02T00:00:00.000' AS DateTime), 5, 419.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2482', N'CC202', N'EQUILEX', CAST(N'2019-05-02T00:00:00.000' AS DateTime), CAST(N'2019-05-12T00:00:00.000' AS DateTime), 5, 7111.25)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-2483', N'CC204', N'EQUILEX', CAST(N'2019-01-24T00:00:00.000' AS DateTime), CAST(N'2019-02-03T00:00:00.000' AS DateTime), 5, 1863.44)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2526', N'CC202', N'TETRADEC', CAST(N'2019-05-06T00:00:00.000' AS DateTime), CAST(N'2019-05-06T00:00:00.000' AS DateTime), 5, 330)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2528', N'CC204', N'BIGREAL', CAST(N'2019-05-10T00:00:00.000' AS DateTime), CAST(N'2019-05-10T00:00:00.000' AS DateTime), 5, 64.96)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2548', N'CC204', N'MANHATT', CAST(N'2019-05-06T00:00:00.000' AS DateTime), CAST(N'2019-05-06T00:00:00.000' AS DateTime), 5, 632)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2568', N'CC204', N'XL ME', CAST(N'2019-05-07T00:00:00.000' AS DateTime), CAST(N'2019-05-07T00:00:00.000' AS DateTime), 5, 240)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2569', N'CC204', N'ELTYCH', CAST(N'2019-05-07T00:00:00.000' AS DateTime), CAST(N'2019-05-07T00:00:00.000' AS DateTime), 5, 40.6368)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2602', N'CC206', N'CCARM', CAST(N'2019-05-10T00:00:00.000' AS DateTime), CAST(N'2019-07-10T00:00:00.000' AS DateTime), 5, 384)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2603', N'CC203', N'CCARM', CAST(N'2019-05-10T00:00:00.000' AS DateTime), CAST(N'2019-09-21T00:00:00.000' AS DateTime), 5, 3922)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2605', N'CC204', N'BIGREAL', CAST(N'2019-05-10T00:00:00.000' AS DateTime), CAST(N'2019-05-11T00:00:00.000' AS DateTime), 5, 634.63)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2608', N'CC204', N'BATIF', CAST(N'2019-05-14T00:00:00.000' AS DateTime), CAST(N'2019-05-28T00:00:00.000' AS DateTime), 5, 575.26)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2609', N'CC204', N'LEMEUR', CAST(N'2019-05-14T00:00:00.000' AS DateTime), CAST(N'2019-07-07T00:00:00.000' AS DateTime), 5, 1001.37)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2610', N'CC204', N'CCARM', CAST(N'2019-05-15T00:00:00.000' AS DateTime), CAST(N'2019-05-16T00:00:00.000' AS DateTime), 5, 1343.74)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2611', N'CC204', N'BIGREAL', CAST(N'2019-05-15T00:00:00.000' AS DateTime), CAST(N'2019-06-22T00:00:00.000' AS DateTime), 5, 230.785)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2621', N'CC204', N'RECAM', CAST(N'2019-05-06T00:00:00.000' AS DateTime), CAST(N'2019-05-07T00:00:00.000' AS DateTime), 5, 1499.995)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2635', N'CC302', N'CCARM', CAST(N'2019-05-10T00:00:00.000' AS DateTime), CAST(N'2019-05-11T00:00:00.000' AS DateTime), 5, 1350)
GO
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2679', N'CC204', N'RSO', CAST(N'2019-05-13T00:00:00.000' AS DateTime), CAST(N'2019-05-14T00:00:00.000' AS DateTime), 5, 1268.58)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2815', N'CC204', N'CCARM', CAST(N'2019-05-20T00:00:00.000' AS DateTime), CAST(N'2019-05-21T00:00:00.000' AS DateTime), 5, 675)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2815bis', N'CC204', N'CCARM', CAST(N'2019-05-16T00:00:00.000' AS DateTime), CAST(N'2019-06-21T00:00:00.000' AS DateTime), 5, 591.25)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2820', N'CC204', N'SODEA', CAST(N'2019-05-27T00:00:00.000' AS DateTime), CAST(N'2019-05-27T00:00:00.000' AS DateTime), 5, 234.96)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2898', N'CC303', N'CCARM', CAST(N'2019-05-23T00:00:00.000' AS DateTime), CAST(N'2019-05-24T00:00:00.000' AS DateTime), 5, 3640)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2939', N'CC204', N'ALSA NOVOS', CAST(N'2019-05-24T00:00:00.000' AS DateTime), CAST(N'2019-06-04T00:00:00.000' AS DateTime), 5, 632.14)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--2976', N'CC204', N'REXELY', CAST(N'2019-05-21T00:00:00.000' AS DateTime), CAST(N'2019-05-22T00:00:00.000' AS DateTime), 5, 314.712)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3010', N'CC204', N'RSO', CAST(N'2019-05-28T00:00:00.000' AS DateTime), CAST(N'2019-05-29T00:00:00.000' AS DateTime), 5, 348.43)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3029', N'CC204', N'ALSA NOVOS', CAST(N'2019-05-29T00:00:00.000' AS DateTime), CAST(N'2019-05-29T00:00:00.000' AS DateTime), 5, 300)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3030', N'CC204', N'POMPI', CAST(N'2019-06-03T00:00:00.000' AS DateTime), CAST(N'2019-06-04T00:00:00.000' AS DateTime), 5, 106.35)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3031', N'CC204', N'RUDOL', CAST(N'2019-06-03T00:00:00.000' AS DateTime), CAST(N'2019-06-03T00:00:00.000' AS DateTime), 5, 341.8)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3051', N'CC204', N'COTECHI', CAST(N'2019-06-03T00:00:00.000' AS DateTime), CAST(N'2019-06-03T00:00:00.000' AS DateTime), 5, 139)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3053', N'CC204', N'CCARM', CAST(N'2019-06-03T00:00:00.000' AS DateTime), CAST(N'2019-06-04T00:00:00.000' AS DateTime), 5, 1089.8)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3058', N'CC202', N'MGSYS', CAST(N'2019-06-05T00:00:00.000' AS DateTime), CAST(N'2019-07-05T00:00:00.000' AS DateTime), 5, 2887.04)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3060', N'CC202', N'CCARM', CAST(N'2019-06-03T00:00:00.000' AS DateTime), CAST(N'2019-07-03T00:00:00.000' AS DateTime), 5, 8200)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3061', N'CC301', N'TRAFIV', CAST(N'2019-05-22T00:00:00.000' AS DateTime), CAST(N'2019-06-22T00:00:00.000' AS DateTime), 5, 2720)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3072', N'CC301', N'PHOENYX', CAST(N'2019-06-04T00:00:00.000' AS DateTime), CAST(N'2019-06-04T00:00:00.000' AS DateTime), 5, 7930.591)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3073', N'CC202', N'EQUILEX', CAST(N'2019-05-22T00:00:00.000' AS DateTime), CAST(N'2019-06-22T00:00:00.000' AS DateTime), 5, 7111.25)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3171', N'CC202', N'CARRIE', CAST(N'2019-06-05T00:00:00.000' AS DateTime), CAST(N'2019-06-05T00:00:00.000' AS DateTime), 5, 490.9012)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3172', N'CC202', N'GUERN', CAST(N'2019-06-07T00:00:00.000' AS DateTime), CAST(N'2019-07-04T00:00:00.000' AS DateTime), 5, 724.858)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3172b', N'CC202', N'GUERN', CAST(N'2019-06-05T00:00:00.000' AS DateTime), CAST(N'2019-07-02T00:00:00.000' AS DateTime), 5, 729.512)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3233', N'CC301', N'LEMEUR', CAST(N'2019-06-04T00:00:00.000' AS DateTime), CAST(N'2019-06-05T00:00:00.000' AS DateTime), 5, 7320)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3234', N'CC301', N'AUMALE', CAST(N'2019-06-12T00:00:00.000' AS DateTime), CAST(N'2019-06-13T00:00:00.000' AS DateTime), 5, 7448)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3235', N'CC204', N'BIGREAL', CAST(N'2019-06-12T00:00:00.000' AS DateTime), CAST(N'2019-07-14T00:00:00.000' AS DateTime), 5, 531.67)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3240', N'CC204', N'EQUILEX', CAST(N'2019-06-18T00:00:00.000' AS DateTime), CAST(N'2019-07-19T00:00:00.000' AS DateTime), 5, 1080.432)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--33269', N'CC301', N'LEMEUR', CAST(N'2019-06-04T00:00:00.000' AS DateTime), CAST(N'2019-06-05T00:00:00.000' AS DateTime), 5, 859.36)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3330', N'C1000', N'SM BO', CAST(N'2019-06-12T00:00:00.000' AS DateTime), CAST(N'2019-07-02T00:00:00.000' AS DateTime), 5, 721.41)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3331', N'CC204', N'RECAM', CAST(N'2019-06-17T00:00:00.000' AS DateTime), CAST(N'2019-06-18T00:00:00.000' AS DateTime), 5, 1485.102)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3332', N'CC204', N'CCARM', CAST(N'2019-06-17T00:00:00.000' AS DateTime), CAST(N'2019-06-18T00:00:00.000' AS DateTime), 5, 1194)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3402', N'C1000', N'SM BO', CAST(N'2019-06-18T00:00:00.000' AS DateTime), CAST(N'2019-07-02T00:00:00.000' AS DateTime), 5, 992.95)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3404', N'CC203', N'ALSA NOVOS', CAST(N'2019-06-21T00:00:00.000' AS DateTime), CAST(N'2019-06-21T00:00:00.000' AS DateTime), 5, 397.44)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3483', N'CC202', N'AMPLI SERVICE', CAST(N'2019-06-21T00:00:00.000' AS DateTime), CAST(N'2019-06-21T00:00:00.000' AS DateTime), 5, 2190)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3484', N'CC204', N'AMPLI SERVICE', CAST(N'2019-06-25T00:00:00.000' AS DateTime), CAST(N'2019-07-06T00:00:00.000' AS DateTime), 5, 492.46)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3485', N'CC204', N'RUDOL', CAST(N'2019-07-01T00:00:00.000' AS DateTime), CAST(N'2019-08-11T00:00:00.000' AS DateTime), 5, 212.15)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3614', N'CC204', N'CCARM', CAST(N'2019-07-01T00:00:00.000' AS DateTime), CAST(N'2019-07-02T00:00:00.000' AS DateTime), 5, 373.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3615', N'CC301', N'COMMENDOR', CAST(N'2019-07-01T00:00:00.000' AS DateTime), CAST(N'2019-07-01T00:00:00.000' AS DateTime), 5, 1297)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3616', N'CC204', N'RUDOL', CAST(N'2019-07-01T00:00:00.000' AS DateTime), CAST(N'2019-07-01T00:00:00.000' AS DateTime), 5, 530.8608)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3620', N'CC301', N'LEMEUR', CAST(N'2019-07-01T00:00:00.000' AS DateTime), CAST(N'2019-07-02T00:00:00.000' AS DateTime), 5, 1180)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3621', N'CC204', N'AVGE', CAST(N'2019-07-03T00:00:00.000' AS DateTime), CAST(N'2019-07-15T00:00:00.000' AS DateTime), 5, 716.42)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3683', N'CC204', N'NICOLI', CAST(N'2019-07-03T00:00:00.000' AS DateTime), CAST(N'2019-07-04T00:00:00.000' AS DateTime), 5, 145)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3685', N'CC204', N'BILLIAUX', CAST(N'2019-07-05T00:00:00.000' AS DateTime), CAST(N'2019-07-06T00:00:00.000' AS DateTime), 5, 119.97)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3820', N'CC204', N'RSO', CAST(N'2019-07-08T00:00:00.000' AS DateTime), CAST(N'2019-07-09T00:00:00.000' AS DateTime), 5, 57.44)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3829', N'CC204', N'AVGE', CAST(N'2019-07-05T00:00:00.000' AS DateTime), CAST(N'2019-08-01T00:00:00.000' AS DateTime), 5, 1215.22)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3835', N'CC301', N'LEMEUR', CAST(N'2019-07-08T00:00:00.000' AS DateTime), CAST(N'2020-07-05T00:00:00.000' AS DateTime), 5, 3184.3)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3836', N'CC204', N'LEMEUR', CAST(N'2019-07-08T00:00:00.000' AS DateTime), CAST(N'2019-08-31T00:00:00.000' AS DateTime), 5, 523.69)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3860', N'CC204', N'LEMEUR', CAST(N'2019-07-08T00:00:00.000' AS DateTime), CAST(N'2019-07-09T00:00:00.000' AS DateTime), 5, 796.11)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3958', N'CC202', N'DICTEP', CAST(N'2019-07-10T00:00:00.000' AS DateTime), CAST(N'2019-07-10T00:00:00.000' AS DateTime), 5, 860)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3967', N'CC204', N'BOUVV', CAST(N'2019-07-10T00:00:00.000' AS DateTime), CAST(N'2019-07-10T00:00:00.000' AS DateTime), 5, 25.02)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--3968', N'CC204', N'ETEX', CAST(N'2019-07-10T00:00:00.000' AS DateTime), CAST(N'2019-07-10T00:00:00.000' AS DateTime), 5, 52.37)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4005', N'CC204', N'LEMEUR', CAST(N'2019-07-10T00:00:00.000' AS DateTime), CAST(N'2019-07-11T00:00:00.000' AS DateTime), 5, 3316.4)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4006', N'C1000', N'SM BO', CAST(N'2019-07-15T00:00:00.000' AS DateTime), CAST(N'2019-07-15T00:00:00.000' AS DateTime), 5, 446.98)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4008', N'CC204', N'RUDOL', CAST(N'2019-07-16T00:00:00.000' AS DateTime), CAST(N'2019-07-16T00:00:00.000' AS DateTime), 5, 53.56)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4009', N'CC204', N'RUDOL', CAST(N'2019-07-19T00:00:00.000' AS DateTime), CAST(N'2019-07-19T00:00:00.000' AS DateTime), 5, 156.29)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4010', N'CC204', N'OUEST SYS', CAST(N'2019-07-19T00:00:00.000' AS DateTime), CAST(N'2019-07-19T00:00:00.000' AS DateTime), 5, 305.85)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4011', N'CC102', N'SCHERM', CAST(N'2019-07-23T00:00:00.000' AS DateTime), CAST(N'2019-07-23T00:00:00.000' AS DateTime), 5, 85.96)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4012', N'CC101', N'COMPLEC', CAST(N'2019-07-23T00:00:00.000' AS DateTime), CAST(N'2019-07-24T00:00:00.000' AS DateTime), 5, 47.76)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4013', N'CC101', N'COMPLEC', CAST(N'2019-07-23T00:00:00.000' AS DateTime), CAST(N'2019-07-24T00:00:00.000' AS DateTime), 5, 813.135)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4014', N'CC102', N'COMPLEC', CAST(N'2019-07-23T00:00:00.000' AS DateTime), CAST(N'2019-07-24T00:00:00.000' AS DateTime), 5, 129.81)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4015', N'CC102', N'DISTRILAIX', CAST(N'2019-07-23T00:00:00.000' AS DateTime), CAST(N'2019-07-23T00:00:00.000' AS DateTime), 5, 249.6)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4016', N'CC101', N'REXELOX', CAST(N'2019-07-23T00:00:00.000' AS DateTime), CAST(N'2019-07-24T00:00:00.000' AS DateTime), 5, 192)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4017', N'CC101', N'EFRAPP', CAST(N'2019-07-23T00:00:00.000' AS DateTime), CAST(N'2019-07-24T00:00:00.000' AS DateTime), 5, 2780.6)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4018', N'CC102', N'KLEINNE', CAST(N'2019-07-23T00:00:00.000' AS DateTime), CAST(N'2019-07-23T00:00:00.000' AS DateTime), 5, 604)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4019', N'CC102', N'AMPLI SERVICE', CAST(N'2019-07-23T00:00:00.000' AS DateTime), CAST(N'2019-07-23T00:00:00.000' AS DateTime), 5, 350.04)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4020', N'CC102', N'KLEINNE', CAST(N'2019-07-23T00:00:00.000' AS DateTime), CAST(N'2019-07-23T00:00:00.000' AS DateTime), 5, 724.8)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4021', N'CC101', N'AIR SOFT', CAST(N'2019-07-23T00:00:00.000' AS DateTime), CAST(N'2019-07-24T00:00:00.000' AS DateTime), 5, 81.39)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4022', N'CC101', N'RSO', CAST(N'2019-07-23T00:00:00.000' AS DateTime), CAST(N'2019-07-24T00:00:00.000' AS DateTime), 5, 6.9)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4023', N'CC101', N'AVNI', CAST(N'2019-07-23T00:00:00.000' AS DateTime), CAST(N'2019-07-23T00:00:00.000' AS DateTime), 5, 2824.88)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4024', N'CC302', N'BERVELLER', CAST(N'2019-07-23T00:00:00.000' AS DateTime), CAST(N'2019-07-23T00:00:00.000' AS DateTime), 5, 1180.68)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4025', N'CC104', N'BERVELLER', CAST(N'2019-07-23T00:00:00.000' AS DateTime), CAST(N'2019-07-23T00:00:00.000' AS DateTime), 5, 539.08)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4268', N'CC204', N'LEMEUR', CAST(N'2019-07-16T00:00:00.000' AS DateTime), CAST(N'2019-08-17T00:00:00.000' AS DateTime), 5, 1261.775)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4291', N'CC102', N'RECAM', CAST(N'2019-07-23T00:00:00.000' AS DateTime), CAST(N'2019-07-28T00:00:00.000' AS DateTime), 5, 49.35)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4295', N'CC204', N'AVGE', CAST(N'2019-07-24T00:00:00.000' AS DateTime), CAST(N'2019-08-19T00:00:00.000' AS DateTime), 5, 409.71)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4313', N'CC301', N'MGSYS', CAST(N'2019-07-24T00:00:00.000' AS DateTime), CAST(N'2019-07-25T00:00:00.000' AS DateTime), 5, 12994)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4314', N'CC301', N'TETRADEC', CAST(N'2019-07-24T00:00:00.000' AS DateTime), CAST(N'2019-07-24T00:00:00.000' AS DateTime), 5, 11735.06)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4315', N'CC301', N'TETRADEC', CAST(N'2019-07-24T00:00:00.000' AS DateTime), CAST(N'2019-07-24T00:00:00.000' AS DateTime), 5, 11427.24)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4316', N'CC301', N'PHOENYX', CAST(N'2019-07-24T00:00:00.000' AS DateTime), CAST(N'2019-07-24T00:00:00.000' AS DateTime), 5, 4172.66846)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4317', N'CC301', N'AUMALE', CAST(N'2019-07-24T00:00:00.000' AS DateTime), CAST(N'2019-07-25T00:00:00.000' AS DateTime), 5, 5336)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4318', N'CC204', N'LEMEUR', CAST(N'2019-07-24T00:00:00.000' AS DateTime), CAST(N'2019-07-25T00:00:00.000' AS DateTime), 5, 518.4)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4322', N'CC102', N'AQUA OR', CAST(N'2019-07-29T00:00:00.000' AS DateTime), CAST(N'2019-07-29T00:00:00.000' AS DateTime), 5, 228)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4419', N'CC102', N'EQUILEX', CAST(N'2019-07-29T00:00:00.000' AS DateTime), CAST(N'2019-07-29T00:00:00.000' AS DateTime), 5, 647.5001)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4420', N'C1000', N'SM BO', CAST(N'2019-07-29T00:00:00.000' AS DateTime), CAST(N'2019-07-29T00:00:00.000' AS DateTime), 5, 166.92)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4439', N'CC201', N'EQUILEX', CAST(N'2019-07-29T00:00:00.000' AS DateTime), CAST(N'2019-07-29T00:00:00.000' AS DateTime), 5, 1856.93)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4467', N'CC204', N'FUCKLER', CAST(N'2019-07-29T00:00:00.000' AS DateTime), CAST(N'2019-10-29T00:00:00.000' AS DateTime), 5, 2388.858)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4476', N'CC102', N'BEYO', CAST(N'2019-07-31T00:00:00.000' AS DateTime), CAST(N'2019-07-31T00:00:00.000' AS DateTime), 5, 1872.45)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4477', N'CC102', N'JO FLEXCO', CAST(N'2019-08-01T00:00:00.000' AS DateTime), CAST(N'2019-08-01T00:00:00.000' AS DateTime), 5, 10.44)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4478', N'CC204', N'LEMEUR', CAST(N'2019-08-01T00:00:00.000' AS DateTime), CAST(N'2019-08-04T00:00:00.000' AS DateTime), 5, 739.9)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4480', N'CC204', N'ALSA NOVOS', CAST(N'2019-07-31T00:00:00.000' AS DateTime), CAST(N'2019-07-31T00:00:00.000' AS DateTime), 5, 1163.368)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4482', N'CC102', N'HERRMO', CAST(N'2019-07-31T00:00:00.000' AS DateTime), CAST(N'2019-07-31T00:00:00.000' AS DateTime), 5, 341.384)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4494', N'CC204', N'AMPLI SERVICE', CAST(N'2019-07-31T00:00:00.000' AS DateTime), CAST(N'2019-08-18T00:00:00.000' AS DateTime), 5, 1787.04)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4512', N'CC203', N'CCARM', CAST(N'2019-08-02T00:00:00.000' AS DateTime), CAST(N'2019-08-03T00:00:00.000' AS DateTime), 5, 307)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4513', N'CC102', N'REXELOX', CAST(N'2019-08-02T00:00:00.000' AS DateTime), CAST(N'2019-08-02T00:00:00.000' AS DateTime), 5, 552.2888)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--45241', N'CC301', N'ECSPSYS', CAST(N'2019-09-13T00:00:00.000' AS DateTime), CAST(N'2019-09-13T00:00:00.000' AS DateTime), 5, 780)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4549', N'CC204', N'CRA SF', CAST(N'2019-08-06T00:00:00.000' AS DateTime), CAST(N'2019-08-07T00:00:00.000' AS DateTime), 5, 1299.84)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4550', N'CC301', N'AUMALE', CAST(N'2019-08-06T00:00:00.000' AS DateTime), CAST(N'2019-08-07T00:00:00.000' AS DateTime), 5, 1090)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4562', N'CC204', N'BEYO', CAST(N'2019-08-06T00:00:00.000' AS DateTime), CAST(N'2019-08-06T00:00:00.000' AS DateTime), 5, 2676.9)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4590', N'CC102', N'HERRMO', CAST(N'2019-08-12T00:00:00.000' AS DateTime), CAST(N'2019-08-12T00:00:00.000' AS DateTime), 5, 243.56)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4591', N'CC102', N'AVGE', CAST(N'2019-08-13T00:00:00.000' AS DateTime), CAST(N'2019-09-14T00:00:00.000' AS DateTime), 5, 465.33)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4655', N'CC102', N'AMPLI SERVICE', CAST(N'2019-08-07T00:00:00.000' AS DateTime), CAST(N'2019-09-23T00:00:00.000' AS DateTime), 5, 1296.16)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4660', N'CC204', N'AMPLI SERVICE', CAST(N'2019-08-13T00:00:00.000' AS DateTime), CAST(N'2019-08-13T00:00:00.000' AS DateTime), 5, 1193.2)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4661', N'CC102', N'FUCKLER', CAST(N'2019-08-13T00:00:00.000' AS DateTime), CAST(N'2019-08-13T00:00:00.000' AS DateTime), 5, 348.168)
GO
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4662', N'CC102', N'CRA SF', CAST(N'2019-08-14T00:00:00.000' AS DateTime), CAST(N'2019-08-15T00:00:00.000' AS DateTime), 5, 1153.35)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4663', N'CC103', N'CCARM', CAST(N'2019-08-14T00:00:00.000' AS DateTime), CAST(N'2019-08-15T00:00:00.000' AS DateTime), 5, 204)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4664', N'CC102', N'JO FLEXCO', CAST(N'2019-08-19T00:00:00.000' AS DateTime), CAST(N'2019-08-19T00:00:00.000' AS DateTime), 5, 653.8349)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4665', N'CC101', N'BERVELLER', CAST(N'2019-08-19T00:00:00.000' AS DateTime), CAST(N'2019-08-19T00:00:00.000' AS DateTime), 5, 2035.68)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4666', N'CC103', N'ALSA NOVOS', CAST(N'2019-08-19T00:00:00.000' AS DateTime), CAST(N'2019-08-19T00:00:00.000' AS DateTime), 5, 704.99)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4667', N'CC102', N'AMPLI SERVICE', CAST(N'2019-08-19T00:00:00.000' AS DateTime), CAST(N'2019-08-19T00:00:00.000' AS DateTime), 5, 435.99)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4668', N'CC204', N'BEYO', CAST(N'2019-08-20T00:00:00.000' AS DateTime), CAST(N'2019-08-20T00:00:00.000' AS DateTime), 5, 6443.734)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4669', N'CC101', N'FUCKLER', CAST(N'2019-08-21T00:00:00.000' AS DateTime), CAST(N'2019-08-21T00:00:00.000' AS DateTime), 5, 325)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4670', N'CC101', N'CCARM', CAST(N'2019-08-21T00:00:00.000' AS DateTime), CAST(N'2019-08-22T00:00:00.000' AS DateTime), 5, 152)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4671', N'CC102', N'CRA SF', CAST(N'2019-08-21T00:00:00.000' AS DateTime), CAST(N'2019-08-22T00:00:00.000' AS DateTime), 5, 198.3)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4818', N'CC102', N'HERRMO', CAST(N'2019-08-22T00:00:00.000' AS DateTime), CAST(N'2019-08-22T00:00:00.000' AS DateTime), 5, 405.77)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4820', N'CC204', N'RUDOL', CAST(N'2019-08-27T00:00:00.000' AS DateTime), CAST(N'2019-08-28T00:00:00.000' AS DateTime), 5, 73.256)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4836', N'CC102', N'NOREM', CAST(N'2019-08-26T00:00:00.000' AS DateTime), CAST(N'2019-08-27T00:00:00.000' AS DateTime), 5, 452)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4884', N'CC102', N'BERAER', CAST(N'2019-08-28T00:00:00.000' AS DateTime), CAST(N'2019-08-28T00:00:00.000' AS DateTime), 5, 217.17)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4885', N'CC102', N'INTERF', CAST(N'2019-08-28T00:00:00.000' AS DateTime), CAST(N'2019-09-04T00:00:00.000' AS DateTime), 5, 567.6)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4886', N'CC102', N'FUCKLER', CAST(N'2019-08-28T00:00:00.000' AS DateTime), CAST(N'2019-09-25T00:00:00.000' AS DateTime), 5, 744.72)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4888', N'CC102', N'LEMEUR', CAST(N'2019-08-29T00:00:00.000' AS DateTime), CAST(N'2019-08-30T00:00:00.000' AS DateTime), 5, 717.6)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4889', N'CC101', N'VIOLAIX', CAST(N'2019-08-29T00:00:00.000' AS DateTime), CAST(N'2019-08-29T00:00:00.000' AS DateTime), 5, 260)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4893', N'CC201', N'THYSS', CAST(N'2019-08-29T00:00:00.000' AS DateTime), CAST(N'2019-08-29T00:00:00.000' AS DateTime), 5, 1407.68)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4908', N'CC204', N'ALSA NOVOS', CAST(N'2019-08-30T00:00:00.000' AS DateTime), CAST(N'2019-08-30T00:00:00.000' AS DateTime), 5, 409)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4910', N'CC204', N'CHIMIZ', CAST(N'2019-08-30T00:00:00.000' AS DateTime), CAST(N'2019-08-30T00:00:00.000' AS DateTime), 5, 1275.68)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4911', N'CC102', N'BERVELLER', CAST(N'2019-08-30T00:00:00.000' AS DateTime), CAST(N'2019-08-30T00:00:00.000' AS DateTime), 5, 559.72)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4912', N'CC102', N'RUDOL', CAST(N'2019-09-10T00:00:00.000' AS DateTime), CAST(N'2019-09-10T00:00:00.000' AS DateTime), 5, 18.9)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4913', N'CC101', N'EFRAPP', CAST(N'2019-09-10T00:00:00.000' AS DateTime), CAST(N'2019-09-11T00:00:00.000' AS DateTime), 5, 323.78)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4914', N'CC102', N'OUEST SYS', CAST(N'2019-09-11T00:00:00.000' AS DateTime), CAST(N'2019-09-11T00:00:00.000' AS DateTime), 5, 850.4)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4915', N'CC102', N'HOLTE', CAST(N'2019-09-11T00:00:00.000' AS DateTime), CAST(N'2019-09-11T00:00:00.000' AS DateTime), 5, 125)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4916', N'CC102', N'HAGER', CAST(N'2019-09-11T00:00:00.000' AS DateTime), CAST(N'2019-09-11T00:00:00.000' AS DateTime), 5, 435.48)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4917', N'CC102', N'BIOSYMBOLE', CAST(N'2019-09-11T00:00:00.000' AS DateTime), CAST(N'2019-09-11T00:00:00.000' AS DateTime), 5, 265)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4918', N'CC102', N'FRANK', CAST(N'2019-09-11T00:00:00.000' AS DateTime), CAST(N'2019-09-11T00:00:00.000' AS DateTime), 5, 749.06)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4919', N'CC102', N'AZIDO', CAST(N'2019-09-11T00:00:00.000' AS DateTime), CAST(N'2019-09-11T00:00:00.000' AS DateTime), 5, 834.1)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4921', N'CC102', N'CPEM', CAST(N'2019-09-11T00:00:00.000' AS DateTime), CAST(N'2019-09-11T00:00:00.000' AS DateTime), 5, 1230)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4922', N'CC102', N'CCARM', CAST(N'2019-09-11T00:00:00.000' AS DateTime), CAST(N'2019-09-12T00:00:00.000' AS DateTime), 5, 1005.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--4925', N'CC102', N'RUDOL', CAST(N'2019-09-16T00:00:00.000' AS DateTime), CAST(N'2019-09-16T00:00:00.000' AS DateTime), 5, 500.4492)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5242', N'CC301', N'COMMENDOR', CAST(N'2019-09-16T00:00:00.000' AS DateTime), CAST(N'2019-09-16T00:00:00.000' AS DateTime), 5, 8408)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5244', N'CC102', N'CCARM', CAST(N'2019-09-17T00:00:00.000' AS DateTime), CAST(N'2019-09-18T00:00:00.000' AS DateTime), 5, 1310.8)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5245', N'CC102', N'SODILO', CAST(N'2019-09-17T00:00:00.000' AS DateTime), CAST(N'2019-09-18T00:00:00.000' AS DateTime), 5, 604)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5246', N'CC102', N'OBERY', CAST(N'2019-09-17T00:00:00.000' AS DateTime), CAST(N'2019-09-17T00:00:00.000' AS DateTime), 5, 908)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5247', N'CC102', N'TRUMPE', CAST(N'2019-09-17T00:00:00.000' AS DateTime), CAST(N'2019-09-17T00:00:00.000' AS DateTime), 5, 789.45)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5248', N'CC101', N'VOVV', CAST(N'2019-09-17T00:00:00.000' AS DateTime), CAST(N'2019-09-17T00:00:00.000' AS DateTime), 5, 420)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5249', N'CC102', N'AGRIMATIC', CAST(N'2019-09-17T00:00:00.000' AS DateTime), CAST(N'2019-09-17T00:00:00.000' AS DateTime), 5, 670.4)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5250', N'CC102', N'WURTZ', CAST(N'2019-09-17T00:00:00.000' AS DateTime), CAST(N'2019-09-17T00:00:00.000' AS DateTime), 5, 1345.07)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5251', N'CC204', N'CCARM', CAST(N'2019-09-17T00:00:00.000' AS DateTime), CAST(N'2019-10-23T00:00:00.000' AS DateTime), 5, 482.1)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5252', N'CC204', N'LEMEUR', CAST(N'2019-09-17T00:00:00.000' AS DateTime), CAST(N'2019-09-18T00:00:00.000' AS DateTime), 5, 974.2123)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5253', N'CC204', N'AVGE', CAST(N'2019-09-17T00:00:00.000' AS DateTime), CAST(N'2019-10-19T00:00:00.000' AS DateTime), 5, 461.51)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5254', N'C1000', N'SM BO', CAST(N'2019-09-17T00:00:00.000' AS DateTime), CAST(N'2019-11-12T00:00:00.000' AS DateTime), 5, 867.99)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5255', N'CC101', N'EFRAPP', CAST(N'2019-09-18T00:00:00.000' AS DateTime), CAST(N'2019-09-19T00:00:00.000' AS DateTime), 5, 1569.82)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5256', N'CC102', N'LEMEUR', CAST(N'2019-09-18T00:00:00.000' AS DateTime), CAST(N'2019-09-19T00:00:00.000' AS DateTime), 5, 514)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5257', N'CC204', N'LEMEUR', CAST(N'2019-09-19T00:00:00.000' AS DateTime), CAST(N'2019-09-20T00:00:00.000' AS DateTime), 5, 293.89)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5258', N'CC301', N'LEMEUR', CAST(N'2019-09-19T00:00:00.000' AS DateTime), CAST(N'2019-09-20T00:00:00.000' AS DateTime), 5, 10100)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5259', N'CC204', N'RUDOL', CAST(N'2019-09-19T00:00:00.000' AS DateTime), CAST(N'2019-11-19T00:00:00.000' AS DateTime), 5, 85.8)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5260', N'CC204', N'CCARM', CAST(N'2019-09-19T00:00:00.000' AS DateTime), CAST(N'2019-10-19T00:00:00.000' AS DateTime), 5, 498.34)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5261', N'C1000', N'BECKEM', CAST(N'2019-09-26T00:00:00.000' AS DateTime), CAST(N'2019-09-26T00:00:00.000' AS DateTime), 5, 181.8)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5262', N'CC204', N'ALSA NOVOS', CAST(N'2019-09-26T00:00:00.000' AS DateTime), CAST(N'2019-09-26T00:00:00.000' AS DateTime), 5, 277.1)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5263', N'CC102', N'COMPLEC', CAST(N'2019-09-26T00:00:00.000' AS DateTime), CAST(N'2019-09-27T00:00:00.000' AS DateTime), 5, 79.17)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5264', N'CC102', N'HERRMO', CAST(N'2019-09-26T00:00:00.000' AS DateTime), CAST(N'2019-09-26T00:00:00.000' AS DateTime), 5, 227.53)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5265', NULL, N'EQUILEX', CAST(N'2019-09-26T00:00:00.000' AS DateTime), CAST(N'2019-09-26T00:00:00.000' AS DateTime), 5, 3429)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5266', NULL, N'LEMEUR', CAST(N'2019-09-27T00:00:00.000' AS DateTime), CAST(N'2019-10-28T00:00:00.000' AS DateTime), 3, 1106.8)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5267', NULL, N'AVGE', CAST(N'2019-09-27T00:00:00.000' AS DateTime), CAST(N'2019-10-29T00:00:00.000' AS DateTime), 5, 129.6)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5268', N'CC204', N'BECKEM', CAST(N'2019-09-27T00:00:00.000' AS DateTime), CAST(N'2019-09-28T00:00:00.000' AS DateTime), 5, 162.16)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5269', N'CC204', N'LEMEUR', CAST(N'2019-09-27T00:00:00.000' AS DateTime), CAST(N'2019-09-28T00:00:00.000' AS DateTime), 5, 205.6)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5270', N'CC105', N'CCARM', CAST(N'2019-09-30T00:00:00.000' AS DateTime), CAST(N'2019-10-01T00:00:00.000' AS DateTime), 5, 5200)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5271', N'CC102', N'BATIF', CAST(N'2019-09-30T00:00:00.000' AS DateTime), CAST(N'2019-09-30T00:00:00.000' AS DateTime), 5, 2734.58)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5273', N'CC102', N'AMPLI SERVICE', CAST(N'2019-09-30T00:00:00.000' AS DateTime), CAST(N'2019-10-18T00:00:00.000' AS DateTime), 5, 524.72)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5274', N'CC204', N'EQUILEX', CAST(N'2019-09-30T00:00:00.000' AS DateTime), CAST(N'2019-10-31T00:00:00.000' AS DateTime), 5, 995.52)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5275', N'CC204', N'AMPLI SERVICE', CAST(N'2019-10-01T00:00:00.000' AS DateTime), CAST(N'2019-11-01T00:00:00.000' AS DateTime), 5, 2535.854)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5276', N'CC204', N'RECAM', CAST(N'2019-10-01T00:00:00.000' AS DateTime), CAST(N'2019-10-03T00:00:00.000' AS DateTime), 5, 1235.77)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5277', N'CC103', N'CCARM', CAST(N'2019-10-01T00:00:00.000' AS DateTime), CAST(N'2019-10-02T00:00:00.000' AS DateTime), 3, 1590.84)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5278', N'CC103', N'CCARM', CAST(N'2019-10-02T00:00:00.000' AS DateTime), CAST(N'2019-10-03T00:00:00.000' AS DateTime), 5, 444)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5279', N'CC102', N'EQUILEX', CAST(N'2019-10-02T00:00:00.000' AS DateTime), CAST(N'2019-10-02T00:00:00.000' AS DateTime), 5, 965.1)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5280', N'CC204', N'AVGE', CAST(N'2019-10-02T00:00:00.000' AS DateTime), CAST(N'2019-12-01T00:00:00.000' AS DateTime), 5, 587.73)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5281', N'C1000', N'BEYO', CAST(N'2019-10-02T00:00:00.000' AS DateTime), CAST(N'2019-10-02T00:00:00.000' AS DateTime), 5, 1630.40955)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5282', N'CC204', N'ALSA NOVOS', CAST(N'2019-10-07T00:00:00.000' AS DateTime), CAST(N'2019-10-07T00:00:00.000' AS DateTime), 5, 404.82)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5283', N'CC204', N'BEYO', CAST(N'2019-10-08T00:00:00.000' AS DateTime), CAST(N'2019-10-08T00:00:00.000' AS DateTime), 5, 7946)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5284', N'CC203', N'GUERN', CAST(N'2019-10-08T00:00:00.000' AS DateTime), CAST(N'2019-10-09T00:00:00.000' AS DateTime), 5, 79.9)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5285', N'CC204', N'BIGREAL', CAST(N'2019-10-08T00:00:00.000' AS DateTime), CAST(N'2019-11-09T00:00:00.000' AS DateTime), 5, 685.84)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5287', N'CC102', N'RUDOL', CAST(N'2019-10-09T00:00:00.000' AS DateTime), CAST(N'2019-11-07T00:00:00.000' AS DateTime), 5, 127.74)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5288', N'CC102', N'LEMEUR', CAST(N'2019-09-16T00:00:00.000' AS DateTime), CAST(N'2019-09-17T00:00:00.000' AS DateTime), 5, 483.96)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5289', N'CC102', N'RECAM', CAST(N'2019-10-09T00:00:00.000' AS DateTime), CAST(N'2019-10-19T00:00:00.000' AS DateTime), 5, 1663.28)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5290', N'CC102', N'BEYO', CAST(N'2019-10-09T00:00:00.000' AS DateTime), CAST(N'2019-10-09T00:00:00.000' AS DateTime), 5, 7440.69)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5291', N'CC102', N'BIGREAL', CAST(N'2019-10-09T00:00:00.000' AS DateTime), CAST(N'2019-11-08T00:00:00.000' AS DateTime), 5, 156.69)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5292', N'CC204', N'RUDOL', CAST(N'2019-10-10T00:00:00.000' AS DateTime), CAST(N'2019-10-11T00:00:00.000' AS DateTime), 5, 550)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5293', N'CC102', N'AMPLI SERVICE', CAST(N'2019-10-14T00:00:00.000' AS DateTime), CAST(N'2019-10-28T00:00:00.000' AS DateTime), 5, 1355.82)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5295', N'CC102', N'BERVELLER', CAST(N'2019-10-14T00:00:00.000' AS DateTime), CAST(N'2019-10-14T00:00:00.000' AS DateTime), 5, 37.7)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5296', N'CC101', N'HENSEL', CAST(N'2019-10-15T00:00:00.000' AS DateTime), CAST(N'2019-10-15T00:00:00.000' AS DateTime), 5, 1267.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5297', N'CC204', N'REXELY', CAST(N'2019-10-15T00:00:00.000' AS DateTime), CAST(N'2019-10-16T00:00:00.000' AS DateTime), 5, 904.0084)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5298', N'CC102', N'ACM DIFFUSION', CAST(N'2019-10-16T00:00:00.000' AS DateTime), CAST(N'2019-10-17T00:00:00.000' AS DateTime), 5, 158.42)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5299', N'CC102', N'CCARM', CAST(N'2019-10-16T00:00:00.000' AS DateTime), CAST(N'2019-10-17T00:00:00.000' AS DateTime), 5, 1123)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5300', N'CC102', N'TRAFIV', CAST(N'2019-10-16T00:00:00.000' AS DateTime), CAST(N'2019-10-16T00:00:00.000' AS DateTime), 5, 540)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5301', N'CC301', N'DICTEP', CAST(N'2019-10-16T00:00:00.000' AS DateTime), CAST(N'2019-10-16T00:00:00.000' AS DateTime), 5, 4854)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5302', N'CC102', N'RUDOL', CAST(N'2019-10-17T00:00:00.000' AS DateTime), CAST(N'2019-10-17T00:00:00.000' AS DateTime), 5, 152.63)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5303', N'CC204', N'KEIMENEUR', CAST(N'2019-10-17T00:00:00.000' AS DateTime), CAST(N'2019-10-17T00:00:00.000' AS DateTime), 5, 86)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5304', N'CC102', N'HENSEL', CAST(N'2019-10-21T00:00:00.000' AS DateTime), CAST(N'2019-10-21T00:00:00.000' AS DateTime), 5, 900)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5305', N'CC102', N'HERRMO', CAST(N'2019-10-21T00:00:00.000' AS DateTime), CAST(N'2019-10-21T00:00:00.000' AS DateTime), 5, 324.574)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5306', N'CC102', N'LEMEUR', CAST(N'2019-10-21T00:00:00.000' AS DateTime), CAST(N'2019-10-22T00:00:00.000' AS DateTime), 5, 1764.3)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5307', N'CC102', N'RUDOL', CAST(N'2019-10-23T00:00:00.000' AS DateTime), CAST(N'2019-10-23T00:00:00.000' AS DateTime), 5, 38.7296)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5308', N'CC204', N'AVGE', CAST(N'2019-10-23T00:00:00.000' AS DateTime), CAST(N'2019-11-13T00:00:00.000' AS DateTime), 5, 3299.32)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5309', N'CC102', N'AVGE', CAST(N'2019-10-23T00:00:00.000' AS DateTime), CAST(N'2019-11-24T00:00:00.000' AS DateTime), 5, 883.71)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5310', N'CC204', N'BEYO', CAST(N'2019-10-23T00:00:00.000' AS DateTime), CAST(N'2019-10-23T00:00:00.000' AS DateTime), 5, 5092.675)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5311', N'CC204', N'SM BO', CAST(N'2019-10-23T00:00:00.000' AS DateTime), CAST(N'2019-11-20T00:00:00.000' AS DateTime), 5, 547.7)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5312', N'CC204', N'CCARM', CAST(N'2019-10-24T00:00:00.000' AS DateTime), CAST(N'2019-10-25T00:00:00.000' AS DateTime), 3, 1600)
GO
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5313', N'CC204', N'BIGREAL', CAST(N'2019-10-24T00:00:00.000' AS DateTime), CAST(N'2019-12-01T00:00:00.000' AS DateTime), 5, 1025.66)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5314', N'CC102', N'BATIF', CAST(N'2019-10-28T00:00:00.000' AS DateTime), CAST(N'2019-11-17T00:00:00.000' AS DateTime), 5, 368.38)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5315', N'CC102', N'CCARM', CAST(N'2019-10-28T00:00:00.000' AS DateTime), CAST(N'2019-10-29T00:00:00.000' AS DateTime), 5, 513.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5317', N'C1000', N'SM BO', CAST(N'2019-10-28T00:00:00.000' AS DateTime), CAST(N'2019-10-28T00:00:00.000' AS DateTime), 5, 520.76)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5318', N'CC204', N'BIGREAL', CAST(N'2019-10-28T00:00:00.000' AS DateTime), CAST(N'2019-10-29T00:00:00.000' AS DateTime), 5, 4730.4)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5319', N'CC204', N'HERRMO', CAST(N'2019-10-29T00:00:00.000' AS DateTime), CAST(N'2019-10-29T00:00:00.000' AS DateTime), 5, 308.6)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5320', N'CC102', N'AVNI', CAST(N'2019-11-04T00:00:00.000' AS DateTime), CAST(N'2019-11-04T00:00:00.000' AS DateTime), 5, 395.28)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5322', N'CC102', N'CRA BR', CAST(N'2019-11-04T00:00:00.000' AS DateTime), CAST(N'2019-11-04T00:00:00.000' AS DateTime), 5, 381.89)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5323', N'CC102', N'AMPLI SERVICE', CAST(N'2019-11-04T00:00:00.000' AS DateTime), CAST(N'2019-12-05T00:00:00.000' AS DateTime), 5, 879.072)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5324', N'CC103', N'CCARM', CAST(N'2019-11-04T00:00:00.000' AS DateTime), CAST(N'2019-12-04T00:00:00.000' AS DateTime), 5, 425.6)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5325', N'CC102', N'BEYO', CAST(N'2019-11-05T00:00:00.000' AS DateTime), CAST(N'2019-11-05T00:00:00.000' AS DateTime), 5, 2966.472)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5326', N'CC204', N'BIGREAL', CAST(N'2019-11-05T00:00:00.000' AS DateTime), CAST(N'2019-11-06T00:00:00.000' AS DateTime), 5, 3140.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5327', N'CC204', N'OUEST SYS', CAST(N'2019-11-05T00:00:00.000' AS DateTime), CAST(N'2019-11-05T00:00:00.000' AS DateTime), 5, 984.54)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5328', N'CC204', N'CCARM', CAST(N'2019-11-06T00:00:00.000' AS DateTime), CAST(N'2019-11-07T00:00:00.000' AS DateTime), 5, 799)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5329', N'CC103', N'RUDOL', CAST(N'2019-11-06T00:00:00.000' AS DateTime), CAST(N'2019-12-05T00:00:00.000' AS DateTime), 5, 2424.555)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5330', N'CC204', N'CCARM', CAST(N'2019-11-06T00:00:00.000' AS DateTime), CAST(N'2019-11-07T00:00:00.000' AS DateTime), 3, 1584.8)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5331', N'CC206', N'AVGE', CAST(N'2019-11-07T00:00:00.000' AS DateTime), CAST(N'2019-12-07T00:00:00.000' AS DateTime), 3, 539.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5332', N'CC204', N'LEMEUR', CAST(N'2019-11-07T00:00:00.000' AS DateTime), CAST(N'2019-11-12T00:00:00.000' AS DateTime), 5, 2780.67)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5333', N'CC204', N'RUDOL', CAST(N'2019-11-07T00:00:00.000' AS DateTime), CAST(N'2019-12-06T00:00:00.000' AS DateTime), 5, 2714.287)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5334', N'CC204', N'LEMEUR', CAST(N'2019-11-07T00:00:00.000' AS DateTime), CAST(N'2019-11-08T00:00:00.000' AS DateTime), 5, 1622.08)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5335', N'CC204', N'LEMEUR', CAST(N'2019-11-07T00:00:00.000' AS DateTime), CAST(N'2019-11-10T00:00:00.000' AS DateTime), 5, 1295.37)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5337', N'CC204', N'ALSA NOVOS', CAST(N'2019-11-13T00:00:00.000' AS DateTime), CAST(N'2019-11-13T00:00:00.000' AS DateTime), 5, 977.76)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5338', N'CC102', N'LEMEUR', CAST(N'2019-11-13T00:00:00.000' AS DateTime), CAST(N'2019-11-14T00:00:00.000' AS DateTime), 5, 670)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5339', N'CC102', N'CCARM', CAST(N'2019-11-18T00:00:00.000' AS DateTime), CAST(N'2019-11-25T00:00:00.000' AS DateTime), 5, 906)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5340', N'CC102', N'CPEM', CAST(N'2019-11-18T00:00:00.000' AS DateTime), CAST(N'2019-11-18T00:00:00.000' AS DateTime), 5, 1588)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5341', N'CC102', N'BEYO', CAST(N'2019-11-18T00:00:00.000' AS DateTime), CAST(N'2019-11-18T00:00:00.000' AS DateTime), 5, 3032.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5342', N'CC102', N'AVGE', CAST(N'2019-11-18T00:00:00.000' AS DateTime), CAST(N'2019-11-19T00:00:00.000' AS DateTime), 5, 89.87)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5343', N'CC204', N'EQUILEX', CAST(N'2019-11-18T00:00:00.000' AS DateTime), CAST(N'2019-11-28T00:00:00.000' AS DateTime), 3, 525.17)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5344', N'CC102', N'CCARM', CAST(N'2019-11-19T00:00:00.000' AS DateTime), CAST(N'2019-11-20T00:00:00.000' AS DateTime), 5, 245)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5345', N'CC103', N'OUEST SYS', CAST(N'2019-11-20T00:00:00.000' AS DateTime), CAST(N'2019-11-20T00:00:00.000' AS DateTime), 5, 984.54)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5346', N'CC103', N'RUDOL', CAST(N'2019-11-20T00:00:00.000' AS DateTime), CAST(N'2019-12-19T00:00:00.000' AS DateTime), 5, 685.26)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5347', N'CC102', N'HERRMO', CAST(N'2019-11-20T00:00:00.000' AS DateTime), CAST(N'2019-11-20T00:00:00.000' AS DateTime), 5, 26.166)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5348', N'CC102', N'COMPLEC', CAST(N'2019-11-20T00:00:00.000' AS DateTime), CAST(N'2019-11-21T00:00:00.000' AS DateTime), 5, 542.531)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5349', N'CC204', N'OUEST SYS', CAST(N'2019-11-21T00:00:00.000' AS DateTime), CAST(N'2019-11-21T00:00:00.000' AS DateTime), 5, 210.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5350', N'CC103', N'CCARM', CAST(N'2019-11-21T00:00:00.000' AS DateTime), CAST(N'2019-11-22T00:00:00.000' AS DateTime), 5, 330)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5351', N'CC204', N'LEMEUR', CAST(N'2019-11-21T00:00:00.000' AS DateTime), CAST(N'2019-12-23T00:00:00.000' AS DateTime), 5, 1410.57)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5352', N'CC102', N'CONTI', CAST(N'2019-11-26T00:00:00.000' AS DateTime), CAST(N'2019-11-26T00:00:00.000' AS DateTime), 5, 454.96)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5353', N'CC301', N'EQUILEX', CAST(N'2019-11-26T00:00:00.000' AS DateTime), CAST(N'2019-11-26T00:00:00.000' AS DateTime), 3, 5970)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5354', N'CC204', N'ALSA NOVOS', CAST(N'2019-11-26T00:00:00.000' AS DateTime), CAST(N'2019-11-26T00:00:00.000' AS DateTime), 5, 1348.11)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5355', N'CC102', N'EQUILEX', CAST(N'2019-11-27T00:00:00.000' AS DateTime), CAST(N'2019-11-27T00:00:00.000' AS DateTime), 5, 1672.92)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5356', N'CC102', N'BIGREAL', CAST(N'2019-12-02T00:00:00.000' AS DateTime), CAST(N'2020-01-10T00:00:00.000' AS DateTime), 3, 525.15)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5357', N'CC204', N'AMPLI SERVICE', CAST(N'2019-12-04T00:00:00.000' AS DateTime), CAST(N'2020-01-04T00:00:00.000' AS DateTime), 5, 3246.214)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5358', N'CC204', N'BIGREAL', CAST(N'2019-12-04T00:00:00.000' AS DateTime), CAST(N'2020-01-12T00:00:00.000' AS DateTime), 5, 1850.22)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5359', N'CC204', N'EQUILEX', CAST(N'2019-12-04T00:00:00.000' AS DateTime), CAST(N'2020-01-02T00:00:00.000' AS DateTime), 3, 2211.77)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5360', N'CC204', N'LEMEUR', CAST(N'2019-12-04T00:00:00.000' AS DateTime), CAST(N'2019-12-07T00:00:00.000' AS DateTime), 5, 2078.19)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019--5361', N'CC204', N'CCARM', CAST(N'2019-12-04T00:00:00.000' AS DateTime), CAST(N'2020-01-03T00:00:00.000' AS DateTime), 1, 3525.66)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-560', N'CC204', N'EMRAD', CAST(N'2019-02-12T00:00:00.000' AS DateTime), CAST(N'2019-02-12T00:00:00.000' AS DateTime), 5, 378.24)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-563', N'CC204', N'LORRAINE NATICA', CAST(N'2019-02-13T00:00:00.000' AS DateTime), CAST(N'2019-02-17T00:00:00.000' AS DateTime), 5, 114.457)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-600', N'CC203', N'CCARM', CAST(N'2019-02-12T00:00:00.000' AS DateTime), CAST(N'2019-04-02T00:00:00.000' AS DateTime), 5, 3638)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-601', N'CC204', N'HAPPY', CAST(N'2019-02-12T00:00:00.000' AS DateTime), CAST(N'2019-02-18T00:00:00.000' AS DateTime), 5, 811.97)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-602', N'C1000', N'PPGA', CAST(N'2019-02-06T00:00:00.000' AS DateTime), CAST(N'2019-02-15T00:00:00.000' AS DateTime), 5, 716.19)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-757', N'CC202', N'BIGREAL', CAST(N'2019-02-18T00:00:00.000' AS DateTime), CAST(N'2019-02-18T00:00:00.000' AS DateTime), 5, 947.64)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-763', N'CC204', N'HAPPY', CAST(N'2019-02-18T00:00:00.000' AS DateTime), CAST(N'2019-02-25T00:00:00.000' AS DateTime), 5, 617.88)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-764', N'CC204', N'INTERF', CAST(N'2019-02-18T00:00:00.000' AS DateTime), CAST(N'2019-02-25T00:00:00.000' AS DateTime), 5, 1267.6)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-765', N'CC204', N'BEYO', CAST(N'2019-02-18T00:00:00.000' AS DateTime), CAST(N'2019-02-25T00:00:00.000' AS DateTime), 5, 4339.752)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-770', N'CC204', N'AVGE', CAST(N'2019-02-20T00:00:00.000' AS DateTime), CAST(N'2019-02-21T00:00:00.000' AS DateTime), 5, 684.31)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-771', N'CC204', N'CCARM', CAST(N'2019-02-21T00:00:00.000' AS DateTime), CAST(N'2019-02-22T00:00:00.000' AS DateTime), 5, 501.4)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-776', N'CC204', N'EUROPE BN', CAST(N'2019-03-01T00:00:00.000' AS DateTime), CAST(N'2019-03-02T00:00:00.000' AS DateTime), 5, 271.35)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-827', N'CC204', N'OUEST SYS', CAST(N'2019-02-01T00:00:00.000' AS DateTime), CAST(N'2019-02-01T00:00:00.000' AS DateTime), 5, 403.95)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-887', N'CC203', N'CCARM', CAST(N'2019-02-21T00:00:00.000' AS DateTime), CAST(N'2019-02-22T00:00:00.000' AS DateTime), 5, 1227)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2019-889', N'CC204', N'BERGERY', CAST(N'2019-02-20T00:00:00.000' AS DateTime), CAST(N'2019-02-20T00:00:00.000' AS DateTime), 5, 469.55)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0002', N'CC204', N'AVGE', CAST(N'2020-01-01T00:00:00.000' AS DateTime), CAST(N'2019-12-11T00:00:00.000' AS DateTime), 3, 291.91)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0003', N'CC102', N'AVGE', CAST(N'2020-01-13T00:00:00.000' AS DateTime), CAST(N'2020-03-13T00:00:00.000' AS DateTime), 5, 915.7385)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020--0003', N'CC204', N'BIGREAL', CAST(N'2020-01-01T00:00:00.000' AS DateTime), CAST(N'2020-02-11T00:00:00.000' AS DateTime), 2, 788.35)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0004', N'CC204', N'LOGICO', CAST(N'2020-01-14T00:00:00.000' AS DateTime), CAST(N'2020-01-26T00:00:00.000' AS DateTime), 5, 2450.031)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0005', N'CC102', N'RUDOL', CAST(N'2020-01-15T00:00:00.000' AS DateTime), CAST(N'2020-01-15T00:00:00.000' AS DateTime), 3, 199.2896)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0006', N'CC102', N'BEYO', CAST(N'2020-01-15T00:00:00.000' AS DateTime), CAST(N'2020-01-15T00:00:00.000' AS DateTime), 5, 5191.69)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0007', N'CC204', N'RUDOL', CAST(N'2020-01-15T00:00:00.000' AS DateTime), CAST(N'2020-02-25T00:00:00.000' AS DateTime), 5, 635.619)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0008', N'CC102', N'LEMEUR', CAST(N'2020-01-15T00:00:00.000' AS DateTime), CAST(N'2020-02-15T00:00:00.000' AS DateTime), 3, 342.03)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0009', N'CC102', N'EVACU', CAST(N'2020-01-15T00:00:00.000' AS DateTime), CAST(N'2020-01-16T00:00:00.000' AS DateTime), 1, 128.3)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0010', N'CC204', N'LEMEUR', CAST(N'2020-01-15T00:00:00.000' AS DateTime), CAST(N'2020-01-16T00:00:00.000' AS DateTime), 5, 1401.65)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0011', N'CC204', N'CCARM', CAST(N'2020-01-15T00:00:00.000' AS DateTime), CAST(N'2020-01-16T00:00:00.000' AS DateTime), 5, 248)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0012', N'CC102', N'BERVELLER', CAST(N'2020-01-16T00:00:00.000' AS DateTime), CAST(N'2020-01-17T00:00:00.000' AS DateTime), 0, 1423.65)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0013', N'CC101', N'LEMEUR', CAST(N'2020-01-16T00:00:00.000' AS DateTime), CAST(N'2020-01-17T00:00:00.000' AS DateTime), 3, 2964.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0014', N'CC204', N'LEMEUR', CAST(N'2020-01-16T00:00:00.000' AS DateTime), CAST(N'2020-01-17T00:00:00.000' AS DateTime), 4, 514.83)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0015', N'CC102', N'HERRMO', CAST(N'2020-01-16T00:00:00.000' AS DateTime), CAST(N'2020-01-16T00:00:00.000' AS DateTime), 5, 425.52)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0016', N'CC101', N'LEMEUR', CAST(N'2020-01-16T00:00:00.000' AS DateTime), CAST(N'2020-02-16T00:00:00.000' AS DateTime), 4, 550)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0017', N'CC204', N'CRA SF', CAST(N'2020-01-16T00:00:00.000' AS DateTime), CAST(N'2020-01-17T00:00:00.000' AS DateTime), 5, 22.86)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0018', N'CC204', N'PNEUSS', CAST(N'2020-01-17T00:00:00.000' AS DateTime), CAST(N'2020-01-18T00:00:00.000' AS DateTime), 5, 131.82)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0019', N'CC102', N'BERVELLER', CAST(N'2020-01-17T00:00:00.000' AS DateTime), CAST(N'2020-01-17T00:00:00.000' AS DateTime), 5, 744.78)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0021', N'CC102', N'AMPLI SERVICE', CAST(N'2020-01-17T00:00:00.000' AS DateTime), CAST(N'2020-02-04T00:00:00.000' AS DateTime), 0, 3254.448)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0022', N'CC204', N'CCARM', CAST(N'2020-01-17T00:00:00.000' AS DateTime), CAST(N'2020-01-18T00:00:00.000' AS DateTime), 1, 462.4)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0023', N'CC102', N'AMPLI SERVICE', CAST(N'2020-01-20T00:00:00.000' AS DateTime), CAST(N'2020-01-29T00:00:00.000' AS DateTime), 5, 808.32)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0024', N'CC101', N'HOLTE', CAST(N'2020-01-21T00:00:00.000' AS DateTime), CAST(N'2020-01-21T00:00:00.000' AS DateTime), 5, 1678.26)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0025', N'CC102', N'AVGE', CAST(N'2020-01-22T00:00:00.000' AS DateTime), CAST(N'2020-01-23T00:00:00.000' AS DateTime), 3, 409.448)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0026', NULL, N'CCARM', CAST(N'2020-01-27T00:00:00.000' AS DateTime), CAST(N'2020-01-28T00:00:00.000' AS DateTime), 0, 3545.875)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0027', N'CC102', N'CPEM', CAST(N'2020-01-27T00:00:00.000' AS DateTime), CAST(N'2020-01-27T00:00:00.000' AS DateTime), 5, 2585)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0028', N'CC102', N'AVGE', CAST(N'2020-01-27T00:00:00.000' AS DateTime), CAST(N'2020-03-12T00:00:00.000' AS DateTime), 5, 491.61)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0029', N'CC102', N'BEYO', CAST(N'2020-01-27T00:00:00.000' AS DateTime), CAST(N'2020-01-27T00:00:00.000' AS DateTime), 5, 716.66)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0030', N'CC301', N'LEMEUR', CAST(N'2020-01-29T00:00:00.000' AS DateTime), CAST(N'2020-02-29T00:00:00.000' AS DateTime), 1, 808.68)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0031', NULL, N'XL ME', CAST(N'2020-01-29T00:00:00.000' AS DateTime), CAST(N'2020-01-30T00:00:00.000' AS DateTime), 1, 4896)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0032', N'CC204', N'ELTYCH', CAST(N'2020-01-30T00:00:00.000' AS DateTime), CAST(N'2020-01-30T00:00:00.000' AS DateTime), 5, 549.5)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0033', N'CC204', N'GUERN', CAST(N'2020-01-30T00:00:00.000' AS DateTime), CAST(N'2020-01-31T00:00:00.000' AS DateTime), 3, 2472.552)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0035', N'CC102', N'AMPLI SERVICE', CAST(N'2020-01-31T00:00:00.000' AS DateTime), CAST(N'2020-03-02T00:00:00.000' AS DateTime), 0, 1367.58)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0036', N'CC204', N'FUCKLER', CAST(N'2020-01-31T00:00:00.000' AS DateTime), CAST(N'2020-05-02T00:00:00.000' AS DateTime), 3, 814.92)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0037', N'CC102', N'BIGREAL', CAST(N'2020-01-31T00:00:00.000' AS DateTime), CAST(N'2020-02-01T00:00:00.000' AS DateTime), 3, 19.56)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0038', N'CC204', N'DALLIER', CAST(N'2020-01-31T00:00:00.000' AS DateTime), CAST(N'2020-01-31T00:00:00.000' AS DateTime), 1, 124.98)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0039', N'CC301', N'DALLIER', CAST(N'2020-01-31T00:00:00.000' AS DateTime), CAST(N'2020-01-31T00:00:00.000' AS DateTime), 1, 1500)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0040', N'CC204', N'COTECHI', CAST(N'2020-02-04T00:00:00.000' AS DateTime), CAST(N'2020-02-04T00:00:00.000' AS DateTime), 1, 648.46)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0041', N'CC203', N'RUDOL', CAST(N'2020-02-04T00:00:00.000' AS DateTime), CAST(N'2020-03-04T00:00:00.000' AS DateTime), 3, 653.84)
GO
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0042', N'CC202', N'TPDO', CAST(N'2020-02-04T00:00:00.000' AS DateTime), CAST(N'2020-02-04T00:00:00.000' AS DateTime), 5, 450)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0043', N'CC102', N'AMPLI SERVICE', CAST(N'2020-02-05T00:00:00.000' AS DateTime), CAST(N'2020-03-07T00:00:00.000' AS DateTime), 1, 1477.16)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0044', N'CC102', N'CCARM', CAST(N'2020-02-05T00:00:00.000' AS DateTime), CAST(N'2020-02-06T00:00:00.000' AS DateTime), 0, 77.325)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0045', N'CC102', N'HENSEL', CAST(N'2020-02-05T00:00:00.000' AS DateTime), CAST(N'2020-02-05T00:00:00.000' AS DateTime), 1, 286.25)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0046', N'CC102', N'LEMEUR', CAST(N'2020-02-05T00:00:00.000' AS DateTime), CAST(N'2020-02-06T00:00:00.000' AS DateTime), 1, 2344.34)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0047', N'CC204', N'LEMEUR', CAST(N'2020-02-05T00:00:00.000' AS DateTime), CAST(N'2020-02-06T00:00:00.000' AS DateTime), 3, 1002.03)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0049', N'CC204', N'AMPLI SERVICE', CAST(N'2020-02-06T00:00:00.000' AS DateTime), CAST(N'2020-03-08T00:00:00.000' AS DateTime), 1, 316.53)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0050', N'CC101', N'GRAVES', CAST(N'2020-02-06T00:00:00.000' AS DateTime), CAST(N'2020-02-06T00:00:00.000' AS DateTime), 2, 197.4)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0051', N'CC204', N'TETRADEC', CAST(N'2020-02-10T00:00:00.000' AS DateTime), CAST(N'2020-02-10T00:00:00.000' AS DateTime), 1, 290)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0052', N'CC103', N'DSCOM', CAST(N'2020-02-10T00:00:00.000' AS DateTime), CAST(N'2020-02-10T00:00:00.000' AS DateTime), 1, 492.96)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0053', N'CC101', N'REXELOX', CAST(N'2020-02-10T00:00:00.000' AS DateTime), CAST(N'2020-02-10T00:00:00.000' AS DateTime), 3, 955.77)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0054', N'CC101', N'SIEHRI', CAST(N'2020-02-11T00:00:00.000' AS DateTime), CAST(N'2020-02-11T00:00:00.000' AS DateTime), 1, 43.89)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0055', N'CC102', N'AMPLI SERVICE', CAST(N'2020-02-11T00:00:00.000' AS DateTime), CAST(N'2020-02-11T00:00:00.000' AS DateTime), 2, 260)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0056', N'CC204', N'RUDOL', CAST(N'2020-02-11T00:00:00.000' AS DateTime), CAST(N'2020-02-12T00:00:00.000' AS DateTime), 1, 538.8204)
INSERT [dbo].[COMMANDES] ([N_CDE], [ID_CC], [ID_TIERS], [DCDE], [DLIVRDEM], [ETAT_CDE], [MT_CDE]) VALUES (N'2020-0057', N'CC204', N'CAT AX', CAST(N'2020-02-12T00:00:00.000' AS DateTime), CAST(N'2020-02-13T00:00:00.000' AS DateTime), 1, 508.5)
GO

INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0006', 1, N'GAZ_BUT.VRAC', CAST(N'2018-01-05T00:00:00.000' AS DateTime), 1.383, 1504, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0007', 1, N'GAZO.', CAST(N'2018-01-05T00:00:00.000' AS DateTime), 1500, 1.168, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0027', 1, N'ECHA.TRIANGULAIRE', CAST(N'2018-01-11T00:00:00.000' AS DateTime), 4, 5, N'3401061439308')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0027', 2, N'COMP.STER10X10', CAST(N'2018-01-11T00:00:00.000' AS DateTime), 4, 2.083, N'315260012851')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0027', 3, N'GEL_ANTI-BRLURE', CAST(N'2018-01-11T00:00:00.000' AS DateTime), 2, 11.983, N'4054596043084')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0027', 4, N'SPRA.MOUST+TIQ', CAST(N'2018-01-11T00:00:00.000' AS DateTime), 5, 6.875, N'3401563309512')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0027', 5, N'STIC.APAISANT', CAST(N'2018-01-11T00:00:00.000' AS DateTime), 5, 4.083, N'3518646040498')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0027', 6, N'PINC.TIQUE', CAST(N'2018-01-11T00:00:00.000' AS DateTime), 35, 5.75, N'3595897217329')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0027', 7, N'DOLI.1G', CAST(N'2018-01-11T00:00:00.000' AS DateTime), 10, 2.135, N'3400935955838')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0029', 1, N'FEU_MARIL46237', CAST(N'2018-01-09T00:00:00.000' AS DateTime), 1, 308.25, N'L46237')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0029', 2, N'PORT', CAST(N'2018-01-13T00:00:00.000' AS DateTime), 1, 18.33, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0052', 2, N'BACH.3X5NYLON', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 2, 22.9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0052', 3, N'ELIN.EL2T2M', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 2, 4.75, N'TUB02T02M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0052', 4, N'ELIN.CH4X1.3ML8MM', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 1, 128, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0052', 5, N'MOUS.60MM', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 10, 1.15, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0052', 6, N'BACH.6X10NYLON', CAST(N'2018-01-11T00:00:00.000' AS DateTime), 3, 103.7, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0053', 1, N'LIQU.LRD_5L', CAST(N'2018-01-11T00:00:00.000' AS DateTime), 8, 15.438, N'600825164')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0053', 2, N'LIQU.LR30_20L', CAST(N'2018-01-11T00:00:00.000' AS DateTime), 3, 75.523, N'600824976')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0053', 3, N'HUIL.CHAINBIO1', CAST(N'2018-01-11T00:00:00.000' AS DateTime), 20, 9.878, N'600686130')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0053', 4, N'HUIL.CHAINBIO5', CAST(N'2018-02-08T00:00:00.000' AS DateTime), 4, 36.8125, N'600389147')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0101', 1, N'FICH.BRISTOL125/200', CAST(N'2018-01-15T00:00:00.000' AS DateTime), 1, 3.8, N'13638')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0101', 2, N'ATTA.CASE3S', CAST(N'2018-01-15T00:00:00.000' AS DateTime), 2, 30, N'33952')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0101', 3, N'RUBA.AB', CAST(N'2018-01-15T00:00:00.000' AS DateTime), 8, 1.55, N'18270')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0101', 4, N'CART.BROLC980CN', CAST(N'2018-01-15T00:00:00.000' AS DateTime), 2, 12.46, N'75470')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0101', 5, N'CART.BROTN241BK', CAST(N'2018-01-15T00:00:00.000' AS DateTime), 3, 50.23, N'23120')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0101', 6, N'CART.BROTN241C', CAST(N'2018-01-15T00:00:00.000' AS DateTime), 3, 49.81, N'23122')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0101', 7, N'CART.BROTN241M', CAST(N'2018-01-15T00:00:00.000' AS DateTime), 3, 49.81, N'23123')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0101', 8, N'CART.BROTN241Y', CAST(N'2018-01-15T00:00:00.000' AS DateTime), 3, 49.81, N'23124')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0101', 9, N'BOUI.ELEC', CAST(N'2018-01-15T00:00:00.000' AS DateTime), 1, 22.9, N'21531')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0101', 10, N'TAMP.A_FACON', CAST(N'2018-01-15T00:00:00.000' AS DateTime), 1, 71.84, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0101', 11, N'CACH.DB1L+DAT', CAST(N'2018-01-15T00:00:00.000' AS DateTime), 1, 42, N'39175')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0101', 12, N'ETIQ.A70X32ROUGE', CAST(N'2018-01-15T00:00:00.000' AS DateTime), 1, 14.65, N'24289')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0249', 1, N'SAC_KAR69074790', CAST(N'2017-11-23T00:00:00.000' AS DateTime), 5, 21, N'KAR69074790')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0249', 2, N'AMPO.NAVE12V5W', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 10, 1.3, N'OSRA6418')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0249', 3, N'VERR.105X50I', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 10, 0.385, N'SAFW000335018')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0249', 4, N'FREI.FIL.LOCT271', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 1, 36.66, N'LOCT282850')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0249', 5, N'FILT.HIFSA12922', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 2, 13.32, N'HIFI SA12922')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0249', 6, N'BATT.STARN8', CAST(N'2018-02-10T00:00:00.000' AS DateTime), 2, 144, N'STARN8')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0249', 7, N'FILT.HIFSA6001', CAST(N'2018-02-10T00:00:00.000' AS DateTime), 2, 17.3, N'HIFISA6001')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0249', 8, N'AMPO.STOP_BLANC*', CAST(N'2018-03-10T00:00:00.000' AS DateTime), 10, 0.85, N'OSR7506')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0249', 9, N'AMPO.STOP12V21/5W', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 10, 1.19, N'OSRA7528')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0249', 10, N'PINC.FAC185.20VE', CAST(N'2018-02-10T00:00:00.000' AS DateTime), 1, 20.75, N'FAC185.20VE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0249', 11, N'OUTI.A_DEGFAC.872271', CAST(N'2018-02-10T00:00:00.000' AS DateTime), 1, 25.5, N'FAC872271')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0249', 12, N'LAME_FAC872272', CAST(N'2017-12-24T00:00:00.000' AS DateTime), 1, 11.11, N'FAC872272')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0249', 13, N'PINC.FAC405.12MT', CAST(N'2018-02-10T00:00:00.000' AS DateTime), 1, 33.5, N'FAC405.12MT')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0249', 14, N'CLE_MIXCKRA3421', CAST(N'2018-02-10T00:00:00.000' AS DateTime), 1, 22, N'KRA3421')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0249', 15, N'CLE_MIXCKRA3410', CAST(N'2018-02-10T00:00:00.000' AS DateTime), 1, 9.2, N'KRA3410')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0249', 16, N'GIRO. SOD17389', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 1, 76.5, N'SOD17389')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0249', 17, N'DECA.SOUDER', CAST(N'2018-03-10T00:00:00.000' AS DateTime), 1, 9.85, N'SOD05699')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0249', 18, N'PIST.SOUDER1000W', CAST(N'2018-03-10T00:00:00.000' AS DateTime), 1, 15.57, N'SOD05631')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0250', 1, N'ACTI.BIO_1L', CAST(N'2018-01-16T00:00:00.000' AS DateTime), 6, 14.75, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0250', 2, N'AGIT.ACAFE', CAST(N'2018-03-18T00:00:00.000' AS DateTime), 2, 7.95, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0250', 3, N'CHIF.BLANC', CAST(N'2018-02-16T00:00:00.000' AS DateTime), 4, 35.5, N'0109497')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0250', 4, N'MAST.290DC', CAST(N'2018-01-16T00:00:00.000' AS DateTime), 36, 16.27, N'0205155')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0250', 5, N'DEGR.HD2', CAST(N'2018-01-16T00:00:00.000' AS DateTime), 10, 112.2, N'SURFZYME HD2-0225102')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0250', 6, N'PEIN.NOIR', CAST(N'2017-12-15T00:00:00.000' AS DateTime), 4, 210.5, N'AS1045')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0250', 7, N'SPRA.NETT.FR', CAST(N'2018-02-03T00:00:00.000' AS DateTime), 12, 11.48, N'ASFORNET-0202113')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0251', 2, N'PRIS.LEG052082', CAST(N'2018-01-24T00:00:00.000' AS DateTime), 2, 30.65, N'LG52082')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0251', 3, N'FICH.CF10/16A', CAST(N'2017-10-05T00:00:00.000' AS DateTime), 10, 6.678, N'LEG050446')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0251', 4, N'AMPO.8W_E27', CAST(N'2018-01-24T00:00:00.000' AS DateTime), 10, 14.38, N'GISU')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0251', 5, N'BLOC_BRE1152821', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 2, 9.88, N'BRNN 1152821')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0251', 6, N'TAXE', CAST(N'2017-10-25T00:00:00.000' AS DateTime), 10, 0.2, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0251', 7, N'FICH.CM10/16A', CAST(N'2017-10-03T00:00:00.000' AS DateTime), 10, 4.976, N'LEG050446')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0251', 8, N'PILE_LR6', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 5, 2.9, N'8280 4006101404')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0251', 10, N'AMPO.E14POIRE15W', CAST(N'2018-01-24T00:00:00.000' AS DateTime), 3, 1.89, N'ORBI118612')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0251', 11, N'BARR.LG34389', CAST(N'2018-01-24T00:00:00.000' AS DateTime), 1, 12.05, N'LEG034389')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0251', 13, N'PROJ.30WLED', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 5, 65, N'BRNN1171600202')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0251', 14, N'CONV.AIRA688254', CAST(N'2018-01-24T00:00:00.000' AS DateTime), 1, 193, N'A690484')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0251', 15, N'PILE_LR03', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 5, 2.9, N'CIPE 116816')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0251', 16, N'TAXE', CAST(N'2017-10-25T00:00:00.000' AS DateTime), 1, 1.67, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0251', 17, N'TAXE', CAST(N'2017-10-25T00:00:00.000' AS DateTime), 5, 0.2, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0251', 18, N'GRAV.DREF0130290JC', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 1, 47.8, N'RS394-958')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0251', 19, N'OUTI.DREMEL', CAST(N'2018-01-24T00:00:00.000' AS DateTime), 1, 18.2, N'RS420-271')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0251', 20, N'CORD.RJ45CAT6-7M', CAST(N'2018-01-24T00:00:00.000' AS DateTime), 3, 7.4, N'C852660')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0252', 1, N'GNR_BF', CAST(N'2018-01-24T00:00:00.000' AS DateTime), 571, 0.808, N'BIOFREE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0253', 1, N'VIS_THPAB16X300', CAST(N'2018-01-16T00:00:00.000' AS DateTime), 100, 3.7, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0253', 2, N'CLE_ACIR', CAST(N'2018-01-16T00:00:00.000' AS DateTime), 1, 489, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0253', 3, N'ACCU_18V4.0AH', CAST(N'2018-01-16T00:00:00.000' AS DateTime), 1, 135, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0254', 1, N'CLOC.ECHA556000181', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 1, 57.01, N'A556000181')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0254', 2, N'CIRC.ECH90070200028', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 1, 1.29, N'90070200028')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0254', 3, N'ROUL.ECH90080706001', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 2, 12.815, N'90080706001')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0254', 4, N'CIRC.ECH90070100012', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 1, 0.77, N'9007010012')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0254', 5, N'COLL.ECHA172000150', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 1, 69.78, N'A172000150')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0254', 6, N'BOUC.ECH13100455530', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 1, 9, N'13100455530')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0254', 7, N'EVEN.ECHA356000031', CAST(N'2018-03-12T00:00:00.000' AS DateTime), 1, 5.53, N'A356000031')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0254', 8, N'BOUG.NGKBPMR6A', CAST(N'2018-02-20T00:00:00.000' AS DateTime), 1, 8.38, N'BPMR7A')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0254', 9, N'RESS.ECHV451000480', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 1, 3.41, N'V451000480')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0254', 10, N'PATI.ECHA553000030', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 1, 20.65, N'A553000030')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0254', 11, N'FILT.ECHA226000220', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 1, 10.33, N'A226000220')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0254', 12, N'ECRO.ECH90050200006', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 2, 0.09, N'9005020006')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0254', 13, N'AXE_ECH61001149931', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 1, 38.63, N'61001149931')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0254', 14, N'CABL.ECHV430000390', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 1, 25.83, N'V430000390')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0254', 15, N'FILT.ECH13031006230', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 1, 13.18, N'ECH13031006230')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0254', 16, N'GUID.STH30050004809', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 1, 40.04, N'STH30050004809')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0254', 17, N'BEC_HUSQ505598002', CAST(N'2018-02-20T00:00:00.000' AS DateTime), 2, 11.775, N'505698002')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0254', 18, N'FILT.LOM2175048', CAST(N'2018-01-10T00:00:00.000' AS DateTime), 1, 28.29, N'LOMBARDINI217048')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0254', 19, N'GAIN.ECH17812743230', CAST(N'2018-03-12T00:00:00.000' AS DateTime), 1, 4.36, N'17812743230')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0255', 1, N'SEAU_PLAST.N10L', CAST(N'2018-01-12T00:00:00.000' AS DateTime), 2, 1.65, N'MO341080')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0255', 2, N'SEAU_POLY.12L', CAST(N'2018-01-12T00:00:00.000' AS DateTime), 2, 4.28, N'MO341120')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0255', 3, N'MECH.BOIS18/360', CAST(N'2018-01-12T00:00:00.000' AS DateTime), 2, 24.79, N'2608597645')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0255', 4, N'BROS.PEINT80', CAST(N'2018-01-11T00:00:00.000' AS DateTime), 2, 9.62, N'OUTILPARFAIT180280')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0255', 5, N'FEUT.ALU/MAMMOUTH', CAST(N'2018-01-12T00:00:00.000' AS DateTime), 1, 88.8, N'FALU')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0255', 6, N'PROT.D12/25', CAST(N'2018-01-12T00:00:00.000' AS DateTime), 4, 8.69, N'MO303451')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0255', 7, N'DECO.BOS06012331004', CAST(N'2018-01-12T00:00:00.000' AS DateTime), 1, 233.17, N'0601231004')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0255', 8, N'TAXE', CAST(N'2018-01-02T00:00:00.000' AS DateTime), 1, 0.17, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0342', 1, N'ROUL.CLA60050044782', CAST(N'2018-01-31T00:00:00.000' AS DateTime), 135, 0.44, N'60050044782')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0342', 2, N'POIG.CLA6005012705', CAST(N'2018-01-30T00:00:00.000' AS DateTime), 1, 51.04, N'6005012705')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0342', 3, N'BAGU.CLA6005012726', CAST(N'2018-01-31T00:00:00.000' AS DateTime), 2, 3.82, N'6005012726')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0342', 4, N'ETAI_CLA6005012666', CAST(N'2018-01-31T00:00:00.000' AS DateTime), 8, 0.71, N'6005012666')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0342', 5, N'ETAI_CLA6005012737', CAST(N'2018-01-31T00:00:00.000' AS DateTime), 10, 0.94, N'6005012737')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0342', 6, N'GARN.CLA6005012706', CAST(N'2018-01-31T00:00:00.000' AS DateTime), 1, 5.55, N'6005012706')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0342', 7, N'GARN.CLA6005012707', CAST(N'2018-01-31T00:00:00.000' AS DateTime), 1, 5.55, N'6005012707')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0342', 8, N'BAGU.CLA6005012725', CAST(N'2018-01-31T00:00:00.000' AS DateTime), 4, 2.06, N'6005012725')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0342', 9, N'CHAS.CLA6005014627', CAST(N'2018-01-31T00:00:00.000' AS DateTime), 1, 206.7, N'6005014627')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0342', 10, N'SERR.CLA6005012546', CAST(N'2018-01-31T00:00:00.000' AS DateTime), 1, 36.85, N'6005012546')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0342', 11, N'AMOR.CLA6005012549', CAST(N'2018-01-31T00:00:00.000' AS DateTime), 1, 34.28, N'6005012549')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0342', 12, N'ETAI_CLA6005012696', CAST(N'2018-01-31T00:00:00.000' AS DateTime), 12, 0.79, N'6005012696')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0342', 13, N'BAGU.CLA6005012695', CAST(N'2018-01-31T00:00:00.000' AS DateTime), 4, 3.15, N'6005012695')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0342', 14, N'AMOR.CLA6005012542', CAST(N'2018-01-31T00:00:00.000' AS DateTime), 2, 34.21, N'6005012542')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0342', 15, N'SIEG.CLA6005010612', CAST(N'2018-01-31T00:00:00.000' AS DateTime), 1, 340.8, N'6005010612')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0342', 16, N'VITR.CLA6005014581', CAST(N'2018-01-31T00:00:00.000' AS DateTime), 2, 372.52, N'6005014581')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0342', 17, N'VITR.CLA6005014584', CAST(N'2018-01-31T00:00:00.000' AS DateTime), 1, 111.62, N'6005012584')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0348', 1, N'SPRA.LUBR.INTFLTF', CAST(N'2015-03-28T00:00:00.000' AS DateTime), 12, 20.05, N'9074')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0348', 2, N'GRAI.INT.LS1/2', CAST(N'2018-01-31T00:00:00.000' AS DateTime), 1, 420.4, N'8896')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0348', 3, N'GRAI.INT.LS1/2C', CAST(N'2018-02-05T00:00:00.000' AS DateTime), 24, 24.65, N'8894')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0348', 4, N'PORT', CAST(N'2018-02-07T00:00:00.000' AS DateTime), 1, 30, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0450', 1, N'MANC.BM.VIS', CAST(N'2018-02-08T00:00:00.000' AS DateTime), 15, 7.8, N'G404')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0450', 2, N'PELL.PM+BAL.', CAST(N'2018-02-08T00:00:00.000' AS DateTime), 5, 8.1, N'G250')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0450', 3, N'BALA.SOIE', CAST(N'2018-02-08T00:00:00.000' AS DateTime), 3, 42.6, N'G165')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0450', 4, N'LAVE_PONT_NYL.', CAST(N'2018-02-08T00:00:00.000' AS DateTime), 2, 35.7, N'G284')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0450', 5, N'MANC.LPA', CAST(N'2018-02-08T00:00:00.000' AS DateTime), 2, 24.5, N'G3005')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0450', 6, N'POUC.R0-18', CAST(N'2018-02-08T00:00:00.000' AS DateTime), 3, 13.2, N'G495')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0568', 1, N'ECRO.SER230', CAST(N'2018-01-30T00:00:00.000' AS DateTime), 2, 42.35, N'9140170')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0568', 2, N'GRAI.8X100_45', CAST(N'2018-01-30T00:00:00.000' AS DateTime), 50, 0.749, N'2370071')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0568', 3, N'MECH.AC04', CAST(N'2018-03-02T00:00:00.000' AS DateTime), 10, 0.9, N'5020029')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0568', 4, N'FORE.SDS+08X210', CAST(N'2018-01-30T00:00:00.000' AS DateTime), 5, 9.25, N'5020066')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0568', 6, N'LAMP.LEDSF', CAST(N'2018-02-09T00:00:00.000' AS DateTime), 2, 89, N'7955')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0568', 7, N'EQUA.4PCE', CAST(N'2018-01-30T00:00:00.000' AS DateTime), 2, 25, N'9140442')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0568', 8, N'DISQ.300DIAM', CAST(N'2018-01-30T00:00:00.000' AS DateTime), 2, 160.3, N'5400011')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0568', 9, N'KIT_LOM3906438', CAST(N'2018-03-02T00:00:00.000' AS DateTime), 1, 182, N'DIVERS')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0568', 10, N'FILT.PERK26561117', CAST(N'2018-01-30T00:00:00.000' AS DateTime), 4, 7.65, N'9140441')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0568', 11, N'FLEX.HYDSM', CAST(N'2018-01-30T00:00:00.000' AS DateTime), 1, 14.02, N'FLEXIBLE HP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0568', 12, N'PORT', CAST(N'2018-02-09T00:00:00.000' AS DateTime), 1, 52, N'PORT ET EMBALLAGE USINE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0568', 13, N'FILT.DESDC2', CAST(N'2018-01-30T00:00:00.000' AS DateTime), 50, 125, N'9104371')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0772', 1, N'FOUR.FUM', CAST(N'2018-02-05T00:00:00.000' AS DateTime), 3, 38.88, N'JFFF4EEM')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0772', 2, N'MERL.ECL2.5', CAST(N'2018-02-05T00:00:00.000' AS DateTime), 1, 25.4, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0772', 3, N'MERL.ECL3.5', CAST(N'2018-02-05T00:00:00.000' AS DateTime), 1, 29.3, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0772', 4, N'BECH.', CAST(N'2018-02-05T00:00:00.000' AS DateTime), 2, 30.29, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0772', 6, N'FIL_DEB2.4X275C', CAST(N'2018-02-05T00:00:00.000' AS DateTime), 2, 35.57, N'00009302612')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0772', 7, N'GRAI.MS_TUBE', CAST(N'2018-02-05T00:00:00.000' AS DateTime), 2, 2.85, N'530183I-A1')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0772', 8, N'ELAG.WOLOR750', CAST(N'2018-02-05T00:00:00.000' AS DateTime), 1, 64.75, N'OR87V')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0772', 9, N'ASPE.2T', CAST(N'2018-03-18T00:00:00.000' AS DateTime), 3, 18.0266, N'ASPEN2T')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0772', 10, N'ASPE.4T', CAST(N'2018-02-05T00:00:00.000' AS DateTime), 3, 18.0266, N'ASPEN4T')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0772', 11, N'CHAI.STH39910030060', CAST(N'2018-02-05T00:00:00.000' AS DateTime), 10, 16.67, N'39910030060')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0772', 12, N'CHAI.STH36100030044', CAST(N'2018-02-05T00:00:00.000' AS DateTime), 3, 16.6667, N'90PX044E')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0772', 13, N'SAC_STH49015009031', CAST(N'2018-02-05T00:00:00.000' AS DateTime), 1, 46.79, N'49015009031')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0772', 14, N'BOUG.NGKBPMR6A', CAST(N'2018-03-18T00:00:00.000' AS DateTime), 6, 4.91, N'BPMR7A')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0772', 15, N'CLIQ.STH11251957200', CAST(N'2018-03-18T00:00:00.000' AS DateTime), 1, 2.58, N'11251957200')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0772', 16, N'ROND.STH00009580923', CAST(N'2018-02-05T00:00:00.000' AS DateTime), 1, 2.01, N'00009580923')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0772', 17, N'VIS_STH11257916200', CAST(N'2018-02-05T00:00:00.000' AS DateTime), 4, 1.25, N'11257916200')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0772', 19, N'GUID.HUS503141201', CAST(N'2018-02-05T00:00:00.000' AS DateTime), 1, 5.98, N'503141201')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0772', 20, N'GUID.HUS503141301', CAST(N'2018-02-05T00:00:00.000' AS DateTime), 1, 6.34, N'503141301')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0772', 21, N'BAND.HUS503137802', CAST(N'2018-03-18T00:00:00.000' AS DateTime), 1, 13.24, N'HUS503137802')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0772', 22, N'GUID.HUS503138001', CAST(N'2018-02-05T00:00:00.000' AS DateTime), 1, 5.88, N'503138001')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0772', 23, N'PATI.ECHA553000030', CAST(N'2018-02-05T00:00:00.000' AS DateTime), 1, 20.65, N'A553000030')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0772', 24, N'BUTO.STH11257912805', CAST(N'2018-02-05T00:00:00.000' AS DateTime), 1, 4.31, N'11257912805')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 1, N'LAME_BOS2608661642', CAST(N'2018-02-06T00:00:00.000' AS DateTime), 1, 33.12, N'2608661642')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 2, N'COFF.BOS2608664131', CAST(N'2018-02-06T00:00:00.000' AS DateTime), 1, 39.01, N'2608664131')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 3, N'PINC.DECOF600', CAST(N'2018-03-09T00:00:00.000' AS DateTime), 1, 14.15, N'310206')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 4, N'COUT.PEINTI12', CAST(N'2018-02-06T00:00:00.000' AS DateTime), 1, 4.05, N'MO223320')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 5, N'SILI.NEUT.TRANS', CAST(N'2018-02-23T00:00:00.000' AS DateTime), 5, 5.51, N'128796')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 6, N'SILI.NEUT.BLC', CAST(N'2018-03-06T00:00:00.000' AS DateTime), 2, 3.66, N'128783')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 7, N'PIST._JOINT', CAST(N'2018-03-09T00:00:00.000' AS DateTime), 1, 72.1, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 8, N'POUC.R6-29', CAST(N'2018-02-05T00:00:00.000' AS DateTime), 9, 10.24, N'28976')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 9, N'GAIN.40VERTE', CAST(N'2018-02-06T00:00:00.000' AS DateTime), 100, 0.64, N'GTF40V')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 10, N'GAIN.90TPC25M', CAST(N'2018-02-05T00:00:00.000' AS DateTime), 100, 1.74, N'GTF90')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 11, N'VBA_TCF4.5X50', CAST(N'2018-02-06T00:00:00.000' AS DateTime), 1, 10.73, N'46435185')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 12, N'BLOC_P204/83H88P', CAST(N'2018-03-09T00:00:00.000' AS DateTime), 1, 59.4, N'BPP8883')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 13, N'BA13_2.5/0.6', CAST(N'2018-02-06T00:00:00.000' AS DateTime), 10.5, 4.81, N'BA13600')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 14, N'DALL.OSB18MM', CAST(N'2018-03-09T00:00:00.000' AS DateTime), 5.06, 6.78, N'OSB18H')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 15, N'DALL.OSB12MM', CAST(N'2018-03-09T00:00:00.000' AS DateTime), 5.06, 4.59, N'OSB12H')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 16, N'LAIN.DVPV80', CAST(N'2018-03-09T00:00:00.000' AS DateTime), 10.8, 4.11, N'LV80')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 17, N'COLL.CP25', CAST(N'2018-02-06T00:00:00.000' AS DateTime), 1, 13.89, N'CCP25')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 18, N'ENDU.SB25', CAST(N'2018-02-05T00:00:00.000' AS DateTime), 1, 20.01, N'ESB25P')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 19, N'RAIL_R48', CAST(N'2018-02-06T00:00:00.000' AS DateTime), 9, 0.84, N'R48')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 20, N'RAIL_M48', CAST(N'2018-02-06T00:00:00.000' AS DateTime), 12, 1.06, N'R48')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 21, N'VIS_PLACO3.9X35', CAST(N'2018-03-09T00:00:00.000' AS DateTime), 1, 6.66, N'46133081')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 22, N'FERM.12.5/260/120', CAST(N'2018-02-06T00:00:00.000' AS DateTime), 3.12, 11.15, N'FC12.5GF')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 23, N'TUYA.PVC32', CAST(N'2018-02-06T00:00:00.000' AS DateTime), 1, 4.82, N'T324')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 24, N'COLL.PVC32', CAST(N'2018-03-09T00:00:00.000' AS DateTime), 5, 1, N'CM32')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 25, N'TUYA.PVC40', CAST(N'2018-02-06T00:00:00.000' AS DateTime), 4, 5.59, N'T404')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 26, N'COLL.PVC40', CAST(N'2018-03-09T00:00:00.000' AS DateTime), 20, 1.11, N'CM40')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 27, N'MECA.DCU', CAST(N'2018-02-06T00:00:00.000' AS DateTime), 1, 40.72, N'MW90C')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 28, N'MANC.CU14', CAST(N'2018-03-09T00:00:00.000' AS DateTime), 3, 0.59, N'270CU14')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 29, N'COUD.CU14', CAST(N'2018-03-09T00:00:00.000' AS DateTime), 2, 0.91, N'90CU14')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 30, N'BOUC.CU14F', CAST(N'2018-03-09T00:00:00.000' AS DateTime), 3, 0.67, N'300CU14')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 31, N'REDU.CU16-14', CAST(N'2018-02-06T00:00:00.000' AS DateTime), 2, 1.07, N'240CU1614')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-0886', 32, N'TRAP.600X600', CAST(N'2018-03-09T00:00:00.000' AS DateTime), 1, 38.61, N'WTV60')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1193', 1, N'SERV.AUMSA10.2', CAST(N'2018-03-14T00:00:00.000' AS DateTime), 4, 1776, N'SA10.2')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1194', 1, N'GAZ_BUT.VRAC', CAST(N'2018-03-13T00:00:00.000' AS DateTime), 2, 1504, NULL)
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1195', 3, N'BORN.WAG221415', CAST(N'2017-12-22T00:00:00.000' AS DateTime), 1, 54, N'WAGO222415')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1195', 4, N'BORN.WAG2273208', CAST(N'2018-03-26T00:00:00.000' AS DateTime), 1, 14.66, N'WAGO273108')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1195', 5, N'SAC_SPI620922', CAST(N'2018-01-31T00:00:00.000' AS DateTime), 2, 65.03, N'SPIT 620001')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1195', 6, N'FILT.SPIT644006', CAST(N'2018-01-31T00:00:00.000' AS DateTime), 2, 82.38, N'644006')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1195', 7, N'COLL.LEG031920', CAST(N'2018-02-01T00:00:00.000' AS DateTime), 2, 54.12, N'LEG031920')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1195', 8, N'CLOU.3.1/100', CAST(N'2018-02-01T00:00:00.000' AS DateTime), 2, 176, N'SENCO NN50122')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1195', 9, N'AMPO.LED5W', CAST(N'2018-02-01T00:00:00.000' AS DateTime), 6, 8, N'BENE5920731-N')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1195', 10, N'TAXE', CAST(N'2017-11-16T00:00:00.000' AS DateTime), 6, 0.2, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1195', 11, N'PORT', CAST(N'2018-01-31T00:00:00.000' AS DateTime), 1, 46, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1195', 36, N'CUIV.NUD25', CAST(N'2018-02-01T00:00:00.000' AS DateTime), 25, 2, N'999.6025.0')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1195', 37, N'REPA.SPE190689', CAST(N'2018-03-26T00:00:00.000' AS DateTime), 2, 24, N'SPE190689')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1195', 38, N'ENRO.3G2.5-40', CAST(N'2018-02-03T00:00:00.000' AS DateTime), 1, 138, N'136425')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1195', 39, N'FORE.SDS+20X450', CAST(N'2018-03-26T00:00:00.000' AS DateTime), 2, 49.3, N'VEGA136425')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1195', 40, N'CHEV.6X30', CAST(N'2018-02-01T00:00:00.000' AS DateTime), 4, 5.47, N'FISC555006')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1195', 41, N'TELE.FAACXT4_868SLH', CAST(N'2018-03-26T00:00:00.000' AS DateTime), 8, 34.8, N'FAAC XT4 868 SLH BLACK')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1195', 42, N'PORT', CAST(N'2018-01-31T00:00:00.000' AS DateTime), 1, 10, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1196', 1, N'GANT_HYFLEX9', CAST(N'2018-03-13T00:00:00.000' AS DateTime), 60, 2.06, N'MFT200T9')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1196', 2, N'GANT_HYFLEX10', CAST(N'2018-03-13T00:00:00.000' AS DateTime), 60, 2.06, N'MF200T10')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1196', 3, N'GANT_HYFLEX11', CAST(N'2018-03-13T00:00:00.000' AS DateTime), 60, 2.06, N'MF200T11')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1196', 4, N'SAC_POUB30L', CAST(N'2018-03-13T00:00:00.000' AS DateTime), 3, 30.45, N'BLEU')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1196', 5, N'VINA.BLANC', CAST(N'2018-03-13T00:00:00.000' AS DateTime), 6, 0.98, N'HA0122')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1196', 6, N'NETT.SOL_ET_SURF.', CAST(N'2018-03-13T00:00:00.000' AS DateTime), 4, 29.51, N'TH0062')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 1, N'FILT.MANW936/4', CAST(N'2018-03-20T00:00:00.000' AS DateTime), 1, 6.47, N'MANN 936/4')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 2, N'FILT.MANW940/5', CAST(N'2018-03-20T00:00:00.000' AS DateTime), 2, 10.51, N'MANNW940/5')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 3, N'FILT.MANWK731', CAST(N'2018-03-20T00:00:00.000' AS DateTime), 2, 6.66, N'MANNWK731')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 4, N'FILT.MANWK8100', CAST(N'2018-03-20T00:00:00.000' AS DateTime), 1, 21.62, N'MANNWK8100')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 5, N'FILT.HIFSH61153', CAST(N'2018-03-20T00:00:00.000' AS DateTime), 2, 38.72, N'HISH61153')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 6, N'FILT.MANCF850/2', CAST(N'2018-03-20T00:00:00.000' AS DateTime), 2, 17.17, N'MANNCF850')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 7, N'FILT.MANC14210/2', CAST(N'2018-03-20T00:00:00.000' AS DateTime), 2, 26.35, N'MANNC14210/2')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 9, N'DOUI.FACNS27LA', CAST(N'2018-03-20T00:00:00.000' AS DateTime), 2, 16.35, N'FACNS.27LA')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 10, N'DOUI.FACNS30LA', CAST(N'2018-03-20T00:00:00.000' AS DateTime), 1, 19.42, N'FACNS.30LA')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 11, N'AUGM.FACNS232B', CAST(N'2018-03-20T00:00:00.000' AS DateTime), 1, 18.47, N'FACNS232B')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 12, N'DOUI.FACK55B', CAST(N'2018-03-20T00:00:00.000' AS DateTime), 1, 24.61, N'FACK.55B')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 13, N'DOUI.FACNS32LA', CAST(N'2018-03-20T00:00:00.000' AS DateTime), 1, 19.65, N'FACNS32LA')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 14, N'GIRO.MAGLED', CAST(N'2018-03-20T00:00:00.000' AS DateTime), 1, 55.55, N'SODISE 117056')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 15, N'BROS.VEHICUL', CAST(N'2018-03-20T00:00:00.000' AS DateTime), 1, 31.26, N'VAN475752')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 16, N'MANC.TEL.1.5X2.75', CAST(N'2018-03-20T00:00:00.000' AS DateTime), 1, 37.2, N'VAN297552')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 17, N'JERR.20LRGE', CAST(N'2018-04-20T00:00:00.000' AS DateTime), 1, 13.85, N'INF358')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 18, N'PORT.REST17018', CAST(N'2018-04-20T00:00:00.000' AS DateTime), 3, 2.35, N'REST17018')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 19, N'COUR.REST16263', CAST(N'2018-04-20T00:00:00.000' AS DateTime), 1, 44.13, N'REST16263')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 20, N'ETAU_125MM', CAST(N'2018-04-20T00:00:00.000' AS DateTime), 1, 111.6, N'KRA2962')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 21, N'BAND.MOUS40X10', CAST(N'2018-04-20T00:00:00.000' AS DateTime), 10, 2.3, N'MABEO-121948K')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 22, N'BATT.STARN4', CAST(N'2018-03-20T00:00:00.000' AS DateTime), 1, 65, N'STARN4')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 24, N'RACC.FOGU210-37', CAST(N'2018-04-20T00:00:00.000' AS DateTime), 1, 94.9, N'FOG.U210-37')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 25, N'AMPO.GRAIS12V5W', CAST(N'2018-04-20T00:00:00.000' AS DateTime), 10, 0.69, N'OSRA5007')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1201', 28, N'CART.REST6945', CAST(N'2018-04-20T00:00:00.000' AS DateTime), 1, 16.54, N'6945')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1203', 1, N'SPRA.SOUF', CAST(N'2018-04-07T00:00:00.000' AS DateTime), 12, 14.08, N'AS SOUFFLEUR-0202133')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1203', 2, N'ESSU.TOUT', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 96, 1.3575, N'0102146')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1203', 3, N'EPON.VEG.N8', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 10, 2.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1203', 4, N'SPRA.NETT.VIT', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 12, 8.48, N'0217115-TOPGLASS')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1203', 5, N'DILU.N5L', CAST(N'2018-04-01T00:00:00.000' AS DateTime), 6, 34, N'S27-0219114')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1203', 6, N'LIQU.VAISSEL1L', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 12, 8.75, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1203', 7, N'COLL.CYANO', CAST(N'2018-04-22T00:00:00.000' AS DateTime), 2, 19.22, N'0205123')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1203', 8, N'TAPI.COULOIR60X90', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 1, 60.84, N'47628')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1203', 9, N'ESSU.MAIN_KIM6763', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 120, 4.499, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1203', 10, N'SPRA.DEGO', CAST(N'2018-04-22T00:00:00.000' AS DateTime), 2, 17.91, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1203', 11, N'COLL.ETTR', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 12, 20.38, N'AMPLIFIXPRO-0205153')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1203', 12, N'EAU_0.5', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 40, 3.26, N'CRISTALINE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1203', 13, N'EAU_1.5L', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 40, 3.22, N'CRISTALINE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1203', 14, N'CAFE_DOSE48', CAST(N'2018-04-02T00:00:00.000' AS DateTime), 5, 11.64, N'SENSEO CLASSIQUE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1203', 15, N'CAFE_MOULU', CAST(N'2018-04-02T00:00:00.000' AS DateTime), 3, 6.72, N'CARTE NOIR')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1203', 16, N'INFU.', CAST(N'2018-04-22T00:00:00.000' AS DateTime), 8, 6.65, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1203', 17, N'VERR.BC', CAST(N'2018-04-01T00:00:00.000' AS DateTime), 1, 78.49, N'HG10')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1203', 18, N'INSE.POMP.', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 12, 16.37, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1203', 19, N'INSE.VOLANT', CAST(N'2018-04-22T00:00:00.000' AS DateTime), 2, 16.46, N'0202166')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1203', 20, N'INSE.PUNAISE', CAST(N'2018-04-11T00:00:00.000' AS DateTime), 2, 16.05, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1203', 21, N'ASPI.NILVL200', CAST(N'2018-04-22T00:00:00.000' AS DateTime), 1, 299, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1203', 22, N'SAC_NILFVL200', CAST(N'2018-04-22T00:00:00.000' AS DateTime), 2, 31.19, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1203', 23, N'FILT.NIL185X140', CAST(N'2018-04-22T00:00:00.000' AS DateTime), 1, 75.8, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1205', 1, N'DIAB.M.ESCALIER', CAST(N'2018-05-03T00:00:00.000' AS DateTime), 1, 320, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1205', 2, N'SANG.AR5M900SF', CAST(N'2018-02-02T00:00:00.000' AS DateTime), 3, 5.1, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1205', 3, N'BOTT.T43', CAST(N'2018-03-29T00:00:00.000' AS DateTime), 2, 80, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1205', 4, N'BOTT.T42', CAST(N'2018-03-29T00:00:00.000' AS DateTime), 2, 80, N'DUNLOP PUROFORT FULL SAFETY')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1205', 5, N'BOTT.T41', CAST(N'2018-03-29T00:00:00.000' AS DateTime), 2, 80, N'DUNLOP PUROFORT FULL SAFETY')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1205', 6, N'CASQ.C3', CAST(N'2018-05-03T00:00:00.000' AS DateTime), 2, 23.2, N'HONEYWELL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1205', 7, N'VIS_TFF05X20', CAST(N'2018-05-03T00:00:00.000' AS DateTime), 200, 0.04, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1205', 8, N'GOUJ.ENC08/120/55', CAST(N'2018-05-03T00:00:00.000' AS DateTime), 50, 0.57, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1205', 9, N'EQUA.4PCE', CAST(N'2018-05-03T00:00:00.000' AS DateTime), 3, 25, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1205', 10, N'CONF.', CAST(N'2018-04-09T00:00:00.000' AS DateTime), 1, 300, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1222', 1, N'PINC.FAC195.20VE', CAST(N'2017-12-14T00:00:00.000' AS DateTime), 1, 21.92, N'FAC195.20AVSE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1222', 2, N'ENSE.PREKTBSM1', CAST(N'2018-02-01T00:00:00.000' AS DateTime), 1, 62.61, N'PREV KTBSM1')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1222', 3, N'FREI.FIL.NORM', CAST(N'2018-02-01T00:00:00.000' AS DateTime), 1, 40.3, N'LOCT1335884')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1222', 4, N'GIRO. SOD17389', CAST(N'2018-02-01T00:00:00.000' AS DateTime), 2, 19.85, N'SOD16933')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1222', 5, N'COLL.BDE08-12', CAST(N'2018-02-01T00:00:00.000' AS DateTime), 50, 0.3484, N'PROMNP91016')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1222', 6, N'COLL.BDE10-16', CAST(N'2018-02-01T00:00:00.000' AS DateTime), 50, 0.3596, N'PROMNP91016')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1222', 7, N'BATT.STARN4', CAST(N'2018-02-01T00:00:00.000' AS DateTime), 1, 65, N'STARN4')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1222', 8, N'BATT.12V45AH', CAST(N'2018-02-01T00:00:00.000' AS DateTime), 1, 81, N'FULMFB451')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1222', 9, N'POMP.SDMO_CLEAR1.7', CAST(N'2018-02-01T00:00:00.000' AS DateTime), 1, 250, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1222', 10, N'AMPO.MINIWATT5W', CAST(N'2018-03-11T00:00:00.000' AS DateTime), 10, 0.71, N'OSRA2825')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1222', 11, N'ACCU_12V-3AH', CAST(N'2018-03-11T00:00:00.000' AS DateTime), 1, 162.09, N'VANS4030')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1266', 1, N'REPA.MATERIEL', CAST(N'2018-03-17T00:00:00.000' AS DateTime), 1, 956, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1267', 1, N'DETE.BANQS303E', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 2, 115, N'BANNER QS303E')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1267', 2, N'DETE.BANQS30VR3R', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 2, 174, N'BANNER QS303R')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1267', 33, N'DETE.BANQS30ARXQ', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 4, 179, N'QS30ARXQ')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1267', 34, N'CABL.BANMQDC1-530RA', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 16, 78.4, N'MQDC1-530RA')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1267', 35, N'SUPP.BANSMB30SC', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 16, 9.8, N'SMB30SC')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1267', 36, N'DETE.BANQS30EXQ', CAST(N'2018-02-22T00:00:00.000' AS DateTime), 4, 176.8, N'QS30EXQ')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1267', 37, N'BATT.AMP9068', CAST(N'2018-02-22T00:00:00.000' AS DateTime), 2, 306, N'AMP9068')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1267', 38, N'TAXE', CAST(N'2017-12-07T00:00:00.000' AS DateTime), 2, 9.31, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1360', 1, N'VITR.INCASSABLE', CAST(N'2018-03-19T00:00:00.000' AS DateTime), 1, 24, NULL)
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1360', 2, N'COQU.TELEPHONE', CAST(N'2018-03-19T00:00:00.000' AS DateTime), 1, 24, N'J3')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1360', 3, N'CART.SDHC32GO', CAST(N'2018-02-16T00:00:00.000' AS DateTime), 1, 25, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1360', 4, N'CART.SDHC64GO', CAST(N'2018-02-16T00:00:00.000' AS DateTime), 1, 43.1, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1360', 5, N'OBTU.DN27/30MM', CAST(N'2018-03-23T00:00:00.000' AS DateTime), 200, 0.65, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1360', 6, N'PORT', CAST(N'2018-02-16T00:00:00.000' AS DateTime), 1, 15, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1360', 7, N'CAIL.AD1000X2000X18', CAST(N'2018-03-23T00:00:00.000' AS DateTime), 1, 327.6, N'FRANKEL916128-FP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1360', 9, N'BOTT.T42', CAST(N'2018-02-16T00:00:00.000' AS DateTime), 2, 80, N'DUNLOP PUROFORT FULL SAFETY')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1360', 10, N'ADAP.12CANELURES', CAST(N'2018-03-23T00:00:00.000' AS DateTime), 1, 286, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1360', 11, N'PORT', CAST(N'2018-02-16T00:00:00.000' AS DateTime), 1, 15, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1368', 1, N'PROT.FACIALE', CAST(N'2018-03-08T00:00:00.000' AS DateTime), 2, 6.04, N'1013191')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1368', 2, N'COMB.PLUIE_M', CAST(N'2018-03-08T00:00:00.000' AS DateTime), 3, 80.96, N'531023P')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1368', 3, N'BUFF_THERMAL', CAST(N'2018-03-08T00:00:00.000' AS DateTime), 10, 1.92, N'120214U')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1368', 4, N'GANT_SOUD.L', CAST(N'2018-03-07T00:00:00.000' AS DateTime), 3, 4.67, N'513239P')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1368', 5, N'BRET.ORE537804', CAST(N'2018-03-08T00:00:00.000' AS DateTime), 3, 10.24, N'427045X')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1368', 6, N'COMB.JET3', CAST(N'2018-03-06T00:00:00.000' AS DateTime), 20, 5.06, N'012819LBLANC')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1368', 7, N'BONN.S/CASQUE', CAST(N'2018-03-08T00:00:00.000' AS DateTime), 15, 8.48, N'1085054')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1368', 8, N'PORT.ECRAN_S54CE', CAST(N'2018-03-08T00:00:00.000' AS DateTime), 16, 14.5, N'896111X')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1368', 9, N'CASQ.C1', CAST(N'2018-03-07T00:00:00.000' AS DateTime), 3, 11.94, N'106760S')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1368', 10, N'CASQ.INTEGRA', CAST(N'2018-03-08T00:00:00.000' AS DateTime), 4, 43.16, N'1079132')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1368', 11, N'GANT_TNT.8-9', CAST(N'2018-03-09T00:00:00.000' AS DateTime), 10, 10.866, N'1162808')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1368', 12, N'GANT_TNT.9-10', CAST(N'2018-03-09T00:00:00.000' AS DateTime), 10, 10.866, N'1162828')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1368', 13, N'GANT_HYFLEX11', CAST(N'2018-03-08T00:00:00.000' AS DateTime), 60, 2.81, N'1095268')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1395', 1, N'HUIL.2TBIO1', CAST(N'2018-03-28T00:00:00.000' AS DateTime), 20, 20.7605, N'600088194')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1395', 2, N'HUIL.CHAINBIO5', CAST(N'2018-04-12T00:00:00.000' AS DateTime), 12, 36.8125, N'600389147')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1395', 3, N'LIQU.LR30_20L', CAST(N'2018-03-15T00:00:00.000' AS DateTime), 3, 75.523, N'600824976')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1395', 4, N'LIQU.LRD_5L', CAST(N'2018-03-15T00:00:00.000' AS DateTime), 12, 15.439, N'600825164')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1395', 5, N'HUIL.TCMAXX10W40-60', CAST(N'2018-03-15T00:00:00.000' AS DateTime), 60, 4.4256, N'601197505')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1395', 6, N'HUIL.ASMC10W40', CAST(N'2018-03-15T00:00:00.000' AS DateTime), 60, 5.6396, N'600523701')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1395', 7, N'GRAI.BIO50KGS', CAST(N'2018-04-04T00:00:00.000' AS DateTime), 50, 11.8398, N'600393656')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1395', 8, N'TGAP', CAST(N'2018-06-15T00:00:00.000' AS DateTime), 1, 5.06, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1432', 1, N'KIT_ENIKEP0023', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 1, 227.69, N'ENIX KEP0023')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1432', 2, N'KLAX.WER14095050', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 1, 67.09, N'55404589')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1606', 1, N'GAZO.', CAST(N'2018-04-04T00:00:00.000' AS DateTime), 1500, 1.165, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 2, N'GOMM.', CAST(N'2018-05-17T00:00:00.000' AS DateTime), 5, 0.15, N'35329')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 3, N'AGRA.DB24/26', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 1, 3.42, N'23157')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 4, N'AGRA.N10', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 10, 0.1, N'10107')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 5, N'SURL.JNE', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 10, 0.56, N'01423')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 6, N'CART.BROLC1280C', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 5, 14.73, N'82446')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 7, N'CART.BROLC1280M', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 5, 14.73, N'82447')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 8, N'CART.BROLC1280Y', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 5, 14.73, N'82448')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 9, N'CART.BROLC1280NP', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 3, 24.11, N'82445')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 10, N'SOUR.OPT.', CAST(N'2018-04-05T00:00:00.000' AS DateTime), 2, 19.9, N'24515')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 11, N'CART.BROLC3219XLBK', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 3, 25.39, N'34338')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 12, N'CART.BROLC3219XLC', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 3, 16.82, N'34339')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 13, N'CART.BROLC3219XLM', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 3, 16.82, N'34340')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 14, N'CART.BROLC3219XLY', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 3, 16.82, N'34341')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 15, N'CORB.MURALE', CAST(N'2018-05-17T00:00:00.000' AS DateTime), 1, 3.39, N'25711')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 16, N'SUPP.ECR_PC', CAST(N'2018-04-07T00:00:00.000' AS DateTime), 1, 31.74, N'56088')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 17, N'CALC', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 1, 20.6, N'63154')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 18, N'ETIQ.DYMMANAGER160', CAST(N'2018-05-17T00:00:00.000' AS DateTime), 1, 25.5, N'85490')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 19, N'AIMA.N22(6)', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 2, 0.72, N'79935')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 20, N'AIMA.R22(6)', CAST(N'2018-05-17T00:00:00.000' AS DateTime), 2, 0.72, N'79936')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 21, N'AIMA.B22(6)', CAST(N'2018-05-17T00:00:00.000' AS DateTime), 2, 0.72, N'79934')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 22, N'STYL.G-2N', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 24, 1.06, N'40454')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 23, N'BLOC_DBA4', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 10, 0.74, N'63209')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 24, N'BLOC_DBA5', CAST(N'2018-04-19T00:00:00.000' AS DateTime), 10, 0.4, N'63208')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 25, N'POST_IT76X127FLUO', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 24, 1.15, N'10311')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 26, N'CART.EPST1301', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 6, 21.11, N'80867')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 27, N'CART.EPST1306', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 6, 40.84, N'80871')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 28, N'LOUP.', CAST(N'2018-05-17T00:00:00.000' AS DateTime), 1, 1.66, N'68274')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 29, N'SURL.TURQ', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 10, 0.29, N'2D-82337')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 30, N'SURL.ROSE', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 10, 0.29, N'2D-64134')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 31, N'SURL.VERT', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 10, 0.29, N'2D-64133')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 32, N'CLAS.8VM', CAST(N'2018-04-19T00:00:00.000' AS DateTime), 10, 1.59, N'59032')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 33, N'CLAS.8BL', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 10, 1.59, N'59028')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 34, N'TAIL.CRAY+RES', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 2, 1.7, N'72236')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 35, N'SEPA.VERT.H19', CAST(N'2018-05-17T00:00:00.000' AS DateTime), 3, 59.5, N'4470042SC')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 36, N'PILE_LR20', CAST(N'2018-05-17T00:00:00.000' AS DateTime), 2, 4.51, N'51272')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 37, N'PILE_LR03_32PCES', CAST(N'2018-05-17T00:00:00.000' AS DateTime), 1, 6.3, N'20908')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 38, N'PILE_LR6_32PCES', CAST(N'2018-05-17T00:00:00.000' AS DateTime), 1, 6.3, N'20909')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 39, N'POCH.PERF.TR', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 1, 5.49, N'62883')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 40, N'POCH.POLYA4', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 1, 6.6, N'62886')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 41, N'STYL.G-2BL', CAST(N'2018-03-29T00:00:00.000' AS DateTime), 12, 1.06, N'40450')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 42, N'ATTA.CASE3S', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 1, 38.02, N'55462')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 43, N'BAGU.RELIER_6MM', CAST(N'2018-03-22T00:00:00.000' AS DateTime), 2, 1.97, N'22216')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1641', 44, N'BAGU.RELIER_9MM', CAST(N'2018-05-17T00:00:00.000' AS DateTime), 2, 2.44, N'40986')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1642', 1, N'NETT.DALLE', CAST(N'2018-04-04T00:00:00.000' AS DateTime), 20, 23.95, N'51449')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1642', 2, N'PULV.1.5L', CAST(N'2018-04-04T00:00:00.000' AS DateTime), 2, 37.72, N'MA008')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1642', 3, N'ACCU_CARPOWER', CAST(N'2018-04-04T00:00:00.000' AS DateTime), 1, 88, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1642', 4, N'RUBA.MASQ50CL', CAST(N'2018-04-04T00:00:00.000' AS DateTime), 12, 3.08, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1716', 1, N'GIRO. REN5010468860', CAST(N'2018-04-10T00:00:00.000' AS DateTime), 1, 196.09, N'5010468860')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1717', 1, N'GILE.SECALPHA150', CAST(N'2018-04-10T00:00:00.000' AS DateTime), 3, 269.1, N'G10715')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1717', 2, N'GILE.SECDV150', CAST(N'2018-04-10T00:00:00.000' AS DateTime), 2, 174, N'G13169')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1717', 3, N'BRAS.PLASTORM150N', CAST(N'2018-04-10T00:00:00.000' AS DateTime), 3, 19.39, N'58354')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1729', 1, N'GROU.NOR1200', CAST(N'2018-04-10T00:00:00.000' AS DateTime), 1, 6145, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1731', 1, N'TRONC.MS261', CAST(N'2018-04-09T00:00:00.000' AS DateTime), 1, 545, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1731', 2, N'SOUF.HUS580BTS', CAST(N'2018-04-09T00:00:00.000' AS DateTime), 1, 590, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1731', 3, N'TOND.VIKMB756GS', CAST(N'2018-04-09T00:00:00.000' AS DateTime), 1, 1250, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1731', 4, N'CHAI.STH39700030074', CAST(N'2018-04-09T00:00:00.000' AS DateTime), 1, 16.6667, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1805', 1, N'CONV.ATL520215', CAST(N'2018-03-14T00:00:00.000' AS DateTime), 1, 150.9, N'520215')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1805', 2, N'TAXE', CAST(N'2017-12-27T00:00:00.000' AS DateTime), 1, 1.67, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1805', 3, N'PRIS.LEG555304', CAST(N'2018-03-14T00:00:00.000' AS DateTime), 10, 21, N'LEG555304')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1805', 4, N'DISJ.SCHA9N21025', CAST(N'2018-03-14T00:00:00.000' AS DateTime), 10, 13.99, N'SCHA9N21025')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1805', 5, N'FILT.RIT3172100', CAST(N'2018-03-14T00:00:00.000' AS DateTime), 30, 13.9, N'RIT3172100')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1805', 6, N'CORD.SCHBMXFCC203', CAST(N'2018-03-14T00:00:00.000' AS DateTime), 3, 59.84, N'BMXFCC203')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1805', 7, N'CORD.SCHBMXFCC201', CAST(N'2018-03-14T00:00:00.000' AS DateTime), 1, 37.39, N'SCH BMXFCC201')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1805', 8, N'PILE_9V', CAST(N'2018-03-14T00:00:00.000' AS DateTime), 20, 2.9, N'CIPE095883')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1805', 9, N'PILE_CR2032', CAST(N'2018-03-14T00:00:00.000' AS DateTime), 12, 2.4, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1805', 10, N'PILE_6V', CAST(N'2018-03-14T00:00:00.000' AS DateTime), 4, 11.9, N'36045812-LR820')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1805', 11, N'BATT.FUL30', CAST(N'2018-03-14T00:00:00.000' AS DateTime), 2, 231, NULL)
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1805', 12, N'PORT', CAST(N'2018-03-13T00:00:00.000' AS DateTime), 1, 65, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1805', 13, N'GOUL.SICGPC35-35ALU', CAST(N'2018-03-14T00:00:00.000' AS DateTime), 1, 32.52, N'7313 S2565014')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1806', 1, N'VERR.CLA079525258XR', CAST(N'2018-04-12T00:00:00.000' AS DateTime), 2, 23.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1807', 1, N'ONDU.S2SSRS1000', CAST(N'2018-04-12T00:00:00.000' AS DateTime), 3, 1220, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1834', 1, N'VASE_PER34136', CAST(N'2018-04-12T00:00:00.000' AS DateTime), 1, 374.72, N'34136')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1834', 2, N'BOUC.PER34150', CAST(N'2018-04-12T00:00:00.000' AS DateTime), 1, 46.02, N'34150')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1834', 3, N'BAGU.PER33053', CAST(N'2018-04-12T00:00:00.000' AS DateTime), 6, 3.01, N'33053')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1834', 4, N'DURI.PER26481', CAST(N'2018-04-12T00:00:00.000' AS DateTime), 2, 5.72, N'26481')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1834', 5, N'COLL.PER19609', CAST(N'2018-04-12T00:00:00.000' AS DateTime), 4, 3.51, N'19609')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1834', 6, N'TABL.PER41244', CAST(N'2018-04-12T00:00:00.000' AS DateTime), 1, 1549.1, N'41244')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1834', 7, N'SOND.PER41192', CAST(N'2018-04-12T00:00:00.000' AS DateTime), 1, 154.46, N'41192')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1835', 1, N'PNEU_207/75R17.5', CAST(N'2018-04-13T00:00:00.000' AS DateTime), 1, 155.6, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 1, N'MEUL.STH52027507010', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 4, 11.82, N'5202-750-7010')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 2, N'MEUL.STH52037507010', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 4, 11.72, N'52037507010')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 3, N'FILT.HUS503895301', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 2, 31.71, N'503895301')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 4, N'BOUC.HUS537215207', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 1, 9.39, N'537215207')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 5, N'GUID.HUS503141401', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 1, 4.68, N'503141401')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 6, N'GUID.HUS503141501', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 1, 5.53, N'503141501')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 7, N'CLOC.HUS503143204', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 1, 58.58, N'503143204')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 8, N'GUID.HUS501589601', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 1, 115.42, N'501589601')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 9, N'GUID.STH30020009741', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 1, 108.16, N'30020009741')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 10, N'CHAI.STH39460000091', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 5, 37.42, N'39460000091')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 11, N'BAGU.STH00006421207', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 1, 11.4, N'00006421207')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 12, N'CIRC.STH94606241001', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 10, 0.65, N'94606241001')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 13, N'CART.STH11290801806', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 2, 28.75, N'11290801806')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 14, N'CLIQ.STH11251957200', CAST(N'2018-04-26T00:00:00.000' AS DateTime), 1, 2.58, N'11251957200')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 15, N'POUL.STH11231950400', CAST(N'2018-04-26T00:00:00.000' AS DateTime), 1, 17.64, N'11231950400')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 16, N'POIG.STH00001903402', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 1, 17.47, N'00001903402')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 17, N'RESS.STH11231900600', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 1, 8.88, N'11291900600')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 18, N'CORD.DLANC3', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 1, 1.83, N'C')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 19, N'VIS_STH90223130680', CAST(N'2018-04-26T00:00:00.000' AS DateTime), 2, 0.79, N'90223130680')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 20, N'TRONC.MS261', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 1, 498, N'MS261')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 21, N'GUID.STH30030005217', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 1, 47, N'30030005217')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 22, N'CROC.WOLRTM', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 1, 10.56, N'RTM')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 23, N'PORT.WOLUTM', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 1, 24.71, N'UTM')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1937', 24, N'SCIE_WOLOYM3', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 1, 35.57, N'WOLF OYM2')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1995', 1, N'VIS_NOR104158', CAST(N'2018-04-19T00:00:00.000' AS DateTime), 2, 0.46, N'104158')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1995', 2, N'ROND.NOR104121', CAST(N'2018-04-19T00:00:00.000' AS DateTime), 2, 0.18, N'104121')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1995', 3, N'BAGU.NOR103599', CAST(N'2018-04-19T00:00:00.000' AS DateTime), 8, 7.72, N'103599')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1995', 4, N'BAGU.NOR103568', CAST(N'2018-04-19T00:00:00.000' AS DateTime), 2, 6.03, N'103568')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1995', 5, N'AXE_NOR102876', CAST(N'2018-04-19T00:00:00.000' AS DateTime), 2, 32.34, N'102876')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1995', 6, N'AXE_NOR102868', CAST(N'2018-04-19T00:00:00.000' AS DateTime), 1, 27, N'102868')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1995', 7, N'AXE_NOR102878', CAST(N'2018-04-19T00:00:00.000' AS DateTime), 1, 27, N'102878')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1995', 8, N'AXE_NOR102877', CAST(N'2018-04-19T00:00:00.000' AS DateTime), 2, 27, N'102877')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-1995', 9, N'ENTR.NOR102870', CAST(N'2018-04-19T00:00:00.000' AS DateTime), 8, 17.52, N'102870')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2005', 1, N'CONT.PERENGLEVAGE', CAST(N'2018-05-10T00:00:00.000' AS DateTime), 1, 696, N'ENGINS DE LEVAGE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2005', 2, N'CONT.PERAPPARAU', CAST(N'2018-05-10T00:00:00.000' AS DateTime), 1, 246, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2005', 3, N'CONT.PERENGLEVAGE', CAST(N'2018-05-10T00:00:00.000' AS DateTime), 1, 1000, N'ENGINS DE LEVAGE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2005', 4, N'CONT.PERAPPARAU', CAST(N'2018-05-10T00:00:00.000' AS DateTime), 1, 1120, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2006', 1, N'ALUM_U50X80X50X5', CAST(N'2018-04-13T00:00:00.000' AS DateTime), 6.15, 10.91, N'624268')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2006', 2, N'ALUM.C50X5', CAST(N'2018-04-13T00:00:00.000' AS DateTime), 6.15, 8.32, N'80651')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2006', 3, N'ALUM_P050X05', CAST(N'2018-04-13T00:00:00.000' AS DateTime), 6.15, 4.59, N'190528')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2006', 4, N'EMBA.', CAST(N'2018-05-10T00:00:00.000' AS DateTime), 1, 9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2041', 1, N'ELEC.DS2000S', CAST(N'2018-04-20T00:00:00.000' AS DateTime), 1, 318.8, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2042', 1, N'FIL_DEB2.4X261', CAST(N'2018-05-14T00:00:00.000' AS DateTime), 2, 32.27, N'0000-930-2246')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2042', 2, N'TETE_ECHX047000330', CAST(N'2018-05-14T00:00:00.000' AS DateTime), 5, 31.67, N'X047000331')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2042', 3, N'ATTA.CAPOT_GM', CAST(N'2018-05-14T00:00:00.000' AS DateTime), 10, 2.78, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2042', 4, N'FIL_DEB2.4X70CARBO', CAST(N'2018-05-14T00:00:00.000' AS DateTime), 5, 20, N'00009304303')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2042', 5, N'TETE_STH40037102115', CAST(N'2018-07-14T00:00:00.000' AS DateTime), 1, 28.6, N'40037102115')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2042', 7, N'FILT.HUS503895301', CAST(N'2018-05-14T00:00:00.000' AS DateTime), 1, 31.71, N'503895301')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2042', 8, N'CLOC.HUS503143204', CAST(N'2018-05-14T00:00:00.000' AS DateTime), 1, 58.58, N'503143204')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2042', 9, N'BOUC.HUS537215202', CAST(N'2018-07-14T00:00:00.000' AS DateTime), 1, 9.39, N'HUSQ537215202')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2042', 10, N'GUID.HUS503141401', CAST(N'2018-05-14T00:00:00.000' AS DateTime), 1, 4.68, N'503141401')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2042', 11, N'GUID.HUS503141501', CAST(N'2018-05-14T00:00:00.000' AS DateTime), 1, 5.53, N'503141501')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2042', 12, N'MANC.WOLZMT2', CAST(N'2018-05-14T00:00:00.000' AS DateTime), 2, 44.92, N'ZMT2')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2042', 13, N'BALA.WOLUBM40', CAST(N'2018-05-14T00:00:00.000' AS DateTime), 1, 16.92, N'UBM40')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2042', 14, N'BALA.WOLUAM50', CAST(N'2018-07-14T00:00:00.000' AS DateTime), 1, 28.06, N'WOLF UAM')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2042', 15, N'CROC.WOLRTM', CAST(N'2018-05-14T00:00:00.000' AS DateTime), 1, 10.56, N'RTM')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2042', 16, N'RATE.WOLDOM40', CAST(N'2018-07-14T00:00:00.000' AS DateTime), 2, 17.97, N'WOLF DOM40')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2042', 17, N'MANC.WOLZMA150', CAST(N'2018-05-14T00:00:00.000' AS DateTime), 2, 17.5, N'WOLF ZMA150')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2042', 18, N'SCIE_WOLOYM3', CAST(N'2018-05-14T00:00:00.000' AS DateTime), 1, 35.57, N'WOLF OYM2')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2042', 19, N'ELAG.WOLOR750', CAST(N'2018-05-14T00:00:00.000' AS DateTime), 1, 50.23, N'OR750')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2042', 20, N'REDU.STH41286400101', CAST(N'2018-07-14T00:00:00.000' AS DateTime), 1, 141.98, N'41286400101')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2042', 21, N'EMBR.ECHP021016610', CAST(N'2018-07-14T00:00:00.000' AS DateTime), 1, 39.66, N'P021016610')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2042', 22, N'GUID.HUS501589601', CAST(N'2018-05-14T00:00:00.000' AS DateTime), 1, 115.42, N'501589601')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2042', 23, N'PROT.STA66070644R', CAST(N'2018-07-14T00:00:00.000' AS DateTime), 1, 12.97, N'66070644R')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2042', 24, N'VIS_STA3960137R', CAST(N'2018-07-14T00:00:00.000' AS DateTime), 2, 2.765, N'3960137R')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2465', 1, N'POST_IT76X76_4C', CAST(N'2018-05-14T00:00:00.000' AS DateTime), 4, 8.28, N'63523')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2465', 3, N'CLAS.8VM', CAST(N'2018-06-11T00:00:00.000' AS DateTime), 10, 2.74, N'59032')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2553', 1, N'GACH.ELEC10/24V', CAST(N'2018-05-18T00:00:00.000' AS DateTime), 1, 96.65, N'860956')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2554', 1, N'WHIT.SPIRIT5', CAST(N'2018-03-17T00:00:00.000' AS DateTime), 1, 16.24, N'WS5')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2554', 2, N'CONC.RAON0.20', CAST(N'2018-03-17T00:00:00.000' AS DateTime), 14.4, 20.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2554', 3, N'RUBA.MASQ25', CAST(N'2018-03-17T00:00:00.000' AS DateTime), 5, 1.66, N'908863')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2554', 4, N'RUBA.MASQ40', CAST(N'2018-04-17T00:00:00.000' AS DateTime), 5, 2.58, N'902864')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2554', 5, N'ROBI.PUIS1/2', CAST(N'2018-03-17T00:00:00.000' AS DateTime), 1, 15.23, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2554', 6, N'MAST.COL.INST.BL', CAST(N'2018-03-17T00:00:00.000' AS DateTime), 2, 7.55, N'SK11FCB')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2554', 7, N'SAC_LESTAGE', CAST(N'2018-03-17T00:00:00.000' AS DateTime), 20, 1.6, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2554', 8, N'GEOT.200G_5M', CAST(N'2018-04-17T00:00:00.000' AS DateTime), 500, 1.26, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2554', 10, N'GAIN.90TPC25M', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 25, 1.74, N'GTF90')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2554', 11, N'GAIN.63TPC25M', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 50, 1.08, N'GTF63R')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2554', 12, N'GAIN.63VERT50M', CAST(N'2018-04-17T00:00:00.000' AS DateTime), 50, 1.08, N'GTF63V')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2554', 13, N'CIME.CE25', CAST(N'2018-04-15T00:00:00.000' AS DateTime), 64, 3.18, N'C25CE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2554', 14, N'FORE.SDS+06X160', CAST(N'2018-04-28T00:00:00.000' AS DateTime), 3, 4.38, N'1618596167')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2554', 15, N'FORE.SDS+08X110', CAST(N'2018-04-28T00:00:00.000' AS DateTime), 3, 4.75, N'10501968')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2554', 16, N'PEIN.BLMAT6', CAST(N'2018-03-17T00:00:00.000' AS DateTime), 1, 34.12, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2554', 17, N'BLOC_P204/83H88P', CAST(N'2018-04-17T00:00:00.000' AS DateTime), 1, 59.4, N'BPP8883')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2554', 18, N'ENSE.PF_VENISE', CAST(N'2018-04-28T00:00:00.000' AS DateTime), 1, 7.12, N'712070')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2554', 20, N'COLO.NOIR', CAST(N'2018-03-17T00:00:00.000' AS DateTime), 1, 10.01, N'MO302470')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2554', 21, N'SILI.SAN.GR', CAST(N'2018-03-16T00:00:00.000' AS DateTime), 1, 7.66, N'890700')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2554', 22, N'SILI.NEUT.BLC', CAST(N'2018-04-14T00:00:00.000' AS DateTime), 1, 5.78, N'128795')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2554', 23, N'ROND.CAR06X20', CAST(N'2018-04-17T00:00:00.000' AS DateTime), 50, 0.067, N'55731674')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2560', 1, N'GAZO.', CAST(N'2018-05-17T00:00:00.000' AS DateTime), 6000, 1.232, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2560', 2, N'GNR_BF', CAST(N'2018-05-17T00:00:00.000' AS DateTime), 2000, 0.813, N'BIOFREE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2560', 3, N'SP95E5', CAST(N'2018-05-17T00:00:00.000' AS DateTime), 2000, 1.31, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 1, N'GAIN.90BLEU50M', CAST(N'2018-05-29T00:00:00.000' AS DateTime), 50, 1.74, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 2, N'GAIN.90TPC25M', CAST(N'2018-05-28T00:00:00.000' AS DateTime), 25, 1.74, N'GTF90')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 3, N'GAIN.63VERT50M', CAST(N'2018-06-29T00:00:00.000' AS DateTime), 100, 1.08, N'GTF63V')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 4, N'GRIL.AV.ROUGE', CAST(N'2018-06-11T00:00:00.000' AS DateTime), 2, 18.43, N'GAR')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 6, N'GAZ_PROP13KGS', CAST(N'2018-05-03T00:00:00.000' AS DateTime), 3, 31.44, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 7, N'TUYA.PE32', CAST(N'2018-06-29T00:00:00.000' AS DateTime), 100, 1.66, N'TPA32')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 8, N'LAIN.DVPV120', CAST(N'2018-06-29T00:00:00.000' AS DateTime), 25.2, 5.88, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 11, N'CADE.S''ENTR40', CAST(N'2018-06-29T00:00:00.000' AS DateTime), 4, 12.32, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 12, N'CIME.PROMPT25', CAST(N'2018-05-29T00:00:00.000' AS DateTime), 1, 22.16, N'VIC25')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 13, N'RUBA.MU33X50', CAST(N'2018-05-29T00:00:00.000' AS DateTime), 6, 8.58, N'115482')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 14, N'ROBI.MAL', CAST(N'2018-07-05T00:00:00.000' AS DateTime), 2, 5.2, N'8031520011')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 15, N'ROBI.EQR.ROS.1/2', CAST(N'2018-07-05T00:00:00.000' AS DateTime), 2, 10.87, N'04917')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 16, N'CIME.CE25', CAST(N'2018-06-27T00:00:00.000' AS DateTime), 2, 3.18, N'C25CE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 17, N'SAC_BIGBAG', CAST(N'2018-06-29T00:00:00.000' AS DateTime), 2, 12, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 18, N'CIME.CE25', CAST(N'2018-06-27T00:00:00.000' AS DateTime), 24, 3.18, N'C25CE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 19, N'GRAV.0-15', CAST(N'2018-05-28T00:00:00.000' AS DateTime), 2, 42.3, N'G015')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 20, N'BA13_2.5/0.6', CAST(N'2018-05-29T00:00:00.000' AS DateTime), 10.5, 4.81, N'BA13600')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 21, N'COLL.DOUB25', CAST(N'2018-05-29T00:00:00.000' AS DateTime), 1, 11.29, N'CD25S')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 22, N'FOUR.S47', CAST(N'2018-05-28T00:00:00.000' AS DateTime), 9, 0.87, N'S47')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 23, N'TIGE_OEILLET250MM', CAST(N'2018-07-05T00:00:00.000' AS DateTime), 20, 0.16, N'A04767')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 24, N'SUSP.PLAF/RESSORT', CAST(N'2018-07-05T00:00:00.000' AS DateTime), 20, 1.26, N'SPR')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 25, N'LATT.TOIT3ML', CAST(N'2018-05-29T00:00:00.000' AS DateTime), 9, 0.42, N'L2548')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 26, N'PEIN.SATBLANC10', CAST(N'2018-05-29T00:00:00.000' AS DateTime), 1, 51.61, N'BM0286001100')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 27, N'BETO.LES165L', CAST(N'2018-07-05T00:00:00.000' AS DateTime), 1, 479.92, N'SM165S')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 28, N'TAXE', CAST(N'2018-05-19T00:00:00.000' AS DateTime), 1, 2.08, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 29, N'SABL.ROUTE', CAST(N'2018-07-05T00:00:00.000' AS DateTime), 2, 27.82, N'1D')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2562', 30, N'PORT', CAST(N'2018-05-04T00:00:00.000' AS DateTime), 1, 38, N'FRANCO')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 1, N'CLE_TRIANGLE5MM', CAST(N'2018-04-13T00:00:00.000' AS DateTime), 5, 17.89, N'AGI394012')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 2, N'CLE_TRIANGLE11MM', CAST(N'2018-04-13T00:00:00.000' AS DateTime), 1, 44.12, N'AGI394013')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 3, N'CABL.R2V4G10', CAST(N'2018-04-13T00:00:00.000' AS DateTime), 80, 4.98, N'CDL1 01382560')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 4, N'GAIN.THER3M85815', CAST(N'2018-04-13T00:00:00.000' AS DateTime), 1, 42.56, N'3M 85815')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 5, N'GAIN.THER3M85833*', CAST(N'2018-05-14T00:00:00.000' AS DateTime), 1, 42.56, N'3M 85833')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 6, N'GAIN.THER3M85842', CAST(N'2018-05-13T00:00:00.000' AS DateTime), 1, 42.56, N'3M 85842')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 7, N'GAIN.THER3M85851', CAST(N'2018-05-13T00:00:00.000' AS DateTime), 5, 49.47, N'3M 85851')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 8, N'PROJ.20WLED', CAST(N'2018-05-13T00:00:00.000' AS DateTime), 5, 39, N'BRENN 1171600204')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 9, N'BORN.WAG222413', CAST(N'2018-04-15T00:00:00.000' AS DateTime), 1, 16.65, N'WAGO221413')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 10, N'RELA.WEI1129421001', CAST(N'2018-05-13T00:00:00.000' AS DateTime), 10, 24, N'1129421001')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 11, N'BATT.AMP9068', CAST(N'2018-04-13T00:00:00.000' AS DateTime), 2, 306, N'AMP9068')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 12, N'TUBE_N14W', CAST(N'2018-05-13T00:00:00.000' AS DateTime), 5, 17, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 13, N'TAXE', CAST(N'2018-01-26T00:00:00.000' AS DateTime), 5, 0.2, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 14, N'BOIT.LEG089281', CAST(N'2018-05-13T00:00:00.000' AS DateTime), 3, 1.356, N'LEG089281')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 15, N'MODU.GOT01020', CAST(N'2018-05-13T00:00:00.000' AS DateTime), 1, 39.08, N'GOTRONIC 01020')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 16, N'TEMP.GOT01557', CAST(N'2018-05-13T00:00:00.000' AS DateTime), 1, 28.25, N'GOTRONIC 01557')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 17, N'PORT', CAST(N'2018-04-12T00:00:00.000' AS DateTime), 1, 10, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 18, N'PILE_CR2032', CAST(N'2018-04-13T00:00:00.000' AS DateTime), 2, 2.4, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 19, N'RUBA.IJAUNE50', CAST(N'2018-05-14T00:00:00.000' AS DateTime), 5, 7.9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 20, N'RUBA.IVERT50', CAST(N'2018-05-13T00:00:00.000' AS DateTime), 3, 7.9, N'0-031614')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 21, N'RUBA.IROUG50', CAST(N'2018-05-13T00:00:00.000' AS DateTime), 2, 7.9, N'0-031610')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 22, N'RUBA.IBLEU50', CAST(N'2018-04-13T00:00:00.000' AS DateTime), 1, 7.9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 23, N'PILE_9V', CAST(N'2018-04-13T00:00:00.000' AS DateTime), 21, 2.9, N'CIPE095883')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 24, N'DISJ.SCHA9N21025', CAST(N'2018-04-13T00:00:00.000' AS DateTime), 3, 77.24, N'SCHA9N21025')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 25, N'SOND.VEG52/6M', CAST(N'2018-04-13T00:00:00.000' AS DateTime), 1, 493.26, N'WL52XXX4AKD1BC1X')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 26, N'SOND.VEG52/12M', CAST(N'2018-05-14T00:00:00.000' AS DateTime), 2, 485.17, N'WL52XXA4ALK1CD1X')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2798', 27, N'ALIM.VEGA', CAST(N'2018-04-13T00:00:00.000' AS DateTime), 1, 148.28, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2846', 1, N'BOUE_COUR+LIGNE', CAST(N'2018-05-30T00:00:00.000' AS DateTime), 4, 43.166, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2846', 2, N'PORT', CAST(N'2018-06-03T00:00:00.000' AS DateTime), 1, 20.833, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2859', 1, N'GOND_RAV12', CAST(N'2018-06-01T00:00:00.000' AS DateTime), 6, 22.95, N'BATIFER165947')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2859', 2, N'OREI.DN12', CAST(N'2018-06-01T00:00:00.000' AS DateTime), 6, 25.14, N'BATIFER165953')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2859', 3, N'CART.SDHC64GO', CAST(N'2018-06-01T00:00:00.000' AS DateTime), 1, 41, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2861', 1, N'PORT.FACEF.6R', CAST(N'2018-06-05T00:00:00.000' AS DateTime), 2, 10.12, N'FACEF.6R')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2861', 2, N'LAME_D315X2.5X32_120DTS', CAST(N'2018-06-05T00:00:00.000' AS DateTime), 1, 191, N'TOOL9135')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2861', 3, N'FILT.HIFSC40003', CAST(N'2018-06-05T00:00:00.000' AS DateTime), 1, 36.46, N'JURASC40003')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2861', 4, N'PINC.FAC192.16VE', CAST(N'2018-06-05T00:00:00.000' AS DateTime), 2, 20.19, N'FAC192.16VE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2861', 5, N'PINC.FAC195.20VE', CAST(N'2018-04-17T00:00:00.000' AS DateTime), 1, 21.92, N'FAC195.20AVSE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2861', 6, N'PINC.FAC185.20VE', CAST(N'2018-07-06T00:00:00.000' AS DateTime), 2, 20.75, N'FAC185.20VE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2861', 7, N'TOUR.FAC831.1', CAST(N'2018-06-05T00:00:00.000' AS DateTime), 1, 11.8, N'FAC831.1')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2861', 8, N'JERR.05LRGE', CAST(N'2018-07-06T00:00:00.000' AS DateTime), 2, 7.18, N'STAR359')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2861', 9, N'BROS.MET5RG', CAST(N'2018-07-06T00:00:00.000' AS DateTime), 5, 1.99, N'NORT66254405437')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2861', 10, N'LAMP.A_SOUDER', CAST(N'2018-07-06T00:00:00.000' AS DateTime), 1, 45.55, N'SOD05692')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2861', 11, N'AMPO.MINIWATT5W', CAST(N'2018-07-13T00:00:00.000' AS DateTime), 20, 0.71, N'OSRA2825')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2861', 12, N'SAND.L60', CAST(N'2018-07-06T00:00:00.000' AS DateTime), 6, 2.77, N'SOD18366')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-2968', 1, N'MODU.SCHBMXP342020', CAST(N'2018-06-05T00:00:00.000' AS DateTime), 2, 859.42, N'SCH BMXP342020')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3035', 1, N'TUBE_RVI5689110248', CAST(N'2018-06-09T00:00:00.000' AS DateTime), 1, 4.83, N'5689110248')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3035', 2, N'FOUR.RVI5005030702', CAST(N'2018-06-09T00:00:00.000' AS DateTime), 2, 0.69, N'5005030702')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3035', 3, N'ECRO.RVI5005030013', CAST(N'2018-06-09T00:00:00.000' AS DateTime), 2, 3.87, N'5005030013')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3035', 4, N'BAGU.RVI5005030003', CAST(N'2018-06-09T00:00:00.000' AS DateTime), 2, 0.76, N'5005030003')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3037', 1, N'POEL.GOD389144', CAST(N'2018-06-12T00:00:00.000' AS DateTime), 1, 785.77, N'FONTEMONT 389144')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3063', 1, N'PRES.CAROUSSEL', CAST(N'2018-06-11T00:00:00.000' AS DateTime), 5, 212.5, N'100')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3064', 1, N'CART.RES6962', CAST(N'2018-06-13T00:00:00.000' AS DateTime), 1, 14.71, N'REST6962')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3064', 2, N'CABL.RES16263', CAST(N'2018-06-13T00:00:00.000' AS DateTime), 1, 44.13, N'REST16263')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3064', 3, N'CABL.RES16264', CAST(N'2018-06-13T00:00:00.000' AS DateTime), 2, 58.09, N'REST16264')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3064', 4, N'PORT.REST17018', CAST(N'2018-07-14T00:00:00.000' AS DateTime), 10, 2.35, N'REST17018')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3064', 5, N'COSS.OB6', CAST(N'2018-06-13T00:00:00.000' AS DateTime), 1, 8.59, N'REST6906')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3064', 6, N'COSS.OB8', CAST(N'2018-06-13T00:00:00.000' AS DateTime), 1, 7.54, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3175', 1, N'EXTR.FUME', CAST(N'2018-06-19T00:00:00.000' AS DateTime), 1, 2010.3, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3175', 2, N'CAGO.SOUDURE', CAST(N'2018-06-19T00:00:00.000' AS DateTime), 1, 750, N'102672')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3175', 3, N'TAXE', CAST(N'2018-06-19T00:00:00.000' AS DateTime), 1, 7.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3216', 12, N'COFF.LEG058957', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 1, 163.38, N'LEG058957')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3216', 13, N'CHAS.LEG057743', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 2, 103.56, N'LEG057743')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3216', 14, N'PRIS.LEG057667', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 2, 4.135, N'LEG057667')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3216', 17, N'COFF.LEG058954', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 1, 481.2, N'LEG058954')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3216', 18, N'BOUT.LEG057745', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 1, 37.94, N'LEG057745')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3216', 19, N'FICH.LEG056478', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 1, 16.41, N'LEG056478')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3216', 20, N'FICH.LEG056477', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 5, 15.78, N'LEG056477')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3216', 21, N'PRIS.LEG555109', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 2, 7.645, N'LEG555109')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3216', 22, N'PRIS.LEG555108', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 2, 7.35, N'LEG555108')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3216', 23, N'FICH.LEG057440', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 1, 33.94, N'LEG057440')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3216', 26, N'FICH.LEG056808', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 5, 18.528, N'LEG056808')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3216', 27, N'PRIS.LEG555189', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 1, 8.58, N'LEG555189')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3216', 28, N'INTE.SCHA9R11440', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 1, 114.37, N'SCHA9R11440')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3216', 29, N'MODU.SCHA9A26946', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 1, 44.04, N'SCHA9A26946')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3216', 30, N'DISJ.SCHA9F77220', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 1, 47.89, N'A977220')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3216', 31, N'PROT.SCHGV2ME16', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 1, 41.71, N'SCHGV2ME16')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3216', 33, N'INVE.LEG027510', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 1, 36.08, N'LEG027510')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3216', 34, N'AMPO.LED6W', CAST(N'2018-02-22T00:00:00.000' AS DateTime), 10, 6, N'BENE119169UL2-C3/N')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3216', 35, N'TAXE', CAST(N'2017-12-07T00:00:00.000' AS DateTime), 10, 0.2, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3216', 36, N'PASS.HAGSL1807507030', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 4, 10.84, N'HAG SL1807507030')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3216', 37, N'MOUL.LEG030008', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 4, 1.33, N'LEG030008')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3217', 2, N'FEU_TRA160434-24', CAST(N'2018-05-31T00:00:00.000' AS DateTime), 4, 240, N'160434-24')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3218', 1, N'FEU_CLA7701026757', CAST(N'2018-06-19T00:00:00.000' AS DateTime), 1, 14.3, N'7701026757')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3218', 2, N'DEMA.CLA11320110', CAST(N'2018-06-19T00:00:00.000' AS DateTime), 1, 362.77, N'11320110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3219', 1, N'GAZO.', CAST(N'2018-06-12T00:00:00.000' AS DateTime), 1200, 1.207, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3219', 2, N'GNR_BF', CAST(N'2018-06-12T00:00:00.000' AS DateTime), 1525, 0.785, N'BIOFREE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3219', 3, N'SP95E5', CAST(N'2018-06-12T00:00:00.000' AS DateTime), 2000, 1.269, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3225', 1, N'PATI.NOR14505700', CAST(N'2018-06-19T00:00:00.000' AS DateTime), 2, 28.8, N'1.45.05.700 - 102828')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3225', 2, N'VIS_ROU11009121', CAST(N'2018-06-19T00:00:00.000' AS DateTime), 4, 0.41, N'1009121 - 101961')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3225', 3, N'ECRO.ROU11105010', CAST(N'2018-06-18T00:00:00.000' AS DateTime), 4, 0.48, N'11105010')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3225', 4, N'PORT', CAST(N'2018-06-19T00:00:00.000' AS DateTime), 1, 17.4, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3245', 1, N'TUBE_R48.3X2A2', CAST(N'2018-06-20T00:00:00.000' AS DateTime), 12.3, 13.78, N'228802')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3245', 2, N'EMBA.', CAST(N'2018-07-16T00:00:00.000' AS DateTime), 1, 9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3248', 1, N'MODU.HERM300', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 20, 36.25, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3248', 2, N'PLOT_HERPLAST', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 48, 7.9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3248', 3, N'PORT.HERASM90', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 1, 57.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3248', 4, N'SERR.HER', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 1, 24, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3248', 5, N'COLL.HERHAUTE_SECU', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 25, 1.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3248', 6, N'GOND.HER', CAST(N'2018-06-23T00:00:00.000' AS DateTime), 1, 10.4, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3248', 8, N'PORT', CAST(N'2018-06-23T00:00:00.000' AS DateTime), 1, 375, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3249', 2, N'RAYO.3T1000X500X2000DEP', CAST(N'2018-06-26T00:00:00.000' AS DateTime), 2, 192, N'FRANKEL 715185FP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3249', 3, N'RAYO.3T1000X500X2000AD', CAST(N'2018-06-26T00:00:00.000' AS DateTime), 3, 151.4, N'FRANKEL 715188FP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3249', 4, N'BAC_BEC3.2R', CAST(N'2018-06-26T00:00:00.000' AS DateTime), 1, 91.3, N'723332FP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3249', 5, N'RAYO.3T800X500X1920DEP', CAST(N'2018-06-26T00:00:00.000' AS DateTime), 1, 243.5, N'FRANKEL 505992FP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3249', 6, N'RAYO.3T800X500X1920AD', CAST(N'2018-06-26T00:00:00.000' AS DateTime), 1, 199, N'507184FP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3249', 7, N'BAC_BEC0.25J', CAST(N'2018-06-26T00:00:00.000' AS DateTime), 1, 36.8, N'611911FP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3249', 8, N'BAC_BEC0.7V', CAST(N'2018-06-26T00:00:00.000' AS DateTime), 1, 27.9, N'611904FP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3249', 9, N'BAC_600X400X220P', CAST(N'2018-06-26T00:00:00.000' AS DateTime), 1, 41.35, N'986414FP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3249', 10, N'COUV.600X400X220', CAST(N'2018-06-26T00:00:00.000' AS DateTime), 1, 22.4, N'987073FP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3249', 11, N'BAC_600X400X320P', CAST(N'2018-06-26T00:00:00.000' AS DateTime), 3, 26.3, N'986417FP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3249', 12, N'COUV.600X400X320', CAST(N'2018-06-26T00:00:00.000' AS DateTime), 1, 22.4, N'986423FP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3250', 1, N'KLAX.CLOCHE12V', CAST(N'2018-06-26T00:00:00.000' AS DateTime), 1, 52, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3250', 2, N'PORT', CAST(N'2018-06-26T00:00:00.000' AS DateTime), 1, 10, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3250', 3, N'INTE.APE647H/2K', CAST(N'2018-06-26T00:00:00.000' AS DateTime), 1, 32, N'RS6928412')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3334', 1, N'ARMO.OUTIL1000X500', CAST(N'2018-06-20T00:00:00.000' AS DateTime), 1, 241.8, N'7062713M - FRANKEL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3334', 2, N'LAMP.POSTE_TRAVAIL', CAST(N'2018-06-20T00:00:00.000' AS DateTime), 1, 60.84, N'1780293 FRANKEL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3334', 3, N'RAYO.CL1536', CAST(N'2018-06-20T00:00:00.000' AS DateTime), 1, 309.6, N'9297543 FRANKEL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3334', 4, N'PLAQ.PERF1029/457', CAST(N'2018-06-20T00:00:00.000' AS DateTime), 1, 70.44, N'1701823 FRANKEL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3334', 5, N'SUPP.PO', CAST(N'2018-06-20T00:00:00.000' AS DateTime), 1, 58.38, N'1701103 FRANKEL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3334', 6, N'BALA.COMPTEUSE3KG', CAST(N'2018-06-20T00:00:00.000' AS DateTime), 1, 342.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3334bis', 5, N'MIRO.VOIRIE_600', CAST(N'2018-04-13T00:00:00.000' AS DateTime), 1, 492, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3334bis', 6, N'POTE.DN7.6/LG4M', CAST(N'2018-04-13T00:00:00.000' AS DateTime), 1, 68.6, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3334bis', 7, N'PANN.B6D_600CL2', CAST(N'2018-04-13T00:00:00.000' AS DateTime), 3, 78, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3334bis', 8, N'COLL.GAL80X40', CAST(N'2018-04-12T00:00:00.000' AS DateTime), 6, 3, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3334bis', 9, N'PANN.AK5_700CL2', CAST(N'2018-04-13T00:00:00.000' AS DateTime), 4, 70.8, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3334bis', 11, N'PANC.KM9_700X200CL2', CAST(N'2018-04-13T00:00:00.000' AS DateTime), 2, 50.55, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3334bis', 12, N'PANC.KM9_700X200CL2', CAST(N'2018-04-13T00:00:00.000' AS DateTime), 2, 50.55, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3334bis', 13, N'PANN.KC1_800/600CL2', CAST(N'2018-04-13T00:00:00.000' AS DateTime), 2, 89.15, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3334bis', 14, N'CABL.TIRF3T200', CAST(N'2018-06-23T00:00:00.000' AS DateTime), 1, 468.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3334bis', 15, N'DIAB.M.ESCALIER', CAST(N'2018-05-18T00:00:00.000' AS DateTime), 1, 320, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3373', 1, N'GEL_SIPHON1', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 5, 14.88, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3373', 2, N'NETT.SURFACE', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 6, 15.2, N'BACTIPAL PRO-0207170')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3373', 3, N'LING.WC', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 12, 12.41, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3373', 4, N'SAVO.GEL350', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 24, 8.97, N'0216147')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3373', 5, N'SAC_POUB130L', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 2, 67.97, N'0111103')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3373', 6, N'TRAC.ORANGE', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 6, 16.81, N'AS LINER -0202120OF')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3373', 8, N'LING.100', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 12, 22.9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3373', 9, N'INSE.POMP.', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 12, 16.37, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3373', 10, N'ESSU.MAIN_KIM6763', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 180, 4.499, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3373', 11, N'PAPI.TOIL380M', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 12, 3.408, N'0102110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3373', 12, N'LIQU.VAISSEL1L', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 12, 8.75, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3373', 13, N'DESO.MECHE', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 30, 5.99, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3373', 14, N'BLOC_WC', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 30, 2.9, N'BOULES')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3373', 15, N'TAMP.', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 30, 1.497, N'0109123 - SPONTEX')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3373', 16, N'TRAC.BLEU', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 6, 16.81, N'0202120BE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3373', 17, N'SPRA.NETT.VIT', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 6, 15.28, N'BIOTEC-VITRE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3373', 18, N'SPRA.COKP750ML', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 6, 15.28, N'BIOTEC-TABLEAU DE BORD')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3373', 19, N'SPRA.DEST.OD', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 3, 16.38, N'BIOTEC AIRPUR GAMME AUTO')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3373', 20, N'DEMO.750ML', CAST(N'2018-06-22T00:00:00.000' AS DateTime), 3, 10.66, N'DEMOUSTIK-0217108')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3374', 1, N'KIT_SPR6019', CAST(N'2018-06-27T00:00:00.000' AS DateTime), 1, 262, N'SPR6019')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3374', 2, N'ADAP.ENIXSXQ6004', CAST(N'2018-06-27T00:00:00.000' AS DateTime), 1, 89.84, N'SXQ6004')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3374', 3, N'ADAP.ENIXSXQ6004', CAST(N'2018-06-27T00:00:00.000' AS DateTime), 1, 123.05, N'SXQ6002')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3377', 1, N'REDU.TUBAGE180/150', CAST(N'2018-07-04T00:00:00.000' AS DateTime), 1, 28.73, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3377', 2, N'WHIT.SPIRIT5', CAST(N'2018-07-04T00:00:00.000' AS DateTime), 2, 16.24, N'WS5')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3377', 3, N'AGRA.VR22/1100', CAST(N'2018-07-04T00:00:00.000' AS DateTime), 1, 15.08, N'40108807')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3377', 4, N'PILE_9V', CAST(N'2018-07-04T00:00:00.000' AS DateTime), 11, 3.1, N'4922121411')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3377', 5, N'PILE_9V', CAST(N'2018-07-04T00:00:00.000' AS DateTime), 9, 2.78, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3377', 6, N'CRAY.CHARP', CAST(N'2018-07-04T00:00:00.000' AS DateTime), 12, 1.4, N'4333103')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3377', 7, N'POIN.TP70', CAST(N'2018-07-03T00:00:00.000' AS DateTime), 1, 14.86, N'55739663')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3377', 8, N'CHEV.6X30', CAST(N'2018-08-04T00:00:00.000' AS DateTime), 8, 4.5, N'IXE6')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3377', 9, N'METR.POL.', CAST(N'2018-07-04T00:00:00.000' AS DateTime), 10, 5.63, N'035458')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3377', 10, N'PILE_LR6', CAST(N'2018-07-04T00:00:00.000' AS DateTime), 10, 3.17, N'4906121414')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3377', 11, N'CIME.SCBE25', CAST(N'2018-07-04T00:00:00.000' AS DateTime), 2, 4.96, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3377', 12, N'CIME.CE25', CAST(N'2018-08-02T00:00:00.000' AS DateTime), 64, 3.18, N'C25CE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3377', 13, N'CHAP.+P110', CAST(N'2018-08-04T00:00:00.000' AS DateTime), 1, 74.9, N'CD110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3377', 14, N'VERR.PORTE100', CAST(N'2018-08-04T00:00:00.000' AS DateTime), 2, 6.63, N'95633279')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3377', 15, N'MECA.DCU', CAST(N'2018-07-04T00:00:00.000' AS DateTime), 1, 40.72, N'MW90C')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3377', 16, N'GAZ_PROP13KGS', CAST(N'2018-06-08T00:00:00.000' AS DateTime), 3, 31.44, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3377', 17, N'CHAR.BOS12V3AH', CAST(N'2018-07-04T00:00:00.000' AS DateTime), 2, 16.27, N'1617014122')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3377', 18, N'CHAP.SAKRET40', CAST(N'2018-07-04T00:00:00.000' AS DateTime), 3, 4.96, N'SCBE25')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3377', 19, N'PROT.SOUBASSEMENT', CAST(N'2018-08-04T00:00:00.000' AS DateTime), 4, 2.76, N'DMSD')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3470', 1, N'RECE.RHEARE-CHS-AAM', CAST(N'2018-07-02T00:00:00.000' AS DateTime), 1, 450, N'RE-CHS-A1 ANNONCE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3470', 2, N'RECE.RHEARE-CHS-A1AV', CAST(N'2018-07-02T00:00:00.000' AS DateTime), 1, 450, N'RE-CHS-A1 ANNONCE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3470', 3, N'RECE.RHEARE-CHS-A1BA', CAST(N'2018-07-02T00:00:00.000' AS DateTime), 1, 350, N'RE-CHS-A1 BASE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3470', 4, N'PORT', CAST(N'2018-07-02T00:00:00.000' AS DateTime), 1, 30, N'FRANCO')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3471', 1, N'VERI.CLAA1096', CAST(N'2018-07-04T00:00:00.000' AS DateTime), 1, 647.46, N'A1096')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3471', 2, N'AXE_D30XL132', CAST(N'2018-07-04T00:00:00.000' AS DateTime), 2, 35.26, N'24486')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3471', 3, N'CIRC.EXT30', CAST(N'2018-07-04T00:00:00.000' AS DateTime), 2, 2.14, N'66105')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3471', 4, N'PORT', CAST(N'2018-07-04T00:00:00.000' AS DateTime), 1, 50, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3473', 1, N'DISQ.115F1', CAST(N'2018-07-03T00:00:00.000' AS DateTime), 50, 3.25, N'5040064')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3473', 2, N'DISQ.125F1', CAST(N'2018-08-03T00:00:00.000' AS DateTime), 50, 2.75, N'5040061')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3473', 3, N'TUBE_SMINOX', CAST(N'2018-08-02T00:00:00.000' AS DateTime), 1, 275, N'TC')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3473', 4, N'PORT', CAST(N'2018-07-13T00:00:00.000' AS DateTime), 1, 50, N'PORT ET EMBALLAGE USINE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3473', 5, N'COUD.EW6L_NU', CAST(N'2018-08-03T00:00:00.000' AS DateTime), 4, 6.97, N'5280010')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3473', 6, N'DISQ.230DIAM', CAST(N'2018-07-03T00:00:00.000' AS DateTime), 2, 130.5, N'5400016')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3473', 7, N'DISQ.230EB', CAST(N'2018-07-03T00:00:00.000' AS DateTime), 10, 9.7, N'5040047')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3473', 8, N'PORT', CAST(N'2018-07-13T00:00:00.000' AS DateTime), 1, 44, N'PORT ET EMBALLAGE USINE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3473', 9, N'MECH.AC05', CAST(N'2018-07-03T00:00:00.000' AS DateTime), 10, 1.26, N'5020032')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3473', 10, N'FLEX.HYDSM', CAST(N'2018-07-03T00:00:00.000' AS DateTime), 1, 41.34, N'FLEXIBLE HP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3473', 11, N'FLEX.HYDSM', CAST(N'2018-07-03T00:00:00.000' AS DateTime), 1, 29.59, N'FLEXIBLE HP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3473', 12, N'COLL.TOUR32-35', CAST(N'2018-07-03T00:00:00.000' AS DateTime), 2, 1.31, N'760011')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3474', 1, N'BOIT.SCHENN05005', CAST(N'2018-07-09T00:00:00.000' AS DateTime), 10, 3.91, N'SCHENN05005')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3474', 2, N'INTE.APE647H/2K', CAST(N'2018-07-10T00:00:00.000' AS DateTime), 10, 31.9, N'RS6928412')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3474', 3, N'MODU.GOT01020', CAST(N'2018-08-09T00:00:00.000' AS DateTime), 10, 39.08, N'GOTRONIC 01020')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3474', 4, N'BORN.WAG222413', CAST(N'2018-07-12T00:00:00.000' AS DateTime), 1, 16.65, N'WAGO221413')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3474', 5, N'BORN.WAG222412', CAST(N'2018-07-12T00:00:00.000' AS DateTime), 1, 24, N'WAGO221412')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3474', 6, N'EMBO.CAB1.5MM D', CAST(N'2018-07-10T00:00:00.000' AS DateTime), 1, 46.74, N'AZ5DE0151')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3474', 7, N'FIL_HO7VK1.5BLANC', CAST(N'2018-08-09T00:00:00.000' AS DateTime), 1, 22.04, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3474', 8, N'FIL_HO7VK1.5NOIR', CAST(N'2018-08-09T00:00:00.000' AS DateTime), 1, 22.04, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3474', 9, N'FIL_HO7VK1.5MAR', CAST(N'2018-08-09T00:00:00.000' AS DateTime), 1, 22.04, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3474', 10, N'KLAX.CLOCHE12V', CAST(N'2018-08-09T00:00:00.000' AS DateTime), 10, 52, N'VA19034')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3474', 11, N'PORT', CAST(N'2018-07-09T00:00:00.000' AS DateTime), 1, 17, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3476', 1, N'PATE_AMERICAINE', CAST(N'2018-07-11T00:00:00.000' AS DateTime), 1, 120.99, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3478', 1, N'CASQ.INTEGRA', CAST(N'2018-07-11T00:00:00.000' AS DateTime), 5, 47.59, N'0000-884-0180')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3478', 2, N'VISI.STH00008840565', CAST(N'2018-07-11T00:00:00.000' AS DateTime), 3, 52.34, N'0000-884-0565')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3478', 3, N'FIL_DEB3X280', CAST(N'2018-07-11T00:00:00.000' AS DateTime), 1, 35.93, N'0000-930-2543')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3478', 4, N'COUR.LB39', CAST(N'2018-07-11T00:00:00.000' AS DateTime), 2, 13.99, N'LB39')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3478', 5, N'PORT', CAST(N'2018-07-11T00:00:00.000' AS DateTime), 1, 12.9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3478', 6, N'CHAI.STH39910030060', CAST(N'2018-07-11T00:00:00.000' AS DateTime), 5, 16.67, N'39910030060')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3478', 7, N'COUP.WOLRMM', CAST(N'2018-07-11T00:00:00.000' AS DateTime), 3, 16.17, N'WOLF RMM')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3478', 8, N'GRAT.WOLFKM', CAST(N'2018-07-11T00:00:00.000' AS DateTime), 3, 7.71, N'WOLF-KM')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3478', 9, N'MOYE.STA66070232R', CAST(N'2018-07-11T00:00:00.000' AS DateTime), 1, 18.37, N'66070232R')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3478', 10, N'LAME_STA66070440R', CAST(N'2018-07-11T00:00:00.000' AS DateTime), 1, 15.18, N'66070440R')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3479', 1, N'CAFE_DOSE48', CAST(N'2018-07-22T00:00:00.000' AS DateTime), 5, 11.64, N'SENSEO CLASSIQUE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3479', 2, N'CAFE_MOULU', CAST(N'2018-07-22T00:00:00.000' AS DateTime), 18, 6.72, N'CARTE NOIR')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3479', 3, N'EAU_0.5/12', CAST(N'2018-07-11T00:00:00.000' AS DateTime), 40, 3.26, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3480', 1, N'SCHA.BIO5', CAST(N'2018-07-11T00:00:00.000' AS DateTime), 6, 47.7, N'BIOTEC')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3480', 2, N'SPRA.DEGO', CAST(N'2018-08-11T00:00:00.000' AS DateTime), 3, 17.91, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3480', 3, N'KIT_RASANT', CAST(N'2018-07-11T00:00:00.000' AS DateTime), 1, 167.12, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3480', 4, N'FLEX.KAR44406530', CAST(N'2018-08-11T00:00:00.000' AS DateTime), 1, 82.8, N'KAR44406530')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3480', 5, N'TUBE_KAR69021540', CAST(N'2018-08-11T00:00:00.000' AS DateTime), 1, 48.2, N'KAR69021540')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3480', 6, N'PORT.', CAST(N'2018-08-11T00:00:00.000' AS DateTime), 1, 20, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3480', 7, N'INSE.POMP.', CAST(N'2018-07-11T00:00:00.000' AS DateTime), 6, 16.37, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3730', 1, N'ARMO.H198X120', CAST(N'2018-07-09T00:00:00.000' AS DateTime), 1, 351, N'4425002+MCSC')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3730', 2, N'ARMO.H198X120', CAST(N'2018-07-09T00:00:00.000' AS DateTime), 1, 351, N'4425002+MCSC')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3730', 3, N'ARMO.H198X120', CAST(N'2018-07-09T00:00:00.000' AS DateTime), 1, 351, N'4425002+MCSC')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3731', 1, N'ARMO.AT1950/120/500', CAST(N'2018-07-03T00:00:00.000' AS DateTime), 1, 999.53, N'904212')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3911', 1, N'PALI.NOR102837', CAST(N'2018-07-18T00:00:00.000' AS DateTime), 2, 272.9, N'102837')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3911', 2, N'ROND.NOR104120', CAST(N'2018-07-18T00:00:00.000' AS DateTime), 8, 0.13, N'104120')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3911', 3, N'VIS_NOR104230', CAST(N'2018-07-18T00:00:00.000' AS DateTime), 8, 0.43, N'104230')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-3911', 4, N'PORT', CAST(N'2018-07-18T00:00:00.000' AS DateTime), 1, 35.9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4028', 1, N'REPA.MAT.AGRI', CAST(N'2018-08-08T00:00:00.000' AS DateTime), 1, 1423.27, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4029', 1, N'RIVE.4.8X10TL', CAST(N'2018-08-08T00:00:00.000' AS DateTime), 1, 9.56, N'REST4300')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4029', 2, N'RIVE.4.8X14TL', CAST(N'2018-08-08T00:00:00.000' AS DateTime), 1, 9.56, N'REST4302')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4029', 4, N'FILT.MANC23440/1', CAST(N'2018-08-08T00:00:00.000' AS DateTime), 1, 44.34, N'MANNC23440/1')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4029', 5, N'FILT.MANW1160/2', CAST(N'2018-08-08T00:00:00.000' AS DateTime), 1, 13.73, N'W1160/2')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4029', 6, N'FILT.MANTB1374-3X', CAST(N'2018-08-08T00:00:00.000' AS DateTime), 2, 39.07, N'MANNTB1374X')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4029', 7, N'FUSI.2BR20A', CAST(N'2018-09-08T00:00:00.000' AS DateTime), 25, 0.4052, N'REST6875')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4029', 8, N'FILT.HIFSH61153', CAST(N'2018-08-08T00:00:00.000' AS DateTime), 5, 38.72, N'HISH61153')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4029', 9, N'FILT.MANW936/4', CAST(N'2018-08-08T00:00:00.000' AS DateTime), 2, 6.47, N'MANN 936/4')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4029', 10, N'FILT.MANC17337/2', CAST(N'2018-08-08T00:00:00.000' AS DateTime), 1, 30.21, N'MANNC17337')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4029', 11, N'CURA.MEC133005', CAST(N'2018-08-08T00:00:00.000' AS DateTime), 30, 29.41, N'MEC133005')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4029', 12, N'FILT.KAR66612170', CAST(N'2018-09-08T00:00:00.000' AS DateTime), 1, 19.61, N'KAR66612170')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4321', 1, N'MANI.NOR103071', CAST(N'2018-08-07T00:00:00.000' AS DateTime), 50, 3.19, N'103071')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4321', 2, N'FLEA.NOR103070', CAST(N'2018-08-07T00:00:00.000' AS DateTime), 50, 2.28, N'103070')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4321', 3, N'VIS_NOR103073', CAST(N'2018-08-07T00:00:00.000' AS DateTime), 50, 1.07, N'103073')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4321', 4, N'ECRO.NOR103018', CAST(N'2018-08-08T00:00:00.000' AS DateTime), 50, 0.37, N'103018')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4321', 5, N'ENTR.NOR103072', CAST(N'2018-08-07T00:00:00.000' AS DateTime), 50, 0.66, N'103072')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4321', 6, N'PORT', CAST(N'2018-08-08T00:00:00.000' AS DateTime), 1, 48, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4322', 1, N'PROF.CAOUT12.95.02', CAST(N'2018-08-08T00:00:00.000' AS DateTime), 18, 54.5, N'A00029363')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4325', 1, N'CABL.EUT27203*', CAST(N'2018-08-16T00:00:00.000' AS DateTime), 1, 37.36, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4325', 2, N'BOUG.CHARCJ6Y', CAST(N'2018-08-16T00:00:00.000' AS DateTime), 3, 6.11, N'RCJ6Y')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4325', 3, N'CLE_ECH13X19', CAST(N'2018-08-16T00:00:00.000' AS DateTime), 3, 10.66, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4325', 4, N'CHAI.STH39970030050', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 5, 16.6667, N'91VXL050E')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4325', 5, N'FIL_DEB3X280', CAST(N'2018-08-16T00:00:00.000' AS DateTime), 2, 64.47, N'0000-930-2543')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4325', 6, N'MEMB.ECH12311240630', CAST(N'2018-08-16T00:00:00.000' AS DateTime), 1, 7.79, N'12311240630')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4325', 7, N'CARB.ECHA021000341', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 1, 115.62, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4325', 8, N'ROUE_JOCKEY', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 1, 24.75, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4325', 9, N'GUID.STH30020009741', CAST(N'2018-08-16T00:00:00.000' AS DateTime), 2, 108.16, N'30020009741')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4325', 10, N'TRONC.MS362', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 1, 495, N'MS362')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4325', 11, N'FILT.ECHA226000220', CAST(N'2018-08-16T00:00:00.000' AS DateTime), 2, 11.74, N'A226000220')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4325', 12, N'AFFU.STH52032000008', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 1, 296.07, N'52032000008')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4325', 13, N'MEUL.STH52027507010', CAST(N'2018-08-16T00:00:00.000' AS DateTime), 1, 12.54, N'5202-750-7010')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4325', 14, N'POUL.HUS537420001', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 1, 38.55, N'537420001')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4326', 1, N'DALL.ACOUST4MM', CAST(N'2018-08-18T00:00:00.000' AS DateTime), 12, 38.35, N'022FORBO')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4326', 2, N'PORT', CAST(N'2018-08-18T00:00:00.000' AS DateTime), 1, 52.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4326', 3, N'EPON.VEG.N8', CAST(N'2018-08-18T00:00:00.000' AS DateTime), 5, 2.946, N'3153036754')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4326', 4, N'PLIN.S14/70', CAST(N'2018-08-18T00:00:00.000' AS DateTime), 3, 6.76, N'253182')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4326', 5, N'BA_5.3X47', CAST(N'2018-08-18T00:00:00.000' AS DateTime), 2, 3.26, N'3355371102')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4326', 7, N'PRIM.BP', CAST(N'2018-08-18T00:00:00.000' AS DateTime), 1, 58.8, N'3529733491')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4326', 8, N'RACR.SOL', CAST(N'2018-08-18T00:00:00.000' AS DateTime), 1, 38.799, N'3549212475')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4437', 1, N'CONT.TECHCAM', CAST(N'2018-08-13T00:00:00.000' AS DateTime), 1, 82.5, N'BB721FG')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4487', 1, N'OXYG.10.5M3', CAST(N'2018-06-29T00:00:00.000' AS DateTime), 1, 86, N'AIRL110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4487', 2, N'ACET.6M3', CAST(N'2018-08-21T00:00:00.000' AS DateTime), 1, 153, N'AIRL310')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4524', 1, N'BORN.WAG222412', CAST(N'2018-07-14T00:00:00.000' AS DateTime), 2, 27.37, N'WAGO221412')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4524', 2, N'BORN.WAG222413', CAST(N'2018-07-14T00:00:00.000' AS DateTime), 2, 16.65, N'WAGO221413')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4524', 3, N'CONT.HAGETC225', CAST(N'2018-08-11T00:00:00.000' AS DateTime), 2, 58.13, N'GAGE ETC225')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4524', 4, N'JEU_FLUTLAC220', CAST(N'2018-07-12T00:00:00.000' AS DateTime), 2, 53.3, N'416.5156.2')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4524', 5, N'CABL.R2V3G1.5', CAST(N'2018-07-12T00:00:00.000' AS DateTime), 200, 0.49, N'U1000R2VCU3G1.5')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4524', 6, N'EXTE.EWO_FLB3202', CAST(N'2018-08-11T00:00:00.000' AS DateTime), 4, 245, N'EWON FLB3202')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4524', 7, N'EXTE.EWO_FLX3101', CAST(N'2018-08-11T00:00:00.000' AS DateTime), 2, 178, N'EWON FLX3101')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4524', 8, N'ANTE.GSM5DBIM', CAST(N'2018-08-11T00:00:00.000' AS DateTime), 2, 37.8, N'EWON ANT-GSM-5DBI-M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4524', 9, N'THER.CHAUF-EAU', CAST(N'2018-08-11T00:00:00.000' AS DateTime), 1, 74, N'THEM070130')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4524', 10, N'PORT', CAST(N'2018-07-11T00:00:00.000' AS DateTime), 1, 40, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4525', 1, N'BALA.EGRVI5001865594', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 1, 33.95, N'0005001865594')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4525', 2, N'BAGU.AUTOC24.7X32X2', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 10, 1.63, N'5010248932')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4525', 3, N'CABO.RVI7484553916', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 1, 30.32, N'7484553916')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4525', 4, N'FEU_RVI7484553913', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 1, 48.08, N'7484553916')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4525', 5, N'CATA_RVI5010096738', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 2, 6.76, N'5010096738')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4528', 1, N'GAZO.', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 5000, 1.249, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4528', 2, N'SP95E5', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 1001, 1.33, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4528', 3, N'GNR_BF', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 1501, 0.81, N'BIOFREE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4528', 4, N'GNR_BF', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 1242, 0.81, N'BIOFREE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4530', 1, N'LECT.HAM39878', CAST(N'2018-08-24T00:00:00.000' AS DateTime), 1, 36, N'HAMA39878')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4530', 2, N'TUBE_N18W', CAST(N'2018-08-23T00:00:00.000' AS DateTime), 25, 2.25, N'631718MAZDA')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4530', 3, N'TAXE', CAST(N'2018-06-08T00:00:00.000' AS DateTime), 25, 0.2, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4530', 4, N'TUBE_N22WLEDS', CAST(N'2018-08-24T00:00:00.000' AS DateTime), 10, 15, N'818132')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4530', 5, N'TAXE', CAST(N'2018-06-08T00:00:00.000' AS DateTime), 10, 0.2, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4530', 6, N'PILE_LR6', CAST(N'2018-08-24T00:00:00.000' AS DateTime), 20, 1.45, N'8280 4006101404')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4530', 7, N'PORT', CAST(N'2018-08-23T00:00:00.000' AS DateTime), 1, 10, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4534', 1, N'FILT.MANC17337/2', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 2, 30.21, N'MANNC17337')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4534', 2, N'FILT.HIFSC40003', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 2, 36.46, N'JURASC40003')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4534', 3, N'FILT.MANW936/4', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 2, 6.47, N'MANN 936/4')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4534', 4, N'FILT.MANW925', CAST(N'2018-08-30T00:00:00.000' AS DateTime), 1, 13.72, N'MANNW925')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4534', 5, N'FILT.MANWK8100', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 2, 21.62, N'MANNWK8100')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4534', 6, N'FILT.MANPF1190X', CAST(N'2018-09-29T00:00:00.000' AS DateTime), 2, 12.56, N'MANNPF1190X')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4534', 7, N'FILT.MANW940', CAST(N'2018-08-30T00:00:00.000' AS DateTime), 2, 7.93, N'MANNW940')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4534', 8, N'FILT.MANP917X', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 1, 5.15, N'MANNP917X')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4534', 9, N'FILT.MANW11102/36', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 2, 12.78, N'MANN W11102/36')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4534', 10, N'FILT.MANWK731', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 2, 6.66, N'MANNWK731')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4534', 11, N'FILT.HIFSH56236', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 1, 19.99, N'JURASH56236')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4534', 12, N'GIRO.MAGNET*', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 1, 55.55, N'VALEO82540')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4534', 13, N'TUBE_ETANCHE', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 1, 22.58, N'LOCT234560')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4534', 14, N'SPRA.NETT.CLIM', CAST(N'2018-09-29T00:00:00.000' AS DateTime), 4, 12.9976, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4534', 15, N'ENTO.PREC4L', CAST(N'2018-10-01T00:00:00.000' AS DateTime), 2, 11.13, N'ALGI07491200')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4534', 16, N'ENTO.PR250', CAST(N'2018-09-29T00:00:00.000' AS DateTime), 2, 7.4, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4534', 17, N'PLAQ.IV', CAST(N'2018-08-30T00:00:00.000' AS DateTime), 2, 12.53, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4534', 18, N'FILT.MANC14210/2', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 2, 26.35, N'MANNC14210/2')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4534', 19, N'BAND.MOUS40X4MM', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 20, 3.5, N'MABEO078095F')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4538', 2, N'PROT.FACIALE', CAST(N'2018-09-05T00:00:00.000' AS DateTime), 5, 16, N'OBA1011623')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4538', 4, N'ECRA.CENS54CE', CAST(N'2018-09-25T00:00:00.000' AS DateTime), 10, 11.5, N'263021')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4538', 5, N'LUNE.BOL_VIPPSI', CAST(N'2018-09-05T00:00:00.000' AS DateTime), 20, 6.1, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4538', 6, N'LUNE.FUMEE', CAST(N'2018-09-05T00:00:00.000' AS DateTime), 10, 5.5, N'VIPCF')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4538', 7, N'GANT_HYDRO9', CAST(N'2018-09-25T00:00:00.000' AS DateTime), 10, 9.8, N'AROES25002')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4538', 11, N'GANT_HYDRO10', CAST(N'2018-09-25T00:00:00.000' AS DateTime), 10, 9.8, N'AROES25003')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4538', 12, N'BOTT.T42', CAST(N'2018-09-05T00:00:00.000' AS DateTime), 2, 54.8, N'DUNLOP PUROFORT +')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4538', 13, N'BOTT.T43', CAST(N'2018-09-05T00:00:00.000' AS DateTime), 2, 54.8, N'DUNLOP PUROFORT +')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4538', 15, N'LUNE.SOUD.', CAST(N'2018-09-25T00:00:00.000' AS DateTime), 2, 7.37, N'149058')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4538', 16, N'CHAU.TR43', CAST(N'2018-09-25T00:00:00.000' AS DateTime), 1, 130, N'0FRATILIACH031006')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4538', 17, N'CHAU.TR44', CAST(N'2018-09-25T00:00:00.000' AS DateTime), 1, 130, N'0FRATILIACH031007')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4538', 18, N'CHAU.TR45', CAST(N'2018-09-25T00:00:00.000' AS DateTime), 1, 130, N'0FRATILIACH031008')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4538', 19, N'CRAM.ANTI_DERAP', CAST(N'2018-09-25T00:00:00.000' AS DateTime), 18, 13.8, N'0ER16754')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4573', 1, N'FER_P080X10', CAST(N'2018-08-23T00:00:00.000' AS DateTime), 6.2, 12.7, N'54224')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4573', 2, N'FER_P090X10', CAST(N'2018-08-23T00:00:00.000' AS DateTime), 6.2, 22.9, N'111589')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4573', 3, N'FER_P035X08A2', CAST(N'2018-08-23T00:00:00.000' AS DateTime), 31, 4.51, N'54003')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4574', 1, N'EAU_0.5/12', CAST(N'2018-08-23T00:00:00.000' AS DateTime), 40, 3.26, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4574', 2, N'EAU_1.5L', CAST(N'2018-08-23T00:00:00.000' AS DateTime), 20, 3.22, N'CRISTALINE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4574', 3, N'SUCR.DOSE', CAST(N'2018-09-03T00:00:00.000' AS DateTime), 4, 25.7, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4575', 1, N'BOIT.CLPR40', CAST(N'2018-08-21T00:00:00.000' AS DateTime), 2, 28.18, N'76142')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4575', 2, N'PAPI.A4BLEU', CAST(N'2018-08-21T00:00:00.000' AS DateTime), 5, 4.17, N'15839')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4575', 3, N'PAPI.A4JAUNE', CAST(N'2018-08-21T00:00:00.000' AS DateTime), 4, 4.17, N'15841')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4575', 4, N'ROLL.CORRECT2', CAST(N'2018-08-21T00:00:00.000' AS DateTime), 24, 1.96, N'42577')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4575', 5, N'CLAS.DOSLIT', CAST(N'2018-08-21T00:00:00.000' AS DateTime), 3, 4.04, N'11293')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4575', 6, N'TAPI.SOURIS', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 1, 5.47, N'67518')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4575', 7, N'PAPI.A3BLANC', CAST(N'2018-08-21T00:00:00.000' AS DateTime), 30, 5.03, N'58434')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4772', 5, N'BOUC.ROU205602', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 4, 30.94, N'ROUSSEAU 205602')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4772', 6, N'CART.ROU4102541', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 4, 67.37, N'4102541')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4772', 7, N'CART.ROU4102543', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 4, 51.11, N'ROUSSEAU 4102543')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4772', 8, N'MANI.NOR103071', CAST(N'2018-08-30T00:00:00.000' AS DateTime), 50, 3.19, N'103071')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4772', 9, N'ENTR.NOR103072', CAST(N'2018-08-30T00:00:00.000' AS DateTime), 50, 0.66, N'103072')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4772', 10, N'FLEA.NOR103070', CAST(N'2018-08-30T00:00:00.000' AS DateTime), 50, 2.28, N'103070')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4772', 11, N'FLEA.NOR103059', CAST(N'2018-08-30T00:00:00.000' AS DateTime), 100, 1.06, N'103059')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4772', 12, N'MANI.NOR103067', CAST(N'2018-08-30T00:00:00.000' AS DateTime), 50, 2.26, N'103067')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4772', 13, N'ECRO.NOR103022', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 50, 0.23, N'103022')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4772', 14, N'ENTR.NOR103072', CAST(N'2018-08-30T00:00:00.000' AS DateTime), 50, 0.66, N'103072')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4772', 15, N'VIS_NOR103085', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 50, 0.59, N'103085')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4772', 16, N'MANI.NOR103066', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 50, 2.26, N'103066')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4772', 17, N'FLEA.NOR103052', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 100, 1.01, N'103052')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4772', 18, N'PORT', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 1, 53, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4839', 1, N'INSE.POMP.', CAST(N'2018-08-07T00:00:00.000' AS DateTime), 36, 16.37, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4839', 2, N'SPRA.NETT.FR', CAST(N'2018-08-25T00:00:00.000' AS DateTime), 12, 11.82, N'ASFORNET-0202113')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4839', 3, N'COLL.CYANO', CAST(N'2018-09-07T00:00:00.000' AS DateTime), 3, 19.67, N'0205123')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4839', 4, N'PAPI.TOIL380M', CAST(N'2018-08-07T00:00:00.000' AS DateTime), 18, 5.656, N'0102110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4839', 5, N'SPRA.COLLE', CAST(N'2018-09-07T00:00:00.000' AS DateTime), 2, 28.58, N'COLLINDUS')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4840', 1, N'TRAC.ORANGE', CAST(N'2018-08-30T00:00:00.000' AS DateTime), 12, 16.81, N'AS LINER -0202120OF')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4840', 2, N'TRAC.ROUGE', CAST(N'2018-08-30T00:00:00.000' AS DateTime), 5, 16.81, N'0202120RF')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4840', 3, N'TRAC.VERT', CAST(N'2018-08-30T00:00:00.000' AS DateTime), 5, 16.81, N'0202120VF')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4840', 4, N'SPRA.DEGRIP', CAST(N'2018-08-30T00:00:00.000' AS DateTime), 12, 15.32, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4840', 5, N'SPRA.DEGI.750', CAST(N'2018-08-30T00:00:00.000' AS DateTime), 12, 11.67, N'0109735')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4840', 7, N'CHIF.BLANC', CAST(N'2018-09-30T00:00:00.000' AS DateTime), 4, 34.32, N'0109497')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4840', 8, N'POUB.50L_INOX', CAST(N'2018-09-30T00:00:00.000' AS DateTime), 1, 102.64, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4841', 2, N'FIL_SOUDURE_HC12/10', CAST(N'2018-09-06T00:00:00.000' AS DateTime), 1, 457.52, N'622643')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4841', 3, N'ELEC.DS800_2,5', CAST(N'2018-09-06T00:00:00.000' AS DateTime), 1, 205.39, N'622900')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4842', 1, N'VIS_NOR103077', CAST(N'2018-09-07T00:00:00.000' AS DateTime), 50, 1.21, N'103077')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4842', 2, N'ECRO.NOR103019', CAST(N'2018-09-07T00:00:00.000' AS DateTime), 50, 0.31, N'103019')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4842', 3, N'ENTR.NOR103076', CAST(N'2018-09-07T00:00:00.000' AS DateTime), 50, 0.69, N'103076')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4842', 4, N'PORT', CAST(N'2018-09-07T00:00:00.000' AS DateTime), 1, 26.8, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4843', 1, N'FER_P035X08A2', CAST(N'2018-09-07T00:00:00.000' AS DateTime), 8, 54.6, N'54003')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4846', 1, N'FOYE.SEA_C069', CAST(N'2018-09-06T00:00:00.000' AS DateTime), 4, 136, N'C069')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4846', 2, N'CONN.SEA099', CAST(N'2018-09-06T00:00:00.000' AS DateTime), 4, 6.72, N'C099')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4846', 3, N'FOYE.SEA_C071', CAST(N'2018-09-06T00:00:00.000' AS DateTime), 4, 144.5, N'C071')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4846', 4, N'CONN.SEA101', CAST(N'2018-09-06T00:00:00.000' AS DateTime), 4, 6.72, N'C101')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4847', 1, N'LUMI.600X600LED', CAST(N'2018-09-11T00:00:00.000' AS DateTime), 6, 40, N'69108338')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4847', 2, N'INTE.LEG69731', CAST(N'2018-09-11T00:00:00.000' AS DateTime), 6, 7.22, N'69731')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4847', 3, N'INTE.LEG69711', CAST(N'2018-09-11T00:00:00.000' AS DateTime), 2, 6.72, N'69711')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4847', 4, N'INTE.LEG69715', CAST(N'2018-09-11T00:00:00.000' AS DateTime), 1, 13.63, N'69715')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4847', 5, N'LAMP.39WLED', CAST(N'2018-09-11T00:00:00.000' AS DateTime), 4, 50, N'69108355')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4847', 6, N'TUBE_IRL32', CAST(N'2018-09-11T00:00:00.000' AS DateTime), 36, 0.701, N'69027004')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4847', 7, N'TUBE_IRL25', CAST(N'2018-09-11T00:00:00.000' AS DateTime), 36, 0.477, N'69027003')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4847', 8, N'BOIT.SCHENN05007', CAST(N'2018-09-11T00:00:00.000' AS DateTime), 3, 8.41, N'SCH60077673')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4847', 9, N'COLL.SCHENN47930', CAST(N'2018-09-11T00:00:00.000' AS DateTime), 1, 21.51, N'44101645')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4847', 10, N'CABL.R2V3G1.5', CAST(N'2018-09-11T00:00:00.000' AS DateTime), 100, 0.4209, N'12111361')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4847', 11, N'CABL.R2V5G1.5', CAST(N'2018-09-11T00:00:00.000' AS DateTime), 100, 0.673, N'12111561')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4847', 12, N'CABL.R2V3G2.5', CAST(N'2018-09-11T00:00:00.000' AS DateTime), 100, 0.6362, N'12113361')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4847', 13, N'BLOC_SCHR9PRC240', CAST(N'2018-09-11T00:00:00.000' AS DateTime), 1, 41.6, N'27545495')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4847', 14, N'BLOC_SCHR9PRC610', CAST(N'2018-09-11T00:00:00.000' AS DateTime), 1, 8.43, N'27545500')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-4847', 15, N'BLOC_SCHR9PRC616', CAST(N'2018-09-11T00:00:00.000' AS DateTime), 1, 8.43, N'27545501')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-488', 1, N'KIT_NETTOYAGE', CAST(N'2018-02-08T00:00:00.000' AS DateTime), 1, 177, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-488', 2, N'NETT.CHLORE', CAST(N'2018-02-08T00:00:00.000' AS DateTime), 20, 10, N'30355')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-488', 3, N'MAST.POLY.CRYST', CAST(N'2018-02-08T00:00:00.000' AS DateTime), 3, 23.04, N'83735T')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-488', 4, N'MAST.POLY.BLC', CAST(N'2018-02-08T00:00:00.000' AS DateTime), 3, 23.04, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-488', 5, N'ACCU_CARPOWER', CAST(N'2018-02-08T00:00:00.000' AS DateTime), 2, 88, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-489', 1, N'PANN.A14_500CL2', CAST(N'2018-02-08T00:00:00.000' AS DateTime), 2, 290, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-489', 2, N'PORT', CAST(N'2018-02-10T00:00:00.000' AS DateTime), 1, 0, N'OFFERT')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-491', 1, N'ARRE.MOTEUR', CAST(N'2018-02-13T00:00:00.000' AS DateTime), 1, 77.92, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-491', 2, N'CHAP.PALPZZR450R-68', CAST(N'2018-02-13T00:00:00.000' AS DateTime), 1, 388.5, N'9140444')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-491', 3, N'REPA.MATERIEL', CAST(N'2018-02-13T00:00:00.000' AS DateTime), 1, 85, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-491', 4, N'PORT', CAST(N'2018-02-23T00:00:00.000' AS DateTime), 1, 80, N'PORT ET EMBALLAGE USINE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-491', 5, N'FILT.PERK2654403', CAST(N'2018-02-23T00:00:00.000' AS DateTime), 2, 10.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-491', 6, N'HORA.24V_TFX', CAST(N'2018-02-23T00:00:00.000' AS DateTime), 1, 141.8, N'9140454')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-491', 7, N'PORT', CAST(N'2018-02-23T00:00:00.000' AS DateTime), 1, 15, N'PORT ET EMBALLAGE USINE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-491', 8, N'PORT', CAST(N'2018-02-23T00:00:00.000' AS DateTime), 1, 22, N'PORT ET EMBALLAGE USINE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-491', 9, N'REPA.MATERIEL', CAST(N'2018-02-13T00:00:00.000' AS DateTime), 1, 297.15, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-491', 10, N'FLEX.HYDSM', CAST(N'2018-02-13T00:00:00.000' AS DateTime), 3, 31.5, N'FLEXIBLE HP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-491', 11, N'FLEX.HYDSM', CAST(N'2018-02-13T00:00:00.000' AS DateTime), 1, 41.75, N'FLEXIBLE HP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-491', 12, N'COUP.GROM1/2F', CAST(N'2018-02-13T00:00:00.000' AS DateTime), 2, 26.21, N'9102052')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-491', 13, N'UNIO.M_GE12S1/2ED', CAST(N'2018-02-23T00:00:00.000' AS DateTime), 2, 3.88, N'5140101')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-491', 14, N'FILT.DESDC2', CAST(N'2018-02-13T00:00:00.000' AS DateTime), 12, 128.75, N'9104371')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-491', 15, N'FLEX.HYDSM', CAST(N'2018-02-13T00:00:00.000' AS DateTime), 2, 56.75, N'FLEXIBLE HP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-491', 16, N'FLEX.HYDSM', CAST(N'2018-02-13T00:00:00.000' AS DateTime), 1, 86.5, N'FLEXIBLE HP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-491', 17, N'PORT', CAST(N'2018-02-23T00:00:00.000' AS DateTime), 1, 30, N'PORT ET EMBALLAGE USINE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5028', 1, N'SOND.VEG52/12M', CAST(N'2018-10-14T00:00:00.000' AS DateTime), 1, 960.4, N'WL52XXA4ALK1CD1X')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5028', 2, N'CART.SCHBMXAMI0410', CAST(N'2018-09-13T00:00:00.000' AS DateTime), 1, 509.9, N'BMXAMI0410')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5028', 3, N'PORT', CAST(N'2018-09-12T00:00:00.000' AS DateTime), 1, 30, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5029', 1, N'HAUT_BEH20-9237', CAST(N'2018-09-13T00:00:00.000' AS DateTime), 1, 94.5, N'20-9237')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5029', 2, N'BLOC_BEH20-9585', CAST(N'2018-09-13T00:00:00.000' AS DateTime), 1, 36, N'20_9585')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5029', 3, N'AMPL.BEH20-0054', CAST(N'2018-09-13T00:00:00.000' AS DateTime), 1, 100.8, N'20-0054')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5029', 4, N'PORT', CAST(N'2018-09-13T00:00:00.000' AS DateTime), 1, 15, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5043 et 5044', 1, N'DISQ.150DIAM', CAST(N'2018-09-13T00:00:00.000' AS DateTime), 2, 52.9, N'5400010')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5043 et 5044', 2, N'DISQ.125EB', CAST(N'2018-09-03T00:00:00.000' AS DateTime), 25, 5.74, N'5040048')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5043 et 5044', 3, N'DISQ.LAM110X40', CAST(N'2018-09-13T00:00:00.000' AS DateTime), 30, 8.5, N'5040035')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5043 et 5044', 4, N'FORE.SDS+06X210', CAST(N'2018-09-03T00:00:00.000' AS DateTime), 10, 6.38, N'5020065')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5043 et 5044', 5, N'MECH.AC13', CAST(N'2018-09-03T00:00:00.000' AS DateTime), 5, 9.12, N'5020049')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5043 et 5044', 6, N'COFF.IMPAKTOR', CAST(N'2018-10-03T00:00:00.000' AS DateTime), 2, 87.75, N'5050250')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5043 et 5044', 7, N'PINC.KNI8705300', CAST(N'2018-09-03T00:00:00.000' AS DateTime), 1, 47.55, N'5010054')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5043 et 5044', 8, N'OBTU.VKA12L/S', CAST(N'2018-09-13T00:00:00.000' AS DateTime), 10, 1.5, N'5820116')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5043 et 5044', 9, N'ECRO.M12L', CAST(N'2018-09-03T00:00:00.000' AS DateTime), 10, 0.64, N'5810018')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5043 et 5044', 10, N'BOUC.ROV12L', CAST(N'2018-09-13T00:00:00.000' AS DateTime), 10, 4.5, N'2360402')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5043 et 5044', 11, N'PAPI.E/M_BLC1000', CAST(N'2018-09-03T00:00:00.000' AS DateTime), 108, 13.8, N'380MX24CMX18GR/M - 9111666')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5043 et 5044', 12, N'FILT.DESDC2', CAST(N'2018-09-03T00:00:00.000' AS DateTime), 15, 128.75, N'9104371')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5043 et 5044', 13, N'TUBE_SMINOX', CAST(N'2018-10-03T00:00:00.000' AS DateTime), 2, 196, N'TC')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5043 et 5044', 14, N'TUBE_SMINOX', CAST(N'2018-10-03T00:00:00.000' AS DateTime), 1, 275, N'TC')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5043 et 5044', 15, N'PORT', CAST(N'2018-09-13T00:00:00.000' AS DateTime), 1, 130, N'PORT ET EMBALLAGE USINE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5080', 1, N'DISQ.230DIAM', CAST(N'2018-09-15T00:00:00.000' AS DateTime), 1, 183.22, N'0664 007 230')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5080', 2, N'DISQ.125DIAM/CH', CAST(N'2018-09-15T00:00:00.000' AS DateTime), 1, 179, N'662652125')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5080', 3, N'COFF.FRTULTRA_INOX', CAST(N'2018-09-15T00:00:00.000' AS DateTime), 1, 299, N'0627004913')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5080', 4, N'LAME_SAUT.MU105', CAST(N'2018-09-15T00:00:00.000' AS DateTime), 10, 3.99, N'0604400002')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5080', 5, N'DISQ.125MULTICUT', CAST(N'2018-09-15T00:00:00.000' AS DateTime), 4, 19.9, N'0670200125')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5104', 1, N'CORP.NOR102832', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 1, 461.1, N'102832')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5104', 2, N'SUPP.NOR102838', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 1, 98.82, N'102838')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5104', 3, N'SUPP.NOR102839', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 1, 98.82, N'102839')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5104', 4, N'VIS_NOR104245', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 4, 0.74, N'104245')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5104', 5, N'ROND.NOR104137', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 12, 0.15, N'104137')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5104', 6, N'VIS_NOR101960', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 4, 1.59, N'101960')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5104', 7, N'ECRO.NOR103690', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 4, 1.03, N'103690')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5104', 8, N'RACL.NOR102806', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 1, 215.03, N'102806')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5104', 9, N'VIS_NOR101961', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 4, 0.41, N'101961')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5104', 10, N'ECRO.NOR103018', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 12, 0.48, N'103018')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5104', 11, N'PORT', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 1, 44, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5104', 12, N'PATI.NOR102828', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 2, 28.8, N'102828')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5116', 1, N'ARCA.11.5M3', CAST(N'2017-03-07T00:00:00.000' AS DateTime), 1, 138, N'ARL894')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5116', 2, N'OXYG.10.5M3', CAST(N'2018-07-27T00:00:00.000' AS DateTime), 2, 86, N'AIRL110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5116', 3, N'OXYG.4.2M3', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 2, 67.5, N'AIRL150')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5116', 4, N'ACET.6M3', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 1, 153, N'AIRL310')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5116', 5, N'ACET.3M3', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 1, 95, N'M20')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5117', 1, N'VITR.CLA113008110', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 1, 30.11, N'11308110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5122', 1, N'REPA.MATERIEL', CAST(N'2018-09-19T00:00:00.000' AS DateTime), 1, 1878.11, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5125', 1, N'BEC_HUSQ505598002', CAST(N'2018-10-31T00:00:00.000' AS DateTime), 1, 11.88, N'505698002')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5125', 2, N'BEC_HUSQ505598003', CAST(N'2018-09-20T00:00:00.000' AS DateTime), 1, 3.34, N'505698003')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5125', 3, N'PNEU_4.00-8', CAST(N'2018-10-31T00:00:00.000' AS DateTime), 1, 37.58, N'E480X400-8')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5125', 4, N'CARB.ECHA021001030', CAST(N'2018-10-31T00:00:00.000' AS DateTime), 1, 166.53, N'A021001030')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5125', 5, N'CLAV.ECH90032303014', CAST(N'2018-10-31T00:00:00.000' AS DateTime), 1, 1.29, N'90032303014')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5125', 6, N'MODU.ECHA411000050', CAST(N'2018-10-31T00:00:00.000' AS DateTime), 1, 96.8, N'411000050')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5125', 7, N'RESS.ECHA426000000', CAST(N'2018-10-31T00:00:00.000' AS DateTime), 1, 1.46, N'A426000000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5125', 8, N'PORT.WOLUTM', CAST(N'2018-09-20T00:00:00.000' AS DateTime), 3, 28.08, N'UTM')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5125', 9, N'HOUE_+M', CAST(N'2018-09-20T00:00:00.000' AS DateTime), 1, 39.18, N'JHHD15EMF')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 1, N'AGEN.MINIST.SP', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 16, 11.88, N'49998')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 2, N'AGEN.CT', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 2, 1.31, N'60593')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 3, N'BLOC_EPHE8.2X12DG', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 2, 0.74, N'64992')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 4, N'CALE.12M', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 22, 1.53, N'66179-43X63')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 5, N'CALE.2X6M', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 5, 0.57, N'52097- 38X54')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 6, N'KIT_ACCES.TABLEAU', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 1, 26.12, N'75244')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 7, N'CART.HPHC920XLKIT', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 2, 63.17, N'22520')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 8, N'ATTA.CASE3S', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 1, 38.8, N'55462')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 9, N'RUBA.AB', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 8, 1.49, N'18270')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 10, N'RUBA.AB19X66', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 3, 0.44, N'18274')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 11, N'TROM.25', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 1, 1.71, N'51946')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 12, N'CISE.BUREAU', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 3, 1.16, N'64190')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 13, N'CALC', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 1, 21.6, N'63154')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 14, N'CLE_USB08G', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 6, 6.46, N'72822')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 15, N'POCH.PERF.TR', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 1, 5.49, N'62883')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 16, N'CART.SDHC32GO', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 2, 21.19, N'30071')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 17, N'MARQ.NOIR_PER.2.5', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 10, 0.48, N'41948')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 18, N'INTE.A4_ALPHA.', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 8, 0.6, N'11265')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 19, N'CLAS.5BL', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 10, 1.59, N'59008')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 20, N'CLAS.8VM', CAST(N'2018-09-19T00:00:00.000' AS DateTime), 10, 1.59, N'59032')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 21, N'STYL.G-2N', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 24, 1.09, N'40454')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 22, N'INTE.A4_6ONG', CAST(N'2018-09-19T00:00:00.000' AS DateTime), 10, 0.32, N'11256')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 23, N'INTE.MENS', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 4, 0.75, N'49397')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 24, N'PAPI.A4BLANC160G', CAST(N'2018-09-19T00:00:00.000' AS DateTime), 5, 4.45, N'15856')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 25, N'PAPI.A4BLANC', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 40, 2.56, N'58429')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 26, N'ECRA.TREPIED', CAST(N'2018-09-19T00:00:00.000' AS DateTime), 1, 104, N'47011')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141', 27, N'SIEG.BUREAU*', CAST(N'2018-08-22T00:00:00.000' AS DateTime), 1, 202, N'33102')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141bis', 1, N'TABL.SUR_PIED80CM', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 1, 121.03, N'33265')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141bis', 2, N'TABL.SUR_PIED120CM', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 1, 141.79, N'33266')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141bis', 3, N'TAMB.DR241CL', CAST(N'2018-10-19T00:00:00.000' AS DateTime), 1, 76.71, N'23155')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141bis', 4, N'AGRA.48/6', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 3, 2.49, N'82586')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141bis', 5, N'POCH.POLYA4', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 2, 6.6, N'62886')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5141bis', 6, N'AIMA.B22(6)', CAST(N'2018-11-13T00:00:00.000' AS DateTime), 5, 0.72, N'79934')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 1, N'LAME_SAUT.BOIS50', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 10, 2.43, N'0604100003')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 2, N'ALVE.FORET', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 2, 6.67, N'09500120')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 4, N'VIS_CHC06X16', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 250, 0.0432, N'0084616')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 5, N'VIS_CHC05X20', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 250, 0.0432, N'0084520')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 7, N'ECRO.BN10A2', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 100, 0.1825, N'039110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 8, N'ECRO.BN10', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 100, 0.1153, N'536810')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 9, N'TARA.M8', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 1, 31.8, N'06398')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 10, N'RUBA.SIGNLARG', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 4, 19.43, N'0985899500')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 12, N'VIS_THT08X50A2', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 100, 0.3296, N'0095850')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 13, N'ECRO.H12', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 200, 0.0984, N'5317 12')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 14, N'ECRO.H16', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 100, 0.18, N'0317 16')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 15, N'CUTT.PROF', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 6, 12.87, N'0703600119')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 16, N'VIS_FHC12X40', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 100, 0.3296, N'0089 12 40')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 17, N'VIS_FHC12X50', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 100, 0.4032, N'00891250')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 18, N'MECH.AC04', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 10, 4.57, N'062040 ULTRA')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 19, N'MECH.AC06', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 10, 6.4, N'062060')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 20, N'MECH.AC08', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 6, 9.04, N'062080 ULTRA')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 22, N'COFF.EMBTX', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 1, 95.66, N'0702 930 083')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 23, N'COFF.IMPAKTOR', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 1, 163.81, N'0702930030')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 24, N'COFF.EMBMIXTMINI', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 1, 92.36, N'0702930081')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 25, N'MASS.1,5ME', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 1, 24.37, N'0695500092')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 28, N'FORE.SDS+06X160', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 6, 9.15, N'0648260160')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 29, N'FORE.SDS+08X210', CAST(N'2018-09-10T00:00:00.000' AS DateTime), 6, 12.79, N'0648280210')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 31, N'VIS_THP20X 80', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 25, 1.28, N'0053 20 80')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 32, N'ELEC.RUT.2.5', CAST(N'2018-09-10T00:00:00.000' AS DateTime), 3, 67.98, N'0982044152')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 33, N'MESU.3ML', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 2, 7.37, N'0705 240 3')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 34, N'LAME_CUTPROF.', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 6, 8.96, N'0703600026')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 35, N'CUTT.SECURIT', CAST(N'2018-09-10T00:00:00.000' AS DateTime), 5, 28.4, N'0703600140')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 36, N'LAME_TRAPEZE', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 5, 4.8, N'0703600140')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5142', 37, N'CADE.40', CAST(N'2018-09-01T00:00:00.000' AS DateTime), 4, 10.6, N'0695 011 076')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5143', 1, N'AXE_NOR107648', CAST(N'2018-09-19T00:00:00.000' AS DateTime), 3, 48.58, N'103648')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5143', 2, N'ROND.NOR106838', CAST(N'2018-09-19T00:00:00.000' AS DateTime), 3, 5.82, N'106838')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5143', 3, N'VIS_NOR104160', CAST(N'2018-09-19T00:00:00.000' AS DateTime), 3, 1.28, N'104160')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5143', 4, N'ROND.NOR104124', CAST(N'2018-09-19T00:00:00.000' AS DateTime), 2, 0.55, N'104124')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5143', 5, N'ROND.NOR107690', CAST(N'2018-09-19T00:00:00.000' AS DateTime), 1, 9.42, N'107690')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5143', 6, N'AXE_NOR107649', CAST(N'2018-09-19T00:00:00.000' AS DateTime), 1, 54.63, N'107649')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5143', 7, N'ROND.NOR104126', CAST(N'2018-09-19T00:00:00.000' AS DateTime), 1, 0.24, N'104126')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5143', 8, N'VIS_NOR106160', CAST(N'2018-09-19T00:00:00.000' AS DateTime), 2, 2.17, N'106160')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5143', 9, N'VERI.NOR117393', CAST(N'2018-09-19T00:00:00.000' AS DateTime), 1, 595.9, N'107653')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5143', 10, N'VERI.NOR107656', CAST(N'2018-09-19T00:00:00.000' AS DateTime), 1, 674.92, N'107656')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5143', 11, N'ACCU.NOR100643', CAST(N'2018-09-19T00:00:00.000' AS DateTime), 1, 213.67, N'100643')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5143', 12, N'CLAP.NOR103130', CAST(N'2018-09-19T00:00:00.000' AS DateTime), 1, 59.42, N'103130')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5143', 13, N'ADAP.NOR102099', CAST(N'2018-09-19T00:00:00.000' AS DateTime), 2, 5.13, N'102099')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5143', 14, N'ADAP.NOR102122', CAST(N'2018-09-19T00:00:00.000' AS DateTime), 1, 2.98, N'102122')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5143', 15, N'ADAP.NOR102112', CAST(N'2018-09-19T00:00:00.000' AS DateTime), 1, 15.85, N'102112')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5143', 16, N'PORT', CAST(N'2018-09-19T00:00:00.000' AS DateTime), 1, 63, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5152', 1, N'AGRA.400X80X400', CAST(N'2018-09-20T00:00:00.000' AS DateTime), 3500, 0.42, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5152', 2, N'EMBA.', CAST(N'2018-09-20T00:00:00.000' AS DateTime), 1, 40, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5153', 1, N'POMP.TSULSC4', CAST(N'2018-09-24T00:00:00.000' AS DateTime), 1, 490, N'9140509')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5153', 2, N'TUYA.ASPI25', CAST(N'2018-09-24T00:00:00.000' AS DateTime), 1, 185, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5153', 3, N'RACC.SYM.ALU25/30', CAST(N'2018-09-24T00:00:00.000' AS DateTime), 4, 21.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5170', 1, N'HUIL.TT+15W40-60', CAST(N'2018-09-28T00:00:00.000' AS DateTime), 60, 4.123, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5170', 2, N'GRAI.BIO', CAST(N'2018-09-28T00:00:00.000' AS DateTime), 40, 6.319, N'600351595')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5170', 3, N'HUIL.TSP80W90-1', CAST(N'2018-09-28T00:00:00.000' AS DateTime), 20, 7.002, N'600815219')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5170', 4, N'HUIL.TCMC10W40', CAST(N'2018-09-28T00:00:00.000' AS DateTime), 4, 35.36, N'600805036')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5170', 5, N'HUIL.2TBIO1', CAST(N'2018-10-11T00:00:00.000' AS DateTime), 20, 21.789, N'600088194')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5170', 6, N'HUIL.CHAINBIO1', CAST(N'2018-09-28T00:00:00.000' AS DateTime), 40, 10.367, N'600686130')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5170', 7, N'HUIL.CHAINBIO5', CAST(N'2018-10-26T00:00:00.000' AS DateTime), 12, 38.6175, N'600389147')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5170', 8, N'TGAP', CAST(N'2018-12-29T00:00:00.000' AS DateTime), 1, 4.31, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5206', 1, N'ECRA.ELEC.135X180', CAST(N'2018-09-24T00:00:00.000' AS DateTime), 1, 765, N'15528')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5254', 1, N'SWIT.PHOFLSWITCH23042GC2SFP', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 28, 571.2, N'2702653')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5254', 2, N'MODU.PHO.FLSFPLX', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 56, 147.84, N'2891767')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5254', 3, N'CABL.PHO.FLSM_PATCH1.0LCLC', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 58, 46.59, N'2989187')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5254', 4, N'BORN.PHO.PTCBEI24DC/1-8ANO', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 32, 22.28, N'2908262')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5254', 5, N'DIST_PHOPTFIX6/18X2.5-NS35RD', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 26, 5.0669, N'3273114')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5254', 6, N'DIST_PHOPTFIX6/18X2.5-NS35BU', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 26, 5.0669, N'3273112')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5254', 7, N'CONN.PHOCUC_IND_CIZNI_S/R4IE8', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 120, 8.31, N'1421607')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5254', 8, N'SERV.PHOFLSNMPOPCSERVERV3', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 1, 1389.44, N'2701139')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5254', 9, N'ROUT.PHOTCDSLROUTERX500A/B', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 2, 611.77, N'2902710')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5254', 10, N'DISP.PHOTCMGUARDRS40004GVPN', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 2, 1400.8, N'2903586')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5254', 11, N'ASSI.', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 3, 1275, N'5736081')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5254', 12, N'SWIT.PHO2702909', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 3, 685.44, N'2702909')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5254', 13, N'RAIL_PHOFLDINRA', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 3, 181.44, N'2891053')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5254', 14, N'ALIM.PHO2903147', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 3, 38.14, N'2903147')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5272', 1, N'PNEU_13.6-24', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 2, 345, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5272', 2, N'PNEU_16.9-34', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 2, 599, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5272', 3, N'MO_MAT.AGRI', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 4, 42, N'MONTAGE ET DEMONTAGE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5272', 5, N'DEPL.', CAST(N'2018-09-18T00:00:00.000' AS DateTime), 1, 40, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5311', 1, N'AXE_NOR107648', CAST(N'2018-09-29T00:00:00.000' AS DateTime), 1, 48.58, N'103648')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5311', 2, N'ADAP.NOR102122', CAST(N'2018-09-29T00:00:00.000' AS DateTime), 2, 2.98, N'102122')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5311', 3, N'FLEA.NOR103059', CAST(N'2018-09-28T00:00:00.000' AS DateTime), 100, 1.06, N'103059')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5311', 4, N'MANI.NOR103067', CAST(N'2018-09-28T00:00:00.000' AS DateTime), 50, 2.26, N'103067')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5311', 5, N'ENTR.NOR103076', CAST(N'2018-09-29T00:00:00.000' AS DateTime), 50, 0.69, N'103076')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5311', 6, N'VIS_NOR103077', CAST(N'2018-09-29T00:00:00.000' AS DateTime), 50, 1.21, N'103077')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5317', 1, N'CAME.SVCR-03-213011', CAST(N'2018-10-27T00:00:00.000' AS DateTime), 26, 658.35, N'SVCR-03-213011')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5317', 2, N'BOIT.SVAX.08-202888', CAST(N'2018-10-27T00:00:00.000' AS DateTime), 26, 100.89, N'SVAX-08-202888')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5317', 3, N'ADAP.SVAX-08-202641', CAST(N'2018-10-27T00:00:00.000' AS DateTime), 26, 45.315, N'SVAX-08-202641')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5317', 4, N'ENRE.SVER-48-217345', CAST(N'2018-09-27T00:00:00.000' AS DateTime), 13, 230.85, N'SVER-48-217345')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5317', 5, N'DISQ.SVAX-11-217659', CAST(N'2018-09-27T00:00:00.000' AS DateTime), 13, 323.292, N'SVAX-11-217659')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5317', 6, N'COFF.RCAC-12-000606', CAST(N'2018-09-27T00:00:00.000' AS DateTime), 11, 325.729, N'RCAC-12-000606')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5317', 7, N'SUPP.RCAA-20-000401', CAST(N'2018-10-27T00:00:00.000' AS DateTime), 11, 45.085, N'RCAA-20-000401')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5317', 8, N'BAND.RCAA-10-000108', CAST(N'2018-10-27T00:00:00.000' AS DateTime), 11, 59.021, N'RCAA-10-000108')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5317', 9, N'CABL.CICO-32-712002', CAST(N'2018-09-27T00:00:00.000' AS DateTime), 2000, 1.668, N'CICO-32-712002')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-532', 1, N'CORD.POLY18', CAST(N'2018-02-03T00:00:00.000' AS DateTime), 100, 0.576, N'ACCD')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-532', 2, N'CORD.POLY8', CAST(N'2018-02-03T00:00:00.000' AS DateTime), 200, 0.117, N'ACCD')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-532', 3, N'ETIQ.MAG30X100', CAST(N'2018-02-03T00:00:00.000' AS DateTime), 2, 64, N'263384-78')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-532', 4, N'VIS_THP08X50', CAST(N'2018-02-03T00:00:00.000' AS DateTime), 200, 0.106, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-532', 5, N'ECRO.BN08', CAST(N'2018-02-03T00:00:00.000' AS DateTime), 100, 0.022, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-532', 6, N'CORD.POLY20', CAST(N'2018-03-10T00:00:00.000' AS DateTime), 100, 0.62, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-532', 7, N'VIS_TCF05X20', CAST(N'2018-02-03T00:00:00.000' AS DateTime), 200, 0.045, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-532', 8, N'CHAI.AC6', CAST(N'2018-02-03T00:00:00.000' AS DateTime), 25, 2.1, N'ACCD')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-532', 9, N'CAFE.ELEC', CAST(N'2018-03-10T00:00:00.000' AS DateTime), 2, 59, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-532', 10, N'COQU.TELEPHONE', CAST(N'2018-03-06T00:00:00.000' AS DateTime), 1, 24, N'J3')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-532', 11, N'VITR.INCASSABLE', CAST(N'2018-03-06T00:00:00.000' AS DateTime), 1, 24, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-532', 12, N'SACH.PLAST.HT280', CAST(N'2018-03-10T00:00:00.000' AS DateTime), 1, 99, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-532', 13, N'FORE.SDSM28X400', CAST(N'2018-03-10T00:00:00.000' AS DateTime), 1, 110, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-532', 14, N'ADAP.12CANELURES', CAST(N'2018-03-10T00:00:00.000' AS DateTime), 1, 120, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-532', 15, N'OBTU.DN27/30MM', CAST(N'2018-03-10T00:00:00.000' AS DateTime), 1, 30, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5345', 1, N'RACC.UNGCU08-3/8M', CAST(N'2018-10-02T00:00:00.000' AS DateTime), 10, 4.93, N'S00458')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5345', 2, N'CUIV.ECROUI08', CAST(N'2018-10-02T00:00:00.000' AS DateTime), 5, 4.68, N'S07310')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5391', 1, N'SIEG.ASS/DEB54-74', CAST(N'2018-10-02T00:00:00.000' AS DateTime), 1, 173, N'9921')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5391', 2, N'TAXE', CAST(N'2018-10-02T00:00:00.000' AS DateTime), 1, 0.42, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5392', 1, N'MODI.SCHTM221CE24T', CAST(N'2018-10-03T00:00:00.000' AS DateTime), 2, 269.6, N'SCHTM221CE24T')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5392', 2, N'INTE.PEPIC-KP2-2HB17-2V1D', CAST(N'2018-10-03T00:00:00.000' AS DateTime), 1, 956.56, N'PEPIC-KP2-2HB17-2V1D')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5392', 3, N'TETE_PEPIQH1-F61-V1', CAST(N'2018-10-03T00:00:00.000' AS DateTime), 2, 351.12, N'IQH1-F61-V1')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5392', 4, N'ETIQ.PEPIQC21-30', CAST(N'2018-10-03T00:00:00.000' AS DateTime), 4, 66.98, N'PEPIQC21-30')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5392', 5, N'CABL.PEPV1SD-G-5M-PUR-ABG-V45-G', CAST(N'2018-10-03T00:00:00.000' AS DateTime), 1, 53.94, N'PEPV1SD-G-5M-PUR-ABG-V45-G')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5392', 6, N'CABL.PEPV1SD-G-5M-PUR-ABG-V1-W', CAST(N'2018-10-03T00:00:00.000' AS DateTime), 2, 30.38, N'PEPV1-G-5M-PUR-ABG-V1-W')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5392', 7, N'CAPA.PEPCBB8-18GS75-E2-V1', CAST(N'2018-10-03T00:00:00.000' AS DateTime), 6, 91.96, N'PEPCBB8-18GS75-E2-V1')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5392', 8, N'CONN.PEPV1-W-2M-PUR', CAST(N'2018-10-03T00:00:00.000' AS DateTime), 6, 8.69, N'PEPV1-W-2M-PUR')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5392', 9, N'CONN.PEPV1-G-2M-PVC', CAST(N'2018-10-03T00:00:00.000' AS DateTime), 1, 7.85, N'PEPV1-G-2M-PVC')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5392', 10, N'VOYA.SCHXB4BVB3', CAST(N'2018-10-03T00:00:00.000' AS DateTime), 1, 6.73, N'SCHXB4BVB3')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5392', 11, N'VOYA.SCHXB4BVB4', CAST(N'2018-10-03T00:00:00.000' AS DateTime), 1, 6.73, N'SCHXB4BVB4')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5392', 12, N'RELA.PHO2966472', CAST(N'2018-10-03T00:00:00.000' AS DateTime), 16, 9.76, N'PHO2966472')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5392', 13, N'RELA.PHO2961121', CAST(N'2018-10-03T00:00:00.000' AS DateTime), 16, 5.11, N'2961121')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5424', 1, N'MEUL.125', CAST(N'2018-10-03T00:00:00.000' AS DateTime), 2, 208.91, N'TR11548627 - GWS17-125 CIEX')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5424', 2, N'PACK_BOS1600A01C4K', CAST(N'2018-10-03T00:00:00.000' AS DateTime), 1, 291.61, N'TR11548639')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5442', 1, N'COMP.24LNUAIR', CAST(N'2018-10-04T00:00:00.000' AS DateTime), 1, 260, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5442', 2, N'ENRO.AUT.AC8MM', CAST(N'2018-10-04T00:00:00.000' AS DateTime), 1, 371.18, N'6410202')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5442', 3, N'SOUF.BUSE_90', CAST(N'2018-10-04T00:00:00.000' AS DateTime), 1, 21.38, N'6410298')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5442', 4, N'PIST.GONFSTD', CAST(N'2018-10-04T00:00:00.000' AS DateTime), 1, 97.34, N'6410445')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5442', 5, N'ENRO.3G2.5-25', CAST(N'2018-10-04T00:00:00.000' AS DateTime), 1, 126.4, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5442', 6, N'RACC.GAZ1/4M', CAST(N'2018-10-04T00:00:00.000' AS DateTime), 4, 4.49, N'6410192')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5442', 7, N'COUP.AC_F1/4PAS6', CAST(N'2018-10-04T00:00:00.000' AS DateTime), 2, 31.84, N'6410184')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5485', 1, N'MASS.1,5ME', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 1, 21.66, N'314127')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5485', 2, N'MASS.1,5ME', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 1, 17.39, N'314127')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5485', 3, N'SEAU_POLY.12L', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 1, 4.28, N'MO341120')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5485', 4, N'FIL_RECUIT2.7', CAST(N'2018-10-01T00:00:00.000' AS DateTime), 5, 20.83, N'FR16')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5485', 5, N'GALE.60', CAST(N'2018-10-01T00:00:00.000' AS DateTime), 3, 61.4, N'GS60')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5485', 6, N'REDU.TUBAGE125/153', CAST(N'2018-10-01T00:00:00.000' AS DateTime), 1, 30.17, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5485', 7, N'COUV.BET50X50', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 1, 19.98, N'RCC50')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5485', 8, N'GAIN.40VERTE', CAST(N'2018-08-31T00:00:00.000' AS DateTime), 150, 0.61, N'GTF40V')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5486', 1, N'SANG.2T2.5M', CAST(N'2018-09-28T00:00:00.000' AS DateTime), 4, 8.7, N'B602T2M50')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5486', 2, N'SANG.2T2M', CAST(N'2018-09-28T00:00:00.000' AS DateTime), 4, 7.35, N'B602T2M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5486', 3, N'SANG.3T4M', CAST(N'2018-09-27T00:00:00.000' AS DateTime), 2, 17.7, N'B903T4M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5486', 4, N'ELIN.EL2T2M', CAST(N'2018-09-27T00:00:00.000' AS DateTime), 2, 4.45, N'TUB02T02M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5486', 5, N'ELIN.EL3T2M', CAST(N'2018-09-28T00:00:00.000' AS DateTime), 2, 6.3, N'TUB03T02M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5486', 6, N'SANG.AR5M1T2DGEC', CAST(N'2018-09-27T00:00:00.000' AS DateTime), 8, 9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5486', 7, N'REPA.APPAREIL_LEVAGE', CAST(N'2018-09-28T00:00:00.000' AS DateTime), 2, 66.4, N'REPARATION')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5486', 8, N'SAC_PET89S42Y045', CAST(N'2018-09-28T00:00:00.000' AS DateTime), 6, 59.6, N'PETZL89S42Y045')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5514', 1, N'GAZO.', CAST(N'2018-10-03T00:00:00.000' AS DateTime), 1500, 1.32, N'GRAND FROID')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5514', 3, N'GNR_BF', CAST(N'2018-10-03T00:00:00.000' AS DateTime), 1000, 0.884, N'BIOFREE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5514', 5, N'GAZO.', CAST(N'2018-10-03T00:00:00.000' AS DateTime), 990, 1.32, N'GRAND FROID')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5514', 6, N'GNR_BF', CAST(N'2018-10-03T00:00:00.000' AS DateTime), 543, 0.884, N'BIOFREE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5514', 7, N'FIOU.CHAUF', CAST(N'2018-10-09T00:00:00.000' AS DateTime), 3500, 0.85833, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5579', 1, N'FORE.SDSM35X920X800', CAST(N'2018-10-09T00:00:00.000' AS DateTime), 2, 250.12, N'0649035920')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5579', 2, N'FORE.SDSM45X990', CAST(N'2018-10-09T00:00:00.000' AS DateTime), 2, 258.17, N'0649445990')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5620', 1, N'COUR.NOR109488', CAST(N'2018-10-10T00:00:00.000' AS DateTime), 2, 35.92, N'109488')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5620', 2, N'PORT', CAST(N'2018-10-10T00:00:00.000' AS DateTime), 1, 13.7, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5621', 1, N'PANT.FOR.FIO_2XL', CAST(N'2018-10-09T00:00:00.000' AS DateTime), 2, 115.87, N'295490/2XL')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5621', 2, N'VEST.FOR.FIO_3XL', CAST(N'2018-10-09T00:00:00.000' AS DateTime), 1, 131.27, N'295489/3XL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5621', 3, N'CHAU.YUKT46', CAST(N'2018-10-09T00:00:00.000' AS DateTime), 1, 118.07, N'295449/46')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5621', 4, N'GANT_FOREST.10', CAST(N'2018-10-09T00:00:00.000' AS DateTime), 3, 27.42, N'295485/XL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5621', 5, N'GANT_FOREST.9', CAST(N'2018-10-09T00:00:00.000' AS DateTime), 3, 27.42, N'295485/L')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5622', 1, N'POMP.RVI5010316436', CAST(N'2018-10-11T00:00:00.000' AS DateTime), 1, 540.54, N'5010316436')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5780', 1, N'GEOT.S51_3M', CAST(N'2018-10-04T00:00:00.000' AS DateTime), 5, 599.4, N'12D')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5780', 2, N'PORT', CAST(N'2018-09-09T00:00:00.000' AS DateTime), 1, 237, N'FRANCO')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5781', 1, N'DALL.BET100/35/8', CAST(N'2018-10-26T00:00:00.000' AS DateTime), 750, 23.12, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5781', 2, N'TUYA.PVC160CR', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 6, 16.59, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5781', 3, N'GEOT.S51_3M', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 1, 810, N'12D')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5782', 1, N'GABI.1000/1000/1000', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 50, 78.97, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5782', 2, N'AGRA.CL40', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 1, 47.68, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5782', 3, N'PINC.CL40', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 1, 50.4, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5783', 1, N'REMP.PALIER', CAST(N'2018-11-24T00:00:00.000' AS DateTime), 8, 283, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5783', 2, N'BAGU.TEF35/28D25LG21.5/1.5', CAST(N'2018-11-24T00:00:00.000' AS DateTime), 50, 3.85, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5784', 1, N'PLAN.CH.TL_EP29', CAST(N'2018-09-25T00:00:00.000' AS DateTime), 6.394, 390, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5784', 2, N'PLAN.SAPTTL3C4M', CAST(N'2018-09-25T00:00:00.000' AS DateTime), 80, 4.8, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5784', 3, N'PORT', CAST(N'2018-09-25T00:00:00.000' AS DateTime), 1, 20, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5785', 1, N'PIQU.ACACIA3.5', CAST(N'2018-09-25T00:00:00.000' AS DateTime), 200, 20, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5787', 12, N'COFF.LEG058957', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 1, 164.4, N'LEG058957')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5787', 13, N'CHAS.LEG057743', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 2, 104.22, N'LEG057743')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5787', 14, N'PRIS.LEG057667', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 2, 4.161, N'LEG057667')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5787', 17, N'COFF.LEG058954', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 1, 484.26, N'LEG058954')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5787', 18, N'BOUT.LEG057745', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 1, 38.18, N'LEG057745')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5787', 19, N'FICH.LEG056478', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 1, 16.51, N'LEG056478')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5787', 21, N'PRIS.LEG555109', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 2, 7.698, N'LEG555109')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5787', 22, N'PRIS.LEG555108', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 2, 7.398, N'LEG555108')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5787', 23, N'FICH.LEG057440', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 1, 34.15, N'LEG057440')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5787', 27, N'PRIS.LEG555189', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 1, 8.63, N'LEG555189')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5787', 28, N'INTE.SCHA9R11440', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 1, 126.37, N'SCHA9R11440')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5787', 29, N'MODU.SCHA9A26946', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 1, 48.78, N'SCHA9A26946')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5787', 30, N'DISJ.SCHA9F77220', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 1, 36.66, N'A977220')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5787', 31, N'PROT.SCHGV2ME16', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 1, 44.15, N'SCHGV2ME16')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5787', 32, N'GAIN.THER3M85833', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 3, 39.52, N'85833')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5787', 33, N'GAIN.THER3M85824', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 5, 39.52, N'85824')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5787', 34, N'GAIN.THER3M85842', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 6, 39.52, N'3M 85842')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5787', 35, N'BOIT.LEG092094', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 1, 96, N'LEG092094')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5787', 36, N'PATT.LEG035802', CAST(N'2018-11-19T00:00:00.000' AS DateTime), 1, 11.27, N'LEG035802')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5787', 37, N'SOCL.LEG057671', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 4, 6.456, N'LEG057671')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5788', 1, N'ENRO.', CAST(N'2018-10-12T00:00:00.000' AS DateTime), 200, 25, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5809', 1, N'LAVE_GLACE2LH', CAST(N'2018-09-17T00:00:00.000' AS DateTime), 32, 4.34, N'0217104-2')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5809', 2, N'LING.90', CAST(N'2018-09-17T00:00:00.000' AS DateTime), 24, 31.83, N'MANOCLIS-0211115')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5809', 3, N'INSE.POMP.', CAST(N'2018-09-17T00:00:00.000' AS DateTime), 36, 16.37, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5809', 4, N'TAPI.COULOIR900/1500', CAST(N'2018-10-03T00:00:00.000' AS DateTime), 1, 109.21, N'0109758')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5812', 1, N'SOND.VEG52/6M', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 2, 493.26, N'WL52XXX4AKD1BC1X')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5812', 2, N'ALIM.VEGA', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 2, 148.28, N'WL52XXX000HS')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5812', 3, N'CABL.RNF2G1.5', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 100, 0.7134, N'CDL1 01360411')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5812', 4, N'RELA.SCHRM22TR33', CAST(N'2018-09-26T00:00:00.000' AS DateTime), 2, 153.18, N'SCH RM22TR33')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5818', 1, N'MORT.WEBVM216', CAST(N'2018-10-12T00:00:00.000' AS DateTime), 126, 18.7, N'WEBER BROUTIN VM216')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5818', 2, N'GRAV.0-15', CAST(N'2018-10-12T00:00:00.000' AS DateTime), 1, 42.79, N'G015')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5893', 1, N'BUSE_WEL_DX113', CAST(N'2018-10-04T00:00:00.000' AS DateTime), 2, 9, N'405-3525')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5893', 2, N'FER_AD.WEL_DSX80', CAST(N'2018-10-04T00:00:00.000' AS DateTime), 2, 259, N'405-3474')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5893', 3, N'FER_AS.WEL_WSP80', CAST(N'2018-10-04T00:00:00.000' AS DateTime), 1, 177, N'292-1943')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5893', 4, N'TIRE_FIL30', CAST(N'2018-10-09T00:00:00.000' AS DateTime), 3, 54.88, N'AGI397063')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5895', 1, N'SERV.AUMSA10.2', CAST(N'2018-10-13T00:00:00.000' AS DateTime), 4, 1842, N'SA10.2')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5896', 1, N'ONDU.S2SSRS1000', CAST(N'2018-10-13T00:00:00.000' AS DateTime), 3, 1238, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5896', 2, N'DETE.BANQS303E', CAST(N'2018-10-12T00:00:00.000' AS DateTime), 4, 119, N'BANNER QS303E')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5896', 3, N'DETE.BANQS30VR3R', CAST(N'2018-10-12T00:00:00.000' AS DateTime), 4, 178, N'BANNER QS303R')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5896', 4, N'SUPP.BANSMB30FA', CAST(N'2018-10-13T00:00:00.000' AS DateTime), 8, 24.9, N'BANNER SMB30FA')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5897', 1, N'SELE.FAUA3199', CAST(N'2018-10-17T00:00:00.000' AS DateTime), 1, 482.32, N'070 A3199')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5897', 2, N'PORT', CAST(N'2018-10-17T00:00:00.000' AS DateTime), 1, 25, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5898', 1, N'FOYE.SEA_C069', CAST(N'2018-10-16T00:00:00.000' AS DateTime), 4, 136, N'C069')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5898', 2, N'CONN.SEA099', CAST(N'2018-10-16T00:00:00.000' AS DateTime), 4, 6.72, N'C099')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5898', 3, N'PORT', CAST(N'2018-10-16T00:00:00.000' AS DateTime), 1, 35, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5899', 1, N'CHAI.STH39700030074', CAST(N'2018-10-16T00:00:00.000' AS DateTime), 10, 15.83, N'36890000074')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5899', 2, N'CHAI.STH38680030072', CAST(N'2018-10-16T00:00:00.000' AS DateTime), 10, 15.83, N'36520000072')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5899', 3, N'FILT.STH41341410300', CAST(N'2018-10-16T00:00:00.000' AS DateTime), 1, 8.33, N'41341410300')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5899', 4, N'CHAI.STH39910030060', CAST(N'2018-10-16T00:00:00.000' AS DateTime), 10, 15, N'36520000060')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5926', 1, N'FILT.DESDC2', CAST(N'2018-09-25T00:00:00.000' AS DateTime), 40, 128.75, N'9104371')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5926', 2, N'PORT', CAST(N'2018-10-05T00:00:00.000' AS DateTime), 1, 30, N'PORT ET EMBALLAGE USINE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5941', 1, N'PAVI.ALLEMAGNE', CAST(N'2018-10-15T00:00:00.000' AS DateTime), 3, 24, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5941', 2, N'PAVI.EUROPE', CAST(N'2018-10-15T00:00:00.000' AS DateTime), 2, 39, N'1000 X 1500')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5941', 3, N'PAVI.FRANCE', CAST(N'2018-10-15T00:00:00.000' AS DateTime), 2, 24, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5941', 4, N'VITRINE EXT.1000', CAST(N'2018-10-15T00:00:00.000' AS DateTime), 1, 480, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5942', 1, N'HAUT_BEH20-9237', CAST(N'2018-10-18T00:00:00.000' AS DateTime), 3, 94.5, N'20-9237')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5942', 4, N'PORT', CAST(N'2018-10-18T00:00:00.000' AS DateTime), 1, 45, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5942', 5, N'BLOC_BEH20-9585', CAST(N'2018-10-18T00:00:00.000' AS DateTime), 3, 36, N'20_9585')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5942', 6, N'AMPL.BEH20-0054', CAST(N'2018-10-18T00:00:00.000' AS DateTime), 3, 100.8, N'20-0054')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5944', 1, N'REPA.APPAREIL_LEVAGE', CAST(N'2018-10-18T00:00:00.000' AS DateTime), 1, 100, N'REPARATION')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5944', 2, N'CONT.PERHARNAI', CAST(N'2018-10-30T00:00:00.000' AS DateTime), 6, 20, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5944', 3, N'REPA.APPAREIL_LEVAGE', CAST(N'2018-10-18T00:00:00.000' AS DateTime), 1, 96, N'REPARATION')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5944', 4, N'CASQ.CHT.BLC', CAST(N'2018-10-18T00:00:00.000' AS DateTime), 2, 42, N'CENTURION SPECTRUM')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5944', 5, N'COMB.JET3', CAST(N'2018-10-18T00:00:00.000' AS DateTime), 25, 5.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5944', 6, N'COMB.JET4', CAST(N'2018-10-17T00:00:00.000' AS DateTime), 10, 5.5, N'734002BLANC')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5944', 7, N'COMB.JET5', CAST(N'2018-10-17T00:00:00.000' AS DateTime), 10, 5.5, N'734002BLANC')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5944', 8, N'GANT_HYDRO10', CAST(N'2018-10-17T00:00:00.000' AS DateTime), 30, 6.9, N'ROSTAING')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5944', 9, N'GANT_HYDRO9', CAST(N'2018-10-17T00:00:00.000' AS DateTime), 50, 6.9, N'ROSTAING')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5944', 10, N'CASQ.C1', CAST(N'2018-10-19T00:00:00.000' AS DateTime), 3, 14.7, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5968', 1, N'RELA.SCHRM22TR33', CAST(N'2018-10-17T00:00:00.000' AS DateTime), 5, 153.18, N'SCH RM22TR33')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5968', 2, N'CHEM.CAB000068', CAST(N'2018-10-17T00:00:00.000' AS DateTime), 30, 19.3, N'000068')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5968', 3, N'COUV.LCM646014', CAST(N'2018-10-17T00:00:00.000' AS DateTime), 30, 24.3, N'LCM646014')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5968', 4, N'ECLI.CAB558288', CAST(N'2018-10-17T00:00:00.000' AS DateTime), 50, 5.4, N'LCM558288')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5968', 5, N'DETE.BANQS303E', CAST(N'2018-10-16T00:00:00.000' AS DateTime), 4, 119, N'BANNER QS303E')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5968', 6, N'DETE.BANQS30VR3R', CAST(N'2018-10-16T00:00:00.000' AS DateTime), 4, 178, N'BANNER QS303R')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5968', 7, N'SUPP.BANSMB30FA', CAST(N'2018-10-17T00:00:00.000' AS DateTime), 8, 24.9, N'BANNER SMB30FA')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5968', 8, N'DISQ.D1TO', CAST(N'2018-11-17T00:00:00.000' AS DateTime), 1, 86, N'134890')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5968', 9, N'EQUE.LCM586058', CAST(N'2018-11-17T00:00:00.000' AS DateTime), 1, 80, N'LCM506058')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5969', 1, N'CONC.0/31.5', CAST(N'2018-10-19T00:00:00.000' AS DateTime), 60, 16.98, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5970', 1, N'DETE.BANQS303E', CAST(N'2018-10-18T00:00:00.000' AS DateTime), 20, 119, N'BANNER QS303E')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5970', 2, N'DETE.BANQS30VR3R', CAST(N'2018-10-18T00:00:00.000' AS DateTime), 20, 178, N'BANNER QS303R')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5970', 3, N'SUPP.BANSMB30FA', CAST(N'2018-10-19T00:00:00.000' AS DateTime), 40, 24.9, N'BANNER SMB30FA')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5971', 1, N'GROU.SDMOK22-C3', CAST(N'2018-10-19T00:00:00.000' AS DateTime), 1, 13105, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5992', 1, N'FOYE.SEA_C071', CAST(N'2018-10-18T00:00:00.000' AS DateTime), 28, 105, N'C071')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5992', 2, N'CONN.SEA101', CAST(N'2018-10-18T00:00:00.000' AS DateTime), 28, 0, N'C101')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5992', 3, N'FOYE.SEA_C069', CAST(N'2018-10-18T00:00:00.000' AS DateTime), 54, 98, N'C069')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5992', 4, N'CONN.SEA099', CAST(N'2018-10-18T00:00:00.000' AS DateTime), 54, 0, N'C099')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5993', 1, N'NETT.SURFACE', CAST(N'2018-10-22T00:00:00.000' AS DateTime), 6, 15.2, N'BACTIPAL PRO-0207170')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-5993', 2, N'ACTI.BIO_1L', CAST(N'2018-10-22T00:00:00.000' AS DateTime), 4, 14.75, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6075', 1, N'SP95E5', CAST(N'2018-10-22T00:00:00.000' AS DateTime), 1000, 1.326, N'00016')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6082', 1, N'DIST.RHEA', CAST(N'2018-10-23T00:00:00.000' AS DateTime), 1, 24966, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6085', 1, N'GABI.1000/1000/1000', CAST(N'2018-10-24T00:00:00.000' AS DateTime), 50, 78.97, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6085', 2, N'AGRA.CL40', CAST(N'2018-10-24T00:00:00.000' AS DateTime), 1, 47.68, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6133', 1, N'TOIT_CLA6005014214', CAST(N'2018-11-23T00:00:00.000' AS DateTime), 1, 981.44, N'6005014214')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6133', 2, N'GARN.CLA6005014217', CAST(N'2018-11-23T00:00:00.000' AS DateTime), 1, 57.95, N'6005014217')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6133', 3, N'GARN.CLA6005014218', CAST(N'2018-11-23T00:00:00.000' AS DateTime), 1, 57.95, N'6005014218')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6133', 4, N'GARN.CLA6005014215', CAST(N'2018-11-23T00:00:00.000' AS DateTime), 1, 87.98, N'6005014215')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6133', 5, N'GARN.CLA6005014216', CAST(N'2018-11-23T00:00:00.000' AS DateTime), 1, 87.98, N'6005014216')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6133', 6, N'MOUS.CLA7700039030', CAST(N'2018-11-23T00:00:00.000' AS DateTime), 2, 56.87, N'7700039030')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6133', 7, N'CACH.CLA7700003354', CAST(N'2018-11-23T00:00:00.000' AS DateTime), 3, 1.33, N'7700003354')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6133', 8, N'ROND.CLA6005014284', CAST(N'2018-11-23T00:00:00.000' AS DateTime), 2, 0.84, N'6005014284')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6133', 9, N'ROND.CLA6005014287', CAST(N'2018-11-23T00:00:00.000' AS DateTime), 4, 4.44, N'6005014287')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6133', 10, N'REPA.MAT.AGRI', CAST(N'2018-10-24T00:00:00.000' AS DateTime), 1, 945, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6133', 11, N'CONS.MA', CAST(N'2018-10-24T00:00:00.000' AS DateTime), 1, 7.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6136', 1, N'FLEX.HYDSM', CAST(N'2018-10-24T00:00:00.000' AS DateTime), 2, 57.68, N'FLEXIBLE HP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6136', 2, N'FLEX.HYDSM', CAST(N'2018-10-24T00:00:00.000' AS DateTime), 2, 41.25, N'FLEXIBLE HP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6136', 3, N'VALV.V8R_GROM', CAST(N'2018-10-24T00:00:00.000' AS DateTime), 4, 29.99, N'9103124')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6136', 4, N'UNIO.G12L-INOXTI', CAST(N'2018-11-24T00:00:00.000' AS DateTime), 2, 14.38, N'5101028')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6136', 5, N'ECRO.12L-INOX', CAST(N'2018-10-24T00:00:00.000' AS DateTime), 5, 2.8, N'5810036')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6136', 6, N'BAGU.ES2-12L/SINOX', CAST(N'2018-11-24T00:00:00.000' AS DateTime), 5, 4.13, N'5890012')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6136', 7, N'TUYA.AC10X17', CAST(N'2018-10-24T00:00:00.000' AS DateTime), 50, 4.46, N'0190322-1')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6137', 1, N'CIME.CE25', CAST(N'2018-11-23T00:00:00.000' AS DateTime), 64, 3.18, N'C25CE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6137', 2, N'COUV.BET50X50', CAST(N'2018-10-25T00:00:00.000' AS DateTime), 1, 19.98, N'RCC50')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6137', 3, N'VISS.BOSGSB18V-85C', CAST(N'2018-11-23T00:00:00.000' AS DateTime), 1, 479, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6137', 4, N'ACCU_18V', CAST(N'2018-11-23T00:00:00.000' AS DateTime), 1, 96.91, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6137', 5, N'TAXE', CAST(N'2018-10-15T00:00:00.000' AS DateTime), 1, 0.42, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6137', 6, N'MART.PGBH18V-20', CAST(N'2018-11-23T00:00:00.000' AS DateTime), 1, 379, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6137', 7, N'TAXE', CAST(N'2018-10-15T00:00:00.000' AS DateTime), 1, 0.42, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6137', 8, N'SCIE_BOSGSA18V-LI', CAST(N'2018-11-23T00:00:00.000' AS DateTime), 1, 362.09, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6137', 9, N'TAXE', CAST(N'2018-10-15T00:00:00.000' AS DateTime), 1, 0.42, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6139', 1, N'PIQU.ACACIA3.5', CAST(N'2018-10-24T00:00:00.000' AS DateTime), 200, 20, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6139', 2, N'PORT', CAST(N'2018-10-25T00:00:00.000' AS DateTime), 1, 200, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6180', 1, N'FIOU.CHAUF', CAST(N'2018-10-30T00:00:00.000' AS DateTime), 700, 0.825, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6186', 1, N'CONC.0/31.5', CAST(N'2018-10-24T00:00:00.000' AS DateTime), 30, 16.78, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6186', 2, N'CONC.PORPHYRE0/25', CAST(N'2018-10-24T00:00:00.000' AS DateTime), 14, 28.98, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6186', 3, N'TAXE', CAST(N'2018-10-24T00:00:00.000' AS DateTime), 1, 6, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 1, N'TAMB.DR241CL', CAST(N'2018-11-25T00:00:00.000' AS DateTime), 2, 76.71, N'23155')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 2, N'PAPI.A4IV160', CAST(N'2018-12-20T00:00:00.000' AS DateTime), 2, 4.8, N'36786')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 3, N'PAPI.A3IV160', CAST(N'2018-10-29T00:00:00.000' AS DateTime), 2, 10.19, N'48999')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 4, N'PAPI.A3V160', CAST(N'2018-12-20T00:00:00.000' AS DateTime), 2, 9.74, N'49010')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 5, N'PERF.2TR20F', CAST(N'2018-11-04T00:00:00.000' AS DateTime), 1, 13.9, N'75736')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 6, N'CART.BROTN241BK', CAST(N'2018-10-25T00:00:00.000' AS DateTime), 5, 50.39, N'23120')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 7, N'CART.BROTN241C', CAST(N'2018-10-25T00:00:00.000' AS DateTime), 6, 49.88, N'23122')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 8, N'CART.BROTN241Y', CAST(N'2018-10-25T00:00:00.000' AS DateTime), 5, 49.88, N'23124')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 9, N'CART.BROTN241M', CAST(N'2018-10-25T00:00:00.000' AS DateTime), 5, 49.88, N'23123')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 10, N'PAPI.A4BLANC', CAST(N'2018-10-25T00:00:00.000' AS DateTime), 90, 2.6, N'58429')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 11, N'CLAS.5V', CAST(N'2018-10-25T00:00:00.000' AS DateTime), 10, 1.59, N'59012')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 12, N'CORD.HDMI-2M', CAST(N'2018-12-20T00:00:00.000' AS DateTime), 3, 3.64, N'70384')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 13, N'POCH.CPFCCA', CAST(N'2018-10-25T00:00:00.000' AS DateTime), 2, 16.58, N'52575')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 14, N'POCH.PERF.TR', CAST(N'2018-10-25T00:00:00.000' AS DateTime), 1, 5.49, N'62883')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 15, N'MARQ.TAB.ASS', CAST(N'2018-10-25T00:00:00.000' AS DateTime), 2, 2.75, N'15004')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 16, N'STYL.G-2V', CAST(N'2018-10-25T00:00:00.000' AS DateTime), 12, 1.04, N'62976')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 17, N'FEUT.PNSF', CAST(N'2018-10-25T00:00:00.000' AS DateTime), 10, 0.99, N'63951')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 18, N'FEUT.PNM', CAST(N'2018-10-25T00:00:00.000' AS DateTime), 10, 0.84, N'63957')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 19, N'CART.BRO', CAST(N'2018-11-22T00:00:00.000' AS DateTime), 2, 29.62, N'82335')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 20, N'CART.BROLC1280Y', CAST(N'2018-10-25T00:00:00.000' AS DateTime), 3, 14.73, N'82448')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 21, N'SPIR.N6', CAST(N'2018-10-25T00:00:00.000' AS DateTime), 1, 1.34, N'36128')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 22, N'PAPI.A4BLANC160G', CAST(N'2018-11-22T00:00:00.000' AS DateTime), 1, 4.55, N'15856')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 23, N'PAPI.A4SAUM', CAST(N'2018-10-25T00:00:00.000' AS DateTime), 1, 4.21, N'33751')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 24, N'PAPI.A4VERT', CAST(N'2018-10-25T00:00:00.000' AS DateTime), 1, 4.21, N'15840')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 25, N'BLOC_DBA5', CAST(N'2018-11-22T00:00:00.000' AS DateTime), 10, 0.4, N'63208')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 26, N'BLOC_DBA4', CAST(N'2018-10-25T00:00:00.000' AS DateTime), 10, 0.74, N'63209')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 27, N'TABL.SUR_PIED80CM', CAST(N'2018-10-25T00:00:00.000' AS DateTime), 1, 121.03, N'33265')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6187', 28, N'STYL.G-2N', CAST(N'2018-10-25T00:00:00.000' AS DateTime), 12, 1.04, N'40454')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6188', 3, N'BASE_EWOFLEXY-201', CAST(N'2018-11-01T00:00:00.000' AS DateTime), 1, 437.5, N'EWON FLEXY-201')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6482', 1, N'SANG.2T2.5M', CAST(N'2018-11-06T00:00:00.000' AS DateTime), 8, 9, N'B602T2M50')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6482', 2, N'REPA.MATERIEL', CAST(N'2018-07-26T00:00:00.000' AS DateTime), 1, 165.5, N'ACCD')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6495', 1, N'RAIL_PHOFLDINRA', CAST(N'2018-11-05T00:00:00.000' AS DateTime), 5, 181.44, N'2891053')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6538', 1, N'REMO.ROUT.750KG', CAST(N'2018-11-06T00:00:00.000' AS DateTime), 1, 1187, N'R256')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6538', 2, N'ROUE_JOCKEY', CAST(N'2018-12-17T00:00:00.000' AS DateTime), 1, 27, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6538', 3, N'RAMP.2ML', CAST(N'2018-11-06T00:00:00.000' AS DateTime), 1, 124.17, N'0102344')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6551', 1, N'GAZO.', CAST(N'2018-11-06T00:00:00.000' AS DateTime), 759, 1.312, N'GRAND FROID')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6586', 1, N'CORD.EWO4PORTS', CAST(N'2018-11-10T00:00:00.000' AS DateTime), 1, 178, N'HSCORD.ALIM-201')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6586', 2, N'CORD.RJ45CAT6-1M', CAST(N'2018-11-10T00:00:00.000' AS DateTime), 20, 3.1, N'CR603B1')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6586', 3, N'CORD.RJ45CAT6-5M', CAST(N'2018-11-10T00:00:00.000' AS DateTime), 20, 6.6, N'CR603B5')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6586', 4, N'DISQ.D1TO', CAST(N'2018-12-11T00:00:00.000' AS DateTime), 1, 97, N'134890')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6586', 5, N'AGRA.N5_10MM', CAST(N'2018-12-10T00:00:00.000' AS DateTime), 3, 60, N'506')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6586', 6, N'AMPO.70W_E27', CAST(N'2018-11-10T00:00:00.000' AS DateTime), 15, 2.5, N'MAZA251722')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6586', 7, N'AMPO.53W_E27', CAST(N'2018-11-10T00:00:00.000' AS DateTime), 15, 2.5, N'MAZA251722')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6637', 1, N'BOUE_BICO.V600NM', CAST(N'2018-11-09T00:00:00.000' AS DateTime), 10, 50.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6637', 2, N'BOUE_CYL.R740NM', CAST(N'2018-11-09T00:00:00.000' AS DateTime), 10, 50.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6638', 1, N'ECRA.MURAL', CAST(N'2018-11-09T00:00:00.000' AS DateTime), 1, 71.48, N'47009')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6651', 3, N'VINA.BLANC', CAST(N'2018-11-07T00:00:00.000' AS DateTime), 12, 4.11, N'0208193')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6651', 4, N'LIQU.VAISSEL1L', CAST(N'2018-11-07T00:00:00.000' AS DateTime), 12, 8.75, N'1 LITRE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6651', 5, N'ESSU.TOUT', CAST(N'2018-11-07T00:00:00.000' AS DateTime), 72, 1.3575, N'0102146')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6651', 6, N'PAPI.TOIL380M', CAST(N'2018-11-07T00:00:00.000' AS DateTime), 18, 5.656, N'0102110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6651', 7, N'SAC_POUB50L', CAST(N'2018-11-07T00:00:00.000' AS DateTime), 2, 137.25, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6651', 8, N'SAC_POUB30L', CAST(N'2018-11-07T00:00:00.000' AS DateTime), 3, 54.88, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6651', 9, N'DESO.MECHE', CAST(N'2018-11-07T00:00:00.000' AS DateTime), 30, 5.99, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6651', 10, N'BLOC_WC', CAST(N'2018-11-07T00:00:00.000' AS DateTime), 32, 2.9, N'BOULES - BREF POWER ACTIV')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6651', 11, N'LING.WC', CAST(N'2018-11-07T00:00:00.000' AS DateTime), 24, 12.11, N'HARPIC')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6651', 12, N'LING.DEPOUS', CAST(N'2018-11-07T00:00:00.000' AS DateTime), 5, 9.95, N'SWIFER POUR MOBILIER')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6651', 14, N'MOUS.CANALISATION', CAST(N'2018-11-07T00:00:00.000' AS DateTime), 12, 23.333, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6651', 15, N'RUBA.2FACE12/10M', CAST(N'2018-11-07T00:00:00.000' AS DateTime), 4, 30.58, N'15M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6651', 16, N'GEL_SIPHON1', CAST(N'2018-11-07T00:00:00.000' AS DateTime), 6, 14.88, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6651', 17, N'TAMP.', CAST(N'2018-11-07T00:00:00.000' AS DateTime), 30, 1.497, N'0109123 - SPONTEX')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6652', 1, N'CLIQ.WER160785/8100SA/SC2', CAST(N'2018-11-09T00:00:00.000' AS DateTime), 1, 488, N'5050183')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6652', 2, N'COFF.EMBPOZI', CAST(N'2018-11-09T00:00:00.000' AS DateTime), 3, 56.5, N'5050284')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6652', 3, N'ASPI.DIM/E21L', CAST(N'2018-11-09T00:00:00.000' AS DateTime), 1, 241, N'920031')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6652', 4, N'LAMP.LEDSTYLO', CAST(N'2018-11-09T00:00:00.000' AS DateTime), 1, 53, N'7887')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6652', 5, N'LAMP.LEDSFM', CAST(N'2018-11-09T00:00:00.000' AS DateTime), 1, 79, N'7994')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6652', 6, N'RACC.10F', CAST(N'2018-11-09T00:00:00.000' AS DateTime), 5, 5.78, N'1980802')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6652', 7, N'ZCO_20', CAST(N'2018-11-09T00:00:00.000' AS DateTime), 5, 0.44, N'7650058')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6787', 1, N'CASQ.CHT.BLC', CAST(N'2018-11-15T00:00:00.000' AS DateTime), 5, 42, N'CENTURION SPECTRUM')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6787', 2, N'COMB.PLUIE_XL', CAST(N'2018-11-14T00:00:00.000' AS DateTime), 3, 120.84, N'SIOEN CHARENTE-4910')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6787', 3, N'COMB.PLUIE_XXL', CAST(N'2018-11-14T00:00:00.000' AS DateTime), 3, 120.84, N'0SIO4910')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6787', 4, N'CORD.POLY6', CAST(N'2018-11-14T00:00:00.000' AS DateTime), 100, 0.094, N'ACCD')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6787', 5, N'CORD.POLY10', CAST(N'2018-11-15T00:00:00.000' AS DateTime), 100, 0.1865, N'ACCD')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6799', 1, N'CHAM.16.9-34', CAST(N'2018-11-16T00:00:00.000' AS DateTime), 1, 137, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6846', 1, N'CORD.SPIR7.5M', CAST(N'2018-10-17T00:00:00.000' AS DateTime), 1, 16.99, N'SOD16339')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6846', 2, N'INTE.RS607-7781', CAST(N'2018-10-17T00:00:00.000' AS DateTime), 1, 21.68, N'RADI607-7781')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6846', 3, N'CHAR.BOSC7', CAST(N'2018-10-17T00:00:00.000' AS DateTime), 1, 89.2, N'C7')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6846', 4, N'SAC_KAR69074790', CAST(N'2018-08-30T00:00:00.000' AS DateTime), 2, 21, N'KAR69074790')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6846', 5, N'VERR.105X50I', CAST(N'2018-10-17T00:00:00.000' AS DateTime), 5, 0.81, N'SAFW000335018')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6846', 6, N'DETE.OXY10M3', CAST(N'2018-10-17T00:00:00.000' AS DateTime), 1, 80.77, N'SAFW000371352')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6846', 7, N'ADAP.13PL/7PL.M', CAST(N'2018-10-31T00:00:00.000' AS DateTime), 1, 17.96, N'INF115BL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6846', 8, N'CURA.MEC133005', CAST(N'2018-10-17T00:00:00.000' AS DateTime), 10, 29.41, N'MEC133005')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6846', 9, N'CURA.MEC157005', CAST(N'2018-11-06T00:00:00.000' AS DateTime), 5, 27.77, N'MEC157005')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6846', 10, N'CURA.MEC174005', CAST(N'2018-10-17T00:00:00.000' AS DateTime), 5, 26.92, N'174005')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6846', 11, N'TUYA.ESS12', CAST(N'2018-10-17T00:00:00.000' AS DateTime), 15, 6.72, N'GATE3225-10015')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6846', 12, N'GIRO.MAGLED', CAST(N'2018-10-17T00:00:00.000' AS DateTime), 1, 55.55, N'SODISE 117056')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6857', 1, N'COUP.19GCU', CAST(N'2018-12-17T00:00:00.000' AS DateTime), 3, 11.9, N'51367')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6857', 2, N'VBA_TFT4.5X070', CAST(N'2018-12-16T00:00:00.000' AS DateTime), 1, 16.67, N'46375191')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6857', 3, N'TIRE.TH10X080', CAST(N'2018-11-16T00:00:00.000' AS DateTime), 50, 0.2412, N'46415422')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6857', 4, N'GAZ_PROP13KGS', CAST(N'2018-10-21T00:00:00.000' AS DateTime), 1, 31.44, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6857', 5, N'PELL+MANCHE', CAST(N'2018-11-05T00:00:00.000' AS DateTime), 2, 15.48, N'130271')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6857', 6, N'CADE.COMB40', CAST(N'2018-12-16T00:00:00.000' AS DateTime), 5, 19.95, N'33296')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6933', 1, N'ESSU.MAIN_KIM6763', CAST(N'2018-11-19T00:00:00.000' AS DateTime), 120, 4.499, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6933', 2, N'SAVO.GEL350', CAST(N'2018-11-19T00:00:00.000' AS DateTime), 24, 9.17, N'0216147')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6933', 3, N'SAC_POUB130L', CAST(N'2018-11-19T00:00:00.000' AS DateTime), 2, 67.97, N'0111103')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6933', 4, N'GEL_JAVEL_WC', CAST(N'2018-11-19T00:00:00.000' AS DateTime), 1, 6.1, N'0207147')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6982', 1, N'VIS_THT10X60A2', CAST(N'2018-11-20T00:00:00.000' AS DateTime), 100, 3.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6982', 2, N'VIS_THP22X80A2', CAST(N'2018-11-20T00:00:00.000' AS DateTime), 200, 0.396, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6982', 3, N'BURI.PLATMAX400', CAST(N'2018-11-20T00:00:00.000' AS DateTime), 2, 25.35, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6982', 4, N'METR.ALU', CAST(N'2018-11-20T00:00:00.000' AS DateTime), 1, 17, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6982', 5, N'METR.POL.', CAST(N'2018-11-20T00:00:00.000' AS DateTime), 10, 5.9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6982', 6, N'POIN.SDS+', CAST(N'2018-11-20T00:00:00.000' AS DateTime), 5, 41, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6982', 7, N'BURI.PLAT250SDS+', CAST(N'2018-11-20T00:00:00.000' AS DateTime), 5, 25.35, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6982', 8, N'COMB.PLUIE_XL', CAST(N'2018-11-19T00:00:00.000' AS DateTime), 3, 117.5, N'SIOEN CHARENTE-4910')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-6982', 9, N'CREM.HYD.', CAST(N'2018-11-20T00:00:00.000' AS DateTime), 7, 12, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-7063', 1, N'REPA.MATERIEL', CAST(N'2018-11-23T00:00:00.000' AS DateTime), 1, 212.95, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-7427', 1, N'CAFE_DOSE48', CAST(N'2018-12-09T00:00:00.000' AS DateTime), 10, 11.295, N'SENSEO CLASSIQUE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-7427', 3, N'TAPI.COCO60X80', CAST(N'2018-12-09T00:00:00.000' AS DateTime), 1, 18, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-7427', 5, N'GEL_ANTISEP.350ML', CAST(N'2018-12-28T00:00:00.000' AS DateTime), 7, 12.55, N'0216151')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-7427', 7, N'KIT_NETTOYAGE', CAST(N'2018-12-28T00:00:00.000' AS DateTime), 1, 75, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-7427', 9, N'CAFE.DOSE_NG', CAST(N'2018-11-28T00:00:00.000' AS DateTime), 1, 138, N'SENSEO NOIR')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-762', 1, N'BROS.REPUL0.5M', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 120, 10.95, N'SBRN_0.5')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-762', 2, N'BROS.REPUL1M', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 180, 16.2, N'SBRN_1.0')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-762', 3, N'MO_MATERIEL', CAST(N'2018-02-21T00:00:00.000' AS DateTime), 1, 440, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-913', 1, N'PAPI.A4BLANC', CAST(N'2018-02-27T00:00:00.000' AS DateTime), 25, 15.58, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-951', 1, N'MOTE.AUMZ011.892', CAST(N'2018-03-02T00:00:00.000' AS DateTime), 2, 496, N'Z011.892')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-951', 2, N'PLAQ.AUMZ035.679', CAST(N'2018-03-02T00:00:00.000' AS DateTime), 6, 6, N'Z035.679')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-951', 3, N'COUV.AUM507.0', CAST(N'2018-03-02T00:00:00.000' AS DateTime), 6, 41, N'REP.507.0')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-951', 4, N'CONN.AUMREP.502.0', CAST(N'2018-03-02T00:00:00.000' AS DateTime), 2, 41, N'REP.502.0')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-951', 5, N'CONN.AUMN1', CAST(N'2018-03-02T00:00:00.000' AS DateTime), 3, 41, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-951', 6, N'OUTI.AUMZ007.735', CAST(N'2018-03-02T00:00:00.000' AS DateTime), 4, 55, N'Z007.735')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-951', 7, N'SUPP.AUMZ032.002', CAST(N'2018-03-02T00:00:00.000' AS DateTime), 4, 7, N'Z032.002')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-951', 8, N'CONT.AUMZ032.068', CAST(N'2018-03-02T00:00:00.000' AS DateTime), 8, 48, N'Z032.068')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-951', 10, N'TRAN.AUMZ002.880', CAST(N'2018-03-02T00:00:00.000' AS DateTime), 2, 425, N'Z002.880')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-978', 1, N'FIOU.CHAUF', CAST(N'2018-03-11T00:00:00.000' AS DateTime), 2000, 0.7, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-997', 1, N'CONT.PERAPPARAU', CAST(N'2018-03-26T00:00:00.000' AS DateTime), 1, 360, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-997', 2, N'CONT.PERENGLEVAGE', CAST(N'2018-03-26T00:00:00.000' AS DateTime), 1, 566, N'ENGINS DE LEVAGE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-997', 3, N'CONT.PERENGLEVAGE', CAST(N'2018-03-26T00:00:00.000' AS DateTime), 1, 1100, N'ENGINS DE LEVAGE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-997', 4, N'CONT.PERECHEL', CAST(N'2018-03-26T00:00:00.000' AS DateTime), 1, 466, N'SARREGUEMINES +MITTERSHEIM')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-997', 5, N'CONT.PERAPPARAU', CAST(N'2018-03-26T00:00:00.000' AS DateTime), 1, 676, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-997', 7, N'EASY_CLIP', CAST(N'2018-03-26T00:00:00.000' AS DateTime), 1, 120, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-997', 8, N'CONT.PERPORTESEC', CAST(N'2018-03-26T00:00:00.000' AS DateTime), 1, 350, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2018-998', 1, N'GACH.ELEC12V_APPLIQ', CAST(N'2018-03-07T00:00:00.000' AS DateTime), 1, 56.48, N'666009')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-001', 1, N'POIG.STH11297911701', CAST(N'2018-12-11T00:00:00.000' AS DateTime), 1, 53.62, N'1129 791 1701')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-001', 3, N'POIG.STH11417911706', CAST(N'2019-01-31T00:00:00.000' AS DateTime), 1, 31.3, N'11417911706')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-001', 4, N'CABO.SOR3425', CAST(N'2019-01-31T00:00:00.000' AS DateTime), 2, 17.16, N'SOR3425')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-001', 5, N'CABO.SOR3426', CAST(N'2019-01-31T00:00:00.000' AS DateTime), 2, 17.16, N'SOR3426')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-001', 6, N'SAPI-HACHE70CM', CAST(N'2019-01-31T00:00:00.000' AS DateTime), 1, 47.99, N'JHHSGM')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-001', 7, N'GUID.STH30050007409', CAST(N'2019-01-02T00:00:00.000' AS DateTime), 3, 52.33, N'30050007409')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-001', 10, N'CHAI.STH39700030074', CAST(N'2019-01-02T00:00:00.000' AS DateTime), 1, 16.64, N'22LPX074')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-001', 14, N'GUID.STH30030086817', CAST(N'2019-01-31T00:00:00.000' AS DateTime), 1, 50.6, N'3003-008-6817')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-001', 15, N'PORT', CAST(N'2019-01-02T00:00:00.000' AS DateTime), 1, 12.9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-001', 16, N'PROT.STH11417929100', CAST(N'2019-01-31T00:00:00.000' AS DateTime), 1, 20.33, N'11417929100')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-001', 17, N'METR.STH00008811200', CAST(N'2019-01-02T00:00:00.000' AS DateTime), 2, 25.17, N'000088111200')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-001', 18, N'LEVI.130CM', CAST(N'2019-01-31T00:00:00.000' AS DateTime), 1, 55.83, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-001', 19, N'FEU_SOR6868', CAST(N'2019-01-31T00:00:00.000' AS DateTime), 1, 30.99, N'6868')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-001', 20, N'FEU_SOR6867', CAST(N'2019-01-31T00:00:00.000' AS DateTime), 1, 30.99, N'6867')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-002', 1, N'BATT.STARN5', CAST(N'2018-12-07T00:00:00.000' AS DateTime), 1, 93, N'STARN5')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-002', 2, N'BATT.STARN6', CAST(N'2019-01-07T00:00:00.000' AS DateTime), 1, 146, N'STARN6')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-002', 3, N'DOUI.FACSTM.8', CAST(N'2018-12-07T00:00:00.000' AS DateTime), 2, 8.25, N'FACSTM.8')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-002', 4, N'DOUI.FACS32L', CAST(N'2018-12-07T00:00:00.000' AS DateTime), 1, 14.16, N'FACS.32LA')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-002', 5, N'AMPO.HALO.H4', CAST(N'2019-01-02T00:00:00.000' AS DateTime), 4, 4.56, N'OSRA64193')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-002', 6, N'ADBL.5L', CAST(N'2019-01-31T00:00:00.000' AS DateTime), 8, 3.68, N'DIFRADBLUE5')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-002', 7, N'BURI.FAC259', CAST(N'2019-01-03T00:00:00.000' AS DateTime), 1, 9.83, N'FAC259')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-002', 8, N'BURI.AC263.25', CAST(N'2019-01-02T00:00:00.000' AS DateTime), 1, 10.69, N'FAC263.25')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-002', 9, N'LAMP.LEDSTYLO', CAST(N'2019-01-31T00:00:00.000' AS DateTime), 2, 16, NULL)
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-002', 10, N'PIST.SOUDER1000W', CAST(N'2019-03-03T00:00:00.000' AS DateTime), 1, 19.84, N'SOD05631')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-002', 11, N'ENSE.FAC.325', CAST(N'2019-01-31T00:00:00.000' AS DateTime), 1, 81.54, N'FAC.325')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-002', 12, N'REGL.20CM', CAST(N'2019-03-03T00:00:00.000' AS DateTime), 1, 1.69, N'FACDELA.1051.200')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-002', 13, N'REGL.30CM', CAST(N'2019-03-03T00:00:00.000' AS DateTime), 1, 2.42, N'FACDELA.1051.300')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-002', 15, N'RACC.GAZ1F', CAST(N'2019-03-03T00:00:00.000' AS DateTime), 1, 9.62, N'PREVEXP F2634')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-002', 16, N'TRES.PRO239', CAST(N'2019-03-03T00:00:00.000' AS DateTime), 1, 41.7, N'PROMTEC239')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-002', 17, N'TRES.PRO242BRN', CAST(N'2019-03-03T00:00:00.000' AS DateTime), 1, 51.28, N'PROMTEC242BRN')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-002', 18, N'PINC.FAC455B', CAST(N'2019-03-03T00:00:00.000' AS DateTime), 1, 39.66, N'FACSTM8')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-002', 19, N'GRAT.GIVRE', CAST(N'2019-01-03T00:00:00.000' AS DateTime), 4, 2, N'FLAU900169')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-002', 20, N'DOUI.KRA301100', CAST(N'2019-03-03T00:00:00.000' AS DateTime), 1, 7.32, N'KRA301100')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-002', 21, N'DOUI.KRA301130', CAST(N'2019-03-03T00:00:00.000' AS DateTime), 1, 7.32, N'KRA301130')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-002', 22, N'DOUI.KRA301170', CAST(N'2019-03-03T00:00:00.000' AS DateTime), 1, 7.32, N'KRA301190')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-002', 23, N'DOUI.KRA301190', CAST(N'2019-03-03T00:00:00.000' AS DateTime), 1, 7.32, N'KRA301190')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-003', 1, N'PILE_9V', CAST(N'2018-12-07T00:00:00.000' AS DateTime), 12, 4.6, N'CIPE095883')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-003', 2, N'ALIM.VEL_LABPS6005', CAST(N'2019-12-31T00:00:00.000' AS DateTime), 1, 86.99, N'090-451CONRAD')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-003', 3, N'CORD.VOL1MM_NOIR', CAST(N'2019-12-31T00:00:00.000' AS DateTime), 2, 5.59, N'108-609CONRAD')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-003', 4, N'CORD.VOL1MM_ROUGE', CAST(N'2019-12-31T00:00:00.000' AS DateTime), 2, 5.49, N'108-608CONRAD')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-003', 5, N'CORD.VOL_SET10PIECES', CAST(N'2019-12-31T00:00:00.000' AS DateTime), 1, 21.99, N'128911-CONRAD')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-003', 6, N'CORD.PJP6036', CAST(N'2019-12-31T00:00:00.000' AS DateTime), 2, 4.2, N'063031-CONRAD')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-003', 7, N'PORT', CAST(N'2019-01-02T00:00:00.000' AS DateTime), 1, 65, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-003', 9, N'DISJ.SCHA9N21020', CAST(N'2019-01-03T00:00:00.000' AS DateTime), 6, 18.16, N'SCHA9N21020')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-003', 14, N'ELEC.24V19W', CAST(N'2019-12-31T00:00:00.000' AS DateTime), 1, 155.77, N'RS307-3607')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-003', 15, N'PIQU.T1', CAST(N'2018-11-30T00:00:00.000' AS DateTime), 1, 9.62, N'FORS DBXO10')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-003', 16, N'COLL.SCHENN47942', CAST(N'2018-11-13T00:00:00.000' AS DateTime), 10, 9.8, N'SCHENN47942')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-003', 17, N'COLL.SCHENN46966', CAST(N'2019-01-03T00:00:00.000' AS DateTime), 10, 10.47, N'SARENN46966')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-003', 18, N'COLL.LEG032031', CAST(N'2019-12-31T00:00:00.000' AS DateTime), 10, 4.9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-003', 19, N'COLL.LEG032032', CAST(N'2019-12-31T00:00:00.000' AS DateTime), 10, 6.7, N'LEG032032')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-003', 20, N'PILE_LR14', CAST(N'2019-01-03T00:00:00.000' AS DateTime), 2, 2.5, N'CIPE 095821')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-003', 21, N'CABL.RNF3G1.5', CAST(N'2019-01-02T00:00:00.000' AS DateTime), 200, 0.8, N'H07RNF3G1.5')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-003', 22, N'TUBE_N18WLEDS', CAST(N'2019-12-31T00:00:00.000' AS DateTime), 5, 14.97, N'CGE-MM04563')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-003', 23, N'TUBE_N22WLEDS', CAST(N'2019-01-03T00:00:00.000' AS DateTime), 4, 17.96, N'CGE-MM04649')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-003', 24, N'JEU_FLUTLAC283', CAST(N'2019-01-03T00:00:00.000' AS DateTime), 1, 39.36, N'FLUAC283')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-00358', 1, N'GAZ_BUT.VRAC', CAST(N'2019-01-18T00:00:00.000' AS DateTime), 1.828, 1682.3, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-005', 1, N'MORT.CH330', CAST(N'2018-12-22T00:00:00.000' AS DateTime), 12, 8.59, N'A050140')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-005', 3, N'FIL_RECUIT1.5', CAST(N'2018-11-21T00:00:00.000' AS DateTime), 1, 21.93, N'FR6')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-005', 4, N'SILI.NEUT.GRIS', CAST(N'2018-11-09T00:00:00.000' AS DateTime), 2, 6.14, N'110252')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-005', 5, N'DECO.BOS06012331004', CAST(N'2018-11-21T00:00:00.000' AS DateTime), 1, 233.17, N'0601231004')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-005', 6, N'TAXE', CAST(N'2018-11-11T00:00:00.000' AS DateTime), 1, 0.42, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-005', 7, N'CHEV.MACON250', CAST(N'2018-12-22T00:00:00.000' AS DateTime), 10, 3.48, N'334712')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-005', 8, N'ECRO.H22A2', CAST(N'2018-12-22T00:00:00.000' AS DateTime), 50, 1.68, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-005', 10, N'PILE_9V', CAST(N'2018-11-21T00:00:00.000' AS DateTime), 2, 2.78, N'4922121411')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-005', 11, N'LAME_SEG85BI-MATIRE', CAST(N'2018-12-22T00:00:00.000' AS DateTime), 1, 27.8, N'2608661758')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-005', 12, N'LAME_PLONG32/40METAL', CAST(N'2018-12-22T00:00:00.000' AS DateTime), 2, 26.45, N'2608662018')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-005', 13, N'LAME_PLONG65/40B/M', CAST(N'2018-12-22T00:00:00.000' AS DateTime), 1, 86.17, N'2608661907')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-005', 14, N'LAME_PLONG32/40BSPC', CAST(N'2018-12-22T00:00:00.000' AS DateTime), 1, 63.27, N'2608662361')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-005', 15, N'LAME_PLONG32BOIS', CAST(N'2018-12-22T00:00:00.000' AS DateTime), 1, 16.54, N'2608661903')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-005', 22, N'MESU.5ML', CAST(N'2019-01-02T00:00:00.000' AS DateTime), 3, 7.8, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-005', 23, N'CORD.MAC1.5 PINCK', CAST(N'2019-01-03T00:00:00.000' AS DateTime), 1, 17.39, N'MO823110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-005', 24, N'CHEV.FRAP.FK6X40', CAST(N'2019-01-03T00:00:00.000' AS DateTime), 3, 6.74, N'A270080')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-005', 25, N'VBA_TFT04X040', CAST(N'2019-01-03T00:00:00.000' AS DateTime), 2, 14.51, N'46478694')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-005', 26, N'TRUE.C20', CAST(N'2019-01-31T00:00:00.000' AS DateTime), 1, 5.9, N'6008220401')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-005', 27, N'TRUE.I20', CAST(N'2019-01-03T00:00:00.000' AS DateTime), 2, 6.09, N'6003220401')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-005', 28, N'LAME_SEG85BOIS-MET', CAST(N'2019-01-31T00:00:00.000' AS DateTime), 1, 26.28, N'2608661636')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-006', 1, N'SPRA.DEGI.750', CAST(N'2018-12-17T00:00:00.000' AS DateTime), 12, 12.02, N'0109735')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-006', 2, N'SPRA.NETT.FR.B', CAST(N'2019-01-01T00:00:00.000' AS DateTime), 12, 14.88, N'ECOSOLVRAPIDE-0202210')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-006', 3, N'MOP_PRESTO', CAST(N'2019-02-17T00:00:00.000' AS DateTime), 10, 1.95, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-011', 1, N'PANT.FOR.ORE295453L', CAST(N'2019-03-05T00:00:00.000' AS DateTime), 1, 115.87, N'295490/L')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-011', 2, N'PANT.FOR.ORE295453/XL', CAST(N'2019-03-05T00:00:00.000' AS DateTime), 1, 115.87, N'295490/XL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-011', 3, N'GANT_TRONC.L', CAST(N'2019-03-05T00:00:00.000' AS DateTime), 3, 28.7, N'295485/L')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-011', 4, N'GANT_TRONC.M', CAST(N'2019-03-05T00:00:00.000' AS DateTime), 3, 28.7, N'295485/M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-011', 5, N'GANT_TRONC.XL', CAST(N'2019-03-05T00:00:00.000' AS DateTime), 3, 28.7, N'295485/XL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-013', 1, N'REGA.BET30X30', CAST(N'2019-02-08T00:00:00.000' AS DateTime), 1, 22.46, N'RCF30')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-013', 2, N'COUV.BET30X30', CAST(N'2019-02-08T00:00:00.000' AS DateTime), 1, 7.3, N'RCC30')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-013', 3, N'GRAV.SUP60', CAST(N'2019-02-08T00:00:00.000' AS DateTime), 2, 61.4, N'GS60')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-013', 4, N'CULO.110PVC45F', CAST(N'2019-02-08T00:00:00.000' AS DateTime), 1, 5.07, N'Y110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-013', 5, N'DRAI.AGRIJ100X50', CAST(N'2019-02-08T00:00:00.000' AS DateTime), 6, 1.63, N'D100')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-013', 6, N'TUYA.PVC160CR', CAST(N'2019-02-08T00:00:00.000' AS DateTime), 2, 8.435, N'T1602')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-013', 7, N'COUV.BET600', CAST(N'2019-02-15T00:00:00.000' AS DateTime), 1, 27.41, N'CB600')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-013', 8, N'CIME.PROMPT25', CAST(N'2019-02-08T00:00:00.000' AS DateTime), 2, 22.16, N'VIC25')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-013', 9, N'SABL.DM0/6', CAST(N'2019-02-08T00:00:00.000' AS DateTime), 2, 41.47, N'SJ2')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-013', 10, N'CHAUX_35KGS', CAST(N'2019-02-07T00:00:00.000' AS DateTime), 2, 9.21, N'CHAUX35')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-013', 11, N'AGRA.CL40', CAST(N'2018-12-27T00:00:00.000' AS DateTime), 1, 47.68, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-013', 12, N'GRAV.0-15', CAST(N'2019-02-07T00:00:00.000' AS DateTime), 2, 42.3, N'G015')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-013', 13, N'CIME.CE25', CAST(N'2019-03-09T00:00:00.000' AS DateTime), 64, 3.32, N'C25CE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-013', 14, N'CIME.PROMPT25', CAST(N'2019-02-08T00:00:00.000' AS DateTime), 2, 22.65, N'VIC25')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-014', 1, N'BOIT.AUX_LETTRES', CAST(N'2019-03-08T00:00:00.000' AS DateTime), 1, 58.44, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-014', 2, N'GAZ_BUT13KGS', CAST(N'2019-02-08T00:00:00.000' AS DateTime), 2, 31.44, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-014', 3, N'RUBA.MASQ25CL', CAST(N'2019-03-08T00:00:00.000' AS DateTime), 5, 1.66, N'902863')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-014', 4, N'MAST.ACRYL.BLC', CAST(N'2019-01-28T00:00:00.000' AS DateTime), 4, 3.73, N'128783')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-014', 5, N'SILI.SAN.TRANS', CAST(N'2019-02-08T00:00:00.000' AS DateTime), 2, 5.9, N'128791')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-014', 6, N'PLAT.FIN2.5KG', CAST(N'2019-03-08T00:00:00.000' AS DateTime), 1, 4.7, N'85011089')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-014', 7, N'GENO.', CAST(N'2019-02-07T00:00:00.000' AS DateTime), 2, 29.8, N'MO154140')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-014', 8, N'CAMI.7L+RECH.', CAST(N'2019-03-08T00:00:00.000' AS DateTime), 6, 14.86, N'2685')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-014', 9, N'GRIL.CAM14L_PLAST', CAST(N'2019-03-08T00:00:00.000' AS DateTime), 4, 1.35, N'994180')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-014', 10, N'MONT.ROUL400', CAST(N'2019-03-14T00:00:00.000' AS DateTime), 5, 1.77, N'992240')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-014', 11, N'POUC.R2-21', CAST(N'2019-02-07T00:00:00.000' AS DateTime), 5, 6.45, N'28972')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-014', 12, N'PIST.EAU_MULTJ', CAST(N'2019-03-24T00:00:00.000' AS DateTime), 1, 24.94, N'308091')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-014', 13, N'PIST.EAU_LAITON', CAST(N'2019-03-24T00:00:00.000' AS DateTime), 2, 22.32, N'308091')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-014', 14, N'BROS.A_TAPISSER', CAST(N'2019-03-24T00:00:00.000' AS DateTime), 1, 3.59, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-014', 15, N'MOUS.PU500ML', CAST(N'2019-02-08T00:00:00.000' AS DateTime), 2, 6.42, N'102373')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-02028-30', 1, N'MODU.IDE_MGKLX2', CAST(N'2020-02-02T00:00:00.000' AS DateTime), 1, 397, N'IDEAL-MGKLX2')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-02028-30', 2, N'DISQ.D.WEST2TO_BLACK', CAST(N'2020-02-02T00:00:00.000' AS DateTime), 2, 166.8, N'C331235-HORN')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-02028-30', 3, N'DISQ.SSD1TO', CAST(N'2020-02-02T00:00:00.000' AS DateTime), 1, 192.3, N'SAMSUNG MZ-76P1T0B/EU')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-02028-30', 4, N'TEST.IDE_R151006', CAST(N'2020-02-02T00:00:00.000' AS DateTime), 1, 588, N'IDEAL-R151006')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-02028-30', 5, N'TEST.CIN24-517', CAST(N'2020-02-02T00:00:00.000' AS DateTime), 1, 142.96, N'RS886-3098')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-02028-30', 6, N'COMM.LEG27510', CAST(N'2020-02-02T00:00:00.000' AS DateTime), 1, 37.25, N'LEG27510')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-02028-30', 7, N'COMM.HIR_SPIDER5TX', CAST(N'2020-02-02T00:00:00.000' AS DateTime), 2, 193, N'RS826-3246')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-02028-30', 8, N'BP_SCHA9E180328', CAST(N'2019-02-05T00:00:00.000' AS DateTime), 2, 12.09, N'ENN35028')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-02028-30', 9, N'DISJ.SCHA9F74201', CAST(N'2019-02-05T00:00:00.000' AS DateTime), 6, 65.71, N'SCH24201')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-02028-30', 10, N'DISJ.SCHA9F74202', CAST(N'2020-02-02T00:00:00.000' AS DateTime), 6, 67.26, NULL)
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-02028-30', 11, N'VOYA.SCHXB4BVB3', CAST(N'2019-02-22T00:00:00.000' AS DateTime), 2, 10.54, N'SCHXB4BVB3')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-02028-30', 12, N'VOYA.SCHXB4BVB4', CAST(N'2020-02-02T00:00:00.000' AS DateTime), 2, 10.54, N'SCHXB4VB4')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-02028-30', 13, N'DISJ.SCHA9N21361', CAST(N'2019-02-05T00:00:00.000' AS DateTime), 6, 55.95, N'SCHA9N21361')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-02028-30', 14, N'ECO_TAXE', CAST(N'2019-02-05T00:00:00.000' AS DateTime), 3, 0.5, N'ECO TAXE COMMUTATEUR')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-02028-30', 15, N'MODI.SCHBMXNOE0110', CAST(N'2020-02-02T00:00:00.000' AS DateTime), 1, 1144.09, N'SCHBMXNOE0110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-02028-30', 16, N'BP_SCHXB4BA21', CAST(N'2020-02-02T00:00:00.000' AS DateTime), 2, 8.19, N'SCH XB4BA21')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-02028-30', 17, N'ALIM.IDE151006', CAST(N'2020-02-02T00:00:00.000' AS DateTime), 1, 284, N'IDEAL R151006')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-02028-30', 18, N'PORT', CAST(N'2019-02-04T00:00:00.000' AS DateTime), 1, 60, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1019', 1, N'GANT_HYFLEX10', CAST(N'2019-02-25T00:00:00.000' AS DateTime), 120, 2.08, N'MF200T10')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1019', 2, N'BOUC.BIL303L20', CAST(N'2019-02-25T00:00:00.000' AS DateTime), 1, 26.4, N'HGB030')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1019', 3, N'GANT_MT8', CAST(N'2019-02-25T00:00:00.000' AS DateTime), 10, 6.36, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1019', 4, N'GANT_NITRIL10', CAST(N'2019-02-25T00:00:00.000' AS DateTime), 4, 17.6, N'AUU5000TXL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1019', 5, N'LUNE.DE PROTECT.', CAST(N'2019-02-25T00:00:00.000' AS DateTime), 6, 8.46, N'AVALASTE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1020', 2, N'TAPI.COCO60X80', CAST(N'2019-03-04T00:00:00.000' AS DateTime), 1, 15.88, N'HA0206')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1020', 3, N'TAPI.COULOIR60X90', CAST(N'2019-02-21T00:00:00.000' AS DateTime), 1, 32.94, N'BB0029A')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1020', 4, N'PEIN.SP9016_SOL', CAST(N'2019-03-04T00:00:00.000' AS DateTime), 6, 22.9, N'SP0003')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1020', 5, N'TAPI.CAILL150X100', CAST(N'2019-03-04T00:00:00.000' AS DateTime), 1, 72.84, N'BB0028')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1020', 6, N'POIG.PIST.PEINT.', CAST(N'2019-03-04T00:00:00.000' AS DateTime), 1, 32.4, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1020', 7, N'MOP_PRESTO', CAST(N'2019-03-04T00:00:00.000' AS DateTime), 1, 41.7, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1198', 1, N'FIOU.CHAUF', CAST(N'2019-03-12T00:00:00.000' AS DateTime), 2173, 0.7667, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1199', 1, N'FIOU.CHAUF', CAST(N'2019-03-11T00:00:00.000' AS DateTime), 1595, 0.7667, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1200', 1, N'ECRO.CAGE_M6', CAST(N'2019-03-07T00:00:00.000' AS DateTime), 100, 0.189, N'RS523-121')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1200', 2, N'VIS_TCB2.5X6A2', CAST(N'2019-03-07T00:00:00.000' AS DateTime), 100, 0.052, N'542-5426')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1200', 3, N'KIT_RS542-5426', CAST(N'2019-03-07T00:00:00.000' AS DateTime), 100, 0.69, N'RS542-5426')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1326', 1, N'PLAN.CH.TL_EP29', CAST(N'2019-03-06T00:00:00.000' AS DateTime), 18, 390, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1326', 2, N'PLAN.SAPTTL3C4M', CAST(N'2019-03-06T00:00:00.000' AS DateTime), 240, 4.8, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1326', 3, N'PORT', CAST(N'2019-03-06T00:00:00.000' AS DateTime), 1, 25, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1327', 1, N'GANT_HYDRO7', CAST(N'2019-04-22T00:00:00.000' AS DateTime), 12, 6.9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1327', 2, N'GANT_HYDRO8', CAST(N'2019-02-21T00:00:00.000' AS DateTime), 12, 6.9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1327', 3, N'GANT_HYDRO10', CAST(N'2019-02-20T00:00:00.000' AS DateTime), 70, 6.9, N'ROSTAING')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1327', 4, N'MASQ.AP', CAST(N'2019-02-21T00:00:00.000' AS DateTime), 50, 5.6, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1327', 5, N'COMB.JET5', CAST(N'2019-02-20T00:00:00.000' AS DateTime), 30, 5.5, N'734002BLANC')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1327', 6, N'GANT_VIBRA.10', CAST(N'2019-02-21T00:00:00.000' AS DateTime), 2, 55.1, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1327', 7, N'GANT_VIBRA.9', CAST(N'2019-02-21T00:00:00.000' AS DateTime), 2, 55.1, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1327', 8, N'GANT_MONOTHERM', CAST(N'2019-02-20T00:00:00.000' AS DateTime), 24, 1.9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1327', 9, N'COMB.JET4', CAST(N'2019-02-20T00:00:00.000' AS DateTime), 30, 5.5, N'734002BLANC')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1327', 10, N'CUIS.T41', CAST(N'2019-02-21T00:00:00.000' AS DateTime), 1, 73.1, N'THIGH SAFETY PVC DUNLOP T41')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1328', 1, N'COUD.BOB1B6598908', CAST(N'2019-03-07T00:00:00.000' AS DateTime), 1, 96.55, N'1B6598908')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1328', 2, N'BAGU.BOB1B6553411', CAST(N'2019-03-07T00:00:00.000' AS DateTime), 1, 31.84, N'1B6553411')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1328', 3, N'COLL.BOB1B6616213', CAST(N'2019-03-07T00:00:00.000' AS DateTime), 1, 39.16, N'1B6661213')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1328', 4, N'FLEX.BOB1B6576386', CAST(N'2019-03-07T00:00:00.000' AS DateTime), 2, 5.1, N'1B6576386')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1328', 5, N'TAMI.BOB1B6650239', CAST(N'2019-03-07T00:00:00.000' AS DateTime), 1, 13.54, N'1B6650239')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1328', 6, N'COLL.BOB1B42HS04', CAST(N'2019-03-07T00:00:00.000' AS DateTime), 4, 3.62, N'1B42HS04')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1328', 7, N'FILT.BOB1B6678034', CAST(N'2019-03-07T00:00:00.000' AS DateTime), 2, 65.65, N'1B6678034')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1328', 9, N'DENT_1B7107330_PACK', CAST(N'2019-03-07T00:00:00.000' AS DateTime), 1, 346.98, N'1B7107330')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1328', 10, N'ECRO_BOB1B95D6', CAST(N'2019-03-07T00:00:00.000' AS DateTime), 1, 27.36, N'1B95D6')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1328', 11, N'GOUP.BOB1B6560382', CAST(N'2019-03-07T00:00:00.000' AS DateTime), 6, 10.94, N'1B6560382')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1328', 12, N'COUP.BOB1B6672960', CAST(N'2019-03-07T00:00:00.000' AS DateTime), 6, 44.86, N'1B6672960')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1328', 13, N'BAGU.BOB1B6803213', CAST(N'2019-03-07T00:00:00.000' AS DateTime), 2, 41.03, N'1B6803213')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1328', 14, N'AXE_BOB6806971', CAST(N'2019-03-07T00:00:00.000' AS DateTime), 3, 119.95, N'1B6806971')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1328', 15, N'PORT', CAST(N'2019-03-07T00:00:00.000' AS DateTime), 1, 40, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1349', 9, N'FOYE.SEA_C069', CAST(N'2019-03-06T00:00:00.000' AS DateTime), 4, 123.25, N'C069')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1349', 10, N'FOYE.SEA_C071', CAST(N'2019-03-06T00:00:00.000' AS DateTime), 4, 131.75, N'C071')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1349', 11, N'CONN.SEA099', CAST(N'2019-03-06T00:00:00.000' AS DateTime), 4, 6.72, N'C099')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1349', 12, N'CONN.SEA101', CAST(N'2019-03-06T00:00:00.000' AS DateTime), 4, 6.72, N'C101')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1350', 7, N'XENO.TRA252133', CAST(N'2019-03-06T00:00:00.000' AS DateTime), 16, 170, N'252896')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1351', 3, N'COUV.AUM500.0', CAST(N'2019-03-13T00:00:00.000' AS DateTime), 24, 41, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1351', 4, N'RESI.AUMZ022.918', CAST(N'2019-03-13T00:00:00.000' AS DateTime), 10, 49, N'Z022.918')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1351', 5, N'RESI.AUMZ025.084', CAST(N'2019-03-13T00:00:00.000' AS DateTime), 5, 49, N'Z025.084')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1352', 1, N'PAPI.A4BLANC', CAST(N'2019-03-13T00:00:00.000' AS DateTime), 30, 15.8, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1353', 1, N'BOUC.RS817-8855', CAST(N'2019-03-15T00:00:00.000' AS DateTime), 100, 0.356, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1353', 2, N'GPS_TOM_VIA52', CAST(N'2019-03-15T00:00:00.000' AS DateTime), 2, 171.35, N'START62 EUROPE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1353', 3, N'CHAR.CROSSCALL_SPIDER X5', CAST(N'2019-03-15T00:00:00.000' AS DateTime), 2, 45.1, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1353', 4, N'CAFE.DOSE', CAST(N'2019-04-15T00:00:00.000' AS DateTime), 1, 62.4, N'SENSEO')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1353', 5, N'CAFE.ELEC', CAST(N'2019-04-19T00:00:00.000' AS DateTime), 1, 59, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1354', 1, N'MOUS.PU500ML', CAST(N'2019-03-16T00:00:00.000' AS DateTime), 3, 6.42, N'102373')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1354', 2, N'TARG.40MM', CAST(N'2019-03-16T00:00:00.000' AS DateTime), 1, 4.6, N'59673')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1354', 3, N'GAIN.40TPC25M', CAST(N'2019-03-15T00:00:00.000' AS DateTime), 1, 15.25, N'GTF40')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1354', 4, N'ROUL.JETABLE180', CAST(N'2019-03-16T00:00:00.000' AS DateTime), 3, 4.43, N'961180')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1354', 5, N'CADE.COMB50', CAST(N'2019-04-15T00:00:00.000' AS DateTime), 2, 27.6, N'33301')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1354', 6, N'POUC.R2-21', CAST(N'2019-03-15T00:00:00.000' AS DateTime), 4, 5.56, N'28972')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1354', 7, N'NEZ_ROB26/34L', CAST(N'2019-04-19T00:00:00.000' AS DateTime), 3, 3.94, N'51363')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1354', 8, N'METR.POL.', CAST(N'2019-03-16T00:00:00.000' AS DateTime), 10, 5.74, N'035458')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1354', 9, N'CLOU.STRI3.5/45', CAST(N'2019-03-16T00:00:00.000' AS DateTime), 1, 12.53, N'55217840')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1354', 10, N'CLOU.STRIE4.5/70', CAST(N'2019-03-16T00:00:00.000' AS DateTime), 2, 25.5, N'46248235')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1354', 11, N'GAZ_PROP13KGS', CAST(N'2019-02-18T00:00:00.000' AS DateTime), 1, 31.44, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1354', 12, N'SELL.100/40MF', CAST(N'2019-03-16T00:00:00.000' AS DateTime), 1, 5.55, N'SL104')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1354', 13, N'CLOU.STRI3.5/45', CAST(N'2019-03-16T00:00:00.000' AS DateTime), 1, 11.39, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1357', 1, N'GEOT.110G_2M', CAST(N'2019-03-21T00:00:00.000' AS DateTime), 6, 205.92, N'DIVERS')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1418', 1, N'REMP.PALIER', CAST(N'2019-03-06T00:00:00.000' AS DateTime), 10, 258.75, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1618', 1, N'SIEG.ASS/DEB56-76', CAST(N'2019-03-25T00:00:00.000' AS DateTime), 2, 216, N'9904')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1618', 2, N'ACCO.SAD', CAST(N'2019-03-25T00:00:00.000' AS DateTime), 2, 40, N'1277')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1618', 3, N'ROUL.SAD_50MM', CAST(N'2019-03-25T00:00:00.000' AS DateTime), 2, 8, N'10208')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1618', 4, N'TAXE', CAST(N'2019-03-25T00:00:00.000' AS DateTime), 1, 1.92, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1619', 1, N'BASE_DELL_PRECISION3930', CAST(N'2019-02-25T00:00:00.000' AS DateTime), 1, 1600, N'POWEREDGE R230')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1619', 2, N'SOUR.DEL', CAST(N'2019-02-25T00:00:00.000' AS DateTime), 1, 10, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1619', 3, N'PC_DEL_G7_17-7790_8GO', CAST(N'2019-02-25T00:00:00.000' AS DateTime), 1, 0, N'BN78603')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1619', 4, N'SAC.PC15/17"', CAST(N'2019-02-25T00:00:00.000' AS DateTime), 1, 0, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1619', 5, N'STYL.DEL_PN579X', CAST(N'2019-02-25T00:00:00.000' AS DateTime), 1, 50, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1619', 6, N'ECRA.DEL_P2719H', CAST(N'2019-02-25T00:00:00.000' AS DateTime), 1, 195, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1628', 1, N'CAPT.NIV1052', CAST(N'2018-11-22T00:00:00.000' AS DateTime), 2, 4070, N'VIVUS-1052')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1628', 2, N'SYST.NIV1015', CAST(N'2019-01-31T00:00:00.000' AS DateTime), 1, 520, N'NIVUS1015')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1628', 3, N'PORT', CAST(N'2019-01-31T00:00:00.000' AS DateTime), 1, 15, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1630', 1, N'SERV.AUMSA10.2', CAST(N'2019-03-07T00:00:00.000' AS DateTime), 4, 1862, N'SA10.2')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1631', 1, N'BAIE_DEX755418', CAST(N'2019-02-20T00:00:00.000' AS DateTime), 1, 1147, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1631', 2, N'ETAG.DEX755523', CAST(N'2019-02-20T00:00:00.000' AS DateTime), 5, 77, N'755253')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1631', 3, N'PANN.DEX258156', CAST(N'2019-02-20T00:00:00.000' AS DateTime), 1, 32, N'258156')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1631', 4, N'CONN.DEX418060', CAST(N'2019-02-20T00:00:00.000' AS DateTime), 24, 5.9, N'418060')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1631', 5, N'PORT.DEX333418', CAST(N'2019-02-20T00:00:00.000' AS DateTime), 2, 37, N'333418')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1631', 6, N'KIT_DEX755273', CAST(N'2019-02-20T00:00:00.000' AS DateTime), 1, 18.69, N'755273')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1631', 7, N'PASS.DEXDPVPP1', CAST(N'2019-02-20T00:00:00.000' AS DateTime), 1, 16.3, N'DPVPP1')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1631', 8, N'ROUT.CIS_RV345P', CAST(N'2019-03-23T00:00:00.000' AS DateTime), 1, 0, N'CISCO RV345P')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1670', 1, N'SCOR.', CAST(N'2019-03-28T00:00:00.000' AS DateTime), 20, 10, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1670', 2, N'LAIT.0/32', CAST(N'2019-03-28T00:00:00.000' AS DateTime), 20, 16.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1671', 1, N'DRAI.AGRIJ65X50', CAST(N'2019-03-27T00:00:00.000' AS DateTime), 50, 0.77, N'D65')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1671', 2, N'SABL.0/3', CAST(N'2019-03-27T00:00:00.000' AS DateTime), 5, 42.79, N'S034')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1671', 3, N'GRAV.0-15', CAST(N'2019-03-26T00:00:00.000' AS DateTime), 5, 42.79, N'G015')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1671', 4, N'PANN.PAF10', CAST(N'2019-03-27T00:00:00.000' AS DateTime), 3, 21.55, N'PAF10')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1671', 5, N'BETO.C25/30', CAST(N'2019-03-27T00:00:00.000' AS DateTime), 3, 93.5, N'XF1B/350KG')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1671', 6, N'PORT', CAST(N'2019-03-02T00:00:00.000' AS DateTime), 1, 24, N'FRANCO')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1673', 1, N'GALE.BOB_TR10120700', CAST(N'2019-04-03T00:00:00.000' AS DateTime), 5, 150.91, N'TR10120700')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1673', 2, N'PORT', CAST(N'2019-04-03T00:00:00.000' AS DateTime), 1, 40, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1735', 1, N'LAMP.2X18W_LED', CAST(N'2019-02-21T00:00:00.000' AS DateTime), 2, 58, N'CGE88858763')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1735', 3, N'PILE_CR2032', CAST(N'2019-02-21T00:00:00.000' AS DateTime), 20, 1.65, N'CR2032')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1735', 4, N'BORN.WAG273101', CAST(N'2019-02-20T00:00:00.000' AS DateTime), 6, 10.35, N'WAGO273101')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1735', 5, N'BORN.WAG222413', CAST(N'2019-02-23T00:00:00.000' AS DateTime), 6, 19.55, N'WAGO221413')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1735', 7, N'BLOC_BRE1152821', CAST(N'2019-02-21T00:00:00.000' AS DateTime), 6, 9.09, N'BRNN 1152821')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1735', 9, N'BOIT.SCHENN05004', CAST(N'2019-02-21T00:00:00.000' AS DateTime), 10, 2.16, N'SCHENN05004')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1735', 10, N'BOIT.SCHENN05005', CAST(N'2019-02-20T00:00:00.000' AS DateTime), 10, 4, N'SCHENN05005')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1735', 15, N'PILE_9V', CAST(N'2019-01-25T00:00:00.000' AS DateTime), 80, 4.59, N'CIPE095883')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1735', 16, N'FEU_GUE.502-2', CAST(N'2019-03-24T00:00:00.000' AS DateTime), 1, 496, N'KENT ZP124')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1735', 17, N'FICH.LEG050632', CAST(N'2019-01-01T00:00:00.000' AS DateTime), 1, 2.82, N'LEG50632')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1735', 18, N'BLOC_LEG050083', CAST(N'2019-01-01T00:00:00.000' AS DateTime), 1, 15.82, N'LEG050083')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1735', 19, N'BLOC_LEG50097', CAST(N'2019-02-20T00:00:00.000' AS DateTime), 1, 22.15, N'LEG050097')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1735', 20, N'DISJ.SCHGV2ME07', CAST(N'2019-03-24T00:00:00.000' AS DateTime), 1, 43.02, N'GV2ME7')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1735', 22, N'DECL.SCHGVAX385', CAST(N'2019-03-24T00:00:00.000' AS DateTime), 1, 31.77, N'GVAX385')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1735', 23, N'COFF.SCHGV3MCK04', CAST(N'2019-03-24T00:00:00.000' AS DateTime), 1, 34.47, N'GV2MCK04')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1735', 24, N'CORD.FLETL75', CAST(N'2019-02-21T00:00:00.000' AS DateTime), 2, 23, N'FLETL75-1')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1735', 25, N'CABL.R2V5G1.5', CAST(N'2019-02-21T00:00:00.000' AS DateTime), 100, 0.78, N'U1000R2VCU5G1.5')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1735', 26, N'CABL.R2V5G2.5', CAST(N'2019-03-23T00:00:00.000' AS DateTime), 100, 1.1, N'CDL1 01360822')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1735', 29, N'DISJ.SCHA9F77432', CAST(N'2019-03-24T00:00:00.000' AS DateTime), 1, 80.86, N'A977432')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1735', 30, N'PORT', CAST(N'2019-02-20T00:00:00.000' AS DateTime), 1, 60, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1735', 31, N'BLOC_BRE1159321018', CAST(N'2019-02-20T00:00:00.000' AS DateTime), 1, 17.41, N'BRNN 1159321018')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1736', 6, N'ONDU.S2SSRS1000', CAST(N'2019-03-07T00:00:00.000' AS DateTime), 6, 1220, N'LEGR-S2S SYRIUS')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1760', 1, N'ABSO.FEUIL', CAST(N'2019-05-25T00:00:00.000' AS DateTime), 4, 194.5, N'GRIS')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1760', 2, N'PEIN.NOIR', CAST(N'2019-02-21T00:00:00.000' AS DateTime), 6, 219, N'AS1045')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1760', 3, N'NETT.SURFACE', CAST(N'2019-03-25T00:00:00.000' AS DateTime), 12, 15.2, N'BACTIPAL PRO-0207170')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1765', 1, N'REPE.TET_SVCT-04-S40102', CAST(N'2019-04-03T00:00:00.000' AS DateTime), 2, 25, N'SVC04S40102')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1765', 2, N'SWIT.TET_SVHK50301800855', CAST(N'2019-04-03T00:00:00.000' AS DateTime), 2, 35, N'SVHK50301800855')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1765', 3, N'PORT', CAST(N'2019-04-03T00:00:00.000' AS DateTime), 1, 20, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1766', 1, N'ETUI_12.5"', CAST(N'2019-04-02T00:00:00.000' AS DateTime), 1, 13.7, N'30007')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1766', 2, N'MARQ.TAB.ASS', CAST(N'2019-04-02T00:00:00.000' AS DateTime), 3, 2.57, N'15004')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1766', 3, N'PEND.NOIR', CAST(N'2019-04-02T00:00:00.000' AS DateTime), 2, 19.12, N'26495')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1766', 4, N'TAPI.SOURIS_XXL', CAST(N'2019-04-02T00:00:00.000' AS DateTime), 3, 14.71, N'30182')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1766', 5, N'SOUR.OPT.VERT.', CAST(N'2019-04-02T00:00:00.000' AS DateTime), 3, 94.2, N'30178')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1766', 6, N'SWIT.TPLSG1008D', CAST(N'2019-04-02T00:00:00.000' AS DateTime), 2, 26.64, N'35177')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1766', 7, N'CAHI.ACTIV', CAST(N'2019-04-13T00:00:00.000' AS DateTime), 5, 6.94, N'51226')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1766', 8, N'CAHI.MEET', CAST(N'2019-04-21T00:00:00.000' AS DateTime), 5, 8.83, N'55716')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1766', 9, N'POCH.POLYA4', CAST(N'2019-04-02T00:00:00.000' AS DateTime), 2, 6.8, N'62886')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1766', 10, N'AIMA.15F', CAST(N'2019-04-02T00:00:00.000' AS DateTime), 5, 6.11, N'24198')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1966', 1, N'KIT_ROU_B43008', CAST(N'2019-04-10T00:00:00.000' AS DateTime), 1, 470, N'385859')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1966', 2, N'FUSE.ROU_B42742', CAST(N'2019-04-10T00:00:00.000' AS DateTime), 2, 390, N'355352')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-1975', 1, N'KIT_ROU_B43008', CAST(N'2019-04-09T00:00:00.000' AS DateTime), 1, 470, N'385859')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2012', 1, N'LAME_PVC', CAST(N'2019-04-10T00:00:00.000' AS DateTime), 15.4, 24.958, N'54203110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2029', 1, N'PC_DEL_G7_17-7790_8GO', CAST(N'2019-04-10T00:00:00.000' AS DateTime), 1, 1709.44, N'BN78603')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2029', 2, N'SAC.PC15/17"', CAST(N'2019-04-10T00:00:00.000' AS DateTime), 1, 61.29, N'PO1720P')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2030', 1, N'MODI.SCHBMXNOE0110*', CAST(N'2019-04-12T00:00:00.000' AS DateTime), 1, 1144.09, N'SCHN-BMXNOE0110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2031', 1, N'JERR.DBLE', CAST(N'2019-02-25T00:00:00.000' AS DateTime), 3, 35.17, N'505698000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2031', 2, N'SCIE_WOLOYM3', CAST(N'2019-02-25T00:00:00.000' AS DateTime), 1, 36.59, N'WOLF OYM3')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2031', 3, N'TRONC.MS201TCM', CAST(N'2019-02-26T00:00:00.000' AS DateTime), 1, 488.86, N'STIHL MS201TC-M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2031', 4, N'GUID.STH30050007409', CAST(N'2019-02-25T00:00:00.000' AS DateTime), 2, 52.42, N'30050007409')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2031', 5, N'CHAI.STH39970030050', CAST(N'2019-04-07T00:00:00.000' AS DateTime), 2, 16.67, N'91VXL050E')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2077', 1, N'CLOU.3.1/100', CAST(N'2019-04-13T00:00:00.000' AS DateTime), 4, 131.3, N'SENCO NN50122')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2077', 2, N'ALIM.PHO2866763', CAST(N'2019-04-13T00:00:00.000' AS DateTime), 3, 375, N'PHO2866763')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2077', 3, N'MODU.SCHBMXDDO3202K', CAST(N'2019-05-14T00:00:00.000' AS DateTime), 1, 436.49, N'BMXDDO3202K')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2077', 4, N'CART.SCHBMXCPS2000', CAST(N'2019-04-13T00:00:00.000' AS DateTime), 1, 247.82, N'BMXCPC2000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2077', 5, N'CORD.RJ45CAT7-10M', CAST(N'2019-04-13T00:00:00.000' AS DateTime), 3, 27.72, N'HORNC850024')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2077', 6, N'CORD.RJ45CAT7-15M', CAST(N'2019-04-13T00:00:00.000' AS DateTime), 3, 35.06, N'HORNC850035')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2077', 7, N'CORD.RJ45CAT7-20M', CAST(N'2019-04-13T00:00:00.000' AS DateTime), 3, 49.66, N'C850036')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2077', 8, N'CORD.RJ45CAT7-3M', CAST(N'2019-04-13T00:00:00.000' AS DateTime), 3, 10.49, N'HORNC850031')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2077', 9, N'CORD.RJ45CAT7-5M', CAST(N'2019-04-13T00:00:00.000' AS DateTime), 3, 15.86, N'HORNC850032')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2077', 10, N'CORD.RJ45CAT7-7M', CAST(N'2019-04-13T00:00:00.000' AS DateTime), 3, 20.96, N'HORNC850033')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2077', 11, N'LICE.WINDOWS10PRO', CAST(N'2019-04-13T00:00:00.000' AS DateTime), 1, 190, N'OGMI-WINDOWS10')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2077', 12, N'PORT', CAST(N'2019-04-12T00:00:00.000' AS DateTime), 1, 46, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2080', 1, N'DESO.COQ.MELON', CAST(N'2019-04-15T00:00:00.000' AS DateTime), 10, 18.53, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2080', 2, N'MANC.SWIFFER', CAST(N'2019-04-15T00:00:00.000' AS DateTime), 2, 10.25, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2080', 4, N'COLL.ETTR', CAST(N'2019-04-15T00:00:00.000' AS DateTime), 12, 22.19, N'AMPLIFIXPRO-0205153')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2080', 5, N'VERR.BC', CAST(N'2019-04-25T00:00:00.000' AS DateTime), 1, 80.84, N'HG10')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2080', 6, N'SAC_POUB6L', CAST(N'2019-04-25T00:00:00.000' AS DateTime), 1, 39, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2080', 7, N'SPRA.DESO', CAST(N'2019-04-15T00:00:00.000' AS DateTime), 18, 10.95, N'AS DESO ORANGE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2080', 8, N'PEIN.SP9016_SOL', CAST(N'2019-04-25T00:00:00.000' AS DateTime), 12, 22.7, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2080', 9, N'SPRA.SOUD', CAST(N'2019-04-15T00:00:00.000' AS DateTime), 3, 14.34, N'0202153')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2080', 11, N'TRAC.BLEU', CAST(N'2019-04-15T00:00:00.000' AS DateTime), 3, 17.3, N'0202120BE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2080', 12, N'TRAC.JAUNE', CAST(N'2019-04-15T00:00:00.000' AS DateTime), 3, 17.3, N'0202120JF')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2080', 13, N'TRAC.VERT', CAST(N'2019-04-15T00:00:00.000' AS DateTime), 3, 17.3, N'0202120VF')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2080', 14, N'DIFF.INTENSITY', CAST(N'2019-04-25T00:00:00.000' AS DateTime), 2, 19.79, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2162', 1, N'GOUL.LEG075601', CAST(N'2019-04-15T00:00:00.000' AS DateTime), 30, 15.36, N'55501058')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2162', 2, N'PRIS.LEG077101', CAST(N'2019-04-15T00:00:00.000' AS DateTime), 20, 10.41, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2162', 3, N'CABL.R2V3G2.5', CAST(N'2019-04-15T00:00:00.000' AS DateTime), 50, 0.6812, N'12113361')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2162', 4, N'DISJ.SCHA9N21366', CAST(N'2019-04-15T00:00:00.000' AS DateTime), 20, 22.73, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2162', 5, N'BORN.WAG221415', CAST(N'2019-04-15T00:00:00.000' AS DateTime), 2, 11.51, N'WAGO 222415')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2162', 6, N'BORN.WAG222413', CAST(N'2019-04-15T00:00:00.000' AS DateTime), 1, 14.21, N'27385404')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2162', 7, N'CORD.RJ45CAT6-5M', CAST(N'2019-04-15T00:00:00.000' AS DateTime), 20, 3.52, N'27408528')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2162', 8, N'CORD.RJ45CAT6-10M', CAST(N'2019-04-15T00:00:00.000' AS DateTime), 20, 6.33, N'27408538')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2162', 9, N'GAIN.63TPC25M', CAST(N'2019-04-15T00:00:00.000' AS DateTime), 25, 0.5285, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2163', 1, N'EAU_0.5', CAST(N'2019-04-12T00:00:00.000' AS DateTime), 50, 3.39, N'CRISTALINE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2163', 2, N'EAU_1.5L', CAST(N'2019-04-12T00:00:00.000' AS DateTime), 30, 3.35, N'CRISTALINE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2163', 3, N'CAFE_DOSE48', CAST(N'2019-04-23T00:00:00.000' AS DateTime), 10, 12.11, N'SENSEO CLASSIQUE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2163', 4, N'SUCR.DOSE', CAST(N'2019-04-23T00:00:00.000' AS DateTime), 3, 26.73, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2228', 1, N'GAZ_BUT.VRAC', CAST(N'2019-04-29T00:00:00.000' AS DateTime), 2, 1682.3, NULL)
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2229', 1, N'MOTE.MERF20MLH', CAST(N'2019-04-18T00:00:00.000' AS DateTime), 1, 2540.83, N'3MOTEU')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2234', 1, N'SP95E5', CAST(N'2019-04-17T00:00:00.000' AS DateTime), 3000, 1.325, N'00016')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2234', 2, N'GAZO.', CAST(N'2019-04-17T00:00:00.000' AS DateTime), 2000, 1.209, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2234', 3, N'GNR_BF', CAST(N'2019-04-17T00:00:00.000' AS DateTime), 1000, 0.82, N'BIOFREE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--22897', 1, N'GAZO.', CAST(N'2019-05-20T00:00:00.000' AS DateTime), 1500, 1.24833, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--22897', 2, N'GNR_BF', CAST(N'2019-05-20T00:00:00.000' AS DateTime), 1500, 0.80833, N'BIOFREE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 1, N'CADE.40', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 6, 10.6, N'0695 011 076')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 2, N'COLL.BDE08-16', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 25, 2.29, N'0538008016')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 3, N'MECH.AC16', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 5, 50.66, N'062160')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 4, N'FREI.FIL.NORM', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 3, 36.39, N'0893200002')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 5, N'SILI.NEUT.GRIS', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 4, 2.84, N'ACETIQUE 08983119')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 6, N'SILI.NEUT.TRANS', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 4, 2.84, N'ACETIQUE08983114')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 7, N'TIGE_FIL12AZ', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 6, 6.72, N'0959912')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 8, N'TIGE_FIL10AZ', CAST(N'2019-04-26T00:00:00.000' AS DateTime), 6, 4.94, N'0959910')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 9, N'TIGE_FIL20AZ', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 20, 16.58, N'0959920')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 10, N'MECH.AC04', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 10, 4.57, N'062040 ULTRA')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 11, N'MECH.AC06.5', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 10, 8.01, N'062065 ULTRA')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 12, N'FORE.SDS+05X160', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 6, 11.13, N'0648250160')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 13, N'MASS.1,5ME', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 1, 35.99, N'0708000021')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 14, N'LAME_CUTPROF.', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 10, 4.3, N'0703600020')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 15, N'CUTT.PROF', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 4, 12.87, N'0703600119')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 16, N'CUTT.DEP', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 5, 5.47, N'0703600009')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 17, N'LAME_CUTPOCHE', CAST(N'2019-04-28T00:00:00.000' AS DateTime), 5, 3.01, N'0710 410 091')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 18, N'CRAY.MAC', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 12, 1.93, N'0695900216')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 19, N'MANC.BC', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 6, 6.98, N'0698800150')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 20, N'COFF.IMPAKTOR', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 3, 163.81, N'0702930030')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 21, N'COFF.EMBTX', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 4, 49.47, N'0702930072')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 22, N'COFF.EMBMIXTMIDI', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 4, 38.48, N'0702930073')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 23, N'ROND.PL.CH06', CAST(N'2019-04-26T00:00:00.000' AS DateTime), 500, 0.0142, N'54076')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 24, N'ROND.PL.CH10', CAST(N'2019-04-26T00:00:00.000' AS DateTime), 500, 0.0226, N'040710')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 25, N'ROND.GR12', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 200, 0.0883, N'044712')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 26, N'ROND.CAR06X17X3', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 200, 0.049, N'04976')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 27, N'ROND.CAR06X22X2', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 100, 0.0577, N'045966')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 28, N'LAME_SAB.ACIER150', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 10, 7.94, N'0605219001')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 29, N'LAME_SAB.BOIS225', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 10, 8.69, N'0605 117 003')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 30, N'LAME_SAB.MU150', CAST(N'2019-04-26T00:00:00.000' AS DateTime), 10, 7.14, N'0605224002')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 31, N'MECH.AC11', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 3, 21.27, N'0620110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 32, N'VIS_THP12X100', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 100, 0.5698, N'0053 12 100')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 33, N'MOUS.PU500ML', CAST(N'2019-04-26T00:00:00.000' AS DateTime), 8, 6.5, N'08982272')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 34, N'JEU_TOURN.SL-PH', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 1, 84.32, N'0701500506')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 35, N'JEU_TOURN.TX', CAST(N'2019-05-04T00:00:00.000' AS DateTime), 1, 51.05, N'0701 500 507')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 36, N'BROS.MET4RG', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 6, 3.52, N'26957105')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 37, N'ROND.PL.CH24', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 25, 0.1858, N'040724')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 38, N'TIGE_FIL08AZ', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 2, 3.92, N'095998')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 39, N'MORT.CH330', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 12, 14.05, N'0912 001 330')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 40, N'BECH.', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 2, 32.08, N'069821012')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2314', 41, N'RUBA.SIGNLARG', CAST(N'2019-04-26T00:00:00.000' AS DateTime), 6, 19.43, N'0985899500')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2315', 1, N'ELIN.EL2T3M', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 2, 7.8, N'TUB02T03M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2315', 2, N'ELIN.EL5T3M', CAST(N'2019-04-26T00:00:00.000' AS DateTime), 1, 18.3, N'TUB05T03M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2315', 3, N'MANI.DRTE2TO', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 1, 6.06, N'MDGS2T000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2315', 4, N'ELIN.EL2T1M', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 1, 3.4, N'TUB02T01M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2315', 5, N'REPA.APPAREIL_LEVAGE', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 1, 96, N'REPARATION')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2315', 6, N'REPA.APPAREIL_LEVAGE', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 1, 142, N'REPARATION')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2315', 7, N'ELIN.EL3T4M', CAST(N'2019-04-26T00:00:00.000' AS DateTime), 1, 14.7, N'TUB03T04M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2315bis', 1, N'MALE.ASTREINTE', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 1, 69, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2315bis', 2, N'CAIS.PALETTE', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 1, 370, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2316', 1, N'CONT.CHA6460', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 1, 682, N'CHAP01126501')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2316', 2, N'DISJ.SCHA9N61526', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 1, 80.73, N'SCHA9N61526')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2316', 3, N'DISJ.SCHA9F75402', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 1, 168.48, N'A9F75402')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2316', 4, N'AMPO.ORB130188', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 6, 29, N'ORBITEC130188')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2316', 5, N'PILE_CR17335SE', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 1, 8.2, N'LABO BR2/3CLG')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2316', 6, N'PORT', CAST(N'2019-04-26T00:00:00.000' AS DateTime), 1, 10, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2316', 7, N'BARR.LG34389', CAST(N'2019-05-11T00:00:00.000' AS DateTime), 1, 12.43, N'LEG034389')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2316', 8, N'PILE_LR14', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 3, 4.59, N'CIPE 095821')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2316', 9, N'COLL.SCHENN47930', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 1, 27.13, N'ENN47930')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2316', 10, N'CABL.R2V5G2.5', CAST(N'2019-05-27T00:00:00.000' AS DateTime), 50, 1.1, N'CDL1 01360822')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2316', 11, N'BOIT.SCHNSYTBS342912', CAST(N'2019-04-27T00:00:00.000' AS DateTime), 2, 55.99, N'NSYTBS349912')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2317', 1, N'ABSO.30L', CAST(N'2019-04-29T00:00:00.000' AS DateTime), 3, 76.2, N'0201101')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2317', 2, N'TRAC.ORANGE', CAST(N'2019-04-29T00:00:00.000' AS DateTime), 24, 17.3, N'AS LINER -0202120OF')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2317', 3, N'MANC.BM.VIS', CAST(N'2019-04-29T00:00:00.000' AS DateTime), 10, 2.6, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2317', 4, N'BALA.CANT.', CAST(N'2019-04-29T00:00:00.000' AS DateTime), 2, 12.22, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2317', 5, N'BALA.COCO38', CAST(N'2019-04-29T00:00:00.000' AS DateTime), 4, 8.74, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2317', 6, N'BALA.FIBRE60', CAST(N'2019-05-09T00:00:00.000' AS DateTime), 4, 13.88, N'50105')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2317', 7, N'EGOU.VAISSELLE', CAST(N'2019-05-10T00:00:00.000' AS DateTime), 1, 39.85, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2317', 8, N'POUB.M50L', CAST(N'2019-04-29T00:00:00.000' AS DateTime), 2, 34.8, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2317', 9, N'LAVE_PONT_NYL', CAST(N'2019-04-29T00:00:00.000' AS DateTime), 4, 15.51, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2317', 10, N'MANC.LPF', CAST(N'2019-04-29T00:00:00.000' AS DateTime), 4, 15.62, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2317', 11, N'SAVO.AT4L', CAST(N'2019-04-29T00:00:00.000' AS DateTime), 4, 32.14, N'ARMA PERLE VERT')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2317', 12, N'CHIF.BLANC', CAST(N'2019-05-30T00:00:00.000' AS DateTime), 4, 36.57, N'0109497')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2317', 13, N'FLUO.15GR', CAST(N'2019-04-29T00:00:00.000' AS DateTime), 3, 95.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2318', 1, N'BALA.WOLUBM25', CAST(N'2019-04-30T00:00:00.000' AS DateTime), 2, 13.17, N'UBM25')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2318', 2, N'RATI.WOLHUM15', CAST(N'2019-04-30T00:00:00.000' AS DateTime), 2, 12.42, N'HUM15')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2318', 3, N'LIME_04MM', CAST(N'2019-04-30T00:00:00.000' AS DateTime), 12, 1.0691, N'70504')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2318', 4, N'HOUE_+M', CAST(N'2019-04-30T00:00:00.000' AS DateTime), 1, 53.63, N'JHHD15EMF')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2318', 5, N'FIL_DEB3X280', CAST(N'2019-04-30T00:00:00.000' AS DateTime), 1, 39.54, N'0000-930-2543')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2318', 6, N'ROUE_JOCKEY', CAST(N'2019-06-10T00:00:00.000' AS DateTime), 1, 26.93, N'680719A')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2319', 1, N'RECE.RHEARE-CHS-AAM', CAST(N'2019-03-20T00:00:00.000' AS DateTime), 3, 403, N'RE-CHS-A1 ANNONCE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2319', 2, N'RECE.RHEARE-CHS-A1AV', CAST(N'2019-03-20T00:00:00.000' AS DateTime), 2, 403, N'RE-CHS-A1 ANNONCE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2319', 3, N'RECE.RHEARE-CHS-A1BA', CAST(N'2019-03-20T00:00:00.000' AS DateTime), 3, 318, N'RE-CHS-A1 BASE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2319', 5, N'RECE.RHEARE-CHS-A1AL', CAST(N'2019-03-20T00:00:00.000' AS DateTime), 2, 426, N'RE-CHS-A1 ALARME')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2319', 1, N'HARN.OR539172', CAST(N'2019-04-30T00:00:00.000' AS DateTime), 2, 41.5833, N'OREGON 539172')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2319bis', 1, N'TELE.RHE_CHS-A1', CAST(N'2019-03-20T00:00:00.000' AS DateTime), 110, 247.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2320', 1, N'LAME_D315X2.5X32_120DTS', CAST(N'2019-05-03T00:00:00.000' AS DateTime), 1, 191, N'TOOL9135')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2320', 2, N'DISQ.BLEU', CAST(N'2019-05-03T00:00:00.000' AS DateTime), 6, 6.24, N'INF593')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2320', 3, N'DECA.2000W', CAST(N'2019-05-03T00:00:00.000' AS DateTime), 1, 77, N'HITARH600TLAZ')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2320', 4, N'RACC.GAZ1/2M', CAST(N'2019-05-14T00:00:00.000' AS DateTime), 2, 2.73, N'PREVIRP066151')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2320', 5, N'PILE_CR17335SE', CAST(N'2019-05-03T00:00:00.000' AS DateTime), 2, 39.32, N'BATCR17335SE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2320', 7, N'BOUG.NGKLFR6A', CAST(N'2019-05-14T00:00:00.000' AS DateTime), 4, 12.42, N'LFR6A')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2320', 8, N'TEST.BAT12V', CAST(N'2019-05-03T00:00:00.000' AS DateTime), 1, 269, N'CLASAC5245')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2320', 9, N'FILT.MANW940/5', CAST(N'2019-05-03T00:00:00.000' AS DateTime), 2, 9.99, N'MANNW940/5')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2320', 10, N'FILT.PREVKTM_SM3', CAST(N'2019-05-14T00:00:00.000' AS DateTime), 1, 85.45, N'PREVKTM SM3')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2320', 11, N'TUYA.AC10X15', CAST(N'2019-05-03T00:00:00.000' AS DateTime), 30, 2.41, N'PREVSURFLEX10C30')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2320', 12, N'COLL.OET13-15', CAST(N'2019-05-14T00:00:00.000' AS DateTime), 1, 0.18, N'PREV1315')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2320', 13, N'COUP.AC_PAS10', CAST(N'2019-05-03T00:00:00.000' AS DateTime), 1, 21.22, N'PREVISI061810')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2467', 1, N'DISP.HYDROCARBURES', CAST(N'2019-05-02T00:00:00.000' AS DateTime), 20, 70.25, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2468', 1, N'SPRA.NETT.ELEC', CAST(N'2019-05-02T00:00:00.000' AS DateTime), 6, 21.95, N'60561')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2468', 2, N'DOSE_NET.SOL', CAST(N'2019-05-02T00:00:00.000' AS DateTime), 50, 0.99, N'12004')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2468', 3, N'RUBA.TOILE', CAST(N'2019-05-02T00:00:00.000' AS DateTime), 10, 7, N'RM309N50')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2468', 4, N'REPU.MART.', CAST(N'2019-05-02T00:00:00.000' AS DateTime), 6, 19.93, N'R2 GEL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2468', 5, N'SPRA.NETT.ELECSR', CAST(N'2019-05-02T00:00:00.000' AS DateTime), 6, 8.12, N'60533')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2482', 1, N'FILT.DESDC2', CAST(N'2019-05-02T00:00:00.000' AS DateTime), 55, 128.75, N'9104371')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2482', 2, N'PORT', CAST(N'2019-05-12T00:00:00.000' AS DateTime), 1, 30, N'PORT ET EMBALLAGE USINE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2483', 2, N'TENT.3X3', CAST(N'2019-01-24T00:00:00.000' AS DateTime), 1, 450, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2483', 3, N'DISQ.150DIAM', CAST(N'2019-02-03T00:00:00.000' AS DateTime), 4, 52.9, N'5400010')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2483', 4, N'DISQ.115TR', CAST(N'2019-01-24T00:00:00.000' AS DateTime), 25, 3.15, N'5040069')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2483', 5, N'DISQ.LAM110X40', CAST(N'2019-02-03T00:00:00.000' AS DateTime), 20, 8.5, N'5040035')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2483', 6, N'DISQ.230TR.EP3', CAST(N'2019-02-03T00:00:00.000' AS DateTime), 25, 8.15, N'5040075')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2483', 7, N'DISQ.230TR.EP2.5', CAST(N'2019-01-24T00:00:00.000' AS DateTime), 25, 8.15, N'5040046')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2483', 8, N'MECH.AC13', CAST(N'2019-01-24T00:00:00.000' AS DateTime), 1, 20, N'5020247')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2483', 9, N'RACC.MODY3/4', CAST(N'2019-02-03T00:00:00.000' AS DateTime), 1, 24.36, N'1980896')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2483', 10, N'COUP.GROM3/4F', CAST(N'2019-02-03T00:00:00.000' AS DateTime), 1, 57.45, N'9102053')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2483', 11, N'FLEX.HP.SM', CAST(N'2019-01-24T00:00:00.000' AS DateTime), 1, 198.46, N'SUPER JET 3/8')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2483', 12, N'GRAI.8X100', CAST(N'2019-02-03T00:00:00.000' AS DateTime), 80, 0.37, N'2370011')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2483', 13, N'GRAI.10X150H1', CAST(N'2019-02-03T00:00:00.000' AS DateTime), 70, 0.431, N'2370014')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2483', 14, N'GRAI.6X100H1', CAST(N'2019-02-03T00:00:00.000' AS DateTime), 80, 0.34, N'2370010')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2483', 15, N'GRAI.8X125H1', CAST(N'2019-02-03T00:00:00.000' AS DateTime), 70, 0.37, N'2370012')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2483', 16, N'DIVE', CAST(N'2019-02-03T00:00:00.000' AS DateTime), 1, 12.33, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2483', 17, N'DIVE', CAST(N'2019-02-03T00:00:00.000' AS DateTime), 4, 0.58, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-2483', 18, N'PORT', CAST(N'2019-02-03T00:00:00.000' AS DateTime), 1, 117.8, N'PORT ET EMBALLAGE USINE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2526', 1, N'CAME.SAMQNV-7080R', CAST(N'2019-05-06T00:00:00.000' AS DateTime), 1, 300, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2526', 2, N'SUPP.SAMSBP-300WM1', CAST(N'2019-05-06T00:00:00.000' AS DateTime), 1, 30, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2528', 1, N'WHIT.SPIRIT5', CAST(N'2019-05-07T00:00:00.000' AS DateTime), 4, 16.24, N'WS5')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2548', 1, N'LICE.CAMERA', CAST(N'2019-05-06T00:00:00.000' AS DateTime), 4, 158, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2568', 1, N'PILE_6V50AHLD', CAST(N'2019-05-07T00:00:00.000' AS DateTime), 4, 60, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2569', 1, N'TUBE_IRL20', CAST(N'2019-05-07T00:00:00.000' AS DateTime), 51, 0.305, N'ENN40620')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2569', 2, N'TUBE_IRL25', CAST(N'2019-05-07T00:00:00.000' AS DateTime), 51, 0.4918, N'69027003')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2602', 1, N'GANT_MTH10', CAST(N'2019-05-11T00:00:00.000' AS DateTime), 50, 2.2, N'2094140')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2602', 2, N'GANT_MT9', CAST(N'2019-07-10T00:00:00.000' AS DateTime), 50, 2.2, N'2094140')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2602', 3, N'BOTT.T44', CAST(N'2019-05-11T00:00:00.000' AS DateTime), 2, 82, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2603', 1, N'CONT.PERENGLEVAGE', CAST(N'2019-05-10T00:00:00.000' AS DateTime), 1, 696, N'ENGINS DE LEVAGE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2603', 2, N'CONT.PERAPPARAU', CAST(N'2019-05-10T00:00:00.000' AS DateTime), 1, 246, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2603', 3, N'CONT.PERENGLEVAGE', CAST(N'2019-05-10T00:00:00.000' AS DateTime), 1, 1600, N'ENGINS DE LEVAGE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2603', 4, N'CONT.PERAPPARAU', CAST(N'2019-05-10T00:00:00.000' AS DateTime), 1, 1380, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2605', 1, N'VISS.BOSGSR18VLI', CAST(N'2019-05-11T00:00:00.000' AS DateTime), 1, 299, N'0615990K3G')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2605', 2, N'WHIT.SPIRIT1', CAST(N'2019-05-11T00:00:00.000' AS DateTime), 4, 15.93, N'WS1')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2605', 3, N'PLAT.BISEAUTE', CAST(N'2019-05-11T00:00:00.000' AS DateTime), 1, 18.39, N'MO234531')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2605', 4, N'COUT.AENDI12', CAST(N'2019-05-11T00:00:00.000' AS DateTime), 1, 4.1, N'MO223320')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2605', 5, N'COUT.PEINT8', CAST(N'2019-05-11T00:00:00.000' AS DateTime), 1, 5.94, N'26028')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2605', 6, N'COUT.PEINTI10', CAST(N'2019-05-11T00:00:00.000' AS DateTime), 1, 7.18, N'260210')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2605', 7, N'MART.PGBH3-28-DFR', CAST(N'2019-05-10T00:00:00.000' AS DateTime), 1, 235.46, N'0611267600')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2605', 8, N'TAXE', CAST(N'2019-03-19T00:00:00.000' AS DateTime), 2, 0.42, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2608', 1, N'CADE/PG', CAST(N'2019-05-14T00:00:00.000' AS DateTime), 5, 65.45, N'PLAN IR 476185 - N1')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2608', 2, N'FRAI_FONCT-FACT', CAST(N'2019-05-14T00:00:00.000' AS DateTime), 1, 4.57, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2608', 3, N'CLE_IR476185PPG', CAST(N'2019-05-14T00:00:00.000' AS DateTime), 5, 11.31, N'IR476185PPG -CLE DE PASSE GENERAL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2608', 4, N'CYLI.30X40/PG', CAST(N'2019-05-14T00:00:00.000' AS DateTime), 3, 50.5, N'PLAN NIR476185 - N1')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2608', 5, N'BLOC_P204/83H88P', CAST(N'2019-05-14T00:00:00.000' AS DateTime), 1, 35.39, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2609', 2, N'EMBO.BORNPZ2', CAST(N'2019-05-15T00:00:00.000' AS DateTime), 5, 1.77, N'AGIR-084295')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2609', 3, N'EMBO.BORNPZ1', CAST(N'2019-05-15T00:00:00.000' AS DateTime), 5, 1.876, N'AGIR-084293')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2609', 4, N'EMBO.BORNPZ3', CAST(N'2019-05-15T00:00:00.000' AS DateTime), 5, 1.77, N'AGIR-084297')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2609', 5, N'CABL.USBC/HDMI', CAST(N'2019-05-15T00:00:00.000' AS DateTime), 2, 52.9, N'HORN-C127568')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2609', 7, N'DISJ.SCHA9N61526', CAST(N'2019-05-15T00:00:00.000' AS DateTime), 3, 80.73, N'SCHA9N61526')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2609', 8, N'DISJ.SCHA9N61528', CAST(N'2019-05-15T00:00:00.000' AS DateTime), 2, 81.05, N'SCHA9N61528')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2609', 9, N'CABL.CAT6', CAST(N'2019-05-14T00:00:00.000' AS DateTime), 200, 0.52, N'CDL1 01248960')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2609', 10, N'EMBA.LEG031950', CAST(N'2019-05-15T00:00:00.000' AS DateTime), 2, 19.38, N'LEGR031950')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2609', 11, N'COLL.SCHENN47942', CAST(N'2019-03-25T00:00:00.000' AS DateTime), 2, 10.18, N'SCHENN47942')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2609', 12, N'PILE_LS26500', CAST(N'2019-05-15T00:00:00.000' AS DateTime), 1, 18.64, N'LS26500 - PCL7411B')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2609', 13, N'FER_AS20-40W', CAST(N'2019-07-07T00:00:00.000' AS DateTime), 2, 33.9, N'ROBUR 381061')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2609', 14, N'PIST.SOUDER75W', CAST(N'2019-07-07T00:00:00.000' AS DateTime), 2, 89.82, N'ROBUR 381105')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2609', 15, N'PORT', CAST(N'2019-05-14T00:00:00.000' AS DateTime), 1, 35, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2610', 1, N'DISQ.300DIAM', CAST(N'2019-05-16T00:00:00.000' AS DateTime), 2, 152.7, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2610', 3, N'DISQ.230DIAM', CAST(N'2019-05-16T00:00:00.000' AS DateTime), 4, 130.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2610', 5, N'FORE.SDSM45X990', CAST(N'2019-05-16T00:00:00.000' AS DateTime), 2, 258.17, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2611', 1, N'PELL+MANCHE', CAST(N'2019-05-05T00:00:00.000' AS DateTime), 1, 19.19, N'130271')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2611', 2, N'PIOC.CANT2.5', CAST(N'2019-05-16T00:00:00.000' AS DateTime), 1, 35.73, N'470121')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2611', 3, N'CADE.50', CAST(N'2019-06-14T00:00:00.000' AS DateTime), 2, 14.54, N'33602')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2611', 4, N'REDU.PVC100/40', CAST(N'2019-06-14T00:00:00.000' AS DateTime), 1, 7.59, N'T4')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2611', 5, N'ROBI.EQR.ROS.1/2', CAST(N'2019-06-22T00:00:00.000' AS DateTime), 1, 11.05, N'04917')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2611', 6, N'COLL.PVC40', CAST(N'2019-06-16T00:00:00.000' AS DateTime), 10, 1.14, N'CM40')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2611', 7, N'PATT.VIS7X60', CAST(N'2019-06-14T00:00:00.000' AS DateTime), 10, 0.08, N'PV6')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2611', 8, N'FIXA.WC', CAST(N'2019-06-14T00:00:00.000' AS DateTime), 1, 4.38, N'A500240')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2611', 9, N'TE_PVC100-87MF', CAST(N'2019-06-14T00:00:00.000' AS DateTime), 1, 8.18, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2611', 10, N'REGA.BET30X30', CAST(N'2019-05-16T00:00:00.000' AS DateTime), 1, 22.46, N'RCF30')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2611', 11, N'COUV.30', CAST(N'2019-06-16T00:00:00.000' AS DateTime), 1, 7.3, N'RCC30')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2611', 12, N'BETO.C25/30', CAST(N'2019-05-16T00:00:00.000' AS DateTime), 0.75, 93.5, N'XF1B/350KG')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2611', 13, N'BA_CP2.5M', CAST(N'2019-06-05T00:00:00.000' AS DateTime), 5, 0.7, N'PACP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2621', 1, N'ROND.PL.CH12', CAST(N'2019-05-07T00:00:00.000' AS DateTime), 200, 0.0444, N'540712')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2621', 2, N'ECRO.H12', CAST(N'2019-05-07T00:00:00.000' AS DateTime), 200, 0.0984, N'5317 12')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2621', 3, N'NIVE.TUB40CMAG.', CAST(N'2019-05-07T00:00:00.000' AS DateTime), 2, 55.33, N'0705408040')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2621', 4, N'NIVE.TUB100CMAG.', CAST(N'2019-05-07T00:00:00.000' AS DateTime), 1, 77.92, N'0705408100')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2621', 7, N'PILE_9V', CAST(N'2019-05-07T00:00:00.000' AS DateTime), 50, 4.72, N'0981100005')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2621', 8, N'POIN.SDSMAX', CAST(N'2019-05-06T00:00:00.000' AS DateTime), 2, 22.32, N'0638 740 0')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2621', 9, N'POIN.MAC300X16', CAST(N'2019-05-07T00:00:00.000' AS DateTime), 2, 13.98, N'0704 509 300')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2621', 10, N'BURI.MAC300X24', CAST(N'2019-05-07T00:00:00.000' AS DateTime), 2, 13.6, N'0704 504 300')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2621', 11, N'BURI.MAC400X28', CAST(N'2019-05-06T00:00:00.000' AS DateTime), 2, 18.03, N'0704505400')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2621', 12, N'MECH.AC14', CAST(N'2019-05-07T00:00:00.000' AS DateTime), 1, 38.1, N'0620140')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2621', 13, N'ECRO.H20', CAST(N'2019-05-07T00:00:00.000' AS DateTime), 25, 0.4678, N'0317 20')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2621', 14, N'TENA.230', CAST(N'2019-05-07T00:00:00.000' AS DateTime), 2, 26.01, N'0703 713 260')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2621', 18, N'FORE.SDSM65X900', CAST(N'2019-05-07T00:00:00.000' AS DateTime), 1, 300.29, N'0649465990')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2621', 19, N'FORE.SDSM65X550', CAST(N'2019-05-07T00:00:00.000' AS DateTime), 1, 270.05, N'0649465550')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2621', 20, N'MESU.5ML', CAST(N'2019-05-07T00:00:00.000' AS DateTime), 3, 25.99, N'070500005')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2621', 21, N'GRAI.CUIVRE100GR', CAST(N'2019-05-07T00:00:00.000' AS DateTime), 1, 9.87, N'089001')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2621', 22, N'SPRA.LISSE_JOINT', CAST(N'2019-05-07T00:00:00.000' AS DateTime), 3, 5.99, N'0894510400')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2621', 23, N'ASSO.SILICONE', CAST(N'2019-05-07T00:00:00.000' AS DateTime), 1, 111.43, N'0956891')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2621', 24, N'EMBO.PHN1L25', CAST(N'2019-05-07T00:00:00.000' AS DateTime), 12, 1.8, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2635', 1, N'ARMO.PROD.DANGEREUX', CAST(N'2019-05-11T00:00:00.000' AS DateTime), 1, 1350, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2679', 1, N'RUBA.3M_SJ3560/25MM', CAST(N'2019-05-14T00:00:00.000' AS DateTime), 3, 356.32, N'837-3189')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2679', 2, N'RUBA.3M_VHB', CAST(N'2019-05-14T00:00:00.000' AS DateTime), 3, 53.86, N'763-8841')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2679', 3, N'RUBA.3M9080HL', CAST(N'2019-05-14T00:00:00.000' AS DateTime), 3, 12.68, N'458-7129')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2815', 1, N'APPA.PHOTO', CAST(N'2019-05-21T00:00:00.000' AS DateTime), 1, 472, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2815', 2, N'TELE.SSFIL', CAST(N'2019-05-21T00:00:00.000' AS DateTime), 3, 30, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2815', 3, N'BATT.AP.PHOTO', CAST(N'2019-05-21T00:00:00.000' AS DateTime), 1, 113, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2815bis', 1, N'BACH.3X4CAMION', CAST(N'2019-05-17T00:00:00.000' AS DateTime), 1, 315.25, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2815bis', 2, N'PALE.PLAST. CL', CAST(N'2019-06-21T00:00:00.000' AS DateTime), 1, 276, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2820', 1, N'TUBE_ETANCHE', CAST(N'2019-05-27T00:00:00.000' AS DateTime), 3, 32.94, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2820', 2, N'INSE.MOUSSE', CAST(N'2019-05-27T00:00:00.000' AS DateTime), 6, 22.69, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2898', 1, N'TREU.HUCSUPERWINCH_TALON18', CAST(N'2019-05-24T00:00:00.000' AS DateTime), 2, 1670, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2898', 2, N'MO_MATERIEL', CAST(N'2019-05-24T00:00:00.000' AS DateTime), 2, 150, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2939', 1, N'LIQU.VAISSEL1L', CAST(N'2019-05-24T00:00:00.000' AS DateTime), 12, 3.58, N'AF00111L')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2939', 2, N'PEIN.SP9016_SOL', CAST(N'2019-06-04T00:00:00.000' AS DateTime), 6, 21.62, N'SP0003')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2939', 3, N'SPRA.SOUF', CAST(N'2019-05-24T00:00:00.000' AS DateTime), 12, 13.72, N'AF0001')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2939', 4, N'DEBO.1L', CAST(N'2019-05-24T00:00:00.000' AS DateTime), 2, 12.95, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2939', 5, N'SAVO.GEL500ML', CAST(N'2019-05-24T00:00:00.000' AS DateTime), 12, 3.61, N'TP0036')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2939', 7, N'GANT_MT9', CAST(N'2019-05-24T00:00:00.000' AS DateTime), 40, 2.7, N' T9')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2939', 8, N'GANT_MT10', CAST(N'2019-05-24T00:00:00.000' AS DateTime), 40, 2.7, N'NYM73LN T10')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2939', 9, N'BALA.MCOURT', CAST(N'2019-06-04T00:00:00.000' AS DateTime), 4, 2.4, N'109521')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2976', 1, N'DECA.2000W', CAST(N'2019-05-22T00:00:00.000' AS DateTime), 1, 82.68, N'BIZ90600')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2976', 3, N'CHEV.PARCR5X37', CAST(N'2019-05-22T00:00:00.000' AS DateTime), 100, 0.3905, N'BIZ720093')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2976', 4, N'CHEV.PARCR6X52', CAST(N'2019-05-22T00:00:00.000' AS DateTime), 100, 0.4488, N'BIZ720096')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2976', 5, N'BORN.WAG2273203', CAST(N'2019-05-22T00:00:00.000' AS DateTime), 3, 13.61, N'WAG273100')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2976', 7, N'GAIN.THERBIZ217004', CAST(N'2019-05-22T00:00:00.000' AS DateTime), 2, 33.416, N'BIZ217004')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2976', 8, N'BORN.WAG221415', CAST(N'2019-05-22T00:00:00.000' AS DateTime), 3, 13.34, N'WAG222415')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--2976', 9, N'TAXE', CAST(N'2019-05-21T00:00:00.000' AS DateTime), 1, 0.42, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3010', 1, N'COMM.HIR_SPIDER5TX', CAST(N'2019-05-29T00:00:00.000' AS DateTime), 2, 152.85, N'SPIDER 5 TX - 826-3246')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3010', 2, N'LOUP.RS162-5345', CAST(N'2019-05-29T00:00:00.000' AS DateTime), 1, 34.19, N'162-5345')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3010', 3, N'SUPP.RS221-7531', CAST(N'2019-05-29T00:00:00.000' AS DateTime), 1, 8.54, N'221-7531')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3029', 1, N'REPU.TIQUE_PEAU', CAST(N'2019-05-29T00:00:00.000' AS DateTime), 12, 12, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3029', 2, N'REPU.TIQUE_VET.', CAST(N'2019-05-29T00:00:00.000' AS DateTime), 12, 13, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3030', 1, N'AB50', CAST(N'2019-06-04T00:00:00.000' AS DateTime), 2, 43.34, N'S07673')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3030', 2, N'AB50', CAST(N'2019-06-04T00:00:00.000' AS DateTime), 1, 19.67, N'S04229')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3031', 1, N'METR.STH00008811200', CAST(N'2019-06-03T00:00:00.000' AS DateTime), 4, 25.17, N'000088111200')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3031', 2, N'ROTO.ECH15680142230', CAST(N'2019-06-03T00:00:00.000' AS DateTime), 1, 141.26, N'15680142230')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3031', 3, N'BATT.Y60N30LAKR', CAST(N'2019-06-03T00:00:00.000' AS DateTime), 1, 99.86, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3051', 1, N'CONT.TACHY', CAST(N'2019-06-03T00:00:00.000' AS DateTime), 1, 139, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3053', 1, N'SANG.AR5M900', CAST(N'2019-04-10T00:00:00.000' AS DateTime), 10, 14.6, N'908/1')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3053', 2, N'BAC_600X400X240A', CAST(N'2019-06-04T00:00:00.000' AS DateTime), 12, 29.6, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3053', 3, N'COUR.DIA_DET9-062', CAST(N'2019-06-04T00:00:00.000' AS DateTime), 1, 178, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3053', 4, N'COUR.DIA_DET9-132', CAST(N'2019-06-04T00:00:00.000' AS DateTime), 1, 274, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3053', 5, N'SANG.AR5M900SF', CAST(N'2019-04-10T00:00:00.000' AS DateTime), 10, 12.4, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3053', 6, N'ELIN.EL2T1M', CAST(N'2019-06-04T00:00:00.000' AS DateTime), 3, 4.2, N'TUB02T01M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3058', 1, N'AXE_D52XL120D', CAST(N'2019-07-05T00:00:00.000' AS DateTime), 8, 80.08, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3058', 2, N'AXE_D52XL120G', CAST(N'2019-07-05T00:00:00.000' AS DateTime), 8, 91.52, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3058', 3, N'MANC.CAR88LG180', CAST(N'2019-07-05T00:00:00.000' AS DateTime), 4, 274.56, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3058', 4, N'ECRO.M52EP26', CAST(N'2019-07-05T00:00:00.000' AS DateTime), 8, 52, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3060', 1, N'PIQU.ACACIA3.5', CAST(N'2019-07-03T00:00:00.000' AS DateTime), 400, 20, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3060', 2, N'PORT', CAST(N'2019-07-03T00:00:00.000' AS DateTime), 1, 200, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3061', 7, N'XENO.TRA252133', CAST(N'2019-06-22T00:00:00.000' AS DateTime), 16, 170, N'252896')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3072', 1, N'SWIT.PHOFLSWITCH23042GC2SFP', CAST(N'2019-06-04T00:00:00.000' AS DateTime), 7, 578.34, N'2702653')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3072', 2, N'MODU.PHO.FLSFPLX', CAST(N'2019-06-04T00:00:00.000' AS DateTime), 14, 149.69, N'2891767')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3072', 3, N'CABL.PHO.FLSM_PATCH1.0LCLC', CAST(N'2019-06-04T00:00:00.000' AS DateTime), 14, 48.9, N'2989187')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3072', 4, N'DIST_PHOPTFIX6/18X2.5-NS35RD', CAST(N'2019-06-04T00:00:00.000' AS DateTime), 24, 5.3619, N'3273114')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3072', 5, N'DIST_PHOPTFIX6/18X2.5-NS35BU', CAST(N'2019-06-04T00:00:00.000' AS DateTime), 24, 5.3619, N'3273112')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3072', 6, N'ALIM.PHO2903147', CAST(N'2019-06-04T00:00:00.000' AS DateTime), 2, 40.06, N'2903147')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3072', 7, N'BORN.PHO.PTCBEI24DC/1-8ANO', CAST(N'2019-06-04T00:00:00.000' AS DateTime), 9, 22.57, N'2908262')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3072', 8, N'RAIL_PHOFLDINRA', CAST(N'2019-06-04T00:00:00.000' AS DateTime), 3, 187.11, N'2891053')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3073', 1, N'FILT.DESDC2', CAST(N'2019-06-22T00:00:00.000' AS DateTime), 55, 128.75, N'9104371')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3073', 2, N'PORT', CAST(N'2019-06-22T00:00:00.000' AS DateTime), 1, 30, N'PORT ET EMBALLAGE USINE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3171', 1, N'CONC.0/31.5', CAST(N'2019-06-05T00:00:00.000' AS DateTime), 30.34, 16.18, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3172', 1, N'GRIL.SERR.4X4X40X40', CAST(N'2019-06-07T00:00:00.000' AS DateTime), 1, 36.99, N'998087')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3172', 2, N'FER_P040X05A2', CAST(N'2019-06-08T00:00:00.000' AS DateTime), 6, 10.748, N'505889')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3172', 3, N'EMBA.', CAST(N'2019-07-04T00:00:00.000' AS DateTime), 1, 9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3172', 4, N'TOLE_LAR5/7_1.25X2.5', CAST(N'2019-06-08T00:00:00.000' AS DateTime), 2, 234.96, N'57134')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3172', 5, N'FER_P040X06', CAST(N'2019-06-08T00:00:00.000' AS DateTime), 12.4, 3.88, N'53880')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3172', 6, N'FER_R12MM*', CAST(N'2019-06-08T00:00:00.000' AS DateTime), 12.4, 1.9, N'54704')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3172', 7, N'FER_R16MM', CAST(N'2019-06-08T00:00:00.000' AS DateTime), 12.4, 3.27, N'54720')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3172', 8, N'FER_P025X04', CAST(N'2019-07-04T00:00:00.000' AS DateTime), 12.4, 2.6, N'53619')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3172b', 1, N'FER_P035X08A2', CAST(N'2019-06-06T00:00:00.000' AS DateTime), 24, 13.125, N'54003')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3172b', 2, N'FER_P050X15', CAST(N'2019-06-06T00:00:00.000' AS DateTime), 6.2, 11.86, N'54372')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3172b', 3, N'FER_P050X30', CAST(N'2019-06-06T00:00:00.000' AS DateTime), 24, 11.5, N'254673')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3172b', 4, N'FER_R06MMINOX', CAST(N'2019-06-06T00:00:00.000' AS DateTime), 6, 1.71, N'105941')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3172b', 5, N'FER_R08MMINOX', CAST(N'2019-06-06T00:00:00.000' AS DateTime), 6, 2.985, N'105952')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3172b', 6, N'FER_R10MMINOX', CAST(N'2019-06-06T00:00:00.000' AS DateTime), 6, 4.635, N'105963')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3172b', 7, N'EMBA.', CAST(N'2019-07-02T00:00:00.000' AS DateTime), 1, 9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3233', 1, N'ONDU.S2SSRS1000', CAST(N'2019-06-05T00:00:00.000' AS DateTime), 6, 1220, N'LEGR-S2S SYRIUS')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3234', 1, N'SERV.AUMSA10.2', CAST(N'2019-06-13T00:00:00.000' AS DateTime), 4, 1862, N'SA10.2')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3235', 1, N'FIL_TENDPV2.4', CAST(N'2019-06-13T00:00:00.000' AS DateTime), 1, 9.45, N'FTPV24')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3235', 2, N'MASS.4KGME', CAST(N'2019-07-13T00:00:00.000' AS DateTime), 1, 40.48, N'125464')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3235', 5, N'FER_TOR10', CAST(N'2019-06-13T00:00:00.000' AS DateTime), 2, 6.785, N'FT10')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3235', 6, N'FER_TOR12', CAST(N'2019-06-13T00:00:00.000' AS DateTime), 2, 9.44, N'FT12')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3235', 7, N'FER_TOR14', CAST(N'2019-06-13T00:00:00.000' AS DateTime), 2, 12.7, N'FT14')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3235', 8, N'PILE_LR6_32PCES', CAST(N'2019-07-13T00:00:00.000' AS DateTime), 1, 10.84, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3235', 9, N'GOUT.PVC60', CAST(N'2019-07-13T00:00:00.000' AS DateTime), 4, 7.27, N'LG16')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3235', 10, N'TALO.GOUT60PVC', CAST(N'2019-07-13T00:00:00.000' AS DateTime), 2, 2.46, N'FCN16')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3235', 11, N'COLL.PVC250', CAST(N'2019-07-14T00:00:00.000' AS DateTime), 1, 6.51, N'504711')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3235', 12, N'MANC.PIO60/40FIB', CAST(N'2019-07-14T00:00:00.000' AS DateTime), 1, 24.24, N'79603663')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3235', 13, N'HOUE_+M', CAST(N'2019-06-13T00:00:00.000' AS DateTime), 2, 23.46, N'540141')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3235', 14, N'COFF.BOS2608664624', CAST(N'2019-07-14T00:00:00.000' AS DateTime), 2, 60.09, N'2608664624')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3235', 15, N'CADE.COMB50', CAST(N'2019-07-13T00:00:00.000' AS DateTime), 2, 27.6, N'33301')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3235', 16, N'ACCU_12V-2AH', CAST(N'2019-07-14T00:00:00.000' AS DateTime), 2, 63, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3240', 1, N'POMP.GRAISSE_ACCU', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 1, 329.5, N'2370146-2')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3240', 2, N'DISQ.LAM110X40', CAST(N'2019-06-28T00:00:00.000' AS DateTime), 30, 8.5, N'5040035 - WENDT')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3240', 3, N'SAC_DIM/ASAC21L', CAST(N'2019-07-19T00:00:00.000' AS DateTime), 20, 7.92, N'9200038')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3240', 4, N'LAMP.LEDSTYLO', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 2, 95, N'7887')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3240', 5, N'PORT', CAST(N'2019-06-28T00:00:00.000' AS DateTime), 1, 20, N'PORT ET EMBALLAGE USINE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3240', 6, N'ADAP.MBSPCT1/2', CAST(N'2019-07-19T00:00:00.000' AS DateTime), 1, 2.14, N'4100019')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3240', 7, N'UNIO.M_GE15L1/2ED', CAST(N'2019-07-19T00:00:00.000' AS DateTime), 2, 3.63, N'5140055')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3240', 8, N'UNIO.M_EGE15LR_ED', CAST(N'2019-07-19T00:00:00.000' AS DateTime), 2, 8.99, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3240', 9, N'CLAP.AR_F1/2HP', CAST(N'2019-07-19T00:00:00.000' AS DateTime), 1, 23.4, N'9104134')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3240', 10, N'BAGU.BSA-BSP1/2', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 1, 0.52, N'2340053')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3240', 11, N'UNIO.M_GE16S1/2ED', CAST(N'2019-07-19T00:00:00.000' AS DateTime), 2, 4.62, N'5140107')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3240', 12, N'BAGU.ES2-16S', CAST(N'2019-07-19T00:00:00.000' AS DateTime), 2, 1.067, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3240', 13, N'ECRO.M16S', CAST(N'2019-07-19T00:00:00.000' AS DateTime), 4, 2.021, N'5810030')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3240', 14, N'COUD.EW16S', CAST(N'2019-07-19T00:00:00.000' AS DateTime), 2, 16.86, N'5280040')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3240', 15, N'BAGU.ES2-16S', CAST(N'2019-07-19T00:00:00.000' AS DateTime), 2, 1.067, N'5800021')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3240', 16, N'COUD.EW15L_NU', CAST(N'2019-07-19T00:00:00.000' AS DateTime), 2, 10.46, N'5280018')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--33269', 1, N'LICE.SCHFSACSAUCDGUTYS', CAST(N'2019-06-05T00:00:00.000' AS DateTime), 1, 707.26, N'FSACSAUCDGUTYS')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--33269', 2, N'MAJO.SCHFSACSARCDVJD', CAST(N'2019-06-05T00:00:00.000' AS DateTime), 1, 152.1, N'FSACSARCDVJD')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3330', 1, N'SOUR.OPT.VERT.SF', CAST(N'2019-06-12T00:00:00.000' AS DateTime), 1, 30.81, N'25863 OU 35659')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3330', 2, N'COLL.DBSTICK8.2', CAST(N'2019-06-12T00:00:00.000' AS DateTime), 10, 0.52, N'11462')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3330', 3, N'SURL.JNE', CAST(N'2019-06-12T00:00:00.000' AS DateTime), 10, 0.57, N'01423')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3330', 4, N'CART.EPST1306', CAST(N'2019-06-12T00:00:00.000' AS DateTime), 8, 41.23, N'80871')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3330', 5, N'HUB_USB3.0', CAST(N'2019-07-02T00:00:00.000' AS DateTime), 1, 18.86, N'16363')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3330', 6, N'ARMO.H198X120SD', CAST(N'2019-07-02T00:00:00.000' AS DateTime), 1, 331, N'4425002SDSD')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3331', 1, N'COFF.DIADRILL6-68MM', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 1, 383.7, N'06637007')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3331', 2, N'CORD.MAC1.5', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 6, 3.8, N'069872050')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3331', 3, N'CORD.MAC1.5 PINCK', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 6, 6.69, N'0698752100')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3331', 4, N'GANT_NITRIL10', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 3, 13.13, N'06877732010')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3331', 7, N'FORE.SDS+16X450', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 2, 63.54, N'0648116450')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3331', 8, N'CHEV.12X60', CAST(N'2019-06-17T00:00:00.000' AS DateTime), 4, 4.73, N'090301260')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3331', 9, N'CHEV.6X30', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 4, 10.16, N'09068636')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3331', 10, N'FORE.SDS+06X160', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 6, 9.15, N'0648260160')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3331', 11, N'LAME_SAB.PROG300', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 3, 38.46, N'065510003')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3331', 12, N'VBA_TCF4.5X40', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 1, 12.35, N'015545 40')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3331', 13, N'LAME_SAB.PROG150', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 23.18, 23.18, N'0605510001')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3331', 14, N'LAME_SAB.PROG225', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 3, 30.83, N'0605510002')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3332', 1, N'MANC.TRON.', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 30, 35.8, N'4635')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3332', 2, N'FOUR_MINI', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 1, 120, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3402', 1, N'CART.SAM_MLTD203LEL', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 1, 101.25, N'23206')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3402', 2, N'CART.EPST1301', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 6, 21.31, N'80867')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3402', 3, N'CART.EPST1306', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 4, 41.23, N'80871')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3402', 6, N'CART.HP3HZ52AE', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 4, 92.09, N'07624')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3402', 7, N'POCH.PERF.TR', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 4, 6.66, N'62883')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3402', 8, N'CLE_USB08G', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 6, 5.52, N'72822')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3402', 9, N'POST_IT76X127FLUO', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 40, 1.15, N'10311')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3402', 10, N'STYL.G-2BL', CAST(N'2019-06-25T00:00:00.000' AS DateTime), 24, 1.09, N'40450')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3402', 11, N'STYL.G-2N', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 12, 1.09, N'40454')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3402', 12, N'STYL.G-2R', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 24, 1.09, N'40455')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3402', 13, N'TROM.25', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 6, 1.99, N'51946')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3402', 14, N'MARQ.NOIR_PER.2.5', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 10, 0.49, N'41948')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3402', 15, N'RUBA.AB19X66', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 4, 0.44, N'18274')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3402', 16, N'MARQ.MULTI_SURF.', CAST(N'2019-06-18T00:00:00.000' AS DateTime), 20, 0.91, N'24109')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3402', 17, N'SOUR.OPT.', CAST(N'2019-07-02T00:00:00.000' AS DateTime), 1, 22.6, N'24515')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3404', 3, N'GANT_HYFLEX10', CAST(N'2019-06-21T00:00:00.000' AS DateTime), 96, 2.08, N'MF200T10')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3404', 4, N'GANT_HYFLEX9', CAST(N'2019-06-21T00:00:00.000' AS DateTime), 96, 2.06, N'MFT200T9')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3483', 1, N'PEIN.NOIR', CAST(N'2019-05-20T00:00:00.000' AS DateTime), 10, 219, N'AS1045')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3484', 1, N'EAU_0.5', CAST(N'2019-07-04T00:00:00.000' AS DateTime), 80, 3.39, N'CRISTALINE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3484', 2, N'EAU_1.5L', CAST(N'2019-07-04T00:00:00.000' AS DateTime), 50, 3.35, N'CRISTALINE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3484', 3, N'CAFE_MOULU', CAST(N'2019-07-06T00:00:00.000' AS DateTime), 8, 6.72, N'CARTE NOIR')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3485', 1, N'POUL.STH11231950400', CAST(N'2019-08-11T00:00:00.000' AS DateTime), 1, 17.64, N'11231950400')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3485', 2, N'AIGU.STH11181953500', CAST(N'2019-07-01T00:00:00.000' AS DateTime), 1, 0.62, N'11181953500')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3485', 3, N'CLIQ.STH11251957200', CAST(N'2019-08-11T00:00:00.000' AS DateTime), 1, 2.96, N'11251957200')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3485', 4, N'TETE_ECHX047000330', CAST(N'2019-07-01T00:00:00.000' AS DateTime), 4, 31.67, N'X047000331')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3485', 5, N'RESS.STH11291900601', CAST(N'2019-07-01T00:00:00.000' AS DateTime), 1, 13.48, N'11291900601')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3485', 6, N'DOUI.STH11297925500', CAST(N'2019-07-01T00:00:00.000' AS DateTime), 1, 0.94, N'11297925500')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3485', 7, N'GARN.STH11281220100', CAST(N'2019-07-01T00:00:00.000' AS DateTime), 10, 0.49, N'1128220100')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3485', 8, N'BROS.B2025', CAST(N'2019-07-01T00:00:00.000' AS DateTime), 1, 44.93, N'B2025')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3614', 1, N'PULV.1.5L', CAST(N'2019-07-02T00:00:00.000' AS DateTime), 5, 27.5, N'OC1501')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3614', 2, N'PULV.5L', CAST(N'2019-07-02T00:00:00.000' AS DateTime), 2, 64, N'2712')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3614', 3, N'ELAG.WOLOS83', CAST(N'2019-07-02T00:00:00.000' AS DateTime), 1, 108, N'4817')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3615', 1, N'HAUT_COMC-AFLS10HHG', CAST(N'2019-07-01T00:00:00.000' AS DateTime), 2, 597, N'C-AFLS10HHG')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3615', 2, N'INJE.COMC-PA15WPOE', CAST(N'2019-07-01T00:00:00.000' AS DateTime), 1, 53, N'C-PA15WPOE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3615', 3, N'PORT', CAST(N'2019-07-01T00:00:00.000' AS DateTime), 1, 50, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3616', 1, N'ELAG.WOLOS900T', CAST(N'2019-07-01T00:00:00.000' AS DateTime), 1, 54.19, N'OS900T')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3616', 2, N'SCIE_WOLOYM3', CAST(N'2019-07-01T00:00:00.000' AS DateTime), 1, 24.57, N'WOLF OYM3')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3616', 3, N'MANC.WOLZMT2', CAST(N'2019-07-01T00:00:00.000' AS DateTime), 1, 40.26, N'ZMT2')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3616', 4, N'FLEX.STH41287103000', CAST(N'2019-07-01T00:00:00.000' AS DateTime), 1, 186.22, N'4128 710 3000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3616', 5, N'ARBR.STH41287113300', CAST(N'2019-07-01T00:00:00.000' AS DateTime), 1, 21.46, N'41287113300')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3616', 6, N'JOIN.STH96459457570', CAST(N'2019-07-01T00:00:00.000' AS DateTime), 1, 2.14, N'96459457570')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3616', 7, N'MEUL.STH52037507013', CAST(N'2019-07-01T00:00:00.000' AS DateTime), 6, 5.86, N'5203 750 7013')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3616', 8, N'ELAG.WOLOS84V', CAST(N'2019-07-01T00:00:00.000' AS DateTime), 1, 65.48, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3616', 9, N'TETE_STH40027102170', CAST(N'2019-07-01T00:00:00.000' AS DateTime), 4, 30, N'40027102170')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3620', 1, N'ONDU.S2SMSRT3000', CAST(N'2019-07-02T00:00:00.000' AS DateTime), 1, 1180, N'MSRT 3000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3621', 1, N'REDU.PREVA4_1238', CAST(N'2019-07-04T00:00:00.000' AS DateTime), 2, 1.8, N'PREVA4-1238')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3621', 2, N'BOUG.NGKBPR5ES', CAST(N'2019-07-04T00:00:00.000' AS DateTime), 8, 2.71, N'NGK BPR5ES')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3621', 3, N'CLE_MIXFAC40.13', CAST(N'2019-07-04T00:00:00.000' AS DateTime), 1, 4.24, N'FAC440-13')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3621', 4, N'BOIT.OUT4PL', CAST(N'2019-07-04T00:00:00.000' AS DateTime), 1, 36.24, N'KRA3950')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3621', 5, N'SAC_FACBS.R20', CAST(N'2019-07-04T00:00:00.000' AS DateTime), 1, 80.65, N'FACBS.R20')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3621', 6, N'BOIT.OUTFACBS.T20', CAST(N'2019-07-04T00:00:00.000' AS DateTime), 1, 50.65, N'FACBS.T20')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3621', 7, N'FILT.HIFSO8013', CAST(N'2019-07-04T00:00:00.000' AS DateTime), 3, 24.18, N'HIFI SO8013')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3621', 9, N'FILT.HIFSA16302', CAST(N'2019-07-04T00:00:00.000' AS DateTime), 2, 37.54, N'HIFI SA16302')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3621', 10, N'FILT.HIFSN327', CAST(N'2019-07-04T00:00:00.000' AS DateTime), 3, 16.3, N'HIFI SN327')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3621', 11, N'FILT.HIFSH56411', CAST(N'2019-07-04T00:00:00.000' AS DateTime), 6, 29.76, N'HIFI SH56411')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3621', 12, N'FILT.HIFSH66124', CAST(N'2019-07-04T00:00:00.000' AS DateTime), 2, 54.38, N'HIFI SH66124')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3621', 13, N'DISQ.TACHY140', CAST(N'2019-07-15T00:00:00.000' AS DateTime), 2, 17.76, N'5001831497')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3683', 1, N'PROF.ROU4700353', CAST(N'2019-07-03T00:00:00.000' AS DateTime), 1, 15, N'ROUSSEAU 4700353')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3683', 2, N'AXE_ROU3858145', CAST(N'2019-07-03T00:00:00.000' AS DateTime), 1, 130, N'3858145')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3685', 1, N'COUP.CIR_RVI26524137', CAST(N'2019-07-06T00:00:00.000' AS DateTime), 1, 119.97, N'26524137')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3820', 1, N'LECT.DVD', CAST(N'2019-07-09T00:00:00.000' AS DateTime), 1, 57.44, N'786-9235')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3829', 1, N'JEU_CLE_ML', CAST(N'2019-07-06T00:00:00.000' AS DateTime), 2, 16.83, N'FAC83SH.JP9APB')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3829', 2, N'JEU_FAC89SR.J7PB', CAST(N'2019-07-06T00:00:00.000' AS DateTime), 1, 41.94, N'FAC89SR.J7PB')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3829', 3, N'JEU_FAC467B.JP12PB', CAST(N'2019-07-06T00:00:00.000' AS DateTime), 1, 186.3, N'FAC467B.JP12PB')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3829', 4, N'JEU_FAC75.J12PB', CAST(N'2019-07-06T00:00:00.000' AS DateTime), 1, 93.33, N'FAC75.J12PB')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3829', 5, N'CLE_MOL.FAC101.8GPB', CAST(N'2019-07-06T00:00:00.000' AS DateTime), 1, 16.2, N'FAC101.8GPB')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3829', 6, N'JEU_FACGJP.A4PB', CAST(N'2019-07-06T00:00:00.000' AS DateTime), 1, 59.67, N'FACGJP.A4PB')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3829', 7, N'MONT.SCIE_MET.', CAST(N'2019-07-06T00:00:00.000' AS DateTime), 2, 18.82, N'FAC601')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3829', 8, N'MART.FAC200H.32PB', CAST(N'2019-07-06T00:00:00.000' AS DateTime), 1, 9.54, N'FAC200H.32PB')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3829', 9, N'MART.FAC200H.36PB', CAST(N'2019-07-06T00:00:00.000' AS DateTime), 1, 11.79, N'FAC200H.36PB')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3829', 10, N'BOIT.OUTFACCBT.11GPB', CAST(N'2019-07-17T00:00:00.000' AS DateTime), 1, 39.06, N'FABT11GPB')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3829', 11, N'COFF.CLIMULTI1/2', CAST(N'2019-07-06T00:00:00.000' AS DateTime), 1, 129.33, N'FACS.161-2P6PB')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3829', 12, N'JEU_CLE_MIXTE6-19', CAST(N'2019-07-06T00:00:00.000' AS DateTime), 1, 60.58, N'FAC440.JP12A')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3829', 13, N'DOUI.FACS21', CAST(N'2019-07-06T00:00:00.000' AS DateTime), 1, 3.23, N'FACS.21')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3829', 14, N'DOUI.FACNS29LA', CAST(N'2019-07-06T00:00:00.000' AS DateTime), 1, 19.51, N'FACNS.29LA')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3829', 15, N'BOIT.OUTFACBP.C19N', CAST(N'2019-07-06T00:00:00.000' AS DateTime), 1, 16.19, N'BP.C19N')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3829', 16, N'JEU_FAC467F.JP10', CAST(N'2019-08-01T00:00:00.000' AS DateTime), 1, 154.22, N'FAC467F.JP10PB')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3829', 17, N'CLE_MOL.FAC101.10G', CAST(N'2019-07-06T00:00:00.000' AS DateTime), 1, 20.15, N'FAC101.10G')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3829', 18, N'COFF.FACR2NANO', CAST(N'2019-07-06T00:00:00.000' AS DateTime), 1, 142.98, N'FACR2NANO')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3829', 19, N'JEU_FACATP..J6PB', CAST(N'2019-07-06T00:00:00.000' AS DateTime), 1, 28.3, N'FACATP.J6PB')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3829', 20, N'JEU_FACCPE.A4', CAST(N'2019-07-06T00:00:00.000' AS DateTime), 1, 55.82, N'FACCPE.A4')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3829', 21, N'MESU.8ML', CAST(N'2019-07-06T00:00:00.000' AS DateTime), 1, 13.52, N'FAC897A.828')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3829', 22, N'MART.FAC200H.28', CAST(N'2019-07-06T00:00:00.000' AS DateTime), 1, 7.43, N'FAC200H.28')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3829', 23, N'CHAS.FAC249.GJ5', CAST(N'2019-07-06T00:00:00.000' AS DateTime), 1, 34.83, N'FAC249.GJ5')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3835', 1, N'MODU.SCHBMXP342000', CAST(N'2019-08-28T00:00:00.000' AS DateTime), 2, 678.5, N'SCHBMXP342000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3835', 2, N'MODI.SCHBMXNOE0110', CAST(N'2020-07-05T00:00:00.000' AS DateTime), 2, 889.85, N'SCHBMXNOE0110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3835', 3, N'PORT', CAST(N'2019-07-08T00:00:00.000' AS DateTime), 1, 47.6, N'EXPRESS')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3836', 1, N'BOUL.TAR81/82', CAST(N'2019-07-09T00:00:00.000' AS DateTime), 1, 30.46, N'TARA81/82')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3836', 2, N'ELEM.TAR83', CAST(N'2019-07-09T00:00:00.000' AS DateTime), 1, 36.54, N'TARA83')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3836', 3, N'PORT', CAST(N'2019-07-08T00:00:00.000' AS DateTime), 1, 25, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3836', 4, N'BOIT.SCHENN05005', CAST(N'2019-07-08T00:00:00.000' AS DateTime), 5, 4.05, N'SCHENN05005')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3836', 5, N'BOIT.SCHENN05004', CAST(N'2019-07-09T00:00:00.000' AS DateTime), 5, 2.19, N'SCHENN05004')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3836', 6, N'FICH.CM10/16AALL', CAST(N'2019-04-01T00:00:00.000' AS DateTime), 5, 3.15, N'BRNN1375641')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3836', 7, N'TELE.FAACXT4_868SLH', CAST(N'2019-08-31T00:00:00.000' AS DateTime), 8, 42, N'FAAC XT4 868 SLH BLACK')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3836', 8, N'PORT', CAST(N'2019-07-08T00:00:00.000' AS DateTime), 1, 20, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3836', 9, N'FUSI.LEG013320', CAST(N'2019-07-09T00:00:00.000' AS DateTime), 6, 0.94, N'LEG013320')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3836', 10, N'PRIS.HAGSNS216', CAST(N'2019-07-09T00:00:00.000' AS DateTime), 2, 11.55, N'HAGER SNS216')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3860', 1, N'CART.SCHBMXAMI0410', CAST(N'2019-07-09T00:00:00.000' AS DateTime), 1, 377.93, N'BMXAMI0410')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3860', 2, N'CORD.RJ45CAT6-3MGR', CAST(N'2019-07-09T00:00:00.000' AS DateTime), 6, 8, N'HORN-C852515')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3860', 3, N'CORD.RJ45CAT6-3MBL', CAST(N'2019-07-09T00:00:00.000' AS DateTime), 6, 8, N'HORN-C852575')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3860', 4, N'CORD.RJ45CAT6-3MJAU', CAST(N'2019-07-09T00:00:00.000' AS DateTime), 6, 8, N'HORN-C852525')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3860', 5, N'CORD.RJ45CAT6-3MVERT', CAST(N'2019-07-09T00:00:00.000' AS DateTime), 6, 8, N'HORN-C852535')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3860', 6, N'CORD.RJ45CAT6-3MBLEU', CAST(N'2019-07-09T00:00:00.000' AS DateTime), 6, 8, N'HORN-C852545')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3860', 7, N'CORD.RJ45CAT6-3MROUG', CAST(N'2019-07-09T00:00:00.000' AS DateTime), 6, 8, N'HORN.C852555')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3860', 8, N'DOCK.HORC738144', CAST(N'2019-07-09T00:00:00.000' AS DateTime), 1, 69, N'HORN-C738144')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3860', 9, N'TAXE', CAST(N'2019-04-23T00:00:00.000' AS DateTime), 1, 0.09, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3860', 10, N'DOCK.HORC738148', CAST(N'2019-07-09T00:00:00.000' AS DateTime), 1, 61, N'HORN-C738148')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3860', 11, N'TAXE', CAST(N'2019-04-23T00:00:00.000' AS DateTime), 1, 0.09, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3958', 1, N'POMP.8+8CM3', CAST(N'2019-07-10T00:00:00.000' AS DateTime), 2, 420, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3958', 2, N'PORT', CAST(N'2019-07-10T00:00:00.000' AS DateTime), 1, 20, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3967', 1, N'JOIN.', CAST(N'2019-07-10T00:00:00.000' AS DateTime), 1, 2.48, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3967', 2, N'BRID.', CAST(N'2019-07-10T00:00:00.000' AS DateTime), 1, 14.42, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3967', 3, N'RACC.', CAST(N'2019-07-10T00:00:00.000' AS DateTime), 1, 8.12, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3968', 1, N'CLAP.AR_F1/2HP', CAST(N'2019-07-10T00:00:00.000' AS DateTime), 1, 26.63, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3968', 2, N'BAGU.DPR12-L/S', CAST(N'2019-07-10T00:00:00.000' AS DateTime), 4, 0.27, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3968', 3, N'COUD.1/2MF', CAST(N'2019-07-10T00:00:00.000' AS DateTime), 2, 10.26, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--3968', 4, N'RACC.GAZ1/2M', CAST(N'2019-07-10T00:00:00.000' AS DateTime), 2, 2.07, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4005', 1, N'BATT.AMP9068', CAST(N'2019-07-11T00:00:00.000' AS DateTime), 8, 386, N'ENIX9068')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4005', 2, N'PORT', CAST(N'2019-07-10T00:00:00.000' AS DateTime), 1, 160, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4005', 3, N'TAXE', CAST(N'2019-04-25T00:00:00.000' AS DateTime), 1, 68.4, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4006', 1, N'ROLL.CORRECT2', CAST(N'2019-07-15T00:00:00.000' AS DateTime), 12, 1.95, N'42577')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4006', 2, N'SAC.PC15/17"', CAST(N'2019-07-15T00:00:00.000' AS DateTime), 1, 43.9, N'15223')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4006', 3, N'RUBA.DYMS0720530S', CAST(N'2019-07-15T00:00:00.000' AS DateTime), 5, 12.3, N'16992')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4006', 4, N'CART.EPST1306', CAST(N'2019-07-15T00:00:00.000' AS DateTime), 5, 40.83, N'80871')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4006', 5, N'CART.EPST1301', CAST(N'2019-07-15T00:00:00.000' AS DateTime), 5, 21.3, N'80867')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4006', 6, N'CISE.BUREAU', CAST(N'2019-07-15T00:00:00.000' AS DateTime), 3, 2.51, N'64190')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4008', 1, N'COUV.STH11296401702', CAST(N'2019-07-16T00:00:00.000' AS DateTime), 1, 53.56, N'11296401702')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4009', 1, N'HARN.STH00007109001', CAST(N'2019-07-19T00:00:00.000' AS DateTime), 1, 156.29, N'00007109001')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4010', 1, N'ELEC.DS800_2,5', CAST(N'2019-07-19T00:00:00.000' AS DateTime), 1, 210.5, N'OS200.25')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4010', 2, N'ETAI.ARGENT', CAST(N'2019-07-19T00:00:00.000' AS DateTime), 1, 95.35, N'B1031.15')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4011', 1, N'FERM.6.5X6.5X0.07_25ML', CAST(N'2019-07-23T00:00:00.000' AS DateTime), 1, 85.96, N'TSLG650710025')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4012', 1, N'REPE.LEG038442', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 6, 3.98, N'LEG038442')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4012', 2, N'REPE.LEG038443', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 6, 3.98, N'LEG038442')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4013', 1, N'LED_MUR3124049', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 30, 11.8, N'MUR3124049')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4013', 2, N'MODU.SCHABL8PRP24100', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 3, 104.495, N'SCHABL8PRP24100')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4013', 3, N'BLOC_SCHZBVBG1', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 15, 9.71, N'SCHZBVBG1')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4014', 1, N'PROJ.GEN0232269', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 3, 43.27, N'GRX0232269')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4015', 1, N'CADE.38ZENITH', CAST(N'2019-07-23T00:00:00.000' AS DateTime), 10, 24.96, N'11558615')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4016', 1, N'CABL.RNF3G2.5', CAST(N'2019-07-23T00:00:00.000' AS DateTime), 300, 0.64, N'H07RNF3G2.5')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4017', 1, N'ROUL.SCHGE30-FO-2RS', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 20, 22.81, N'GE30-FO-2RS')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4017', 2, N'ROUL.SCHGE40-DO-2RS', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 60, 21.9, N'GE-40-DO-2RS')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4017', 3, N'ROUL.SCHGE40-FO-2RS', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 30, 33.68, N'GE-40-FO-2RS')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4018', 1, N'REPA.MATERIEL', CAST(N'2019-07-23T00:00:00.000' AS DateTime), 1, 604, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4019', 1, N'LING.90', CAST(N'2019-07-23T00:00:00.000' AS DateTime), 12, 29.17, N'MANOCLIS-0211115')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4021', 1, N'AZOT.M20', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 1, 81.39, N'I4001M20R2A001')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4022', 1, N'REGU.RS8064116', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 50, 0.138, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4024', 1, N'ARMO.BOTT', CAST(N'2019-07-23T00:00:00.000' AS DateTime), 1, 539.08, N'GISS829112')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4024', 2, N'CHAR.TRO870-C', CAST(N'2019-07-23T00:00:00.000' AS DateTime), 1, 641.6, N'TROLLEY 870-C')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4025', 1, N'ARMO.BOTT', CAST(N'2019-07-23T00:00:00.000' AS DateTime), 1, 539.08, N'GISS829112')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4268', 1, N'CABL.RNF2G1.5', CAST(N'2019-07-17T00:00:00.000' AS DateTime), 85, 0.653, N'CDL1 01360411')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4268', 2, N'RUBA.IBLC15', CAST(N'2019-07-17T00:00:00.000' AS DateTime), 10, 0.864, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4268', 3, N'RUBA.IBLEU15', CAST(N'2019-07-17T00:00:00.000' AS DateTime), 10, 0.864, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4268', 4, N'RUBA.IBRUN15', CAST(N'2019-07-17T00:00:00.000' AS DateTime), 10, 0.864, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4268', 5, N'RUBA.IGRIS15', CAST(N'2019-07-17T00:00:00.000' AS DateTime), 10, 0.864, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4268', 7, N'RUBA.IROUG15', CAST(N'2019-07-17T00:00:00.000' AS DateTime), 10, 0.864, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4268', 8, N'RUBA.IVERT15', CAST(N'2019-07-17T00:00:00.000' AS DateTime), 10, 0.864, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4268', 9, N'RUBA.IVIOL15', CAST(N'2019-07-17T00:00:00.000' AS DateTime), 10, 0.864, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4268', 10, N'RUBA.IV-J15', CAST(N'2019-07-17T00:00:00.000' AS DateTime), 10, 0.864, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4268', 11, N'RUBA.IBLC50', CAST(N'2019-08-16T00:00:00.000' AS DateTime), 6, 8.9, N'0-031612')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4268', 12, N'RUBA.IBLEU50', CAST(N'2019-07-17T00:00:00.000' AS DateTime), 6, 8.9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4268', 13, N'RUBA.INOIR50', CAST(N'2019-07-17T00:00:00.000' AS DateTime), 6, 8.9, N'0-031609')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4268', 14, N'RUBA.IROUG50', CAST(N'2019-08-16T00:00:00.000' AS DateTime), 6, 8.9, N'0-031610')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4268', 15, N'RUBA.IVERT50', CAST(N'2019-08-16T00:00:00.000' AS DateTime), 6, 8.9, N'0-031614')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4268', 16, N'INTE.SCHBN310RZ-5', CAST(N'2019-07-17T00:00:00.000' AS DateTime), 15, 37.73, N'SCHMERSAL BN310RZ5METRES')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4268', 18, N'PILE_LR6', CAST(N'2019-07-17T00:00:00.000' AS DateTime), 20, 2.73, N'8280 40066211354')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4268', 19, N'GAIN.THER3M85833', CAST(N'2019-07-16T00:00:00.000' AS DateTime), 6, 32.7, N'85833')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4268', 20, N'RUBA.IORANGE50', CAST(N'2019-08-17T00:00:00.000' AS DateTime), 6, 8.9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4291', 1, N'VIS_THP16X80_10.9', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 25, 0.974, N'005216 80')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4291', 2, N'ECRO.H16_10.9', CAST(N'2019-07-28T00:00:00.000' AS DateTime), 100, 0.25, N'0320 16')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4295', 1, N'FILT.MANC14210/2', CAST(N'2019-07-25T00:00:00.000' AS DateTime), 2, 26.35, N'MANNC14210/2')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4295', 2, N'FILT.MANCF850/2', CAST(N'2019-07-25T00:00:00.000' AS DateTime), 2, 17.17, N'MANNCF850')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4295', 3, N'FILT.MANWK731', CAST(N'2019-07-25T00:00:00.000' AS DateTime), 2, 6.83, N'MANNWK731')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4295', 4, N'FILT.HIFSC60008', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 2, 60.82, N'HISC60008')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4295', 5, N'FILT.MANW940/5', CAST(N'2019-07-25T00:00:00.000' AS DateTime), 5, 9.99, N'MANNW940/5')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4295', 6, N'FILT.MANW1160/2', CAST(N'2019-07-25T00:00:00.000' AS DateTime), 1, 13.73, N'W1160/2')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4295', 7, N'FILT.MANTB1374-3X', CAST(N'2019-07-25T00:00:00.000' AS DateTime), 1, 39.07, N'MANNTB1374X')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4295', 8, N'BALA.EGRVI5001865594', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 1, 20.28, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4295', 9, N'FUSI.M2BR15A', CAST(N'2019-07-25T00:00:00.000' AS DateTime), 40, 0.44, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4295', 10, N'JOIN.TOR.R08', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 30, 0, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4295', 11, N'HAUT_PARLEUR130', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 1, 31.89, N'INF845')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4295', 12, N'FUSI.2BR.MAX.60A', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 3, 4.95, N'REST6824')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4313', 1, N'TOLE_CRICS', CAST(N'2019-07-25T00:00:00.000' AS DateTime), 20, 649.7, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4314', 1, N'LICE.RTSK-97-900207', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 1, 1800, N'RTSK-97-900207')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4314', 2, N'DISQ.DSVHK-50-303800458', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 3, 220, N'SVHK-50-303800458')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4314', 3, N'STAT.RTSK-97-900209', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 2, 1750, N'RTSK-97-900209')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4314', 4, N'LICE.RTSK-97-900208', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 30, 66, N'RTSK-97-900208')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4314', 5, N'LICE.RTSK-97-900210', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 1, 280, N'RTSK-97-900210')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4314', 6, N'LICE.RTSK-97-900210', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 1, 0, N'RTSK-97-900210')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4314', 7, N'CLAV.SVHK-40-302600066', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 2, 199, N'SVHK-40-302600066')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4314', 8, N'ECRA.SVHK-40-3025001992', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 4, 870, N'SVHK-40-302501992')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4315', 1, N'CAME.SVHK-30-301311213', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 1, 1550, N'SVHK-30-301311213')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4315', 2, N'BOX_SVHK-50-302701355', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 1, 44, N'SVHK-50-302701355')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4315', 3, N'LICE.RTSK-97-900207', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 1, 1800, N'RTSK-97-900207')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4315', 4, N'STAT.RTSK-97-900209', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 2, 1750, N'RTSK-97-900209')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4315', 5, N'LICE.RTSK-97-900208', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 36, 66, N'RTSK-97-900208')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4315', 6, N'CLAV.SVHK-40-302600066', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 2, 199, N'SVHK-40-302600066')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4315', 7, N'INJE.SVHK-40-101700361', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 1, 60, N'SVHK-40-101700361')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4315', 8, N'LICE.RTSK-97-900210', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 1, 280, N'RTSK-97-900210')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4315', 9, N'LICE.RTSK-97-900210', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 1, 0, N'RTSK-97-900210')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4315', 10, N'ECRA.SVHK-40-3025001992', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 2, 870, N'SVHK-40-302501992')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4315', 11, N'SUPP.SVHK-40-190115893', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 2, 12, N'SVHK-40-190115893')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4316', 1, N'SWIT.PHOFLSWITCH23042GC2SFP', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 4, 578.34, N'2702653')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4316', 2, N'MODU.PHO.FLSFPLX', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 8, 149.69, N'2891767')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4316', 3, N'INJE.PHOINJ1000-T', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 2, 184.5, N'2703006')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4316', 5, N'ALIM.PHO2903148', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 4, 57.62, N'2903148')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4316', 6, N'ADAP.PHODT-LAN-CAT6+', CAST(N'2019-07-24T00:00:00.000' AS DateTime), 2, 95.68, N'2881007')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4317', 1, N'SERV.AUMSA07.6', CAST(N'2019-07-25T00:00:00.000' AS DateTime), 4, 1334, N'SA07.6')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4318', 1, N'OEIL.DEX26205022', CAST(N'2019-07-25T00:00:00.000' AS DateTime), 16, 8.8, N'DEX26205022')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4318', 2, N'OEIL.DEX26205023', CAST(N'2019-07-25T00:00:00.000' AS DateTime), 16, 11.2, N'DEX26205023')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4318', 3, N'OEIL.DEX26205024', CAST(N'2019-07-25T00:00:00.000' AS DateTime), 16, 12.4, N'26205024')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4322', 1, N'EPUI.50CM', CAST(N'2019-07-29T00:00:00.000' AS DateTime), 3, 60.8, N'FIL1420')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4322', 2, N'MANC.EPUISETTE1.8', CAST(N'2019-07-29T00:00:00.000' AS DateTime), 3, 15.2, N'FIL1886')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4419', 1, N'FLEX.HYDSM', CAST(N'2019-07-29T00:00:00.000' AS DateTime), 3, 66.6567, N'FLEXIBLE HP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4419', 2, N'MEUL.AXIALE', CAST(N'2019-07-29T00:00:00.000' AS DateTime), 1, 195.19, N'9140571')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4419', 3, N'FRAI.CBP6MM', CAST(N'2019-07-29T00:00:00.000' AS DateTime), 12, 15.77, N'9140572')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4419', 4, N'FRAI.OGIV6MM', CAST(N'2019-07-29T00:00:00.000' AS DateTime), 2, 15.89, N'9140573')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4419', 5, N'FRAI.OGIV6MMPOINTU', CAST(N'2019-07-29T00:00:00.000' AS DateTime), 2, 15.66, N'9140574')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4420', 1, N'CART.BROLC3217BK', CAST(N'2019-07-29T00:00:00.000' AS DateTime), 4, 13.11, N'34334')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4420', 2, N'CART.BROLC3217C', CAST(N'2019-07-29T00:00:00.000' AS DateTime), 4, 9.54, N'34335')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4420', 3, N'CART.BROLC3217M', CAST(N'2019-07-29T00:00:00.000' AS DateTime), 4, 9.54, N'34336')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4420', 4, N'CART.BROLC3217Y', CAST(N'2019-07-29T00:00:00.000' AS DateTime), 4, 9.54, N'34337')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4439', 1, N'FLEX.HYDSM', CAST(N'2019-07-29T00:00:00.000' AS DateTime), 1, 1856.93, N'FLEXIBLE HP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4467', 1, N'HUIL.10W40/5', CAST(N'2019-07-29T00:00:00.000' AS DateTime), 4, 14.375, N'600519179')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4467', 2, N'HUIL.BIOHYDI46-20', CAST(N'2019-07-29T00:00:00.000' AS DateTime), 6, 271.8, N'600703356')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4467', 3, N'HUIL.CHAINBIO5', CAST(N'2019-08-26T00:00:00.000' AS DateTime), 8, 38.6175, N'600389147')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4467', 4, N'GRAI.LXC2', CAST(N'2019-07-29T00:00:00.000' AS DateTime), 48, 6.441, N'600006785')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4467', 5, N'GRAI.RENOLIT_F_EP3', CAST(N'2019-07-29T00:00:00.000' AS DateTime), 20, 4.08, N'600414450')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4467', 6, N'TGAP', CAST(N'2019-10-29T00:00:00.000' AS DateTime), 1, 0.85, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4476', 1, N'GAZO.', CAST(N'2019-07-31T00:00:00.000' AS DateTime), 1500, 1.2483, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4477', 1, N'CADE.30', CAST(N'2019-08-01T00:00:00.000' AS DateTime), 2, 5.22, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4478', 1, N'SUPP.BANSMB30FA', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 3, 29.9, N'BANNER SMB30FA')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4478', 2, N'RUBA.INOIR19', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 10, 7.9, N'3M80021')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4478', 3, N'BLOC_LEG50097', CAST(N'2019-08-01T00:00:00.000' AS DateTime), 2, 22.15, N'LEG050097')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4478', 4, N'PILE_LR03', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 40, 0.66, N'CIPE 116816')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4478', 5, N'DISQ.230DIAM', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 1, 204, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4478', 6, N'BOIT.SCHENN05004', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 10, 3.65, N'SCHENN05004')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4478', 7, N'BOIT.SCHENN05005', CAST(N'2019-08-01T00:00:00.000' AS DateTime), 10, 6.75, N'SCHENN05005')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4478', 9, N'ENRO.3G2.5-40', CAST(N'2019-08-04T00:00:00.000' AS DateTime), 1, 192.5, N'136425')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4480', 1, N'BLOC_WC', CAST(N'2019-07-31T00:00:00.000' AS DateTime), 25, 3.46, N'APN0063')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4480', 2, N'PEIN.SPNOIRB', CAST(N'2019-07-31T00:00:00.000' AS DateTime), 6, 12.55, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4480', 3, N'SPRA.NETT.ECR', CAST(N'2019-07-31T00:00:00.000' AS DateTime), 6, 9.9, N'AF0033')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4480', 4, N'ESSU.MAIN_KIM6763', CAST(N'2019-07-31T00:00:00.000' AS DateTime), 180, 4.91, N'HA0131')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4480', 5, N'ESSU.TOUT', CAST(N'2019-07-31T00:00:00.000' AS DateTime), 96, 0.608, N'TL0010')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4482', 1, N'PEIN.SATBLANC2.5TEINTE', CAST(N'2019-07-31T00:00:00.000' AS DateTime), 2, 49.61, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4482', 2, N'PEIN.SATBLANC10TEINTE', CAST(N'2019-07-31T00:00:00.000' AS DateTime), 3, 109.17, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4494', 1, N'SCHA.BIO5', CAST(N'2019-07-31T00:00:00.000' AS DateTime), 4, 47.7, N'BIOTEC')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4494', 2, N'SPRA.NETT.VIT', CAST(N'2019-07-31T00:00:00.000' AS DateTime), 12, 15.28, N'BIOTEC-VITRE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4494', 3, N'LING.100', CAST(N'2019-07-31T00:00:00.000' AS DateTime), 12, 22.9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4494', 4, N'SPRA.NETT.FR', CAST(N'2019-08-18T00:00:00.000' AS DateTime), 24, 11.82, N'ASFORNET-0202113')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4494', 5, N'DEGR.HD2', CAST(N'2019-07-31T00:00:00.000' AS DateTime), 4, 213.6, N'SURFZYME HD2-0225102')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4512', 1, N'LUNE.FUMEE', CAST(N'2019-08-03T00:00:00.000' AS DateTime), 20, 10.6, N'BOLL VIPER VIPCF')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4512', 2, N'GANT_NITRIL10', CAST(N'2019-08-03T00:00:00.000' AS DateTime), 10, 9.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4513', 1, N'SUPP.LEG080261', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 52, 2.2307, N'LEG080261')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4513', 2, N'PLAQ.LEG066632', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 5, 2.932, N'LEG066632')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4513', 3, N'PLAQ.LEG066633', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 4, 4.398, N'LEG066633')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4513', 4, N'PRIS.LEG067345', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 3, 11.9134, N'LEG067345')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4513', 5, N'ENJO.LEG068251', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 3, 2.5254, N'LEG068251')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4513', 6, N'BOIT.LEG080051', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 3, 0.8046, N'LEG080051')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4513', 7, N'BOIT.LEG080052', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 6, 3.463, N'LEG080052')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4513', 8, N'BOIT.LEG080053', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 5, 4.39398, N'LEG080053')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4513', 9, N'BOIT.LEG089337', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 3, 4.9945, N'LEG089337')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4513', 10, N'FICH.BIZ620160', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 3, 1.6135, N'BIZ620160')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4513', 11, N'INTE.LEG67001', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 8, 4.6235, N'LEG067001')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4513', 12, N'PRIS.LEG067111', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 18, 3.4064, N'LEG067111')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4513', 13, N'PRIS.LEG067124', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 4, 7.9827, N'LEG067124')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4513', 14, N'PRIS.LEG067126', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 4, 11.9775, N'LEG067126')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4513', 15, N'ENJO.LEG068111', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 32, 0.9773, N'LEG068111')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4513', 16, N'ENJO.LEG068001', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 6, 1.0002, N'LEG068001')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4513', 17, N'ENJO.LEG068002', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 3, 3.691, N'LEG068002')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4513', 18, N'BP_LEG067031', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 3, 7.9335, N'LEG067031')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4513', 19, N'PLAQ.LEG066631', CAST(N'2019-08-02T00:00:00.000' AS DateTime), 31, 1.466, N'LEG066631')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--45241', 1, N'LICE.IP_MIVOICE', CAST(N'2019-09-13T00:00:00.000' AS DateTime), 10, 69, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4549', 1, N'GRIL.CLA6005014651', CAST(N'2019-08-07T00:00:00.000' AS DateTime), 1, 180.39, N'6005014651')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4549', 2, N'VIS_CLA6005012731', CAST(N'2019-08-07T00:00:00.000' AS DateTime), 2, 1.73, N'6005012731')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4549', 3, N'ATTA.CLA6005023804', CAST(N'2019-08-07T00:00:00.000' AS DateTime), 2, 0.37, N'6005023804')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4549', 4, N'JANT.CLA6000149629', CAST(N'2019-08-07T00:00:00.000' AS DateTime), 1, 664.36, N'6000149629')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4549', 5, N'FLAS.CLA6000149631', CAST(N'2019-08-07T00:00:00.000' AS DateTime), 1, 404.33, N'6000149631')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4549', 6, N'VIS_CLA11570000', CAST(N'2019-08-07T00:00:00.000' AS DateTime), 6, 4.59, N'115700000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4549', 7, N'ROND.CLA11570030', CAST(N'2019-08-07T00:00:00.000' AS DateTime), 6, 1.75, N'11570030')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4549', 8, N'ECRO.CLA11570060', CAST(N'2019-08-07T00:00:00.000' AS DateTime), 6, 1.42, N'11570060')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4550', 1, N'MOTE.AUMZ011.892', CAST(N'2019-08-07T00:00:00.000' AS DateTime), 2, 545, N'Z011.892')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4562', 1, N'GNR_BF', CAST(N'2019-08-06T00:00:00.000' AS DateTime), 1348, 0.925, N'BIOFREE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4562', 2, N'GAZO.', CAST(N'2019-08-06T00:00:00.000' AS DateTime), 1000, 1.43, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4590', 1, N'PEIN.AR4RAL1018', CAST(N'2019-08-12T00:00:00.000' AS DateTime), 4, 60.89, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4591', 1, N'PINC.MASSE', CAST(N'2019-09-12T00:00:00.000' AS DateTime), 1, 11.42, N'SAF000010577')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4591', 2, N'PEIN.SP9003', CAST(N'2019-08-14T00:00:00.000' AS DateTime), 2, 12.77, N'AK1233004')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4591', 3, N'PEIN.SPNOIRM', CAST(N'2019-09-12T00:00:00.000' AS DateTime), 2, 12.77, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4591', 4, N'SPRA.NEUT.ROUIL', CAST(N'2019-08-14T00:00:00.000' AS DateTime), 1, 26.78, N'DINI11008')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4591', 5, N'DISQ.230TR.EP1.9INOX', CAST(N'2019-09-12T00:00:00.000' AS DateTime), 10, 3.11, N'NORT66252832686')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4591', 6, N'ROND.CAR06X18', CAST(N'2019-09-12T00:00:00.000' AS DateTime), 150, 0.032, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4591', 7, N'ROND.PL.CH10', CAST(N'2019-09-12T00:00:00.000' AS DateTime), 120, 0.124, N'583')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4591', 8, N'ROND.PL.CH06', CAST(N'2019-09-12T00:00:00.000' AS DateTime), 88, 0.095, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4591', 9, N'BROS.ROT.CIRC115', CAST(N'2019-09-12T00:00:00.000' AS DateTime), 2, 18.74, N'NORT66254406099')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4591', 10, N'BROS.ROT.FC', CAST(N'2019-09-12T00:00:00.000' AS DateTime), 1, 14.9, N'NORT66254406102')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4591', 11, N'AMPO.HALO.H4', CAST(N'2019-08-13T00:00:00.000' AS DateTime), 2, 4.63, N'OSRA64193')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4591', 12, N'AMPO.COFF.', CAST(N'2019-08-13T00:00:00.000' AS DateTime), 2, 14.61, N'OSRA873398')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4591', 13, N'BOUC.BIL303L20', CAST(N'2019-09-14T00:00:00.000' AS DateTime), 1, 25, N'DELTA PLUS')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4591', 14, N'ADAP.13PL/7PL.M', CAST(N'2019-08-28T00:00:00.000' AS DateTime), 1, 17.96, N'INF115BL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4591', 15, N'ADAP.13PL/7PL.F', CAST(N'2019-08-04T00:00:00.000' AS DateTime), 1, 17.96, N'INF116BL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4591', 16, N'BATT.FUL31', CAST(N'2019-09-14T00:00:00.000' AS DateTime), 1, 117, N'FULMEN31')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4591', 17, N'GRAT.GIVRE', CAST(N'2019-08-14T00:00:00.000' AS DateTime), 4, 1.47, N'FLAU900169')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4591', 18, N'COLL.REST949', CAST(N'2019-09-14T00:00:00.000' AS DateTime), 1, 16.46, N'REST949')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4591', 19, N'COLL.REST598', CAST(N'2019-09-14T00:00:00.000' AS DateTime), 1, 8.78, N'REST598')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4591', 20, N'COLL.REST599', CAST(N'2019-09-14T00:00:00.000' AS DateTime), 1, 9.83, N'REST599')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4591', 21, N'RALL.FACS.215', CAST(N'2019-08-14T00:00:00.000' AS DateTime), 1, 7.18, N'FACS.215')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4655', 1, N'INSE.POMP.', CAST(N'2019-08-07T00:00:00.000' AS DateTime), 24, 16.37, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4655', 2, N'MOP_PRESTO', CAST(N'2019-09-23T00:00:00.000' AS DateTime), 10, 1.95, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4655', 3, N'KIT_NETTOYAGE', CAST(N'2019-09-06T00:00:00.000' AS DateTime), 1, 75, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4655', 4, N'SPRA.NETT.FR', CAST(N'2019-08-25T00:00:00.000' AS DateTime), 12, 11.82, N'ASFORNET-0202113')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4655', 5, N'LING.WC', CAST(N'2019-08-07T00:00:00.000' AS DateTime), 10, 9.95, N'HARPIC')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4655', 7, N'NETT.SURFACE', CAST(N'2019-08-07T00:00:00.000' AS DateTime), 12, 15.2, N'BACTIPAL PRO-0207170')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4655', 8, N'TAPI.COULOIR900/1200', CAST(N'2019-09-23T00:00:00.000' AS DateTime), 1, 105, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4655', 9, N'SAC_POUB130L', CAST(N'2019-08-07T00:00:00.000' AS DateTime), 4, 70.01, N'0111103')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4660', 1, N'NETT.INJ.DIES', CAST(N'2019-08-13T00:00:00.000' AS DateTime), 20, 29.83, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4660', 2, N'NETT.INJ.ESS', CAST(N'2019-08-13T00:00:00.000' AS DateTime), 20, 29.83, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4661', 1, N'GRAI.LXC2', CAST(N'2019-08-13T00:00:00.000' AS DateTime), 48, 6.441, N'600006785')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4661', 2, N'PORT', CAST(N'2019-08-13T00:00:00.000' AS DateTime), 1, 39, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4662', 1, N'REPA.MAT.AGRI', CAST(N'2019-08-15T00:00:00.000' AS DateTime), 1, 1153.35, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4663', 1, N'GANT_NITRIL9', CAST(N'2019-08-15T00:00:00.000' AS DateTime), 6, 17, N'MICROFLEX ANSELL EDMONT')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4663', 2, N'GANT_NITRIL10', CAST(N'2019-08-15T00:00:00.000' AS DateTime), 6, 17, N'ANSELL EDMONT MICROFLEX')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4664', 1, N'CLE_FACCMSFAC82H.5', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 1, 1.22, N'FAC82H.5')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4664', 2, N'JEU_FAC89.JP8L', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 1, 17.46, N'02057062')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4664', 3, N'PAUM.SOUD80', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 6, 1.4, N'01018141')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4664', 4, N'PAUM.SOUD100', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 6, 2.68, N'010181421')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4664', 5, N'PAUM.SOUD120', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 6, 3.01, N'01018143')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4664', 6, N'PAUM.GRIL100', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 4, 12.71, N'01018150')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4664', 7, N'SANG.AR10M2.5TDGEC', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 8, 28.13, N'PSSA5010POWER')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4664', 8, N'CYLI.30X30', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 1, 14.97, N'010183031')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4664', 9, N'SERR.LARD.AX50', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 1, 13.63, N'01018387')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4664', 10, N'POIG.ALU', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 1, 8.23, N'01018519')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4664', 11, N'CORD.MAC1.5 PINCK', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 1, 68.4, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4664', 12, N'CORD.MAC2', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 1, 7, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4664', 13, N'CORD.POLY04.5', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 1, 17, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4664', 14, N'PIST.GONFSTD', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 1, 119.7, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4664', 15, N'COUT. OPINEL8', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 1, 7.63, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4664', 16, N'PORT.ETIQ.AS100', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 39, 0.2691, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4664', 17, N'CLE_DPG', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 12, 4.14, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4665', 1, N'HUIL.MOBGEAR632-200L', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 2, 580, N'TTA 12M04505')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4665', 2, N'GRAI.CONTRANSTACK-50KGS', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 1, 300, N'CONDTRANSTACK-60L')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4665', 3, N'SPRA.LUBR.TOTENS700', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 16, 7.88, N'TOTAL140084')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4665', 4, N'GRAI.TOTENS400-50KG', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 2, 193, N'TOTAL121991')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4665', 5, N'GRAI.IBINEOLUBGRV190', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 12, 5.3, N'TEIN515004')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4666', 1, N'CHAU.COF.TECHNICAL-S3-SRC', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 11, 64.09, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4667', 1, N'PEIN.SPNOIRM', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 6, 25.1, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4667', 2, N'PEIN.SP9003', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 6, 25.1, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4667', 3, N'SPRA.NEUT.ROUIL', CAST(N'2019-08-19T00:00:00.000' AS DateTime), 3, 44.93, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4668', 1, N'GAZO.', CAST(N'2019-08-20T00:00:00.000' AS DateTime), 3000, 1.169, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4668', 2, N'GNR_BF', CAST(N'2019-08-20T00:00:00.000' AS DateTime), 1001, 0.734, N'BIOFREE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4668', 3, N'GNR_BF', CAST(N'2019-08-20T00:00:00.000' AS DateTime), 3000, 0.734, N'BIOFREE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4669', 1, N'ANTIGEL20', CAST(N'2019-08-21T00:00:00.000' AS DateTime), 100, 3.25, N'600824693 MAINTAIN FRICOFIN')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4670', 1, N'ELIN.EL3T3M', CAST(N'2019-08-21T00:00:00.000' AS DateTime), 4, 13.25, N'TUB03T03M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4670', 2, N'ELIN.EL4T4M', CAST(N'2019-08-22T00:00:00.000' AS DateTime), 4, 24.75, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4671', 1, N'REPA.MAT.AGRI', CAST(N'2019-08-22T00:00:00.000' AS DateTime), 1, 198.3, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4818', 1, N'DILU.CELLULOSIQ.', CAST(N'2019-08-22T00:00:00.000' AS DateTime), 10, 5.982, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4818', 3, N'POUC.R03-15', CAST(N'2019-08-22T00:00:00.000' AS DateTime), 4, 4.487, N'3289551703098')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4818', 4, N'POUC.R2-21', CAST(N'2019-08-22T00:00:00.000' AS DateTime), 6, 4.771, N'3289550018599')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4818', 5, N'POUC.R4-25', CAST(N'2019-08-22T00:00:00.000' AS DateTime), 6, 9.233, N'3289552303044')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4818', 7, N'POUC.R6-29', CAST(N'2019-08-22T00:00:00.000' AS DateTime), 4, 7.145, N'3289550018612')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4818', 8, N'BROS.PEINT30', CAST(N'2019-08-22T00:00:00.000' AS DateTime), 2, 1.85, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4818', 9, N'BROS.PEINT40', CAST(N'2019-08-22T00:00:00.000' AS DateTime), 2, 2.49, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4818', 10, N'BROS.PEINT50', CAST(N'2019-08-22T00:00:00.000' AS DateTime), 2, 3.3, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4818', 11, N'BROS.PEINT60', CAST(N'2019-08-22T00:00:00.000' AS DateTime), 2, 4.56, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4818', 12, N'MONT.ROUL', CAST(N'2019-08-22T00:00:00.000' AS DateTime), 4, 2.515, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4818', 13, N'MONT.ROUL400', CAST(N'2019-08-22T00:00:00.000' AS DateTime), 4, 4.1, NULL)
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4818', 14, N'MANC.180MUR-PLAF', CAST(N'2019-08-22T00:00:00.000' AS DateTime), 10, 8.14, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4818', 15, N'GRIL.CAM14L_PLAST', CAST(N'2019-08-22T00:00:00.000' AS DateTime), 3, 4.576, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4818', 16, N'GRIL.CAM7L_PLAST', CAST(N'2019-08-22T00:00:00.000' AS DateTime), 3, 2.4, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4818', 17, N'RECH.CAMION14L', CAST(N'2019-08-22T00:00:00.000' AS DateTime), 3, 9.42, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4818', 18, N'RECH.CAMION7L', CAST(N'2019-08-22T00:00:00.000' AS DateTime), 3, 5.11, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4818', 20, N'POUC.R0-18', CAST(N'2019-08-22T00:00:00.000' AS DateTime), 4, 4.655, N'3289550018636')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4820', 1, N'BOUL.STH11201625200', CAST(N'2019-08-27T00:00:00.000' AS DateTime), 1, 1.94, N'11201625200')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4820', 2, N'GOUP.STH93785432640', CAST(N'2019-08-27T00:00:00.000' AS DateTime), 1, 0.52, N'93785432640')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4820', 3, N'ARRE.STH11146567705', CAST(N'2019-08-27T00:00:00.000' AS DateTime), 1, 4.12, N'11146567705')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4820', 4, N'VIS_STH91040033004', CAST(N'2019-08-27T00:00:00.000' AS DateTime), 3, 1.15, N'91040033004')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4820', 6, N'PROT.STH11297929100', CAST(N'2019-08-27T00:00:00.000' AS DateTime), 1, 22.55, N'11297929100')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4820', 7, N'LEVI.STH11281605000', CAST(N'2019-08-28T00:00:00.000' AS DateTime), 1, 11.25, N'11281605000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4820', 8, N'COLL.STH11231605400', CAST(N'2019-08-28T00:00:00.000' AS DateTime), 1, 13.09, N'11231605400')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4820', 9, N'RESS.STH11291627800', CAST(N'2019-08-28T00:00:00.000' AS DateTime), 1, 4.13, N'11291627800')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4820', 10, N'RESS.STH00009971018', CAST(N'2019-08-28T00:00:00.000' AS DateTime), 1, 6.15, N'00009971018')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4820', 11, N'COUV.STH11296487700', CAST(N'2019-08-28T00:00:00.000' AS DateTime), 1, 6.47, N'11296487700')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4836', 1, N'FLEA.NOR103070', CAST(N'2019-08-26T00:00:00.000' AS DateTime), 50, 2.28, N'103070')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4836', 2, N'MANI.NOR103071', CAST(N'2019-08-26T00:00:00.000' AS DateTime), 50, 3.35, N'103071')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4836', 3, N'ENTR.NOR103072', CAST(N'2019-08-26T00:00:00.000' AS DateTime), 50, 0.66, N'103072')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4836', 4, N'VIS_NOR103073', CAST(N'2019-08-26T00:00:00.000' AS DateTime), 50, 1.13, N'103073')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4836', 5, N'ENTR.NOR103072', CAST(N'2019-08-26T00:00:00.000' AS DateTime), 50, 0.66, N'103072')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4836', 6, N'PORT', CAST(N'2019-08-27T00:00:00.000' AS DateTime), 1, 48, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4884', 1, N'REPA.MATERIEL', CAST(N'2019-08-28T00:00:00.000' AS DateTime), 1, 217.17, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4885', 1, N'SPRA.LUBR.INTFGOG', CAST(N'2016-10-22T00:00:00.000' AS DateTime), 6, 35.2, N'9201')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4885', 2, N'SPRA.LUBR.INTFLTF', CAST(N'2016-10-22T00:00:00.000' AS DateTime), 12, 20.05, N'9074')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4885', 3, N'PATE_HT1200', CAST(N'2016-10-22T00:00:00.000' AS DateTime), 3, 33.6, N'8426')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4885', 4, N'PORT', CAST(N'2019-09-04T00:00:00.000' AS DateTime), 1, 15, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4886', 1, N'HUIL.2TBIO1', CAST(N'2019-09-10T00:00:00.000' AS DateTime), 20, 21.789, N'600088194')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4886', 2, N'HUIL.CHAINBIO5', CAST(N'2019-09-25T00:00:00.000' AS DateTime), 8, 38.6175, N'600389147')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4888', 1, N'ASSO.ABIHV3000', CAST(N'2019-08-30T00:00:00.000' AS DateTime), 1, 88, N'ABI-AURORA')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4888', 2, N'LAMP.F_PETNAO+', CAST(N'2019-08-30T00:00:00.000' AS DateTime), 4, 147.2, N'PETZL-EZX66112')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4888', 3, N'CORD.POLY04.5', CAST(N'2019-08-30T00:00:00.000' AS DateTime), 1, 25, N'RAJA-MFP53')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4888', 4, N'TAXE', CAST(N'2019-06-14T00:00:00.000' AS DateTime), 1, 15.8, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4889', 1, N'FRAISAGE', CAST(N'2019-08-29T00:00:00.000' AS DateTime), 100, 2.6, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4893', 1, N'TUBE_VERIN120/100/6000', CAST(N'2019-08-29T00:00:00.000' AS DateTime), 12, 113.14, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4893', 2, N'PORT', CAST(N'2019-08-29T00:00:00.000' AS DateTime), 1, 50, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4908', 1, N'BALA.NILSW250', CAST(N'2019-08-30T00:00:00.000' AS DateTime), 1, 409, N'SW250')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4910', 1, N'ENLE.DIND', CAST(N'2019-08-30T00:00:00.000' AS DateTime), 1, 1275.68, N'HUILE DE VIDANGE / TONNE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4911', 1, N'ACCU_MIL4933451423', CAST(N'2019-08-30T00:00:00.000' AS DateTime), 1, 254.15, N'ATLA4933451430')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4911', 2, N'TAXE', CAST(N'2019-08-30T00:00:00.000' AS DateTime), 1, 0.42, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4911', 3, N'MART.MIL4933451430', CAST(N'2019-08-30T00:00:00.000' AS DateTime), 1, 305.15, N'ATLA4933451430')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4912', 1, N'GOUP.KUB0123279', CAST(N'2019-09-10T00:00:00.000' AS DateTime), 1, 9.96, N'0123279')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4912', 2, N'VIS_KUB0123280', CAST(N'2019-09-10T00:00:00.000' AS DateTime), 1, 1.74, N'0123280')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4912', 3, N'PORT', CAST(N'2019-09-10T00:00:00.000' AS DateTime), 1, 7.2, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4913', 1, N'ROUL.TIM30215-9X025', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 2, 43.96, N'30215EF')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4913', 2, N'ROUL.TIM30310-90KA1', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 1, 34.92, N'30310EF')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4913', 3, N'ROUL.TIM33210-9X025', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 1, 35.38, N'33210EF')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4913', 4, N'BAGU.TYPEC-CS75/95/10DC_NBR', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 1, 25.96, N'75/95/10 DC NBR')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4913', 5, N'JOIN.PAPIER1000/1000/4MM', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 4, 19.89, N'PAPIER 1000X1000X0.4MM')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4913', 6, N'PORT', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 1, 28, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4913', 7, N'COLL.ETTR100ML', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 3, 10.68, N'2326227 A GACHETTE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4914', 1, N'ELEC.DS800_3.2', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 2, 185.2, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4914', 2, N'FIL_SOUDURE_HC10/10', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 1, 480, N'M2500.10')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4915', 1, N'ARBU.', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 1, 125, N'DIVERS ARBUSTES')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4916', 1, N'VIS_MUT980416', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 14, 5.89, N'MU980416')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4916', 2, N'MART.MUT000306', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 14, 22.63, N'MU000306')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4916', 3, N'PORT', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 1, 36.2, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4917', 1, N'NICH.SIMPLE', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 6, 20, N'0064')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4917', 2, N'NICH.TRIPLE', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 2, 60, N'0068')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4917', 3, N'PORT', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 1, 25, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4918', 1, N'BANC_2000/420/400GCH', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 2, 194.71, N'969671')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4918', 2, N'TABL.CHAUSSURE/2000', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 2, 44.97, N'969732')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4918', 3, N'PORT.MANTEAU2M', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 2, 134.85, N'738756')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4919', 3, N'DISQ.D1TO', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 5, 67, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4919', 4, N'TAXE', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 5, 0.08, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4919', 5, N'ADAP.VGAFF', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 5, 5.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4919', 6, N'ADAP.DVI/VGA', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 5, 6, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4919', 7, N'POIN.LASER', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 5, 39, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4919', 8, N'TAXE', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 5, 0.08, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4919', 9, N'SOUR.OPT.', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 5, 29, N'CHERRY MW3000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4919', 10, N'TAXE', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 5, 0.08, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4919', 11, N'SOUR.FILAIRE', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 5, 20, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4919', 12, N'TAXE', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 5, 0.08, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4921', 1, N'GAZO.', CAST(N'2019-09-11T00:00:00.000' AS DateTime), 1000, 1.23, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4922', 1, N'PANN.AK5_700CL2', CAST(N'2019-09-12T00:00:00.000' AS DateTime), 5, 72.9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4922', 2, N'PANC.KM9_700X200CL2', CAST(N'2019-09-12T00:00:00.000' AS DateTime), 5, 72, N'CYCLISTES PIED A TERRE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4922', 3, N'DIAB.PLIANT300KGS', CAST(N'2019-09-12T00:00:00.000' AS DateTime), 1, 149, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4922', 4, N'SANG.AR25AUTO', CAST(N'2019-09-12T00:00:00.000' AS DateTime), 6, 22, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4925', 1, N'COUT.STH41197134100', CAST(N'2019-09-16T00:00:00.000' AS DateTime), 1, 25.67, N'41197134100')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4925', 2, N'BECH.', CAST(N'2019-09-16T00:00:00.000' AS DateTime), 2, 36.42, N'AFO')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4925', 3, N'FOUR.FUM', CAST(N'2019-09-16T00:00:00.000' AS DateTime), 2, 33.7, N'JFFF4EEM')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4925', 4, N'FILT.STH41471410300C', CAST(N'2019-09-16T00:00:00.000' AS DateTime), 4, 5.98, N'41471410300C')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4925', 6, N'BECH.', CAST(N'2019-09-16T00:00:00.000' AS DateTime), 2, 34.42, N'ABO')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4925', 7, N'FOUR.FUM', CAST(N'2019-09-16T00:00:00.000' AS DateTime), 2, 44.18, N'JFFF4EEM')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4925', 8, N'FILT.STH42291201800', CAST(N'2019-09-16T00:00:00.000' AS DateTime), 1, 1.48, N'42291201800')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4925', 9, N'PANT.FOR.STH60', CAST(N'2019-09-16T00:00:00.000' AS DateTime), 1, 128.33, N'00008839360')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4925', 10, N'PORT', CAST(N'2019-09-16T00:00:00.000' AS DateTime), 1, 7.92, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4925', 11, N'PROT.OREQ515062', CAST(N'2019-09-16T00:00:00.000' AS DateTime), 1, 15.17, N'Q515062')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4925', 12, N'PORT', CAST(N'2019-09-16T00:00:00.000' AS DateTime), 1, 10, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--4925', 13, N'PORT.STH56057504304', CAST(N'2019-09-16T00:00:00.000' AS DateTime), 1, 29.26, N'56057504304')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5242', 1, N'HAUT_COMC-AFLS10HHG', CAST(N'2019-09-16T00:00:00.000' AS DateTime), 14, 597, N'C-AFLS10HHG')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5242', 2, N'PORT', CAST(N'2019-09-16T00:00:00.000' AS DateTime), 1, 50, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5244', 1, N'VIS_THPAB18X320', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 100, 8.65, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5244', 2, N'ROND.CAR18X36X3', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 100, 0.16, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5244', 3, N'GANT_NITRIL11', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 5, 26, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5244', 4, N'SANG.AR9M2TDGEC', CAST(N'2019-09-17T00:00:00.000' AS DateTime), 10, 14, N'A0000059')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5244', 5, N'SANG.ARSF1T35MM', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 6, 12.8, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5244', 6, N'BACH.PROSILO', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 1, 83, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5245', 1, N'PLAN.R2X10X280', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 20, 13.5, N'AA0D4990017')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5245', 2, N'PLAN.R2.5X12X280', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 20, 16.7, N'AA0D4990009')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5249', 1, N'FLEA.KUHA5407231', CAST(N'2019-09-17T00:00:00.000' AS DateTime), 72, 2.42, N'A5407231')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5249', 2, N'MANI.KUHA5411236', CAST(N'2019-09-17T00:00:00.000' AS DateTime), 36, 2.47, N'A5411236')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5249', 3, N'ENTR.KUHA5411834', CAST(N'2019-09-17T00:00:00.000' AS DateTime), 36, 2.25, N'A5411834')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5249', 4, N'VIS_KUHA5411862', CAST(N'2019-09-17T00:00:00.000' AS DateTime), 36, 0.75, N'A5411862')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5249', 5, N'ECRO.KUH80201241', CAST(N'2019-09-17T00:00:00.000' AS DateTime), 36, 0.24, N'80201241')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5249', 6, N'ROUL.KUH81103578', CAST(N'2019-09-17T00:00:00.000' AS DateTime), 4, 72.65, N'81103578')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5251', 1, N'CAFE.DOSE', CAST(N'2019-10-19T00:00:00.000' AS DateTime), 2, 79.5, N'SENSEO')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5251', 2, N'CAFE.ELEC', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 2, 45, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5251', 3, N'THER.CAFE_PPE', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 2, 70, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5251', 4, N'COLL.GAL80X40', CAST(N'2019-09-17T00:00:00.000' AS DateTime), 2, 2.3, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5251', 5, N'PANN.C13A_500CL2', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 1, 88.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5252', 1, N'FICH.SCH81771', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 1, 33.44, N'SCH81771')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5252', 2, N'DISJ.SCHA9P24616', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 3, 32.97, N'SCH_A9P24616')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5252', 3, N'PRIS.SCH_PKF32M735', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 1, 26.51, N'SCH_PKF32M735')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5252', 4, N'FICH.SCH83913', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 1, 32.65, N'SCH83913')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5252', 5, N'CABL.R2V5G6', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 21, 2.7035, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5252', 6, N'CABL.RNFTGL5G6', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 10, 3.992, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5252', 7, N'TUBE_IRL25', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 21, 0.5128, N'ENN40625')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5252', 8, N'COLL.SCHENN47962', CAST(N'2019-07-29T00:00:00.000' AS DateTime), 1, 14.75, N'SCHENN47962')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5252', 9, N'COLL.SCHENN47992', CAST(N'2019-07-29T00:00:00.000' AS DateTime), 1, 21.19, N'SAR47992')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5252', 10, N'COLL.SCHENN47942', CAST(N'2019-07-29T00:00:00.000' AS DateTime), 1, 10.18, N'SCHENN47942')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5252', 11, N'SOCL.SCH83171', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 1, 34.26, N'SCH83171')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5252', 12, N'LAMP.PHI386474', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 2, 42, N'PHI386474')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5252', 13, N'BOIT.SCHENN05007', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 2, 10.68, N'SCHENN05007')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5252', 14, N'COFF.SERM48639111', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 1, 489.5, N'SERM48639111')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5253', 1, N'BOOS.KS550.1810', CAST(N'2019-10-19T00:00:00.000' AS DateTime), 1, 362.5, N'KS550-1710')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5253', 3, N'FILT.MANW7053', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 1, 14.95, N'MANN712/8')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5253', 4, N'GRAT.GIVRE', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 2, 2, N'FLAU900169')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5253', 5, N'GRAT.GIVRE', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 2, 1.47, N'FLAU900169')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5253', 6, N'SAC_KAR69074790', CAST(N'2019-08-01T00:00:00.000' AS DateTime), 3, 21, N'KAR69074790')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5253', 7, N'JOIN.TOR.NBR90SH', CAST(N'2019-10-19T00:00:00.000' AS DateTime), 30, 0.67, N'DESR11X2.5NBR90')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5254', 1, N'CART.HP3HZ52AE', CAST(N'2019-09-17T00:00:00.000' AS DateTime), 4, 92.79, N'07624')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5254', 2, N'EPIN.TAB.AFFICH', CAST(N'2019-09-17T00:00:00.000' AS DateTime), 4, 0.47, N'13239')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5254', 3, N'CART.BROLC1280NP', CAST(N'2019-09-17T00:00:00.000' AS DateTime), 5, 24.33, N'82445')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5254', 4, N'HUB_USB3.0', CAST(N'2019-10-07T00:00:00.000' AS DateTime), 1, 18.86, N'16363')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5254', 5, N'CART.SDHC32GO', CAST(N'2019-09-17T00:00:00.000' AS DateTime), 2, 9.6, N'30071')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5254', 6, N'PERF.2TR20F', CAST(N'2019-09-27T00:00:00.000' AS DateTime), 1, 15.26, N'75736')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5254', 7, N'CALC', CAST(N'2019-09-17T00:00:00.000' AS DateTime), 1, 21.01, N'63154')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5254', 8, N'CLAS.8BL', CAST(N'2019-09-17T00:00:00.000' AS DateTime), 20, 1.65, N'59028')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5254', 9, N'ETIQ.DYMMANAGER160', CAST(N'2019-11-12T00:00:00.000' AS DateTime), 1, 27.17, N'85490')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5254', 10, N'DATE.AUTO', CAST(N'2019-09-17T00:00:00.000' AS DateTime), 1, 15.91, N'75761')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5254', 11, N'SOUR.FILAIRE', CAST(N'2019-11-12T00:00:00.000' AS DateTime), 3, 3.33, N'16300')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5254', 12, N'CART.EPST1301', CAST(N'2019-09-17T00:00:00.000' AS DateTime), 10, 21.29, N'80867')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5255', 1, N'FLEX.HYDSM', CAST(N'2019-09-19T00:00:00.000' AS DateTime), 6, 67.67, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5255', 2, N'TUBE_HYDTU-AC--30-3-ZS', CAST(N'2019-09-19T00:00:00.000' AS DateTime), 6, 11.73, N'TU AC 30 3 ZS')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5255', 3, N'TUBE_HYDTU-AC--30-3-HX', CAST(N'2019-09-19T00:00:00.000' AS DateTime), 24, 11.73, N'TU AC 30 3 HX')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5255', 4, N'CONN.STA6030003263-FI-G-30S-W3', CAST(N'2019-09-19T00:00:00.000' AS DateTime), 5, 12.82, N'G30S')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5255', 5, N'CONN.STA6030003829-FI-M-30S-W3', CAST(N'2019-09-19T00:00:00.000' AS DateTime), 10, 5.67, N'M30S')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5255', 6, N'COLL.STASP321.3/21.3PAGDASINOX', CAST(N'2019-09-19T00:00:00.000' AS DateTime), 45, 10.46, N'SP321.3/21.3PAGDASINOX')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5255', 7, N'COLL.STASP430PADPAASINOX', CAST(N'2019-09-19T00:00:00.000' AS DateTime), 15, 12.44, N'SP430PADPAASINOX')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5255', 8, N'GRAI.NOIR', CAST(N'2019-09-19T00:00:00.000' AS DateTime), 1, 33.8, N'BR2 PLUSA')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5256', 1, N'PROJ.ARI50406', CAST(N'2019-09-19T00:00:00.000' AS DateTime), 2, 38.9, N'ARIC50406')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5256', 2, N'PROJ.ARI50482', CAST(N'2019-09-19T00:00:00.000' AS DateTime), 5, 57.4, N'ARIC50482')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5256', 3, N'PROJ.ARI50407', CAST(N'2019-09-19T00:00:00.000' AS DateTime), 2, 74.6, N'ARIC 50407')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5257', 1, N'INTE.SCHENN35021', CAST(N'2019-09-19T00:00:00.000' AS DateTime), 9, 6.61, N'ENN35021')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5257', 2, N'CORD.VGA/USB-1.5M', CAST(N'2019-09-20T00:00:00.000' AS DateTime), 4, 19.2, N'182-8793')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5257', 3, N'CORD.VGA/HDMI-1.5M', CAST(N'2019-09-20T00:00:00.000' AS DateTime), 4, 39.4, N'182-8794')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5259', 1, N'LAME_VIK63607609992', CAST(N'2019-09-19T00:00:00.000' AS DateTime), 1, 0, N'63607609992')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5259', 2, N'TETE_STH40037102115', CAST(N'2019-11-19T00:00:00.000' AS DateTime), 3, 28.6, N'40037102115')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5260', 1, N'PANN."LOGO"', CAST(N'2019-10-06T00:00:00.000' AS DateTime), 6, 78, N'400X300 + LOGO VNF')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5260', 2, N'PORT', CAST(N'2019-10-19T00:00:00.000' AS DateTime), 1, 30.34, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5261', 1, N'MITI.', CAST(N'2019-09-26T00:00:00.000' AS DateTime), 2, 90.9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5262', 1, N'ASPI.NILAERO21-01', CAST(N'2019-09-26T00:00:00.000' AS DateTime), 1, 229, N'107406602')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5262', 2, N'SAC_NILFAERO21/26/31', CAST(N'2019-09-26T00:00:00.000' AS DateTime), 2, 24.05, N'302002404')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5263', 1, N'BATT.PC', CAST(N'2019-09-27T00:00:00.000' AS DateTime), 1, 79.17, N'ENIML91420')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5264', 1, N'PEIN.AR2.5RAL9003', CAST(N'2019-09-26T00:00:00.000' AS DateTime), 2, 45.255, N'3509392511349')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5264', 2, N'PEIN.SATRAL7035', CAST(N'2019-09-26T00:00:00.000' AS DateTime), 1, 87.34, N'5701573718839')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5264', 3, N'PEIN.MAPBLANC3', CAST(N'2019-09-26T00:00:00.000' AS DateTime), 2, 24.84, N'5701573767622')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5265', 1, N'NETT.DIM18240HE', CAST(N'2019-09-26T00:00:00.000' AS DateTime), 1, 3429, N'9200027')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5266', 1, N'KLAX.CLOCHE12V', CAST(N'2019-10-28T00:00:00.000' AS DateTime), 10, 49, N'VA19034')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5266', 2, N'INTE.APE647H/2K', CAST(N'2019-09-28T00:00:00.000' AS DateTime), 10, 15.73, N'RS6928412')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5266', 3, N'BOIT.SCHENN05005', CAST(N'2019-09-27T00:00:00.000' AS DateTime), 10, 4.05, N'SCHENN05005')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5266', 4, N'MODU.GOT01020', CAST(N'2019-10-28T00:00:00.000' AS DateTime), 10, 39.2, N'GOTRONIC 01020')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5266', 5, N'PORT', CAST(N'2019-09-27T00:00:00.000' AS DateTime), 1, 27, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5267', 1, N'PORT.REST17018', CAST(N'2019-10-29T00:00:00.000' AS DateTime), 10, 3.04, N'REST17018')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5267', 2, N'CABL.RES16263', CAST(N'2019-09-28T00:00:00.000' AS DateTime), 1, 45.45, N'REST16263')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5267', 3, N'CABL.RES16264', CAST(N'2019-09-28T00:00:00.000' AS DateTime), 1, 59.83, N'REST16264')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5268', 1, N'RADI.T22_300X800', CAST(N'2019-09-28T00:00:00.000' AS DateTime), 1, 122.91, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5268', 2, N'TETE_THERMO.SI', CAST(N'2019-09-28T00:00:00.000' AS DateTime), 1, 15.6, N'T09220')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5268', 3, N'RACC.', CAST(N'2019-09-28T00:00:00.000' AS DateTime), 1, 23.03, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5269', 1, N'SUPP.HORCBRD2UNR0002', CAST(N'2019-09-28T00:00:00.000' AS DateTime), 4, 51.4, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5271', 1, N'SERR.AXE55L', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 2, 7.37, N'150980')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5271', 2, N'SERR.AXE55R', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 4, 7.37, N'150979')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5271', 3, N'SERR.AXE50', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 1, 9.04, N'249773')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5271', 4, N'ENSE.PF_SANDIEGO3559782', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 1, 10.2, N'307991')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5271', 5, N'ENSE.PF_SANDIEGO3782001', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 6, 10.2, N'313316')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5271', 6, N'VERR.ARNOV', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 2, 34.41, N'139790')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5271', 7, N'CADE.S''ENTR40', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 9, 8.24, N'169837')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5271', 8, N'CLE_DPPP1', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 12, 12.36, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5271', 9, N'CLE_DPPP2', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 25, 12.36, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5271', 10, N'CLE_DPPP3', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 10, 12.36, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5271', 11, N'CLE_DPPP4', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 4, 12.52, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5271', 12, N'CYLI.30X30/PG', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 11, 35.44, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5271', 13, N'CYLI.40X45/PG', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 2, 49.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5271', 14, N'CYLI.30X35/PG', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 7, 38.25, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5271', 15, N'CYLI.45X50/PG', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 11, 55.13, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5271', 16, N'CYLI.30X50/PG', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 2, 46.7, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5271', 17, N'CYLI.30X40/PG', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 2, 41.08, N'PLAN NIR476185 - N1')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5271', 18, N'CYLI.40X40/PG', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 2, 46.7, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5271', 19, N'CYLI.30X45/PG', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 1, 43.88, NULL)
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5271', 20, N'DEMI_CYL30X10', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 3, 32.76, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5271', 21, N'CLE_DPG', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 5, 12.36, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5273', 1, N'SPRA.NETT.VIT', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 12, 15.28, N'BIOTEC-VITRE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5273', 2, N'SPRA.NETT.FR', CAST(N'2019-10-18T00:00:00.000' AS DateTime), 6, 11.82, N'ASFORNET-0202113')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5273', 3, N'NETT.SURFACE', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 6, 15.2, N'BACTIPAL PRO-0207170')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5273', 4, N'SPRA.DEGI', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 12, 12.02, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5273', 5, N'DILU.N5L', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 1, 35, N'S27-0219114')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5274', 1, N'TOUR.JWER05105631001', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 1, 102.35, N'051005631001')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5274', 2, N'TOUR.JWER05133355001', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 1, 67.17, N'05133355001')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5274', 3, N'TOUR.JWER05134000001', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 1, 89, N'05134000001')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5274', 4, N'DISQ.125F1', CAST(N'2019-10-31T00:00:00.000' AS DateTime), 50, 2.75, N'5040061')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5274', 5, N'DISQ.LAM125X80', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 10, 8.5, N'5040071')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5274', 6, N'DISQ.230TR.EP3', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 25, 8.15, N'5040075')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5274', 7, N'DISQ.230EB', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 10, 9.7, N'5040047')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5274', 8, N'DISQ.115TR', CAST(N'2019-09-30T00:00:00.000' AS DateTime), 25, 3.15, N'5040069')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5274', 9, N'DISQ.LAM110X40', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 10, 8.5, N'5040035 - WENDT')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5274', 10, N'PORT', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 1, 50, N'PORT ET EMBALLAGE USINE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5275', 1, N'DESO.MECHE', CAST(N'2019-10-01T00:00:00.000' AS DateTime), 30, 6.14, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5275', 2, N'DESO.COQ.MELON', CAST(N'2019-10-01T00:00:00.000' AS DateTime), 10, 18.53, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5275', 3, N'PAPI.TOIL380M', CAST(N'2019-10-01T00:00:00.000' AS DateTime), 24, 5.826, N'0102110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5275', 4, N'ESSU.MAIN_KIM6763', CAST(N'2019-10-01T00:00:00.000' AS DateTime), 150, 4.949, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5275', 5, N'GEL_WC', CAST(N'2019-10-01T00:00:00.000' AS DateTime), 24, 6.1, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5275', 6, N'VERR.BC', CAST(N'2019-10-11T00:00:00.000' AS DateTime), 1, 80.84, N'HG10')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5275', 7, N'SPRA.NETT.VIT', CAST(N'2019-10-01T00:00:00.000' AS DateTime), 12, 15.28, N'BIOTEC-VITRE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5275', 8, N'SAVO.GEL350', CAST(N'2019-10-01T00:00:00.000' AS DateTime), 24, 9.45, N'0216147')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5275', 9, N'TAMP.', CAST(N'2019-10-01T00:00:00.000' AS DateTime), 80, 1.542, N'0109123 - SPONTEX')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5275', 10, N'NETT.SURFACE', CAST(N'2019-10-01T00:00:00.000' AS DateTime), 6, 15.2, N'BACTIPAL PRO-0207170')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5275', 11, N'CHIF.BLANC', CAST(N'2019-11-01T00:00:00.000' AS DateTime), 4, 35.35, N'0109497')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5275', 12, N'MAST.290DC', CAST(N'2019-10-01T00:00:00.000' AS DateTime), 12, 16.76, N'0205155')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5275', 14, N'BLOC_WC', CAST(N'2019-10-01T00:00:00.000' AS DateTime), 30, 2.99, N'BOULES - BREF POWER ACTIV')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5276', 2, N'LAME_CUTPOCHE', CAST(N'2019-10-03T00:00:00.000' AS DateTime), 8, 3.01, N'0710 410 091')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5276', 3, N'BOUL.1ERG12X60', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 100, 1.91, N'022401260')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5276', 4, N'ECRO.H12', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 200, 0.0984, N'5317 12')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5276', 5, N'VIS_THP10X50A2', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 100, 0.5731, N'00951050')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5276', 6, N'ECRO.H10A2', CAST(N'2019-10-01T00:00:00.000' AS DateTime), 50, 0.1294, N'0322 10')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5276', 7, N'VIS_TRCC12X110Z', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 50, 0.5516, N'022312110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5276', 8, N'CHEV.PARCR4X9', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 400, 0.1836, N'090520414')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5276', 9, N'PIST.SILMC', CAST(N'2019-10-03T00:00:00.000' AS DateTime), 2, 33.36, N'0891 020 912')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5276', 10, N'ASSO.VIS_AP', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 1, 157.47, N'0956211')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5276', 11, N'ASSO.SCIE_CLOCHE', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 1, 270.21, N'0956608001')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5276', 14, N'FORE.SDS+06X210', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 10, 6.95, N'0651 06 210')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5276', 15, N'NIVE.RECT60', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 1, 28.16, N'0705407060')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5276', 16, N'TENA.230', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 2, 26.01, N'0703 713 260')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5276', 18, N'CHEV.PARCR8X16MM', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 100, 0.3905, N'090520816')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5276', 19, N'CHEV.PARCR5X32', CAST(N'2019-10-03T00:00:00.000' AS DateTime), 100, 0.2828, N'090520532')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5276', 20, N'CHEV.PARCR5X12', CAST(N'2019-10-03T00:00:00.000' AS DateTime), 100, 0.2192, N'090520512')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5276', 21, N'CHEV.PARCR16X24', CAST(N'2019-10-03T00:00:00.000' AS DateTime), 100, 0.1858, N'090520426')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5276', 22, N'FORE.SDS+10X160', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 10, 6.79, N'0651 10 160')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5276', 23, N'TIRE.TH08X120', CAST(N'2019-10-03T00:00:00.000' AS DateTime), 100, 0.164, N'01928120')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5277', 1, N'LUNE.FUMEE', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 10, 10.6, N'BOLL VIPER VIPCF')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5277', 2, N'COMB.JET2', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 20, 5.7, N'NON TANCHE MAIS AR')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5277', 3, N'COMB.JET3', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 20, 5.7, N'AR')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5277', 4, N'BOTT.T44', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 1, 95.8, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5277', 5, N'PANT.FOR.FIO_2XL', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 1, 152, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5277', 6, N'GANT_HYDRO9', CAST(N'2019-10-01T00:00:00.000' AS DateTime), 50, 11.2, N'ROSTAING ES25 2122 VERT')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5277', 7, N'BOUC.BIL303L20', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 1, 40, N'DEJA LIVRER POUR REGUL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5277', 9, N'LUNE.BOL_VIPPSI', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 20, 9.8, N'BOLLE VIPER VIPPSI')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5277', 12, N'COQU.CENTS42CE', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 2, 51.52, N'EAGAN CENTURION')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5277', 14, N'COMB.JET5', CAST(N'2019-10-01T00:00:00.000' AS DateTime), 20, 5.5, N'734002BLANC')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5278', 1, N'GANT_HYFLEX10', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 60, 3.7, N'11/618')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5278', 2, N'GANT_HYFLEX11', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 24, 3.7, N'11-618')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5278', 3, N'GANT_HYFLEX9', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 36, 3.7, N'11-618')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5279', 1, N'BUSE_DEBOU17-3/8', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 1, 36, N'9140395')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5279', 2, N'KIT_BROUET.2BRAS', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 1, 145, N'9140396')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5279', 3, N'LANC.DIMLT40090006', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 1, 225, N'9140397')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5279', 4, N'RESE.DIMBC100L', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 1, 435.6, N'9140398')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5279', 5, N'KIT_DIMBF34', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 1, 123.5, N'9140399')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5280', 1, N'PINC.FAC407E', CAST(N'2019-10-03T00:00:00.000' AS DateTime), 1, 40.87, N'FAC470E')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5280', 2, N'BOIT.OUTFACBS.T20', CAST(N'2019-10-03T00:00:00.000' AS DateTime), 1, 52.65, N'FACBS.T20')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5280', 3, N'TOUR.JFACAD.J8VE', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 1, 34.89, N'FACAD.J8VE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5280', 4, N'CLE_MIXCFAC67F.10', CAST(N'2019-11-03T00:00:00.000' AS DateTime), 1, 10.73, N'FAC467F.10')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5280', 5, N'CLE_MIXCFAC67F.13', CAST(N'2019-10-03T00:00:00.000' AS DateTime), 1, 12.82, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5280', 6, N'EQUE.FAC.819.200CLO', CAST(N'2019-10-03T00:00:00.000' AS DateTime), 1, 178.08, N'819.200CLO')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5280', 7, N'FAUS.EQU.FAC817.25', CAST(N'2019-10-03T00:00:00.000' AS DateTime), 1, 65.41, N'FAC817.25')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5280', 8, N'COMP.FACDELA1901.08', CAST(N'2019-10-03T00:00:00.000' AS DateTime), 1, 13.12, N'FAC1901.08')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5280', 9, N'REGL.30CM', CAST(N'2019-12-01T00:00:00.000' AS DateTime), 1, 2.42, N'FAC803.300SLS')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5280', 10, N'PIED_AC_FAC805.2', CAST(N'2019-10-03T00:00:00.000' AS DateTime), 1, 99.98, N'FAC805.2')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5280', 11, N'PINC.FAC491.20G', CAST(N'2019-10-03T00:00:00.000' AS DateTime), 1, 14.36, N'FAC491.20G')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5280', 12, N'PINC.FAC181A.25G', CAST(N'2019-10-03T00:00:00.000' AS DateTime), 1, 16.78, N'FAC181A.25G')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5280', 13, N'POIN.FAC234', CAST(N'2019-10-03T00:00:00.000' AS DateTime), 1, 3.45, N'FAC234')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5280', 14, N'TOUR.J10TOURN.', CAST(N'2019-12-01T00:00:00.000' AS DateTime), 1, 42.17, N'FACAN.J10')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5281', 1, N'FIOU.CHAUF', CAST(N'2019-10-02T00:00:00.000' AS DateTime), 2150, 0.75833, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5282', 1, N'GEL_JAVEL_WC', CAST(N'2019-10-07T00:00:00.000' AS DateTime), 24, 5.9, N'SC0003')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5282', 2, N'LIQU.VAISSEL1L', CAST(N'2019-10-07T00:00:00.000' AS DateTime), 18, 3.58, N'AF00111L')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5282', 3, N'SPRA.DESO', CAST(N'2019-10-07T00:00:00.000' AS DateTime), 6, 11.29, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5282', 4, N'SPRA.DESO', CAST(N'2019-10-07T00:00:00.000' AS DateTime), 12, 10.92, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5283', 1, N'GAZO.', CAST(N'2019-10-08T00:00:00.000' AS DateTime), 5000, 1.191, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5283', 2, N'GNR_BF', CAST(N'2019-10-08T00:00:00.000' AS DateTime), 1000, 0.758, N'BIOFREE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5283', 3, N'SP95E5', CAST(N'2019-10-08T00:00:00.000' AS DateTime), 1000, 1.233, N'00016')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5284', 1, N'CHAU.ORTHO', CAST(N'2019-10-09T00:00:00.000' AS DateTime), 1, 79.9, N'65341786')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5285', 2, N'COUV.BET600', CAST(N'2019-10-16T00:00:00.000' AS DateTime), 1, 22.13, N'CB600')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5285', 3, N'GRAV.0-15', CAST(N'2019-10-08T00:00:00.000' AS DateTime), 1, 41.47, N'G015')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5285', 4, N'VIS_PLACO3.9X35', CAST(N'2019-11-09T00:00:00.000' AS DateTime), 1, 7.06, N'46133081')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5285', 5, N'BLOC_COF20/20/50', CAST(N'2019-11-09T00:00:00.000' AS DateTime), 80, 1.63, N'BL20C')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5285', 6, N'CIME.CE25', CAST(N'2019-11-07T00:00:00.000' AS DateTime), 10, 3.32, N'C25CE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5285', 7, N'FER_TOR10', CAST(N'2019-10-09T00:00:00.000' AS DateTime), 6, 4.601, N'FT10')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5285', 8, N'FER_TOR08', CAST(N'2019-10-09T00:00:00.000' AS DateTime), 11, 3.074, N'FT08')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5285', 9, N'COUV.30', CAST(N'2019-11-09T00:00:00.000' AS DateTime), 9, 7.86, N'RCC30')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5285', 10, N'BURI.BOS1618661000', CAST(N'2019-11-09T00:00:00.000' AS DateTime), 2, 80.78, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5285', 11, N'POIN.BOS2608690106', CAST(N'2019-11-09T00:00:00.000' AS DateTime), 3, 40.73, NULL)
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5285', 12, N'TAXE', CAST(N'2019-08-17T00:00:00.000' AS DateTime), 1, 3.3, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5287', 1, N'SAPI-HACHE70CM', CAST(N'2019-11-07T00:00:00.000' AS DateTime), 1, 47.99, N'JHHSGM')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5287', 2, N'SAPI.STH00008812800', CAST(N'2019-10-09T00:00:00.000' AS DateTime), 1, 19.73, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5287', 3, N'LIME_04MM', CAST(N'2019-10-09T00:00:00.000' AS DateTime), 12, 1.83, N'70504')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5287', 4, N'DISQ.STH41197133100', CAST(N'2019-10-09T00:00:00.000' AS DateTime), 5, 7.612, N'4119133100')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5288', 1, N'GAIN.40VERTE', CAST(N'2019-09-17T00:00:00.000' AS DateTime), 50, 0.55, N'JANO-FLEX40V50')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5288', 2, N'SIRE.WERMA11100075', CAST(N'2019-09-17T00:00:00.000' AS DateTime), 5, 87.81, N'WERMA11100075')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5288', 3, N'BLOC_BRE1159321018', CAST(N'2019-09-16T00:00:00.000' AS DateTime), 1, 17.41, N'BRNN 1159321018')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 1, N'RUBA.SIGNLARG', CAST(N'2019-10-09T00:00:00.000' AS DateTime), 6, 19.43, N'0985899500')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 2, N'TIGE_FIL18AZ', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 50, 3.92, N'095998')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 3, N'ECRO.H18', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 500, 0.34, N'0317 18')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 4, N'ROND.CAR18X36X3', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 100, 0.0956, N'040718')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 6, N'MORT.CH330', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 12, 14.05, N'0912 001 330')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 7, N'PIST.SILMC', CAST(N'2019-10-11T00:00:00.000' AS DateTime), 2, 33.36, N'0891 020 912')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 8, N'LAME_CUTPROF.', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 15, 4.3, N'0703600020')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 9, N'FORE.SDS+20X250', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 4, 67.05, N'XTRON 0648 120 250')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 10, N'MECH.AC18C', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 2, 27.5, N'0628 180')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 11, N'MECH.AC20C', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 2, 34.55, N'0628200')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 12, N'MECH.AC22C', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 2, 41.74, N'0628220')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 14, N'VBA_TFT04X030', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 1, 12.8, N'0155430')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 15, N'VBA_TFT04X060', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 2, 3.28, N'FILETAGE PARTIEL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 16, N'VBA_TFT06X050', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 2, 5.18, N'01551650')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 17, N'VBA_TFT06X070', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 2, 7.06, N'FILETAGE PARTIEL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 18, N'VBA_TFT06X090', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 1, 8.6, N'01551690')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 19, N'VBA_TFT08X110', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 1, 22.2, N'019018120')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 20, N'TENA.250', CAST(N'2019-10-11T00:00:00.000' AS DateTime), 2, 22.92, N'0703713260')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 21, N'TOIL.ABR50X120', CAST(N'2019-10-11T00:00:00.000' AS DateTime), 1, 56, N'0673050120')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 22, N'FORE.SDS+06X110', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 6, 4.68, N'065106110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 23, N'FORE.SDS+06X160', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 6, 5.11, N'0648260160')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 24, N'FORE.SDS+08X110', CAST(N'2019-10-11T00:00:00.000' AS DateTime), 6, 5.82, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 25, N'FORE.SDS+08X160', CAST(N'2019-10-19T00:00:00.000' AS DateTime), 6, 6.61, N'0651 08 160')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 26, N'FORE.SDS+10X110', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 6, 6.88, N'065110110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5289', 27, N'FORE.SDS+10X160', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 6, 7.41, N'0651 10 160')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5290', 1, N'GAZO.LUTZ', CAST(N'2019-10-09T00:00:00.000' AS DateTime), 1000, 1.191, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5290', 2, N'SP95.E5LUTZ', CAST(N'2019-10-09T00:00:00.000' AS DateTime), 1000, 1.233, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5290', 3, N'FIOU.CHAUF', CAST(N'2019-10-09T00:00:00.000' AS DateTime), 2000, 0.71667, N'LUTZELBOURG')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5290', 4, N'FIOU.CHAUF', CAST(N'2019-10-09T00:00:00.000' AS DateTime), 5000, 0.71667, N'PLAN INCLIN')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5291', 1, N'GRIL.AERAT150', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 2, 10.09, N'CARRE 150')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5291', 3, N'WHIT.SPIRIT5', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 4, 15.91, N'WS5')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5291', 4, N'COUT.PEINT7', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 3, 5.73, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5291', 5, N'COUT.PEINT6', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 1, 5.02, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5291', 6, N'SEAU_POLY.12L', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 4, 4.32, N'MO341120')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5291', 7, N'MAST.ACRYL.BLC', CAST(N'2019-09-29T00:00:00.000' AS DateTime), 5, 3.77, N'128783')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5291', 8, N'CIME.CE25', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 1, 3.32, N'C25CE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5291', 9, N'CHAUX_25KGS', CAST(N'2019-10-17T00:00:00.000' AS DateTime), 1, 11.21, N'CHAUX25')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5292', 1, N'TRONC.MS201TCM', CAST(N'2019-10-11T00:00:00.000' AS DateTime), 1, 485, N'STIHL MS201TC-M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5292', 2, N'HACH.80CM', CAST(N'2019-10-10T00:00:00.000' AS DateTime), 1, 65, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5293', 1, N'DISP.HYDROCARBURES', CAST(N'2019-10-14T00:00:00.000' AS DateTime), 6, 70.25, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5293', 2, N'DEBO.1L', CAST(N'2019-10-14T00:00:00.000' AS DateTime), 3, 18.8, N'0206123')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5293', 3, N'COLL.ETTR', CAST(N'2019-10-14T00:00:00.000' AS DateTime), 12, 22.19, N'AMPLIFIXPRO-0205153')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5293', 4, N'MAST.FIXALI', CAST(N'2019-10-28T00:00:00.000' AS DateTime), 12, 22.19, N'MASTIFIXALI-0205152')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5293', 6, N'MAST.290DC', CAST(N'2019-10-14T00:00:00.000' AS DateTime), 12, 16.76, N'0205155')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5293', 7, N'SPRA.DEGI', CAST(N'2019-10-14T00:00:00.000' AS DateTime), 12, 12.02, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5295', 1, N'RUBA.TRANSLUCDE50', CAST(N'2019-10-14T00:00:00.000' AS DateTime), 4, 1.56, N'3M 24482')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5295', 2, N'BOUC.BIL303L20', CAST(N'2019-10-14T00:00:00.000' AS DateTime), 2, 15.73, N'EUPR30202')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5296', 1, N'CIME.CE25', CAST(N'2019-10-15T00:00:00.000' AS DateTime), 320, 2.75, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5296', 2, N'SABL.0/3', CAST(N'2019-10-15T00:00:00.000' AS DateTime), 5, 37, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5296', 3, N'GRAV.0-15', CAST(N'2019-10-15T00:00:00.000' AS DateTime), 5, 36.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5296', 4, N'PORT', CAST(N'2019-10-15T00:00:00.000' AS DateTime), 1, 20, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5297', 1, N'PRIS.SCHENN36030', CAST(N'2019-10-16T00:00:00.000' AS DateTime), 10, 6.684, N'SCH36030')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5297', 2, N'EXTE.COOEXP-PSU', CAST(N'2019-10-16T00:00:00.000' AS DateTime), 2, 192.57, N'COOS3VEXPPSU')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5297', 3, N'BATT.COOSCA00003', CAST(N'2019-10-16T00:00:00.000' AS DateTime), 2, 45.977, N'COOS3VSCA00003')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5297', 4, N'CONN.GGMPLUGIT10G', CAST(N'2019-10-16T00:00:00.000' AS DateTime), 10, 6.8268, N'GGMPLUGIT10G')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5297', 5, N'CONN.W1963590000', CAST(N'2019-10-16T00:00:00.000' AS DateTime), 10, 1.9344, N'WEI1963590000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5297', 6, N'COLL.SCHENN47992', CAST(N'2019-10-15T00:00:00.000' AS DateTime), 2, 16.61, N'SAR47992')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5297', 7, N'GAIN.THERBIZ217004', CAST(N'2019-10-16T00:00:00.000' AS DateTime), 2, 43.87521, N'BIZ217004')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5297', 8, N'GAIN.THER3M85842', CAST(N'2019-10-16T00:00:00.000' AS DateTime), 2, 24.528, N'3M-85842')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5297', 9, N'ADAP.EAD727810', CAST(N'2019-10-16T00:00:00.000' AS DateTime), 4, 14.213, N'EAD727810')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5297', 10, N'CORD.HDMI-5M', CAST(N'2019-10-16T00:00:00.000' AS DateTime), 4, 11.396, N'EAD7882')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5298', 1, N'PAGA.2.1M', CAST(N'2019-10-17T00:00:00.000' AS DateTime), 2, 58.25, N'W09102')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5298', 2, N'GAFF.1.8M', CAST(N'2019-10-17T00:00:00.000' AS DateTime), 1, 12.75, N'M65180')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5298', 3, N'PORT', CAST(N'2019-10-17T00:00:00.000' AS DateTime), 1, 29.17, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5299', 1, N'NITR.1400X10MEP.2MM', CAST(N'2019-10-17T00:00:00.000' AS DateTime), 1, 302, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5299', 2, N'NITR.1400X10MEP.3MM', CAST(N'2019-10-17T00:00:00.000' AS DateTime), 1, 375, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5299', 3, N'NITR.1400X10MEP.4MM', CAST(N'2019-10-17T00:00:00.000' AS DateTime), 1, 446, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5300', 1, N'XENO.TRA252133', CAST(N'2019-10-16T00:00:00.000' AS DateTime), 3, 175, N'252896')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5300', 2, N'PORT', CAST(N'2019-10-16T00:00:00.000' AS DateTime), 1, 15, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5301', 1, N'GROU.HYDRAU', CAST(N'2019-10-16T00:00:00.000' AS DateTime), 1, 4854, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5302', 1, N'MANC.SAPIE40CM', CAST(N'2019-10-17T00:00:00.000' AS DateTime), 1, 6.78, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5302', 2, N'COUT.STH41197134100', CAST(N'2019-10-17T00:00:00.000' AS DateTime), 5, 29.17, N'41197134100')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5303', 1, N'OXYG.10.5M3', CAST(N'2019-10-17T00:00:00.000' AS DateTime), 1, 86, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5304', 1, N'CIME.CE25', CAST(N'2019-10-21T00:00:00.000' AS DateTime), 320, 2.75, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5304', 2, N'PORT', CAST(N'2019-10-21T00:00:00.000' AS DateTime), 1, 20, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5305', 1, N'PEIN.SATBLANC2.5TEINTE', CAST(N'2019-10-21T00:00:00.000' AS DateTime), 2, 49.61, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5305', 2, N'DECA.PV5', CAST(N'2019-10-21T00:00:00.000' AS DateTime), 2, 67, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5305', 3, N'BROS.PEINTRAD40', CAST(N'2019-10-21T00:00:00.000' AS DateTime), 3, 6.88, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5305', 4, N'POUC.R2-21', CAST(N'2019-10-21T00:00:00.000' AS DateTime), 3, 8.253, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5305', 5, N'POUC.R4-25', CAST(N'2019-10-21T00:00:00.000' AS DateTime), 3, 9.143, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5305', 6, N'POUC.R6-29', CAST(N'2019-10-21T00:00:00.000' AS DateTime), 3, 12.79, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5306', 1, N'CONV.AIRA693887', CAST(N'2019-10-22T00:00:00.000' AS DateTime), 1, 282.75, N'AIR A693887')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5306', 2, N'CONV.AIRA693895', CAST(N'2019-10-22T00:00:00.000' AS DateTime), 4, 244.4, N'AIR A693895')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5306', 3, N'CONV.AIRA693817', CAST(N'2019-10-22T00:00:00.000' AS DateTime), 1, 446.55, N'AIR A693817')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5306', 4, N'PROJ.ARI50482', CAST(N'2019-10-22T00:00:00.000' AS DateTime), 1, 57.4, N'ARIC50482')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5307', 1, N'COUP.STH69922956830', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 3, 12.39, N'69922956830')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5307', 2, N'PORT', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 1, 6.02, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5308', 1, N'VERR.105X50I', CAST(N'2019-10-24T00:00:00.000' AS DateTime), 5, 0.81, N'SAFW000335018')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5308', 2, N'AMPO.HALO.H4', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 4, 4.63, N'OSRA64193')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5308', 3, N'CLE_MIXCFAC67F.13', CAST(N'2019-10-24T00:00:00.000' AS DateTime), 1, 11.2, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5308', 4, N'COFF.FACR2NANO', CAST(N'2019-10-24T00:00:00.000' AS DateTime), 1, 124.02, N'FACR2NANO')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5308', 5, N'JEU_CLE_M', CAST(N'2019-10-24T00:00:00.000' AS DateTime), 1, 16.83, NULL)
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5308', 6, N'LAMP.LEDSFM', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 1, 129.14, N'KRA32002')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5308', 7, N'PIST.COLLE', CAST(N'2019-10-24T00:00:00.000' AS DateTime), 1, 78.54, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5308', 8, N'BATT.STARN4', CAST(N'2019-10-24T00:00:00.000' AS DateTime), 1, 66, N'STARN4')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5308', 9, N'PIED_AC_FAC805.1', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 1, 78.73, N'FAC805.1')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5308', 10, N'CURA.MEC133005', CAST(N'2019-10-24T00:00:00.000' AS DateTime), 45, 30, N'MEC133005')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5308', 11, N'CURA.MEC157005', CAST(N'2019-11-13T00:00:00.000' AS DateTime), 40, 28.33, N'MEC157005')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5308', 12, N'CURA.MEC174005', CAST(N'2019-10-24T00:00:00.000' AS DateTime), 10, 27.46, N'174005')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5308', 13, N'COLL.BATONNET', CAST(N'2019-11-13T00:00:00.000' AS DateTime), 1, 14.49, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5309', 1, N'SAND.L100', CAST(N'2019-10-24T00:00:00.000' AS DateTime), 6, 3.55, N'INF492')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5309', 2, N'HUIL.TT+15W40-20', CAST(N'2019-10-24T00:00:00.000' AS DateTime), 60, 4.13, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5309', 3, N'TUYA.REF50', CAST(N'2019-10-24T00:00:00.000' AS DateTime), 6, 10.71, N'EQ0900017')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5309', 4, N'COLL.SERRAGE50', CAST(N'2019-10-24T00:00:00.000' AS DateTime), 2, 4.25, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5309', 5, N'BATT.FUL30', CAST(N'2019-10-24T00:00:00.000' AS DateTime), 1, 146, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5309', 6, N'DOUI.FACNM.50A', CAST(N'2019-10-24T00:00:00.000' AS DateTime), 2, 47.29, N'FACNM.50A')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5309', 7, N'PIED_AC_FAC805.2', CAST(N'2019-10-24T00:00:00.000' AS DateTime), 1, 98.01, N'FAC805.2')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5309', 8, N'TOUR.JFACATHH.JS5', CAST(N'2019-10-24T00:00:00.000' AS DateTime), 1, 41.55, N'FACATHH.JS5')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5309', 9, N'COFF.FACSL.DBOX1PB', CAST(N'2019-10-24T00:00:00.000' AS DateTime), 1, 135.27, N'FACSL.DBOX1PB')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5309', 10, N'CLE_MOL.FAC113A.12CG', CAST(N'2019-11-24T00:00:00.000' AS DateTime), 1, 26.44, N'FAC113A.12CG')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5310', 1, N'GAZO.', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 1200, 1.216, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5310', 2, N'SP95E5', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 2000, 1.263, N'00016')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5310', 3, N'GNR_BF', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 1429, 0.775, N'BIOFREE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 2, N'BLOC_EPHE8.2X12DG', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 2, 0.84, N'64992')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 3, N'CALE.12M', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 28, 1.66, N'66179-43X63')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 4, N'CALE.2X6M', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 5, 0.63, N'52097- 38X54')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 5, N'AGRA.N10', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 10, 0.19, N'10107')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 6, N'PUNA.', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 4, 0.77, N'13239')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 7, N'REGL.30', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 3, 3.84, N'18010')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 8, N'PAPI.A4JAUNE', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 3, 4.19, N'15841')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 11, N'STYL.G-2N', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 24, 1.06, N'40454')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 13, N'FEUT.V5NOIR', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 12, 1.16, N'01121')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 14, N'POCH.POLYA4', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 5, 6.83, N'62886')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 15, N'SURL.JNE', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 10, 0.57, N'01423')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 16, N'CLE_USB08G', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 5, 4.14, N'72822')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 17, N'CLE_USB32G', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 3, 7.24, N'20319')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 18, N'CART.SAM_MLTD203LEL', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 2, 101.25, N'23206')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 19, N'DATE.AUTO', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 1, 4.04, N'75762 SANS PLAQUE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 20, N'TABL.LIEG90X120', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 1, 28.98, N'18832')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 21, N'POST_IT38X51', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 1, 6.39, N'55760')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 22, N'POST_IT76X76', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 2, 1.82, N'64403')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 23, N'INTE.A4_ALPHA.', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 6, 0.76, N'11265')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 24, N'PAPI.A3BLEU', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 5, 8.38, N'36816')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 25, N'ENVE.BL110.X220 PB', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 1, 1.23, N'24121')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 26, N'ENVE.K162.X229', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 1, 12.89, N'64443')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 27, N'FICH.TBLANC', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 2, 1.37, N'07230')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 28, N'FICH.TBLEU', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 1, 1.37, N'07231')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 29, N'FICH.TJAUNE', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 2, 1.37, N'07234')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 30, N'FICH.TROUGE', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 3, 1.37, N'07236')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 32, N'ETIQ.A70X37', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 1, 4.34, N'64629')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 33, N'AGRA.DB24/26-40F', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 1, 10.48, N'84907')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 34, N'COUV.A4-CI', CAST(N'2019-11-20T00:00:00.000' AS DateTime), 2, 4.14, N'64204')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 35, N'CAHI.A4', CAST(N'2019-10-23T00:00:00.000' AS DateTime), 6, 0.46, N'64164')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5311', 36, N'FICH.TROSE', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 2, 1.37, N'07236')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5312', 1, N'SIEG.VERSL4000', CAST(N'2019-10-25T00:00:00.000' AS DateTime), 4, 400, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5313', 1, N'CHEV.PARCR4X32', CAST(N'2019-10-25T00:00:00.000' AS DateTime), 400, 0.1364, N'A506110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5313', 3, N'BARR.MINE2M', CAST(N'2019-10-25T00:00:00.000' AS DateTime), 1, 92.28, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5313', 4, N'GRIL.AERAT140_MOUSTQ', CAST(N'2019-10-25T00:00:00.000' AS DateTime), 2, 10.66, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5313', 5, N'REDU.PVC100/80EXC', CAST(N'2019-10-25T00:00:00.000' AS DateTime), 1, 4.18, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5313', 6, N'REDU.PVC80/63', CAST(N'2019-10-25T00:00:00.000' AS DateTime), 1, 4.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5313', 7, N'CIME.CE25', CAST(N'2019-11-23T00:00:00.000' AS DateTime), 80, 3.32, N'C25CE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5313', 8, N'POIN.SDSMAX', CAST(N'2019-10-25T00:00:00.000' AS DateTime), 1, 22.39, N'2608690167')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5313', 9, N'POIN.SDS+', CAST(N'2019-10-25T00:00:00.000' AS DateTime), 1, 14.79, N'2608690145')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5313', 10, N'SEAU_MAON11', CAST(N'2019-10-25T00:00:00.000' AS DateTime), 1, 9.32, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5313', 11, N'CHEV.B12/10', CAST(N'2019-10-25T00:00:00.000' AS DateTime), 50, 1.692, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5313', 12, N'CHEV.COL10X62', CAST(N'2019-11-23T00:00:00.000' AS DateTime), 4, 5.78, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5313', 13, N'VBA_TCF6X70', CAST(N'2019-10-25T00:00:00.000' AS DateTime), 4, 10.67, N'FLASH AUTO PERFORANTES')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5313', 14, N'SABL.ROUTE', CAST(N'2019-12-01T00:00:00.000' AS DateTime), 8, 42.79, N'1D')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5313', 15, N'GRIL.AV.BLANC100', CAST(N'2019-10-25T00:00:00.000' AS DateTime), 2, 22, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5314', 1, N'VERR.ARNOV', CAST(N'2019-10-28T00:00:00.000' AS DateTime), 2, 34.41, N'139790')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5314', 2, N'CLE_DPPP1', CAST(N'2019-10-28T00:00:00.000' AS DateTime), 5, 10.86, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5314', 3, N'CYLI.30X30/PG', CAST(N'2019-10-28T00:00:00.000' AS DateTime), 1, 35.44, N'PG PP1 PP2')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5314', 4, N'CYLI.30X60/PG', CAST(N'2019-10-28T00:00:00.000' AS DateTime), 1, 55.81, N'PG PP1')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5314', 5, N'CYLI.30X65/PG', CAST(N'2019-10-28T00:00:00.000' AS DateTime), 1, 58.8, N'PG PP1')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5314', 6, N'CADE.S''ENTR40', CAST(N'2019-10-28T00:00:00.000' AS DateTime), 11, 8.24, N'169837')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5314', 7, N'FRAI_FONCT-FACT', CAST(N'2019-11-17T00:00:00.000' AS DateTime), 1, 4.57, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5315', 1, N'BACH.PROSILO', CAST(N'2019-10-29T00:00:00.000' AS DateTime), 2, 83, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5315', 2, N'TIGE_FIL18AZ', CAST(N'2019-10-29T00:00:00.000' AS DateTime), 50, 6.15, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5315', 3, N'ROND.CAR18X36X3', CAST(N'2019-10-29T00:00:00.000' AS DateTime), 400, 0.1, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5317', 1, N'AGEN.MINIST.SP', CAST(N'2019-10-28T00:00:00.000' AS DateTime), 17, 11.82, N'49998')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5317', 2, N'PAPI.A4BLANC', CAST(N'2019-10-28T00:00:00.000' AS DateTime), 100, 2.64, N'58429')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5317', 3, N'PAPI.A3JAUNE', CAST(N'2019-10-28T00:00:00.000' AS DateTime), 5, 8.38, N'15847')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5317', 4, N'FEUT.V5BLEU', CAST(N'2019-10-28T00:00:00.000' AS DateTime), 12, 1.16, N'01120')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5318', 1, N'MORT.WEBVM216', CAST(N'2019-10-28T00:00:00.000' AS DateTime), 192, 19.71, N'WEBER BROUTIN VM216')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5318', 2, N'MORT.WEBVM216', CAST(N'2019-10-28T00:00:00.000' AS DateTime), 48, 19.71, N'WEBER BROUTIN VM216')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5319', 1, N'BROS.PEINT30', CAST(N'2019-10-29T00:00:00.000' AS DateTime), 3, 2.32, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5319', 2, N'BROS.PEINT40', CAST(N'2019-10-29T00:00:00.000' AS DateTime), 3, 3.16, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5319', 3, N'BROS.PEINT50', CAST(N'2019-10-29T00:00:00.000' AS DateTime), 3, 4.02, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5319', 4, N'BROS.PEINT60', CAST(N'2019-10-29T00:00:00.000' AS DateTime), 3, 5.8, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5319', 5, N'BROS.PEINT70', CAST(N'2019-10-29T00:00:00.000' AS DateTime), 3, 7.71, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5319', 6, N'BROS.PEINT80', CAST(N'2019-10-29T00:00:00.000' AS DateTime), 2, 9.46, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5319', 7, N'CALE_APAP', CAST(N'2019-10-29T00:00:00.000' AS DateTime), 2, 7.52, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5319', 8, N'GARN.P120', CAST(N'2019-10-29T00:00:00.000' AS DateTime), 50, 0.78, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5319', 9, N'GARN.P80', CAST(N'2019-10-29T00:00:00.000' AS DateTime), 50, 0.78, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5319', 10, N'GARN.P100', CAST(N'2019-10-29T00:00:00.000' AS DateTime), 50, 0.58, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5319', 11, N'BROS.PEINTRAD40', CAST(N'2019-10-29T00:00:00.000' AS DateTime), 4, 4.09, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5319', 12, N'MANC.180_12MM', CAST(N'2019-10-29T00:00:00.000' AS DateTime), 8, 10.23, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5319', 13, N'MANC.70_12MM', CAST(N'2019-10-29T00:00:00.000' AS DateTime), 12, 2.26, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5319', 14, N'RECH.CAMION7L', CAST(N'2019-10-29T00:00:00.000' AS DateTime), 2, 11.78, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5319', 15, N'RECH.CAMION14L', CAST(N'2019-10-29T00:00:00.000' AS DateTime), 1, 19.16, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5319', 16, N'BROS.PEINTRAD35', CAST(N'2019-10-29T00:00:00.000' AS DateTime), 2, 3.86, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5320', 1, N'CORN.AC120X12', CAST(N'2019-11-04T00:00:00.000' AS DateTime), 18.3, 21.6, NULL)
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5322', 1, N'DEMA.CLA05111613360', CAST(N'2019-11-04T00:00:00.000' AS DateTime), 1, 381.89, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5323', 1, N'SPRA.COKP', CAST(N'2019-11-04T00:00:00.000' AS DateTime), 12, 11.68, N'AS POLISH 35-0202261')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5323', 2, N'SCHA.BIO5', CAST(N'2019-11-04T00:00:00.000' AS DateTime), 4, 47.7, N'BIOTEC')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5323', 3, N'CHIF.BLANC', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 4, 35.35, N'0109497')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5323', 4, N'TAMP.', CAST(N'2019-11-04T00:00:00.000' AS DateTime), 40, 1.542, N'0109123 - SPONTEX')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5323', 5, N'COLL.CYANO', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 2, 20.26, N'0205123')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5323', 6, N'RACL.VIT35', CAST(N'2019-11-04T00:00:00.000' AS DateTime), 3, 18.95, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5323', 7, N'MOUI.35', CAST(N'2019-11-04T00:00:00.000' AS DateTime), 3, 27.99, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5323', 9, N'PAPI.E/M_TORK', CAST(N'2019-11-04T00:00:00.000' AS DateTime), 36, 2.312, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5323', 10, N'TAPI.COCO60X80', CAST(N'2019-11-15T00:00:00.000' AS DateTime), 2, 40.23, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5324', 1, N'BROD.T40', CAST(N'2019-11-05T00:00:00.000' AS DateTime), 1, 123.6, N'JALMARS S3')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5324', 2, N'BOTT.T44', CAST(N'2019-11-05T00:00:00.000' AS DateTime), 2, 86, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5324', 3, N'BOTT.FOURRET40_S3', CAST(N'2019-11-05T00:00:00.000' AS DateTime), 1, 95, N'AGZ000115607')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5324', 4, N'PORT', CAST(N'2019-12-04T00:00:00.000' AS DateTime), 1, 35, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5325', 1, N'FIOU.CHAUF', CAST(N'2019-11-05T00:00:00.000' AS DateTime), 900, 0.725, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5325', 2, N'GAZO.', CAST(N'2019-11-05T00:00:00.000' AS DateTime), 1938, 1.194, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5326', 1, N'CHAM.L2T', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 10, 143, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5326', 2, N'COUV.POUR_L2T', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 10, 148.6, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5326', 3, N'TUYA.56X60TELECOM', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 150, 1.35, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5326', 4, N'GRIL.AV.BLANC100', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 2, 11, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5327', 1, N'CAGO.SOUDURE', CAST(N'2019-11-05T00:00:00.000' AS DateTime), 1, 984.54, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5328', 1, N'ANOD.PLA38390', CAST(N'2019-11-07T00:00:00.000' AS DateTime), 10, 79.9, N'PLA38390')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5329', 1, N'COTT.ORE295454/L', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 2, 93.58, N'295454/L')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5329', 2, N'GANT_TRONC.L', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 2, 27.42, N'295485/L')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5329', 3, N'GANT_TRONC.M', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 2, 27.42, N'295485/M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5329', 4, N'VEST.FOR.L', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 4, 287.5, N'582332254')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5329', 5, N'CHAU.YUKT39', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 1, 102.17, N'295449/39')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5329', 6, N'CHAU.YUKT42', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 1, 102.17, N'295449/42')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5329', 7, N'CHAU.YUKT43', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 1, 102.17, N'295449/43')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5329', 8, N'CHAU.YUKT45', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 2, 102.17, N'295449/45')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5329', 9, N'CASQ.HUS562413', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 2, 42.8333, N'562413')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5329', 10, N'MANC.TRON.', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 7, 45.42, N'572332')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5329', 11, N'PANT.FOR.ORE295453L', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 1, 76.42, N'295453/L YUKON')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5330', 4, N'LUNE.FUMEE', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 20, 10.6, N'BOLL VIPER VIPCF')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5330', 6, N'GANT_TRONC.L', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 10, 22.5, N'ZIMMER 2XD3 REF 6041')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5330', 7, N'GANT_TRONC.M', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 10, 22.5, N'ZIMMER 2XD3 REF 6041')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5330', 8, N'GANT_TRONC.XL', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 10, 22.5, N'ZIMMER 2XD3 REF 6041')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5330', 10, N'GANT_FOREST.10', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 30, 19.2, N'SIP 2SA3 -T10 REF:4333')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5330', 11, N'SANG.AR5M1T2DGEC', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 5, 12, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5330', 12, N'ELIN.EL3T4M', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 2, 14, N'TUB03T04M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5330', 13, N'MOUS.60MM', CAST(N'2019-11-06T00:00:00.000' AS DateTime), 10, 0.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5330', 14, N'MANI.DRTE2TO', CAST(N'2019-11-07T00:00:00.000' AS DateTime), 4, 7.2, N'MDGS2T000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5331', 1, N'OXYG.10.5M3', CAST(N'2019-12-07T00:00:00.000' AS DateTime), 1, 86, N'AIRL110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5331', 2, N'ACET.6M3', CAST(N'2019-12-07T00:00:00.000' AS DateTime), 1, 153, N'AIRL310')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5331', 3, N'OXYG.4.2M3', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 1, 67.5, N'AIRL150')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5331', 4, N'ACET.3M3', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 1, 95, N'M20')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5331', 5, N'ARCA.11.5M3', CAST(N'2018-04-27T00:00:00.000' AS DateTime), 1, 138, N'ARL894')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 1, N'CHEV.8X46', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 9, 6.77, N'FISC555008')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 2, N'CHEV.6X30', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 14, 5.03, N'FISC555006')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 3, N'CHEV.10X60', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 1, 6.88, N'FISC-555010')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 4, N'CHEV.BASC', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 2, 21.86, N'FISH061040')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 5, N'FICH.LEG050632', CAST(N'2019-09-18T00:00:00.000' AS DateTime), 2, 2.82, N'LEG50632')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 6, N'AMPO.60W_E27', CAST(N'2019-11-12T00:00:00.000' AS DateTime), 3, 5.1, N'301.2017.6')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 7, N'TAXE', CAST(N'2019-08-23T00:00:00.000' AS DateTime), 3, 0.16, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 8, N'DETE.STE034702', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 1, 30, N'STEINEL034702')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 9, N'PROJ.MEG_MM07698', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 2, 267.75, N'MEGA-MM07698')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 10, N'CABL.R2V3G2.5', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 200, 0.7, N'U1000R2VCU3G2.5')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 11, N'DENU.CABLE', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 2, 35.09, N'CARLT30155')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 12, N'CLE_ROB394013', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 1, 32.87, N'ROB394013')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 13, N'TEST.DEX_C818083', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 3, 38.5, N'DEXL-C818083')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 14, N'TOUR.ROB412103', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 5, 134.45, N'ROB412103')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 15, N'TOUR.JROB412100', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 2, 33.44, N'ROB 412100')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 16, N'COFF.AGI221001', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 2, 97.2, N'ROB-221001')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 17, N'TEST.AGI221171', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 3, 3.21, N'ROBUR-221171')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 18, N'FORE.SDSM22X200', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 4, 41.21, N'SPIT')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 19, N'DISJ.SCHA9F77440', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 1, 125.42, N'SCHA9F77440')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 20, N'DISJ.SCHA9Q11440', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 1, 185.02, N'SCH A9Q11440')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 21, N'CORD.DISP_HDMI5M', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 4, 34.75, N'RS1828791')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 22, N'PORT', CAST(N'2019-11-07T00:00:00.000' AS DateTime), 1, 10, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 23, N'CONN.PHO1414394', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 10, 6.1, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5332', 24, N'CHEV.PARCR4X32', CAST(N'2019-11-12T00:00:00.000' AS DateTime), 100, 0.2481, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5333', 1, N'PANT.FOR.ORE295453/M', CAST(N'2019-11-07T00:00:00.000' AS DateTime), 4, 76.42, N'YUKON')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5333', 2, N'PANT.FOR.ORE295453L', CAST(N'2019-12-06T00:00:00.000' AS DateTime), 6, 76.42, N'295453/L YUKON')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5333', 3, N'PANT.FOR.ORE295453/XL', CAST(N'2019-12-06T00:00:00.000' AS DateTime), 4, 76.42, N'295453/XL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5333', 4, N'CASQ.HUS562413', CAST(N'2019-11-07T00:00:00.000' AS DateTime), 5, 42.8333, N'562413')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5333', 5, N'CHAU.YUKT40', CAST(N'2019-11-07T00:00:00.000' AS DateTime), 1, 102.16, N'295449/40')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5333', 6, N'CHAU.YUKT41', CAST(N'2019-11-07T00:00:00.000' AS DateTime), 3, 102.16, N'295449/41')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5333', 7, N'CHAU.YUKT42', CAST(N'2019-11-07T00:00:00.000' AS DateTime), 1, 102.16, N'295449/42')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5333', 8, N'CHAU.YUKT43', CAST(N'2019-11-07T00:00:00.000' AS DateTime), 6, 102.16, N'295449/43')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5333', 9, N'CHAU.YUKT44', CAST(N'2019-11-07T00:00:00.000' AS DateTime), 3, 102.16, N'295449/44')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5334', 1, N'AMPO.150W_E40', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 6, 19, N'LEDVANCE024400')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5334', 2, N'COFF.JCL2000', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 6, 244.68, N'JCL 2000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5334', 3, N'PORT', CAST(N'2019-11-07T00:00:00.000' AS DateTime), 1, 40, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5335', 1, N'ENRO.3G2.5-40', CAST(N'2019-11-10T00:00:00.000' AS DateTime), 2, 151.49, N'1136951')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5335', 2, N'AMPO.40W_E14_R50', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 10, 9.92, N'LAMDA-32248814')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5335', 3, N'AMPO.2W', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 10, 2.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5335', 4, N'GOUL.LEG075601', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 30, 15.88, N'LEG75601')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5335', 5, N'PRIS.LEG077101', CAST(N'2019-11-08T00:00:00.000' AS DateTime), 8, 10.45, N'LEG077101')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5335', 6, N'PRIS.LEG076546', CAST(N'2019-11-10T00:00:00.000' AS DateTime), 2, 17.85, N'LEG076546')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5335', 7, N'PRIS.LEG077103', CAST(N'2019-11-10T00:00:00.000' AS DateTime), 2, 18.22, N'LEG077103')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5335', 8, N'CORD.LEG078730', CAST(N'2019-11-10T00:00:00.000' AS DateTime), 2, 8.6, N'LEGR-078730')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5335', 9, N'CABL.CAT6', CAST(N'2019-11-07T00:00:00.000' AS DateTime), 60, 0.57, N'CDL1 01248960')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5335', 10, N'LAMP.LED30W_G1', CAST(N'2019-11-10T00:00:00.000' AS DateTime), 2, 49, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5335', 11, N'INTE.HAG04505', CAST(N'2019-11-10T00:00:00.000' AS DateTime), 1, 86.65, N'HAGER 04505')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5337', 1, N'TROU.ASEP_P35', CAST(N'2019-11-13T00:00:00.000' AS DateTime), 25, 28.64, N'05112019')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5337', 2, N'KIT_PHARMA10', CAST(N'2019-11-13T00:00:00.000' AS DateTime), 4, 65.44, N'ASEP 05112019')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5338', 1, N'CABL.RNF5G4', CAST(N'2019-11-14T00:00:00.000' AS DateTime), 200, 2.8, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5338', 2, N'GAIN.40TPC25M', CAST(N'2019-11-14T00:00:00.000' AS DateTime), 8, 13.75, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5339', 1, N'VIS_THPAB18X320', CAST(N'2019-11-25T00:00:00.000' AS DateTime), 100, 8.65, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5339', 2, N'ROND.CAR18X36X3', CAST(N'2019-11-25T00:00:00.000' AS DateTime), 100, 0.16, NULL)
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5339', 3, N'ECRO.H18', CAST(N'2019-11-19T00:00:00.000' AS DateTime), 100, 0.25, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5340', 1, N'FIOU.CHAUF', CAST(N'2019-11-18T00:00:00.000' AS DateTime), 2000, 0.794, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5341', 1, N'GAZO.', CAST(N'2019-11-18T00:00:00.000' AS DateTime), 2500, 1.213, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5342', 1, N'CABO.6FONCTIONS', CAST(N'2019-11-19T00:00:00.000' AS DateTime), 2, 7.21, N'SOD16109')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5342', 2, N'FEU_INF2231', CAST(N'2019-11-19T00:00:00.000' AS DateTime), 1, 12.18, N'INF2231')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5342', 3, N'FEU_4 FONC.REM', CAST(N'2019-11-18T00:00:00.000' AS DateTime), 1, 2.4, N'INF102')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5342', 4, N'BOIT.SOD03200', CAST(N'2019-11-19T00:00:00.000' AS DateTime), 1, 2.77, N'SOD3200')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5342', 5, N'DORS.', CAST(N'2019-11-19T00:00:00.000' AS DateTime), 1, 0, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5342', 6, N'HUIL.COUPE5L', CAST(N'2019-11-19T00:00:00.000' AS DateTime), 1, 58.1, N'MEC525005')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5343', 1, N'TUYA.ASPI25', CAST(N'2019-11-18T00:00:00.000' AS DateTime), 5, 10.65, N'0800016')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5343', 2, N'TUYA.ASPI32', CAST(N'2019-11-18T00:00:00.000' AS DateTime), 5, 16.6, N'0800016')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5343', 3, N'COLL.TOUR32-35', CAST(N'2019-11-18T00:00:00.000' AS DateTime), 2, 1.31, N'760011')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5343', 4, N'COLL.TOUR40-43', CAST(N'2019-11-18T00:00:00.000' AS DateTime), 2, 1.44, N'7600013')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5343', 5, N'DEMI_RAC.ALU32F', CAST(N'2019-11-18T00:00:00.000' AS DateTime), 2, 5.83, N'1980616')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5343', 6, N'DEMI_RAC.ALU25', CAST(N'2019-11-18T00:00:00.000' AS DateTime), 2, 5.83, N'1980653')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5343', 7, N'COUP.TUB_SAM620-12', CAST(N'2019-11-18T00:00:00.000' AS DateTime), 1, 72, N'5001433')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5343', 8, N'RACC.GAZ1/4M+B', CAST(N'2019-11-18T00:00:00.000' AS DateTime), 1, 4.49, N'6410192')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5343', 9, N'PIST.GONFSTD', CAST(N'2019-11-18T00:00:00.000' AS DateTime), 1, 97.34, N'6410445')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5343', 10, N'DISQ.115F1', CAST(N'2019-11-18T00:00:00.000' AS DateTime), 50, 3.25, N'5040064')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5343', 11, N'PORT', CAST(N'2019-11-28T00:00:00.000' AS DateTime), 1, 22, N'PORT ET EMBALLAGE USINE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5344', 1, N'VIS_THP20X 90_10.9', CAST(N'2019-11-20T00:00:00.000' AS DateTime), 100, 1.65, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5344', 2, N'ECRO.H20_10.9', CAST(N'2019-11-20T00:00:00.000' AS DateTime), 100, 0.6, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5344', 3, N'ROND.GR20', CAST(N'2019-11-20T00:00:00.000' AS DateTime), 100, 0.2, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5345', 1, N'CAGO.SOUDURE', CAST(N'2019-11-20T00:00:00.000' AS DateTime), 1, 984.54, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5346', 1, N'PANT.STH00008886244', CAST(N'2019-11-20T00:00:00.000' AS DateTime), 1, 84.08, N'00008886244')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5346', 2, N'PANT.STH00008886248', CAST(N'2019-11-20T00:00:00.000' AS DateTime), 2, 84.08, N'00008886248')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5346', 3, N'PANT.STH00008886252', CAST(N'2019-11-20T00:00:00.000' AS DateTime), 1, 84.08, N'00008886252')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5346', 4, N'MANC.TRON.', CAST(N'2019-11-20T00:00:00.000' AS DateTime), 2, 45.42, N'572332')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5346', 5, N'GANT_TRONC.M', CAST(N'2019-12-19T00:00:00.000' AS DateTime), 2, 27.42, N'295485/M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5346', 6, N'GANT_TRONC.L', CAST(N'2019-12-19T00:00:00.000' AS DateTime), 2, 27.42, N'295485/L')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5346', 7, N'GANT_TRONC.XL', CAST(N'2019-12-19T00:00:00.000' AS DateTime), 2, 27.42, N'295485/XL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5346', 8, N'COTT.FOR.ORE295453/L', CAST(N'2019-12-19T00:00:00.000' AS DateTime), 1, 93.58, N'295454/L')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5347', 1, N'LASU.IG3', CAST(N'2019-11-20T00:00:00.000' AS DateTime), 1, 21.88, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5347', 2, N'BROS.PEINT50', CAST(N'2019-11-20T00:00:00.000' AS DateTime), 1, 3.22, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5347', 3, N'BROS.PEINT20', CAST(N'2019-11-20T00:00:00.000' AS DateTime), 1, 1.71, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5348', 1, N'LEVI.SCHZC2JY31', CAST(N'2019-11-21T00:00:00.000' AS DateTime), 6, 9.811, N'SCH ZC2JY31')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5348', 2, N'CORP.SCHZC2JC1', CAST(N'2019-11-21T00:00:00.000' AS DateTime), 6, 43.83, N'SCHZC2JC1')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5348', 3, N'TETE_SCHZC2JE01', CAST(N'2019-11-21T00:00:00.000' AS DateTime), 6, 30.01, N'SCH ZC2JC1')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5348', 4, N'CONN.MUR11598100', CAST(N'2019-11-21T00:00:00.000' AS DateTime), 25, 1.625, N'MUR11598100')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5349', 1, N'ELEC.DS800_2,5', CAST(N'2019-11-21T00:00:00.000' AS DateTime), 1, 210.5, N'OS200.25')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5350', 2, N'COMB.JET3', CAST(N'2019-11-22T00:00:00.000' AS DateTime), 30, 5.5, N'ETANCHE ET ARE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5350', 3, N'COMB.JET4', CAST(N'2019-11-21T00:00:00.000' AS DateTime), 30, 5.5, N'ETANCHE ET ARE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5351', 1, N'ENRO.3G2.5-40', CAST(N'2019-11-24T00:00:00.000' AS DateTime), 2, 151.49, N'1136951')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5351', 2, N'SORT.LEG069888', CAST(N'2019-11-22T00:00:00.000' AS DateTime), 10, 3.05, N'LEG069888')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5351', 3, N'CORD.DEXC852542', CAST(N'2019-11-22T00:00:00.000' AS DateTime), 5, 2.3, N'DEX-C852542')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5351', 4, N'CORD.DEXC856830', CAST(N'2019-11-22T00:00:00.000' AS DateTime), 5, 2.4, N'DEX-856830')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5351', 5, N'CORD.DEXC852512', CAST(N'2019-11-22T00:00:00.000' AS DateTime), 5, 2.3, N'DEX-C852512')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5351', 6, N'CORD.DEXC854222', CAST(N'2019-11-22T00:00:00.000' AS DateTime), 5, 1.52, N'DEX-C854222')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5351', 7, N'CORD.DEXC854182', CAST(N'2019-11-22T00:00:00.000' AS DateTime), 5, 1.52, N'DEX-C854182')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5351', 8, N'CORD.DEXC852572', CAST(N'2019-11-22T00:00:00.000' AS DateTime), 5, 2.3, N'DEX-C852572')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5351', 9, N'CORD.DEXC854203', CAST(N'2019-11-22T00:00:00.000' AS DateTime), 5, 1.9, N'DEX-C854203')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5351', 10, N'CORD.DEXC852533', CAST(N'2019-11-22T00:00:00.000' AS DateTime), 5, 2.94, N'DEX-C852533')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5351', 11, N'CORD.DEXC854193', CAST(N'2019-11-22T00:00:00.000' AS DateTime), 5, 1.9, N'DEX-C854193')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5351', 12, N'CORD.DEXC856847', CAST(N'2019-11-22T00:00:00.000' AS DateTime), 5, 3.1, N'DEX-C856847')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5351', 13, N'CORD.DEXC856852', CAST(N'2019-11-22T00:00:00.000' AS DateTime), 5, 3.1, N'DEX-C856852')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5351', 14, N'CORD.DEXC854243', CAST(N'2019-11-22T00:00:00.000' AS DateTime), 5, 1.9, N'DEX-C854243')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5351', 15, N'MODU.SCHBMXDDO3202K', CAST(N'2019-12-23T00:00:00.000' AS DateTime), 1, 290.99, N'BMXDDO3202K')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5351', 16, N'CART.SCHBMXCPS2000', CAST(N'2019-11-22T00:00:00.000' AS DateTime), 1, 165.21, N'BMXCPC2000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5351', 17, N'COFF.LEG058951', CAST(N'2019-12-23T00:00:00.000' AS DateTime), 1, 484.99, N'LEG058951')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5352', 1, N'PNEU_11.5-80-14PLY', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 2, 183.3, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5352', 2, N'CHAM.11.5/12-5X15', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 2, 25.58, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5352', 3, N'MO_MAT.AGRI', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 2, 18.6, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5353', 1, N'POMP.ENGRENAGE_GR', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 2, 425, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5353', 2, N'LANT.POMPE250/110/453', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 2, 450, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5353', 3, N'ACCO.SPIDEX_A28/38', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 2, 675, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5353', 4, N'MOTE.2.2KW1450TR/MIN', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 2, 610, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5353', 5, N'LIMI.24VDC', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 1, 420, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5353', 6, N'CLAP.S10A05', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 1, 180, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5353', 7, N'ACCO.BASE_GROUPE', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 1, 580, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5353', 8, N'MOTE.4KW1450TR/MIN', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 1, 470, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5354', 1, N'GEL_DOUCHE', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 10, 5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5354', 2, N'LAVE_PONT_CH.', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 1, 15.75, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5354', 3, N'LING.90', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 6, 18.46, N'TH0026')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5354', 4, N'LIQU.VAISSEL1L', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 24, 3.58, N'AF00111L')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5354', 5, N'SAVO.GEL350', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 24, 3.5, N'TP0026')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5354', 6, N'PAST.URINOIR', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 4, 11.74, N'US0004')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5354', 7, N'BLOC_WC', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 20, 3.46, N'APN0063')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5354', 8, N'PAPI.TOIL380M', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 12, 2.95, N'TL0008')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5354', 9, N'DESO.MECHE', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 20, 4.44, N'ASSORTIMENT')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5354', 10, N'AB50', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 2, 66.44, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5354', 11, N'BROS.WC+R.', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 6, 10, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5354', 12, N'PEIN.SPGALV', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 6, 11.2, N'AF0016')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5354', 13, N'SPRA.NETT.FR', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 12, 4.88, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5354', 14, N'SPRA.DECO', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 6, 13.2, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5354', 15, N'SPRA.DEGRIP', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 12, 9.68, N'AF0020')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5354', 16, N'CHIF.BLANC', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 2, 30.6, N'COTON 100%')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5354', 17, N'TAPI.COCO40X80', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 2, 15.88, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5354', 18, N'TAPI.CAILL60X80', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 3, 36.04, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5354', 19, N'TAMP.', CAST(N'2019-11-26T00:00:00.000' AS DateTime), 20, 2.312, N'HA0130')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5355', 1, N'PAPI.E/M_BLC1000', CAST(N'2019-11-27T00:00:00.000' AS DateTime), 108, 15.49, N'380MX24CMX18GR/M - 9111666')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5356', 1, N'FICH.HANOUKA13X40', CAST(N'2019-12-03T00:00:00.000' AS DateTime), 16, 4.04, N'22660')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5356', 2, N'LOQU.4GK', CAST(N'2019-12-03T00:00:00.000' AS DateTime), 5, 1.12, N'23962')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5356', 3, N'CISE.BOIS8MM', CAST(N'2019-12-03T00:00:00.000' AS DateTime), 1, 16, N'216383')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5356', 4, N'CISE.BOIS10MM', CAST(N'2019-12-03T00:00:00.000' AS DateTime), 1, 16.25, N'216384')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5356', 5, N'SCIE_DOS300MM', CAST(N'2019-12-03T00:00:00.000' AS DateTime), 1, 16.58, N'82D')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5356', 6, N'COFF.FRT', CAST(N'2019-12-03T00:00:00.000' AS DateTime), 1, 40, N'2607019578')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5356', 7, N'TASS.SAPIN28X72', CAST(N'2019-12-03T00:00:00.000' AS DateTime), 9, 7.83, N'TPN240.28.72S')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5356', 8, N'LAME.20', CAST(N'2019-12-03T00:00:00.000' AS DateTime), 1, 61.48, N'29D')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5356', 9, N'PANN.MDF19MM', CAST(N'2019-12-03T00:00:00.000' AS DateTime), 4, 55.81, N'27D')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5356', 10, N'COLL.BOISINTEXT', CAST(N'2020-01-10T00:00:00.000' AS DateTime), 1, 10.89, N'108768')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5357', 1, N'LAVE_GLACE2LH', CAST(N'2019-12-04T00:00:00.000' AS DateTime), 15, 4.47, N'0217104-2')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5357', 2, N'DESO.CLIP_MEL.', CAST(N'2019-12-04T00:00:00.000' AS DateTime), 30, 10.73, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5357', 3, N'PAPI.TOIL380M', CAST(N'2019-12-04T00:00:00.000' AS DateTime), 24, 5.826, N'0102110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5357', 4, N'ESSU.MAIN_KIM6763', CAST(N'2019-12-04T00:00:00.000' AS DateTime), 120, 4.949, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5357', 5, N'ESSU.TOUT', CAST(N'2019-12-04T00:00:00.000' AS DateTime), 72, 1.3575, N'0102146')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5357', 6, N'VERR.BC', CAST(N'2019-12-14T00:00:00.000' AS DateTime), 1, 80.84, N'HG10')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5357', 7, N'SPRA.DESO', CAST(N'2019-12-04T00:00:00.000' AS DateTime), 6, 16.38, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5357', 8, N'INSE.POMP.', CAST(N'2019-12-04T00:00:00.000' AS DateTime), 24, 16.37, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5357', 9, N'LING.WC', CAST(N'2019-12-04T00:00:00.000' AS DateTime), 24, 12.98, N'HARPIC')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5357', 10, N'NETT.SURFACE', CAST(N'2019-12-04T00:00:00.000' AS DateTime), 12, 15.2, N'BACTIPAL PRO-0207170')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5357', 11, N'CHIF.BLANC', CAST(N'2020-01-04T00:00:00.000' AS DateTime), 2, 35.35, N'0109497')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5357', 12, N'MAST.FIXALI', CAST(N'2019-12-18T00:00:00.000' AS DateTime), 12, 22.19, N'MASTIFIXALI-0205152')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5357', 13, N'SPRA.NETT.FR', CAST(N'2019-12-22T00:00:00.000' AS DateTime), 12, 11.82, N'ASFORNET-0202113')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5357', 15, N'TRAC.ORANGE', CAST(N'2019-12-04T00:00:00.000' AS DateTime), 12, 17.3, N'AS LINER -0202120OF')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5357', 16, N'BALA.CANT.', CAST(N'2019-12-04T00:00:00.000' AS DateTime), 2, 12.22, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5357', 17, N'LAVE_PONT_NYL', CAST(N'2019-12-04T00:00:00.000' AS DateTime), 8, 15.51, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5357', 18, N'MANC.LPF', CAST(N'2019-12-04T00:00:00.000' AS DateTime), 8, 15.62, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 1, N'AGGL.20/20/50', CAST(N'2019-12-04T00:00:00.000' AS DateTime), 70, 1.31, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 2, N'PREL.10', CAST(N'2019-12-12T00:00:00.000' AS DateTime), 2.8, 10.6, N'SPL10')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 3, N'CIME.CE25', CAST(N'2020-01-03T00:00:00.000' AS DateTime), 69, 3.32, N'C25CE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 4, N'CHAUX_35KGS', CAST(N'2019-12-04T00:00:00.000' AS DateTime), 2, 9.21, N'CHAUX35')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 5, N'PALE.TYPE_F', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 1, 19.8, N'G+FRAIS')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 6, N'TURB.AG120MM', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 1, 15.95, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 7, N'WHIT.SPIRIT5', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 8, 15.91, N'WS5')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 8, N'VBA_TFT05X050', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 2, 11.48, N'46478861')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 9, N'VBA_TFT05X060', CAST(N'2020-01-04T00:00:00.000' AS DateTime), 2, 11.74, N'46435239')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 10, N'VBA_TFT05X070', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 2, 16.9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 11, N'VBA_TFT06X040', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 2, 13.4, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 12, N'GANT_MT9', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 30, 3.49, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 13, N'GANT_MT10', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 30, 3.49, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 15, N'FORE.SDS+08X210', CAST(N'2020-01-12T00:00:00.000' AS DateTime), 10, 7.63, N'10501970')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 16, N'CUTT.PROF', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 10, 17.34, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 17, N'MESU.3ML', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 5, 4.57, N'033522')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 18, N'METR.POL.', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 10, 5.74, N'035458')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 19, N'LAME_CUTPROF.', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 10, 4.61, N'030697')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 20, N'PELL.NEIGE', CAST(N'2020-01-05T00:00:00.000' AS DateTime), 5, 21.01, N'196511')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 21, N'PELL+MANCHE', CAST(N'2019-11-24T00:00:00.000' AS DateTime), 6, 15.79, N'130271')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 22, N'LAME_CUTPOCHE', CAST(N'2020-01-04T00:00:00.000' AS DateTime), 6, 2.7, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 23, N'JONC.AQU19L', CAST(N'2020-01-05T00:00:00.000' AS DateTime), 2, 9.24, N'51373')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 24, N'SILI.SAN.BLC', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 5, 7.37, N'102252')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 25, N'SILI.NEUT.BLC', CAST(N'2020-01-02T00:00:00.000' AS DateTime), 5, 8.18, N'128795')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 26, N'SILI.NEUT.GRIS', CAST(N'2019-10-11T00:00:00.000' AS DateTime), 5, 8.18, N'110252')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 27, N'SILI.NEUT.TRANS', CAST(N'2019-12-22T00:00:00.000' AS DateTime), 5, 8.18, N'128796')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 28, N'MESU.5ML', CAST(N'2019-12-04T00:00:00.000' AS DateTime), 5, 7.8, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 29, N'METR.ALU', CAST(N'2020-01-05T00:00:00.000' AS DateTime), 2, 10.94, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 30, N'DISQ.230DIAM', CAST(N'2020-01-12T00:00:00.000' AS DateTime), 1, 88.12, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5358', 31, N'ACCU_18V', CAST(N'2020-01-03T00:00:00.000' AS DateTime), 1, 82.8, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5359', 1, N'PAPI.E/M_BLC1000', CAST(N'2019-12-04T00:00:00.000' AS DateTime), 108, 15.49, N'380MX24CMX18GR/M - 9111666')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5359', 2, N'FORE.SDSM65X310', CAST(N'2019-12-04T00:00:00.000' AS DateTime), 1, 379.35, N'5020272')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5359', 3, N'DISQ.180DIAMCA', CAST(N'2020-01-02T00:00:00.000' AS DateTime), 2, 79.75, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5360', 1, N'BOIT.SCHENN05004', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 10, 2.19, N'SCHENN05004')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5360', 2, N'BORN.WAG221415', CAST(N'2019-10-25T00:00:00.000' AS DateTime), 3, 74.5, N'WAGO222415')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5360', 3, N'BOIT.SCHENN05005', CAST(N'2019-12-04T00:00:00.000' AS DateTime), 15, 4.05, N'SCHENN05005')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5360', 4, N'GAIN.ICTA20', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 1, 28.4, N'ARNX 05120')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5360', 5, N'GAIN.ICTA25', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 1, 39.9, N'ARNX05125')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5360', 6, N'PILE_LR6', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 30, 2.73, N'8280 40066211354')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5360', 7, N'PILE_LR03', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 30, 2.8, N'CIPE 116816')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5360', 8, N'PILE_CR2016', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 10, 1.65, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5360', 9, N'PILE_LR44', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 10, 2.37, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5360', 10, N'RUBA.INOIR19', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 20, 7.9, N'3M80021')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5360', 11, N'CORD.RJ45CAT7-20M', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 6, 49.66, N'C850036')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5360', 12, N'CORD.RJ45CAT7-10M', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 6, 27.72, N'HORNC850024')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5360', 13, N'CABL.R2V3G1.5', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 200, 0.49, N'U1000R2VCU3G1.5')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5360', 14, N'ENRO.3G2.5-40', CAST(N'2019-12-07T00:00:00.000' AS DateTime), 2, 151.49, N'1136951')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5360', 15, N'COLL.SCHENN47962', CAST(N'2019-10-15T00:00:00.000' AS DateTime), 2, 14.75, N'SCHENN47962')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5360', 16, N'COLL.SCHENN47930', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 2, 27.13, N'ENN47930')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5360', 17, N'FICH.CM10/16A', CAST(N'2019-08-28T00:00:00.000' AS DateTime), 10, 5.13, N'LEG050445')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5360', 18, N'FICH.CM10/16AALL', CAST(N'2019-08-28T00:00:00.000' AS DateTime), 10, 3.15, N'BRNN1375641')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5360', 19, N'PROJ.30WLED', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 1, 39.9, N'BRNN1171600202')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5360', 20, N'RUBA.INOIR15', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 30, 0.864, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5360', 21, N'DOMI.10MM', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 10, 2.08, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5360', 22, N'MECH.AC10', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 10, 14.96, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5360', 23, N'FORE.SDS+08X210', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 10, 7.16, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5361', 1, N'BOUC.MOULE', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 13, 175.2, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5361', 2, N'KIT_AXIUM', CAST(N'2019-12-05T00:00:00.000' AS DateTime), 13, 40.95, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5361', 3, N'PORT', CAST(N'2020-01-03T00:00:00.000' AS DateTime), 1, 139.71, N'PORT + INTERVENTION')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019--5361', 4, N'GANT_FOREST.9', CAST(N'2019-12-04T00:00:00.000' AS DateTime), 30, 19.2, N'SIP 2SA3-T9')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-560', 1, N'PEIN.SOLBLANC5', CAST(N'2019-02-12T00:00:00.000' AS DateTime), 1, 47.23, N'AXION BLANC')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-560', 2, N'PEIN.SOLRAL6025', CAST(N'2019-02-12T00:00:00.000' AS DateTime), 1, 65.6, N'AXION TEINTE T0 RAL6025')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-560', 3, N'PEIN.SOLRAL5001', CAST(N'2019-02-12T00:00:00.000' AS DateTime), 1, 72.31, N'AXION TEINTE T5 RAL 5001')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-560', 4, N'PEIN.SOLRAL2012', CAST(N'2019-02-12T00:00:00.000' AS DateTime), 1, 81.45, N'AXION TEINTE T8 RAL2012')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-560', 5, N'DILU.N5L', CAST(N'2019-02-12T00:00:00.000' AS DateTime), 1, 51.65, N'EST')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-560', 6, N'PORT', CAST(N'2019-02-12T00:00:00.000' AS DateTime), 1, 60, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-563', 1, N'FEU_BABORD', CAST(N'2019-02-13T00:00:00.000' AS DateTime), 1, 34.583, N'INTL41046')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-563', 2, N'FEU_TRIBORD', CAST(N'2019-02-13T00:00:00.000' AS DateTime), 2, 34.583, N'INTL41044')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-563', 3, N'PORT', CAST(N'2019-02-17T00:00:00.000' AS DateTime), 1, 10.708, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-600', 1, N'CONT.PERAPPARAU', CAST(N'2019-02-12T00:00:00.000' AS DateTime), 1, 360, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-600', 2, N'CONT.PERENGLEVAGE', CAST(N'2019-02-12T00:00:00.000' AS DateTime), 1, 566, N'ENGINS DE LEVAGE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-600', 3, N'CONT.PERENGLEVAGE', CAST(N'2019-02-12T00:00:00.000' AS DateTime), 1, 1100, N'ENGINS DE LEVAGE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-600', 4, N'CONT.PERECHEL', CAST(N'2019-02-12T00:00:00.000' AS DateTime), 1, 466, N'SARREGUEMINES +MITTERSHEIM')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-600', 5, N'CONT.PERAPPARAU', CAST(N'2019-02-12T00:00:00.000' AS DateTime), 1, 676, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-600', 7, N'EASY_CLIP', CAST(N'2019-02-12T00:00:00.000' AS DateTime), 1, 120, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-600', 8, N'CONT.PERPORTESEC', CAST(N'2019-02-12T00:00:00.000' AS DateTime), 1, 350, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-601', 1, N'ANTI_GRAFFITI', CAST(N'2019-02-12T00:00:00.000' AS DateTime), 1, 148.2, N'EFIGRAFF NW')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-601', 2, N'KIT_NETTOYAGE', CAST(N'2019-02-12T00:00:00.000' AS DateTime), 1, 139.45, N'RUB969')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-601', 3, N'PULV.1.5L', CAST(N'2019-02-12T00:00:00.000' AS DateTime), 2, 37.72, N'MA008')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-601', 4, N'REPU.MART.', CAST(N'2019-02-12T00:00:00.000' AS DateTime), 6, 19.33, N'R2 GEL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-601', 5, N'RATI.', CAST(N'2019-02-12T00:00:00.000' AS DateTime), 100, 2.52, N'51432')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-601', 6, N'RUBA.SIGN', CAST(N'2019-02-12T00:00:00.000' AS DateTime), 10, 3.89, N'RM204')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-601', 7, N'RUBA.TOILE', CAST(N'2019-02-12T00:00:00.000' AS DateTime), 6, 7, N'RM309N50')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-602', 1, N'COLL.INTISSE20', CAST(N'2019-02-06T00:00:00.000' AS DateTime), 1, 21, N'PROGOLD053')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-602', 2, N'COLL.INTISSE5', CAST(N'2019-02-06T00:00:00.000' AS DateTime), 1, 8.42, N'PROGOLD054')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-602', 4, N'COUT.MAROUF', CAST(N'2019-02-06T00:00:00.000' AS DateTime), 3, 1.89, N'4001329000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-602', 5, N'ROUL.COLLEUR', CAST(N'2019-02-06T00:00:00.000' AS DateTime), 2, 4.37, N'4001420000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-602', 9, N'MANC.70ACR', CAST(N'2019-02-06T00:00:00.000' AS DateTime), 2, 9.89, N'MONI327210')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-602', 10, N'BROS.PEINT40', CAST(N'2019-02-06T00:00:00.000' AS DateTime), 3, 3.54, N'PROGOLD034')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-602', 11, N'BROS.PEINT50', CAST(N'2019-02-06T00:00:00.000' AS DateTime), 5, 4.83, N'PROGOLD035')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-602', 12, N'BROS.PEINT8', CAST(N'2019-02-06T00:00:00.000' AS DateTime), 2, 11.27, N'4002836000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-602', 13, N'POUC.6-29', CAST(N'2019-02-06T00:00:00.000' AS DateTime), 5, 8.94, N'PROGOLD043')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-602', 14, N'BROS.A_ENCOLLER', CAST(N'2019-02-06T00:00:00.000' AS DateTime), 1, 22.25, N'MONI492145')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-602', 15, N'BROS.A_TAPISSER', CAST(N'2019-02-06T00:00:00.000' AS DateTime), 1, 2.75, N'4002880000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-602', 16, N'COUT.PEINT6', CAST(N'2019-02-06T00:00:00.000' AS DateTime), 1, 7.38, N'4002880000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-602', 17, N'COUT.PEINT8', CAST(N'2019-02-06T00:00:00.000' AS DateTime), 1, 8.65, N'40018710000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-602', 18, N'PEIN.GAU_G6215GLYCIL', CAST(N'2019-02-06T00:00:00.000' AS DateTime), 1, 143.85, N'30B4VTP15L')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-602', 19, N'PEIN.GAU_G4025', CAST(N'2019-02-06T00:00:00.000' AS DateTime), 1, 143.85, N'30B4VTP15L')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-602', 22, N'TOIL.FIBRE_MUR50X1', CAST(N'2019-02-08T00:00:00.000' AS DateTime), 1, 65, N'TOILT1011N')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-602', 23, N'GRIL.CAM14L_TOLE', CAST(N'2019-02-08T00:00:00.000' AS DateTime), 3, 1.32, N'NESP526180')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-602', 24, N'GRIL.CAM7L_TOLE', CAST(N'2019-02-09T00:00:00.000' AS DateTime), 3, 0.81, N'4001971000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-602', 25, N'PEIN.SATBLANC5', CAST(N'2019-02-06T00:00:00.000' AS DateTime), 3, 50.15, N'30B4VBC05L')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-757', 1, N'GABI.1000/1000/1000', CAST(N'2019-02-18T00:00:00.000' AS DateTime), 12, 78.97, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-763', 1, N'SPRA.NETT.FR', CAST(N'2019-02-18T00:00:00.000' AS DateTime), 24, 7.88, N'60533')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-763', 2, N'SPRA.DEGRIP', CAST(N'2019-02-18T00:00:00.000' AS DateTime), 18, 9.41, N'60504')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-763', 3, N'PEIN.SPGALV', CAST(N'2019-02-18T00:00:00.000' AS DateTime), 6, 20.32, N'60506')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-763', 4, N'SPRA.SOUD', CAST(N'2019-02-18T00:00:00.000' AS DateTime), 3, 13.9, N'CLIMAPIE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-763', 5, N'SPRA.MOUS.NDD', CAST(N'2019-02-18T00:00:00.000' AS DateTime), 6, 15.96, N'60512')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-764', 1, N'GRAI.INT.LS1/2', CAST(N'2019-02-18T00:00:00.000' AS DateTime), 1, 420.4, N'8896')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-764', 2, N'GRAI.INT.LS1/2C', CAST(N'2019-02-23T00:00:00.000' AS DateTime), 24, 24.65, N'8894')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-764', 3, N'SPRA.LUBR.INTFLTF', CAST(N'2016-04-14T00:00:00.000' AS DateTime), 12, 20.05, N'9074')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-764', 4, N'PORT', CAST(N'2019-02-25T00:00:00.000' AS DateTime), 1, 15, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-765', 1, N'GAZO.', CAST(N'2019-02-18T00:00:00.000' AS DateTime), 1500, 1.23, N'GRAND FROID')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-765', 2, N'SP95E5', CAST(N'2019-02-18T00:00:00.000' AS DateTime), 1999, 1.248, N'00016')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-770', 1, N'CLE_MIXFAC40.13', CAST(N'2019-02-21T00:00:00.000' AS DateTime), 1, 3.88, N'FAC440-13')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-770', 2, N'CLE_ART.FAC467F-13', CAST(N'2019-02-21T00:00:00.000' AS DateTime), 1, 12.82, N'FAC.467F-13')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-770', 3, N'BATT.STARN5', CAST(N'2019-01-25T00:00:00.000' AS DateTime), 2, 93, N'STARN5')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-770', 4, N'CURA.MEC174005', CAST(N'2019-02-21T00:00:00.000' AS DateTime), 5, 27.46, N'174005')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-770', 5, N'BAND.REFLEC.G+D10M', CAST(N'2019-02-21T00:00:00.000' AS DateTime), 1, 263.9, N'16418')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-770', 6, N'SAC_KAR69074790', CAST(N'2019-01-04T00:00:00.000' AS DateTime), 2, 21, N'KAR69074790')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-770', 8, N'PIPE.KST150.9221', CAST(N'2019-02-21T00:00:00.000' AS DateTime), 1, 21.72, N'KS150.9221')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-770', 9, N'SOUF.BUSE_110', CAST(N'2019-02-21T00:00:00.000' AS DateTime), 1, 13.96, N'PREV27102MTL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-770', 10, N'RACC.GAZ1/4M', CAST(N'2019-02-21T00:00:00.000' AS DateTime), 1, 2.73, N'PREVIRP066151')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-771', 1, N'CORD.POLY6', CAST(N'2019-02-21T00:00:00.000' AS DateTime), 100, 0.09, N'ACCD')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-771', 2, N'MANI.DRTE2TO', CAST(N'2019-02-22T00:00:00.000' AS DateTime), 4, 6.1, N'MDGS2T000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-771', 3, N'BAC_BEC_METAL28L', CAST(N'2019-02-22T00:00:00.000' AS DateTime), 10, 46.8, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-776', 1, N'POMP.HON06193ZV1000', CAST(N'2019-03-02T00:00:00.000' AS DateTime), 1, 122.58, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-776', 2, N'HELI.HON58130ZV1940ZB', CAST(N'2019-03-02T00:00:00.000' AS DateTime), 1, 102.94, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-776', 3, N'PORT', CAST(N'2019-03-02T00:00:00.000' AS DateTime), 1, 45.83, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-827', 1, N'RACC.RFA', CAST(N'2019-02-01T00:00:00.000' AS DateTime), 2, 31.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-827', 2, N'RACC.RFO', CAST(N'2019-02-01T00:00:00.000' AS DateTime), 2, 31.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-827', 3, N'RACC.RMA', CAST(N'2019-02-01T00:00:00.000' AS DateTime), 2, 22.3, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-827', 4, N'RACC.RMO', CAST(N'2019-02-01T00:00:00.000' AS DateTime), 2, 22.3, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-827', 5, N'ETAI.ARGENT', CAST(N'2019-02-01T00:00:00.000' AS DateTime), 1, 95.35, N'B1031.15')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-827', 6, N'DISQ.LAM110X40', CAST(N'2019-02-01T00:00:00.000' AS DateTime), 10, 9.34, N'8050')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-887', 1, N'ARMO.OUTIL1000X1000', CAST(N'2019-02-22T00:00:00.000' AS DateTime), 3, 409, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-889', 1, N'CARN.DE_CONSTAT', CAST(N'2019-02-20T00:00:00.000' AS DateTime), 15, 29.27, N'411720')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2019-889', 2, N'PORT', CAST(N'2019-02-20T00:00:00.000' AS DateTime), 1, 30.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0002', 1, N'ECRO.ROUE', CAST(N'2019-12-11T00:00:00.000' AS DateTime), 12, 1.36, N'FEB46709')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0002', 3, N'TABL.SOUDEUR', CAST(N'2019-12-11T00:00:00.000' AS DateTime), 1, 30.59, N'GYS045217')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0002', 4, N'TRIF.500LEDS', CAST(N'2019-12-11T00:00:00.000' AS DateTime), 1, 245, N'SOD16435')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0003', 1, N'BATT.FUL33', CAST(N'2020-01-14T00:00:00.000' AS DateTime), 2, 175, N'FULMEN')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0003', 2, N'BATT.FUL32', CAST(N'2020-01-14T00:00:00.000' AS DateTime), 1, 110, N'FULMEN32')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0003', 3, N'BROC_VERS5L', CAST(N'2020-01-14T00:00:00.000' AS DateTime), 1, 19.14, N'ALGI07480000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0003', 4, N'ENTO.PR160', CAST(N'2020-01-14T00:00:00.000' AS DateTime), 4, 6.78, N'ALGI07491000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0003', 5, N'TOUR.J10TOURN.', CAST(N'2020-03-13T00:00:00.000' AS DateTime), 1, 66.49, N'FACAN.J10')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0003', 6, N'BATT.FULA770', CAST(N'2020-03-13T00:00:00.000' AS DateTime), 1, 110, N'FULMFA770')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0003', 7, N'PRES.AMPOULES', CAST(N'2020-03-13T00:00:00.000' AS DateTime), 1, 240, N'OSRA510316')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0003', 8, N'TUYA.ESS6', CAST(N'2020-03-13T00:00:00.000' AS DateTime), 2, 8.13, N'DAY80490')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020--0003', 1, N'CIME.PROMPT25', CAST(N'2019-12-11T00:00:00.000' AS DateTime), 2, 22.65, N'VIC25')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020--0003', 2, N'PILE_CR2032', CAST(N'2019-01-02T00:00:00.000' AS DateTime), 1, 1.93, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020--0003', 3, N'PIST.MOUSSE_PU', CAST(N'2020-01-02T00:00:00.000' AS DateTime), 1, 40.76, N'PBMP')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020--0003', 4, N'MOUS.PUPIST.', CAST(N'2020-01-02T00:00:00.000' AS DateTime), 2, 8.03, N'53389')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020--0003', 5, N'VISS.BOSGSB18V-60C', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 1, 219, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020--0003', 6, N'MEUL.BOSGWS18V-10PC', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 1, 239, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020--0003', 7, N'KIT_ACCU+CHARG18V6.0AH', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 1, 225.04, N'1600A00B8L')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020--0003', 8, N'TAXE', CAST(N'2019-11-10T00:00:00.000' AS DateTime), 3, 0.42, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0004', 1, N'GAZ_BUT.VRAC', CAST(N'2020-01-26T00:00:00.000' AS DateTime), 1.303, 1880.3, N'PROPANE CITERNE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0005', 1, N'COUP.ECH69922956830', CAST(N'2020-01-15T00:00:00.000' AS DateTime), 3, 12.39, N'69922956830')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0005', 2, N'PORT', CAST(N'2020-01-15T00:00:00.000' AS DateTime), 1, 6.02, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0005', 3, N'GUID.STH30050004813', CAST(N'2020-01-15T00:00:00.000' AS DateTime), 2, 55.28, N'30050004813')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0005', 4, N'CHAI.ORE91VXL055E', CAST(N'2020-01-15T00:00:00.000' AS DateTime), 4, 12.5, N'91VXL055E')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0006', 1, N'FIOU.CHAUF', CAST(N'2020-01-15T00:00:00.000' AS DateTime), 7000, 0.74167, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0007', 1, N'CHAI.STH36100030044', CAST(N'2020-01-15T00:00:00.000' AS DateTime), 5, 12.5, N'90PX044E')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0007', 2, N'CHAI.STH39970030050', CAST(N'2020-02-25T00:00:00.000' AS DateTime), 20, 12.5, N'91VXL050E')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0007', 3, N'GOUJ.ESSIEU14', CAST(N'2020-01-15T00:00:00.000' AS DateTime), 4, 3.82, N'200494')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0007', 4, N'BRET.ORE537804', CAST(N'2020-02-25T00:00:00.000' AS DateTime), 14, 13.3083, N'OREGON 537804')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0007', 5, N'MEMB.STH11291214800', CAST(N'2020-02-25T00:00:00.000' AS DateTime), 2, 8.47, N'11291214800')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0007', 6, N'POIN.STH41161215100', CAST(N'2020-02-25T00:00:00.000' AS DateTime), 1, 8.43, N'41161215100')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0007', 7, N'RESS.STH11281223000', CAST(N'2020-02-25T00:00:00.000' AS DateTime), 1, 3.29, N'11281223000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0007', 8, N'LEVI.STH11251215000', CAST(N'2020-02-25T00:00:00.000' AS DateTime), 5, 3.96, N'11251215000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0007', 9, N'PIGN.STH11236402073', CAST(N'2020-02-25T00:00:00.000' AS DateTime), 1, 20.35, N'11236402073')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0007', 10, N'GOUJ.RTN', CAST(N'2020-02-25T00:00:00.000' AS DateTime), 4, 8.8, N'RTN14X150')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0007', 11, N'FILT.STH11391201602', CAST(N'2020-02-25T00:00:00.000' AS DateTime), 1, 13.15, N'11391201602')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0007', 12, N'PORT', CAST(N'2020-01-15T00:00:00.000' AS DateTime), 1, 11, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0008', 3, N'BATT.12V12AH', CAST(N'2020-01-16T00:00:00.000' AS DateTime), 1, 36.79, N'YUASA NP12-12')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0008', 4, N'PROJ.50WLED', CAST(N'2020-02-15T00:00:00.000' AS DateTime), 3, 46.93, N'BRNN1171250532')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0008', 5, N'PROJ.ARI50482', CAST(N'2020-01-16T00:00:00.000' AS DateTime), 1, 58.5, N'ARIC50482')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0008', 6, N'PROJ.ARI50483', CAST(N'2020-01-16T00:00:00.000' AS DateTime), 1, 105.95, N'ARI 50483')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0009', 1, N'REPA.MATERIEL', CAST(N'2020-01-16T00:00:00.000' AS DateTime), 1, 128.3, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0010', 1, N'CORD.POLY04.5', CAST(N'2020-01-16T00:00:00.000' AS DateTime), 2, 26.9, N'RAJA-MFP53')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0010', 4, N'PROJ.ARI50482', CAST(N'2020-01-16T00:00:00.000' AS DateTime), 3, 58.5, N'ARIC50482')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0010', 5, N'PROJ.ARI50483', CAST(N'2020-01-16T00:00:00.000' AS DateTime), 3, 105.95, N'ARI 50483')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0010', 6, N'BATT.COOSCA00003', CAST(N'2020-01-16T00:00:00.000' AS DateTime), 5, 61.82, N'SCA00003')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0010', 7, N'PORT', CAST(N'2020-01-15T00:00:00.000' AS DateTime), 1, 41.9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0010', 8, N'CORD.DEXC128921', CAST(N'2020-01-16T00:00:00.000' AS DateTime), 6, 8.4, N'DEX C128921')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0010', 9, N'CORD.DEXC128146', CAST(N'2020-01-16T00:00:00.000' AS DateTime), 6, 33.9, N'DEX 128146')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0010', 10, N'CONV.DEXC127424', CAST(N'2020-01-16T00:00:00.000' AS DateTime), 6, 30.8, N'DEXLAN C127424')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0010', 11, N'CONN.LINK_CON_EZSLC6F', CAST(N'2020-01-16T00:00:00.000' AS DateTime), 100, 0.649, N'LINK-CON-EZSLC6F')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0011', 1, N'ANNE.DL1.3TO_ARTEON', CAST(N'2020-01-16T00:00:00.000' AS DateTime), 4, 39, N'ARTEON1T3')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0011', 2, N'ELIN.CH2X1.3ML8MM', CAST(N'2020-01-16T00:00:00.000' AS DateTime), 1, 92, N'ELCH062BCLG')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0012', 1, N'FRAI.MAK.PJ7000J', CAST(N'2020-01-17T00:00:00.000' AS DateTime), 1, 290, N'MAKITA PJ7000J')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0012', 2, N'SCIE_MIL.M18FHZ-0X', CAST(N'2020-01-17T00:00:00.000' AS DateTime), 1, 195.07, N'ATLA 4933459887')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0012', 3, N'LAME_SAB.CARB230', CAST(N'2020-01-17T00:00:00.000' AS DateTime), 1, 79.2, N'ATLA48005502')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0012', 4, N'LAME_SAB.SET12PCES', CAST(N'2020-01-17T00:00:00.000' AS DateTime), 2, 45.69, N'ATLA49222229')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0012', 5, N'SCIE_MIL.M18FSX-0C', CAST(N'2020-01-17T00:00:00.000' AS DateTime), 1, 369, N'ATLA')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0012', 6, N'PROJ.MIL.M18HSAL-0', CAST(N'2020-01-17T00:00:00.000' AS DateTime), 1, 399, N'MILWAUKEE M18HSAL-0')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0013', 1, N'INTE.SCHBN31-10RZ-5', CAST(N'2020-01-17T00:00:00.000' AS DateTime), 35, 58.7, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0013', 2, N'AIMA.SCHBP20', CAST(N'2020-01-17T00:00:00.000' AS DateTime), 35, 26, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0014', 1, N'RESI.3M92802', CAST(N'2020-01-17T00:00:00.000' AS DateTime), 5, 53.51, N'3MFR-92802')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0014', 2, N'CONN.POU980535', CAST(N'2020-01-17T00:00:00.000' AS DateTime), 2, 27, N'POUYET 980535')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0014', 3, N'HUBL.LED7.7W', CAST(N'2020-01-17T00:00:00.000' AS DateTime), 8, 24, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0014', 4, N'ECO_TAXE', CAST(N'2020-01-17T00:00:00.000' AS DateTime), 8, 0.16, N'ECO TAXE COMMUTATEUR')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0015', 1, N'PEIN.SATBLANC10TEINTE', CAST(N'2020-01-16T00:00:00.000' AS DateTime), 2, 106.38, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0015', 2, N'PEIN.SATBLANC10TEINTE', CAST(N'2020-01-16T00:00:00.000' AS DateTime), 1, 106.38, N'TEINTE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0015', 3, N'PEIN.SATBLANC10TEINTE', CAST(N'2020-01-16T00:00:00.000' AS DateTime), 2, 106.38, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0016', 1, N'CABL.R2V5G2.5', CAST(N'2020-02-16T00:00:00.000' AS DateTime), 500, 1.1, N'CDL1 01360822')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0017', 1, N'GOUJ.ESSIEU14', CAST(N'2020-01-17T00:00:00.000' AS DateTime), 4, 3.24, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0017', 2, N'PORT', CAST(N'2020-01-17T00:00:00.000' AS DateTime), 1, 9.9, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0018', 1, N'JANT.4J13', CAST(N'2020-01-18T00:00:00.000' AS DateTime), 1, 33.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0018', 2, N'PNEU_145/80R13', CAST(N'2020-01-18T00:00:00.000' AS DateTime), 2, 49.16, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0019', 1, N'GRAI.CONDAKRON_XHD2', CAST(N'2020-01-17T00:00:00.000' AS DateTime), 3, 248.26, N'CONDAKRON XHD2-50')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0021', 1, N'DIST.PT_MX', CAST(N'2020-02-04T00:00:00.000' AS DateTime), 23, 35.88, N'0103999')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0021', 2, N'DIST.SAV350ML', CAST(N'2020-01-24T00:00:00.000' AS DateTime), 36, 40.81, N'ALPHAMOUSS2-0103134 BLANC')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0021', 3, N'PAPI.TOIL380M', CAST(N'2020-01-17T00:00:00.000' AS DateTime), 48, 5.826, N'0102110')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0021', 4, N'SAVO.GEL350', CAST(N'2020-01-17T00:00:00.000' AS DateTime), 72, 9.45, N'0216147')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0022', 1, N'ELIN.EL2T3M', CAST(N'2020-01-18T00:00:00.000' AS DateTime), 2, 11.5, N'TUB02T03M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0022', 2, N'SANG.2T3M', CAST(N'2020-01-17T00:00:00.000' AS DateTime), 2, 12, N'B602T3M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0022', 3, N'SANG.AR9M5TDGSR', CAST(N'2020-01-17T00:00:00.000' AS DateTime), 4, 12, N'SANGLAR2T09MDR')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0022', 4, N'CORD.POLY6', CAST(N'2020-01-17T00:00:00.000' AS DateTime), 100, 0.09, N'ACCD')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0022', 5, N'CORD.POLY12', CAST(N'2020-01-18T00:00:00.000' AS DateTime), 100, 0.496, N'ACCD')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0022', 6, N'CORD.POLY18', CAST(N'2020-01-18T00:00:00.000' AS DateTime), 100, 0.68, N'ACCD')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0022', 7, N'ELIN.EL2T1M', CAST(N'2020-01-18T00:00:00.000' AS DateTime), 4, 4, N'TUB02T01M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0022', 8, N'ELIN.EL2T2M', CAST(N'2020-01-17T00:00:00.000' AS DateTime), 2, 6.2, N'TUB02T02M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0022', 9, N'ELIN.EL3T1M', CAST(N'2020-01-17T00:00:00.000' AS DateTime), 1, 5.4, N'TUB03T01M')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0022', 10, N'MAIL.RAP.ON6MM', CAST(N'2020-01-18T00:00:00.000' AS DateTime), 10, 1.2, N'ACCD')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0022', 11, N'MOUS.60MM', CAST(N'2020-01-17T00:00:00.000' AS DateTime), 10, 0.3, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0022', 12, N'BAC_600X400X320+C', CAST(N'2020-01-18T00:00:00.000' AS DateTime), 4, 48, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0023', 1, N'EAU_0.5/12', CAST(N'2020-01-20T00:00:00.000' AS DateTime), 144, 3.56, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0023', 2, N'EAU_1.5L', CAST(N'2020-01-29T00:00:00.000' AS DateTime), 84, 3.52, N'CRISTALINE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0024', 1, N'MORT.SAKVKT30KGS', CAST(N'2020-01-21T00:00:00.000' AS DateTime), 30, 9.99, N'6062')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0024', 2, N'CIME.CE25', CAST(N'2020-01-21T00:00:00.000' AS DateTime), 56, 3.19, N'6061')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0024', 3, N'SABL.0/3', CAST(N'2020-01-21T00:00:00.000' AS DateTime), 1.6, 22.45, N'5732')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0024', 4, N'MORT.WEBREPEXPRESS', CAST(N'2020-01-21T00:00:00.000' AS DateTime), 24, 46.06, N'28768')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0024', 5, N'PALE.TYPE_F', CAST(N'2020-01-21T00:00:00.000' AS DateTime), 3, 19.52, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0025', 1, N'RACC.PARK299-0135', CAST(N'2020-01-23T00:00:00.000' AS DateTime), 2, 17.36, N'PAR19248-6-6')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0025', 2, N'TUYA.HYD_PARK2CH-6', CAST(N'2020-01-23T00:00:00.000' AS DateTime), 0.8, 19.66, N'PARBCH-2-2')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0025', 3, N'LAVE_GLACE5LH', CAST(N'2020-01-23T00:00:00.000' AS DateTime), 8, 6.44, N'DIFRLG5')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0025', 4, N'COFF.KRA4900-47K', CAST(N'2020-01-23T00:00:00.000' AS DateTime), 1, 224.88, N'KRA4900-47K')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0025', 5, N'HUIL.TT+15W40-20', CAST(N'2020-01-23T00:00:00.000' AS DateTime), 20, 4.13, N'LABO600454821')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0026', 1, N'BAND.HJN51MM', CAST(N'2020-01-28T00:00:00.000' AS DateTime), 2, 60.5, N'926 925-84')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0026', 2, N'PINC.TIQUE', CAST(N'2020-01-28T00:00:00.000' AS DateTime), 30, 5.4625, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0026', 5, N'PROF.MOUS47/12ANGLH', CAST(N'2020-01-28T00:00:00.000' AS DateTime), 1, 0, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0026', 6, N'ARMO.PROD.DANG113L', CAST(N'2020-01-28T00:00:00.000' AS DateTime), 2, 1350, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0026', 7, N'BAC_RETENTION150L', CAST(N'2020-01-28T00:00:00.000' AS DateTime), 1, 186, N'A007030')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0026', 8, N'ARMO.AT1950/120/500', CAST(N'2020-01-28T00:00:00.000' AS DateTime), 1, 375, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0027', 1, N'GAZO.LUTZ', CAST(N'2020-01-27T00:00:00.000' AS DateTime), 1200, 1.175, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0027', 2, N'GAZO.LUTZ', CAST(N'2020-01-27T00:00:00.000' AS DateTime), 1000, 1.175, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0028', 1, N'BOIT.OUTFACBT13GPB', CAST(N'2020-03-12T00:00:00.000' AS DateTime), 1, 36.24, N'FACBT.13GPB')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0028', 2, N'JEU_KRA4165', CAST(N'2020-03-12T00:00:00.000' AS DateTime), 1, 30.88, N'KRA4165')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0028', 3, N'JEU_KRA4161', CAST(N'2020-03-12T00:00:00.000' AS DateTime), 1, 25.68, N'KRA4161')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0028', 4, N'JEU_KNI002012', CAST(N'2020-03-12T00:00:00.000' AS DateTime), 1, 69, N'KNI002012')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0028', 5, N'PINC.FAC180VE', CAST(N'2020-02-28T00:00:00.000' AS DateTime), 1, 20.37, N'FAC180.VSE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0028', 6, N'PINC.KRA3290-230', CAST(N'2020-03-12T00:00:00.000' AS DateTime), 1, 20.56, N'KRA3290-230')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0028', 7, N'OUTI.FAC985962', CAST(N'2019-12-11T00:00:00.000' AS DateTime), 1, 18.1, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0028', 8, N'JEU_CLE_ML', CAST(N'2020-01-28T00:00:00.000' AS DateTime), 1, 18.7, N'FAC83SH.JP9APB')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0028', 9, N'JEU_KRA3401-54', CAST(N'2020-03-12T00:00:00.000' AS DateTime), 1, 132.72, N'KRA3401-54')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0028', 10, N'COFF.CLIMULTI1/2', CAST(N'2020-01-28T00:00:00.000' AS DateTime), 1, 100.64, N'KRA2023')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0028', 11, N'TOUR.MAGASIN', CAST(N'2020-03-12T00:00:00.000' AS DateTime), 1, 6.64, N'KRA4128')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0028', 12, N'COFF.EMBMIXT', CAST(N'2020-03-12T00:00:00.000' AS DateTime), 1, 12.08, N'KRA2786')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0029', 1, N'FIOU.CHAUF_CMR', CAST(N'2020-01-27T00:00:00.000' AS DateTime), 1000, 0.71666, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0030', 1, N'BASE_EWOFLEXY-201', CAST(N'2020-01-30T00:00:00.000' AS DateTime), 1, 592.56, N'EWON FLEXY-201')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0030', 2, N'EXTE.EWO_FLX3101', CAST(N'2020-02-29T00:00:00.000' AS DateTime), 1, 178.12, N'EWON FLX3101')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0030', 3, N'PORT', CAST(N'2020-01-29T00:00:00.000' AS DateTime), 1, 38, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0031', 1, N'PANN."PK"', CAST(N'2020-01-30T00:00:00.000' AS DateTime), 26, 85, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0031', 2, N'SUPP.P80X40X2500', CAST(N'2020-01-30T00:00:00.000' AS DateTime), 26, 49, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0031', 3, N'PANN.B9A_450CL1', CAST(N'2020-01-30T00:00:00.000' AS DateTime), 10, 86, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0031', 4, N'PANC.M8F350X150CL1', CAST(N'2020-01-30T00:00:00.000' AS DateTime), 10, 39, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0031', 5, N'COLL.GAL80X40', CAST(N'2020-01-29T00:00:00.000' AS DateTime), 36, 4.5, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0032', 1, N'SOCL.HAG896023', CAST(N'2020-01-30T00:00:00.000' AS DateTime), 24, 4.37, N'20583412')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0032', 2, N'COUV.HAG853781', CAST(N'2020-01-30T00:00:00.000' AS DateTime), 24, 5.18, N'20667840')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0032', 3, N'ANGL.HAG896054', CAST(N'2020-01-30T00:00:00.000' AS DateTime), 5, 4.8, N'20583415')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0032', 4, N'ANGL.HAG896078', CAST(N'2020-01-30T00:00:00.000' AS DateTime), 10, 4.8, N'20583417')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0032', 6, N'JONC.HAG221795', CAST(N'2020-01-30T00:00:00.000' AS DateTime), 10, 2.88, N'20583421')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0032', 7, N'SUPP.HAG873840', CAST(N'2020-01-30T00:00:00.000' AS DateTime), 10, 9.92, N'27372036')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0032', 8, N'PIEC.HAG873864', CAST(N'2020-01-30T00:00:00.000' AS DateTime), 15, 2.94, N'27372038')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0032', 9, N'PRIS.HAGWXF100', CAST(N'2020-01-30T00:00:00.000' AS DateTime), 10, 2.59, N'27643078')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0032', 10, N'ENJO.HAGWXD100B', CAST(N'2020-01-30T00:00:00.000' AS DateTime), 10, 0.69, N'27642946')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0032', 11, N'EMBO.HAG221771', CAST(N'2020-01-30T00:00:00.000' AS DateTime), 10, 4.34, N'221771')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0033', 1, N'CAIL.MEISTEPCLAIR4005X356X30', CAST(N'2020-01-31T00:00:00.000' AS DateTime), 14, 142.8, N'255327')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0033', 2, N'CORN.AC50X5', CAST(N'2020-01-31T00:00:00.000' AS DateTime), 24, 7.808, N'21185418')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0033', 3, N'FER_P120X 6', CAST(N'2020-01-31T00:00:00.000' AS DateTime), 24, 11.915, N'21112844')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0035', 1, N'LING.90', CAST(N'2020-01-31T00:00:00.000' AS DateTime), 18, 29.17, N'MANOCLIS-0211115')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0035', 2, N'CHIF.BLANC', CAST(N'2020-03-02T00:00:00.000' AS DateTime), 5, 35.35, N'0109497')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0035', 3, N'PEIN.SPGALV', CAST(N'2020-01-31T00:00:00.000' AS DateTime), 12, 19.71, N'0202256')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0035', 4, N'SPRA.DECO', CAST(N'2020-01-31T00:00:00.000' AS DateTime), 6, 13.2, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0035', 5, N'SAC_POUB130L', CAST(N'2020-01-31T00:00:00.000' AS DateTime), 5, 70.01, N'0111103')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0036', 1, N'LIQU.LRD_5L', CAST(N'2020-01-31T00:00:00.000' AS DateTime), 8, 16.2025, N'600825164')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0036', 2, N'GRAI.BIO', CAST(N'2020-01-31T00:00:00.000' AS DateTime), 20, 6.319, N'600351595')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0036', 3, N'HUIL.TT+15W40-60', CAST(N'2020-01-31T00:00:00.000' AS DateTime), 60, 4.123, N'600455026')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0036', 4, N'HUIL.CHAINBIO5', CAST(N'2020-02-28T00:00:00.000' AS DateTime), 8, 38.61, N'600389147')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0036', 5, N'TGAP', CAST(N'2020-05-02T00:00:00.000' AS DateTime), 1, 2.66, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0037', 1, N'TRUE.JOINT12', CAST(N'2020-02-01T00:00:00.000' AS DateTime), 2, 4.37, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0037', 2, N'TRUE.LC160', CAST(N'2020-02-01T00:00:00.000' AS DateTime), 2, 5.41, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0038', 1, N'SOUR.DEL', CAST(N'2020-01-31T00:00:00.000' AS DateTime), 1, 29.98, N'WM326')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0038', 2, N'SAC.PC15/17"', CAST(N'2020-01-31T00:00:00.000' AS DateTime), 1, 50, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0038', 3, N'LECT.DEL_DW316', CAST(N'2020-01-31T00:00:00.000' AS DateTime), 1, 45, N'DW316')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0039', 1, N'PC_DEL_G7_17-7790_16GO', CAST(N'2020-01-31T00:00:00.000' AS DateTime), 1, 1500, N'CNG7716')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0040', 1, N'REPA.MATERIEL', CAST(N'2020-02-04T00:00:00.000' AS DateTime), 1, 648.46, N'REMPLACEMENT TACHYGRAPHE')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0041', 1, N'CHAU.YUKT37', CAST(N'2020-02-04T00:00:00.000' AS DateTime), 1, 102.17, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0041', 2, N'CHAU.YUKT46', CAST(N'2020-02-04T00:00:00.000' AS DateTime), 1, 118.07, N'295449/46')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0041', 3, N'CHAU.YUKT42', CAST(N'2020-02-04T00:00:00.000' AS DateTime), 2, 102.17, N'295449/42')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0041', 4, N'PANT.FOR.ORE295453/M', CAST(N'2020-02-04T00:00:00.000' AS DateTime), 2, 76.42, N'YUKON')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0041', 5, N'PANT.FOR.ORE295453L', CAST(N'2020-03-04T00:00:00.000' AS DateTime), 1, 76.42, N'295453/L YUKON')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0042', 1, N'SCOR.', CAST(N'2020-02-04T00:00:00.000' AS DateTime), 18, 25, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0043', 1, N'LING.90', CAST(N'2020-02-05T00:00:00.000' AS DateTime), 18, 30.04, N'MANOCLIS-0211115')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0043', 2, N'CHIF.BLANC', CAST(N'2020-03-07T00:00:00.000' AS DateTime), 5, 36.41, N'0109497')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0043', 3, N'PEIN.SPGALV', CAST(N'2020-02-05T00:00:00.000' AS DateTime), 12, 21.48, N'0202256')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0043', 4, N'SPRA.DECO', CAST(N'2020-02-05T00:00:00.000' AS DateTime), 6, 22.68, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0043', 5, N'SAC_POUB130L', CAST(N'2020-02-05T00:00:00.000' AS DateTime), 5, 72.11, N'0111103')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0044', 1, N'ECRO.H20', CAST(N'2020-02-06T00:00:00.000' AS DateTime), 100, 0, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0044', 2, N'ROND.CAR20X60X3', CAST(N'2020-02-06T00:00:00.000' AS DateTime), 50, 0.7765, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0044', 3, N'VIS_THP20X100', CAST(N'2020-02-06T00:00:00.000' AS DateTime), 50, 0.77, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0045', 1, N'CIME.CE25', CAST(N'2020-02-05T00:00:00.000' AS DateTime), 10, 2.95, N'CIM25')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0045', 2, N'GRAV.0-15', CAST(N'2020-02-05T00:00:00.000' AS DateTime), 2, 37.5, N'MELAD')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0045', 3, N'PLAN.SAPTTL3C4M', CAST(N'2020-02-05T00:00:00.000' AS DateTime), 25, 4.33, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0045', 4, N'TREI.20/20PAFC', CAST(N'2020-02-05T00:00:00.000' AS DateTime), 7, 10.5, N'TREIS')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0046', 1, N'CONV.AIRA687485', CAST(N'2020-02-06T00:00:00.000' AS DateTime), 7, 89.96, N'AIRE-A687485')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0046', 2, N'TAXE', CAST(N'2019-11-21T00:00:00.000' AS DateTime), 7, 0.83, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0046', 3, N'CALI.ADEL-H718', CAST(N'2020-02-06T00:00:00.000' AS DateTime), 1, 486.6, N'ADEL-H718')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0046', 4, N'CONV.AIRA693817', CAST(N'2020-02-06T00:00:00.000' AS DateTime), 2, 446.51, N'AIR A693817')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0046', 5, N'CONV.AIRA693887', CAST(N'2020-02-06T00:00:00.000' AS DateTime), 1, 282.88, N'AIR A693887')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0046', 6, N'TAXE', CAST(N'2019-11-21T00:00:00.000' AS DateTime), 3, 1.67, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0046', 7, N'PORT', CAST(N'2020-02-05T00:00:00.000' AS DateTime), 1, 41.3, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0047', 1, N'CONV.AIRA691315', CAST(N'2020-02-06T00:00:00.000' AS DateTime), 2, 286.88, N'AIRE-A691315')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0047', 2, N'LAMP.2X36W', CAST(N'2020-02-06T00:00:00.000' AS DateTime), 6, 19.5, N'FILI005224')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0047', 3, N'GAIN.ICTA20', CAST(N'2020-02-06T00:00:00.000' AS DateTime), 1, 28.4, N'ARNX 05120')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0047', 4, N'DEMA.SCHLE1M35P706', CAST(N'2020-02-06T00:00:00.000' AS DateTime), 1, 75.68, N'SCHN-LE1M35P706')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0047', 5, N'BORN.BLM475120', CAST(N'2020-02-06T00:00:00.000' AS DateTime), 2, 34, N'BLM-475120')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0047', 6, N'BORN.BLM475130', CAST(N'2020-02-06T00:00:00.000' AS DateTime), 2, 30.75, N'BLM-475130')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0047', 7, N'BORN.BLM475150', CAST(N'2020-02-06T00:00:00.000' AS DateTime), 2, 32.5, N'BLM 475-150')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0047', 8, N'BOIT.BLM515309', CAST(N'2020-02-06T00:00:00.000' AS DateTime), 5, 1.87, N'BLM-515309')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0047', 9, N'TAXE', CAST(N'2019-11-21T00:00:00.000' AS DateTime), 2, 1.67, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0049', 1, N'COLL.CYANO', CAST(N'2020-03-08T00:00:00.000' AS DateTime), 2, 20.85, N'0205123')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0049', 2, N'SPRA.NETT.FR.B', CAST(N'2020-02-06T00:00:00.000' AS DateTime), 12, 15.33, N'ECOSOLVRAPIDE-0202210')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0049', 3, N'SPRA.COLLE', CAST(N'2020-03-08T00:00:00.000' AS DateTime), 3, 30.29, N'COLLINDUS')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0050', 1, N'CONC.10/14', CAST(N'2020-02-06T00:00:00.000' AS DateTime), 12, 16.25, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0050', 2, N'TGAP', CAST(N'2020-02-06T00:00:00.000' AS DateTime), 12, 0.2, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0051', 1, N'DISQ.D4TO', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 2, 145, N'SVHK-40-303800457')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 1, N'WC_BLANC', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 1, 119.5, N'3115253')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 2, N'PIPE_DN100-350', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 1, 7.61, N'1586752')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 3, N'TUYA.PVC100', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 4, 3, N'3833743')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 4, N'COUD.100PVC45F', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 5, 4.49, N'1727766')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 5, N'COUD.100PVC45MF', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 1, 3.77, N'1734050')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 6, N'CULO.100PVC45F', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 2, 7.11, N'1727810')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 7, N'TAMP.PVC100MF', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 1, 4.47, N'1727908')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 8, N'TAMP.PVC100/40', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 1, 3.5, N'1727904')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 9, N'TUYA.PVC40', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 8, 1.43, N'3833736')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 10, N'COUD.100PVC87F', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 4, 1.05, N'1727774')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 11, N'TE_PVC100-87MF', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 2, 2.3, N'1727917')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 12, N'COLL.PVC500', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 1, 9.7, N'1762052')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 13, N'COUD.40PVC45MF', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 1, 0.75, N'1727781')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 14, N'TE_GCU.PE32', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 1, 19.67, N'3589061')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 15, N'COUD.F_PE32', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 1, 8.99, N'3589070')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 16, N'RACC.U_MF_20/27', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 1, 19.86, N'1822770')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 17, N'MAME.26/34-20/27', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 1, 6.01, N'1822441')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 18, N'CUIV.ECROUI14', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 12, 4.09, N'7774473')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 19, N'FIL_BRASER', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 1, 32.28, N'1025625')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 20, N'MANC.CU14', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 1, 1.55, N'1822501')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 21, N'COUD.CU14', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 10, 0.457, N'1706346')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 22, N'TE_CU16-14-16', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 1, 2.99, N'1706082')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 23, N'FLUX_S39', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 1, 11.75, N'1504913')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0052', 24, N'MITI.DOUCHE', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 2, 59, N'3542250')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0053', 1, N'CABL.R2V37G1.5', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 50, 8.98, N'R2V CU 37G1.5 TGL')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0053', 2, N'CABL.RNF12G1.5', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 100, 3.6353, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0053', 3, N'CABL.CAT6', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 100, 0.7253, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0053', 4, N'CORD.HDMI-20M', CAST(N'2020-02-10T00:00:00.000' AS DateTime), 1, 70.71, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0054', 1, N'REGA.BET50X50X34', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 1, 43.89, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0055', 1, N'PIEG.SUPERCAT', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 80, 3.25, NULL)
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 1, N'KIT_BAHCO4.8', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 2, 22.5, N'168-COMBI-4.8-6920')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 2, N'KIT_BAHCO4', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 2, 22.5, N'168-COMBI-4.0-69')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 3, N'COIN_PL23', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 4, 15.21, N'0000-881-2213')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 4, N'COIN_ECLAT.', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 1, 53.06, N'238051')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 5, N'LIME_04.8MM', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 12, 1.6667, N'70503-1')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 6, N'LIME_05.2MM', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 12, 2.75, N'5605-773-5212')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 7, N'VIS_STH91040033004', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 2, 0.715, N'91040033004')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 8, N'BAND.STH11236486600', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 1, 1.96, N'11236486600')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 9, N'RESS.STH00009971018', CAST(N'2020-02-12T00:00:00.000' AS DateTime), 1, 3.12, N'00009971018')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 10, N'RESS.STH11291627800', CAST(N'2020-02-12T00:00:00.000' AS DateTime), 1, 2.06, N'11291627800')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 11, N'GOUP.STH93785432700', CAST(N'2020-02-12T00:00:00.000' AS DateTime), 1, 0.53, N'93785432700')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 12, N'BAND.STH11216486610', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 1, 2.03, N'11216486610')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 13, N'PIGN.STH11280071000', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 1, 26.25, N'11280071000')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 14, N'GUID.STH30030009421', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 1, 70.74, N'30030009421')
GO
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 15, N'FILT.STH00001201653', CAST(N'2020-02-12T00:00:00.000' AS DateTime), 1, 18.25, N'00001201653')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 16, N'PREF.STH00001410300', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 1, 4.95, N'00001410300')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 17, N'PROT.STH00007929129', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 1, 1.77, N'000079290129')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 18, N'COIN_AC2.5KG', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 1, 16.49, N'JCCFR25')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 19, N'COUV.STH11296401702', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 1, 39.02, N'11296401702')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 20, N'ECRO.STH00009550801', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 4, 0.95, N'00009550801')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 21, N'COUV.STH11296487700', CAST(N'2020-02-12T00:00:00.000' AS DateTime), 1, 4.09, N'11296487700')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 22, N'BUTE.STH11291626600', CAST(N'2020-02-12T00:00:00.000' AS DateTime), 1, 2.54, N'11291626600')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 23, N'COLL.STH11231605400', CAST(N'2020-02-12T00:00:00.000' AS DateTime), 1, 10.11, N'11231605400')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 24, N'BOUL.STH11201625200', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 1, 1.05, N'11201625200')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 25, N'COUV.STH11356401703', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 1, 42.29, N'11356401703')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 26, N'PIEC.STH11356561500', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 1, 4.07, N'11356561500')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 27, N'BAGU.STH00006421223', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 1, 10.78, N'00006421223')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 28, N'PROT.STH00007929132', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 1, 3.47, N'00007929132')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0056', 29, N'RESS.STH11387908303', CAST(N'2020-02-11T00:00:00.000' AS DateTime), 1, 11.12, N'11387908303')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0057', 1, N'SAC_POUB130LAP', CAST(N'2020-02-13T00:00:00.000' AS DateTime), 3, 148.5, N'A240')
INSERT [dbo].[LIGNES] ([N_CDE], [ID_LIGNE], [ID_PIECE], [DLPREV], [VOL_CDE], [PRIX], [REF_TIERS]) VALUES (N'2020-0057', 2, N'LOT_MANC-BROS', CAST(N'2020-02-13T00:00:00.000' AS DateTime), 1, 63, NULL)
GO

INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AXE_ALLONGE', N'MAGBU COLONNE 2', N'F - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUC.GAL.M1"', N'MAG COLONNE 4', N'F - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CAHI.ACTIV', N'NM COLONNE 2', N'G - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.WMAX', N'MAG COLONNE 2', N'J - ROUGE', 200)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.RJ45CAT6-5M', N'NM COLONNE 1', N'A - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CRAY.MAC', N'MAG COLONNE 4', N'B - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.CAOS 12', N'MAGBU COLONNE 3', N'I - VERTE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.TX50', N'MAG COLONNE 2', N'H - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.BRI394018', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.BRI491588', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.DON30801011201', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.DON330510018', N'MAGBU COLONNE 1', N'B - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.DON330510019', N'MAGBU COLONNE 1', N'B - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.ECHA226000360', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.HAT849401', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.HIF17974', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.HIFEN13150AASL13150', N'MAGBU COLONNE 2', N'C - JAUNE', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.HIFRT7', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.HIFSA10126', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.HIFSA12922', N'MAGBU COLONNE 1', N'B - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.HIFSA16302', N'MAGBU COLONNE 1', N'B - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.HIFSA17099', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.HIFSA6001', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.HIFSC60008', N'MAGBU COLONNE 1', N'B - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.HIFSH52933', N'MAGBU COLONNE 1', N'B - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.HIFSH56411', N'MAGBU COLONNE 1', N'B - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.HIFSH61153', N'MAGBU COLONNE 1', N'B - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.HIFSH66124', N'MAGBU COLONNE 1', N'B - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.HIFSN039', N'MAGBU COLONNE 1', N'B - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.HIFSN327', N'MAGBU COLONNE 1', N'B - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.HIFSN555', N'MAGBU COLONNE 1', N'B - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.HIFSO053', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.HIFSO404', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.HIFSO8013', N'MAGBU COLONNE 1', N'B - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.HIFT3142', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.HON330150405', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.KAW11013-2151', N'MAGBU COLONNE 1', N'B - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.KAW11013-2152', N'MAGBU COLONNE 1', N'B - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.LOM2175040', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.LOM2175107', N'MAGBU COLONNE 1', N'B - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.LOM5976005', N'MAGBU COLONNE 2', N'C - JAUNE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.LOM75044', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.MANC14210/2', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.MANC23440/1', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.MANCF1800', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.MANCF850/2', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.MANTB1374-3X', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.MANW1160/2', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.MANW7053', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.MANW75/3', N'MAGBU COLONNE 1', N'B - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.MANW77', N'MAGBU COLONNE 1', N'B - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.MANW940/5', N'MAGBU COLONNE 1', N'B - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.MANWK731', N'MAGBU COLONNE 1', N'B - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.PALEA1392', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.PALEA1412', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.PERK2654403', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.PERK26561117', N'MAGBU COLONNE 1', N'B - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.PERKULPK0002', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.PRE01172', N'MAG COLONNE 1', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.PURC112', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.PURC113', N'MAGBU COLONNE 1', N'B - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.PURC460', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.PURC496', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.PURCS155', N'MAGBU COLONNE 1', N'B - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.PURCS178A', N'MAGBU COLONNE 1', N'B - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.PURL270', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.PURL331', N'MAGBU COLONNE 1', N'B - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.PURLS235', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.PURLS309', N'MAGBU COLONNE 1', N'B - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.PURLS924', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.PURLS932', N'MAGBU COLONNE 1', N'B - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.PURLS933', N'MAGBU COLONNE 1', N'B - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.REN164038513R', N'MAGBU COLONNE 1', N'A - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.REN7701472321', N'MAGBU COLONNE 1', N'B - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.REN7701478538', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.SOL40', N'MAGBU COLONNE 2', N'E- JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.STAUFFSFC5710E', N'MAGBU COLONNE 1', N'B - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.STH41471410300C', N'MAG FOURNI', N'DIVERS', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.WILT20P2', N'NM COLONNE 3', N'K - VERT', 19)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FIOU.1ER', N'PARC', N'CARBURANT', 0.4900017)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FLAC.STH0000881182', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FLAS.ECH61031307132', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FLAS.ECH61031407130', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FLAS.ECHC535000011', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FLASQ.NOR100511', N'MAGBU COLONNE 2', N'C - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FLEA.NOR103059', N'MAGBU COLONNE 2', N'C - ROUGE', 141)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FLEA.NOR103070', N'MAGBU COLONNE 2', N'C - ROUGE', 79)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FLEX.+T1000', N'NM COLONNE 4', N'M - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FLEX.+T300', N'NM COLONNE 4', N'M - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FLUO.1L', N'MAG COLONNE 1', N'C - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.COB3.5', N'MAG COLONNE 2', N'L - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.COB4', N'MAG COLONNE 2', N'L - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.COB6', N'MAG COLONNE 2', N'L - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.PILOTE_SC6', N'MAG COLONNE 2', N'L - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+05A12', N'MAGBU COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+05X110', N'MAGBU COLONNE 2', N'F - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+06.5X260', N'MAGBU COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+06X110', N'MAG FOURNI', N'DIVERS', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+06X110', N'MAGBU COLONNE 2', N'F - BLEU', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+06X160', N'MAG FOURNI', N'DIVERS', 6)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+06X160', N'MAGBU COLONNE 2', N'F - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+06X210', N'MAGBU COLONNE 2', N'F - BLEU', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+06X260', N'MAGBU COLONNE 2', N'F - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+08X110', N'MAG FOURNI', N'DIVERS', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+08X160', N'MAG FOURNI', N'DIVERS', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+08X160', N'MAGBU COLONNE 2', N'F - BLEU', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+08X210', N'MAGBU COLONNE 2', N'F - BLEU', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+10X110', N'MAG FOURNI', N'DIVERS', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+10X110', N'MAGBU COLONNE 2', N'F - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+10X160', N'MAG FOURNI', N'DIVERS', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+10X160', N'MAGBU COLONNE 2', N'F - BLEU', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+12X160', N'MAGBU COLONNE 2', N'F - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+12X210', N'MAGBU COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+12X260', N'MAGBU COLONNE 2', N'F - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+14X160', N'MAGBU COLONNE 2', N'F - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+14X210', N'MAGBU COLONNE 2', N'F - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+14X260', N'MAGBU COLONNE 2', N'F - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+16X160', N'MAGBU COLONNE 2', N'F - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+16X210', N'MAGBU COLONNE 2', N'F - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+16X260', N'MAGBU COLONNE 2', N'F - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+18X250', N'MAGBU COLONNE 2', N'F - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+20X250', N'MAG FOURNI', N'DIVERS', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+22X250', N'MAGBU COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+22X450', N'MAGBU COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDS+25X200', N'MAGBU COLONNE 2', N'F - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDSM16X200', N'MAGBU COLONNE 2', N'F - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDSM18X200', N'MAGBU COLONNE 2', N'F - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDSM20X200', N'MAGBU COLONNE 2', N'F - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDSM20X400', N'MAGBU COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDSM22X200', N'MAG FOURNI', N'DIVERS', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDSM22X200', N'MAGBU COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.TX9', N'MAG COLONNE 2', N'H - VERT', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.TXC10', N'MAG COLONNE 2', N'H - VERT', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.TXC15', N'MAG COLONNE 2', N'H - VERT', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.TXC20', N'MAG COLONNE 2', N'H - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.TXC25', N'MAG COLONNE 2', N'H - VERT', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.TXC30', N'MAG COLONNE 2', N'H - VERT', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.TXC40', N'MAG COLONNE 2', N'H - VERT', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.TXZIN110X25', N'MAG COLONNE 2', N'H - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.TXZIN110X40', N'MAG COLONNE 2', N'H - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.TXZIN30X40', N'MAG COLONNE 2', N'H - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ENRO.3G2.5-40', N'MAG COLONNE 4', N'D - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ENRO.A_FR.', N'NM COLONNE 4', N'O - PALETTE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ENRO.SANGL', N'MAG COLONNE 4', N'E- JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ENSE.FACR151RN', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ENSE.HON1017292', N'NM COLONNE 3', N'K - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ENSE.PLUIE_L', N'NM COLONNE 3', N'I - ROUGE', 19)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ENSE.PLUIE_M', N'NM COLONNE 3', N'I - ROUGE', 18)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ENSE.PLUIE_XXL', N'NM COLONNE 3', N'I - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ENSE.PLUIEXL', N'NM COLONNE 3', N'I - ROUGE', 17)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ENTR.7X150L30', N'MAG COLONNE 1', N'A VERT', 95)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ENTR.ECHC536000030', N'MAGBU COLONNE 2', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ENTR.ECHV353000020', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ENTR.NOR103037', N'MAGBU COLONNE 2', N'C - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ENTR.NOR103076', N'MAGBU COLONNE 2', N'C - ROUGE', 113)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ENTR.NOR27266', N'MAGBU COLONNE 2', N'C - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ENVE.BL110.X220 PB', N'NM COLONNE 2', N'F - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ENVE.K162.X229', N'NM COLONNE 2', N'F - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ENVE.KS30X260X330', N'NM COLONNE 2', N'F - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ENZI.1L', N'MAG COLONNE 1', N'C - VERT', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EPIN.TAB.AFFICH', N'NM COLONNE 2', N'E - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EPON.MG', N'MAG COLONNE 1', N'E - JAUNE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EPON.VEG.N6', N'MAG FOURNI', N'DIVERS', 13)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EPON.VEG.N8', N'MAG FOURNI', N'DIVERS', 22)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EQUA.14PCE', N'NM COLONNE 3', N'H - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EQUA.4PCE', N'NM COLONNE 3', N'H - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ESSU.MAIN_KIM6763', N'NM COLONNE 4', N'O - PALETTE', 271)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ESSU.TOUT', N'NM COLONNE 4', N'O - PALETTE', 192)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ETAI.ARGENT', N'NM COLONNE 3', N'H - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ETIQ.A210X297', N'NM COLONNE 2', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ETIQ.A45.7X21', N'NM COLONNE 2', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ETIQ.A70X25', N'NM COLONNE 2', N'G - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ETIQ.A99.1X33.9', N'NM COLONNE 2', N'G - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ETUI_P.CEINTURE', N'NM COLONNE 3', N'I - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EVEN.ECHA356000030', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FANI.K1', N'NM COLONNE 4', N'P - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FARD.', N'MAG FOURNI', N'DIVERS', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FAUC.', N'MAGBU COLONNE 2', N'D - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FEME.ACO523304', N'MAG COLONNE 4', N'F - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_AS20-40W', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_CARRE10', N'PARC', N'METAUX', 18.3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_CARRE12', N'PARC', N'METAUX', 24.4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_IPN80', N'PARC', N'METAUX', 36.6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_P020X06', N'PARC', N'METAUX', 36.6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_P025X05', N'PARC', N'METAUX', 24)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_P030X05', N'PARC', N'METAUX', 36)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_P030X08', N'PARC', N'METAUX', 30)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_P035X05', N'PARC', N'METAUX', 24.4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_P040X05', N'PARC', N'METAUX', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_P050X06', N'PARC', N'METAUX', 24.4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_P050X08', N'PARC', N'METAUX', 24.4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_P060X08', N'PARC', N'METAUX', 42)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_P070X08', N'PARC', N'METAUX', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_P080X08', N'PARC', N'METAUX', 24.6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_R06MM', N'PARC', N'METAUX', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_R08MM', N'PARC', N'METAUX', 30)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_R10MM', N'PARC', N'METAUX', 30)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_R12MM*', N'PARC', N'METAUX', 18)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_R16MM', N'PARC', N'METAUX', 30)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_R18MM', N'PARC', N'METAUX', 12)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_R20MM', N'PARC', N'METAUX', 24)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_R25MM', N'PARC', N'METAUX', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_T30X4', N'PARC', N'METAUX', 18)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_UAC40X20X5', N'PARC', N'METAUX', 36)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_UAC50X25X5', N'PARC', N'METAUX', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_UPN080MM', N'PARC', N'METAUX', 12.2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FER_UPN100MM', N'PARC', N'METAUX', 12.2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FERU.', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FEU_00000000601', N'MAGBU COLONNE 3', N'I - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FEU_4 FONC.REM', N'MAG FOURNI', N'DIVERS', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FEU_4 FONC.REM', N'MAGBU COLONNE 3', N'I - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FEU_HEL2SD002514161', N'MAGBU COLONNE 3', N'I - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FEU_POUPE', N'MAGBU COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FEU_ROUGE_AV88', N'NM COLONNE 4', N'M - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FEU_RVI5021136890', N'MAGBU COLONNE 3', N'I - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FEU_RVI5800201334', N'MAGBU COLONNE 3', N'I - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FEU_RVI7484553913', N'MAGBU COLONNE 3', N'I - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FEU_SOR68015', N'MAGBU COLONNE 3', N'I - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FEU_SOR6868', N'MAGBU COLONNE 3', N'I - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FEU_TRIBORD', N'MAGBU COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FEUT.BLANC_P', N'NM COLONNE 2', N'G - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FEUT.PNF', N'NM COLONNE 2', N'G - ROUGE', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FEUT.PNM', N'NM COLONNE 2', N'G - ROUGE', 16)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FEUT.PNSF', N'NM COLONNE 2', N'G - ROUGE', 14)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FEUT.PRF', N'NM COLONNE 2', N'G - ROUGE', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FEUT.PRM', N'NM COLONNE 2', N'G - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FEUT.PRSF', N'NM COLONNE 2', N'G - ROUGE', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FEUT.V7N0.7', N'NM COLONNE 2', N'G - ROUGE', 23)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FICH.BALS22053', N'NM COLONNE 2', N'E - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FICH.CF10/16A', N'NM COLONNE 2', N'E - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FICH.CM10/16A', N'NM COLONNE 2', N'E - ROUGE', 13)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FICH.CM10/16AALL', N'NM COLONNE 2', N'E - ROUGE', 17)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FICH.LEG050632', N'NM COLONNE 2', N'E - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FICH.LEG052042', N'NM COLONNE 2', N'E - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FICH.LEG052084', N'NM COLONNE 2', N'E - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FICH.LEG052744', N'NM COLONNE 2', N'E - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FICH.LEG052784', N'NM COLONNE 2', N'E - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FICH.LEG052944', N'NM COLONNE 2', N'E - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FICH.LEG055637', N'NM COLONNE 2', N'E - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FICH.LEG057438', N'NM COLONNE 2', N'E - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FICH.MCA920850', N'NM COLONNE 1', N'A - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FICH.REM.F', N'MAGBU COLONNE 3', N'I - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FIL_DEB2.4X261', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FIL_DEB2.4X70CARBO', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FIL_H07VU1.5BRUN', N'NM COLONNE 2', N'C - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FIL_H07VU2.5BRUN', N'NM COLONNE 2', N'C - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FIL_H07VU2.5NOIR', N'NM COLONNE 2', N'C - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FIL_H07VU2.5ORAN', N'NM COLONNE 2', N'C - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FIL_H07VU4BLEU', N'NM COLONNE 2', N'C - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FIL_H07VU4BRUN', N'NM COLONNE 2', N'C - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FIL_H07VU4NOIR', N'NM COLONNE 2', N'C - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FIL_H07VU4ROUG', N'NM COLONNE 2', N'C - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FIL_H07VU4VJ', N'NM COLONNE 2', N'C - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FIL_RECUIT2.7', N'NM COLONNE 1', N'B - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FIL_SCIE_UNI.', N'MAGBU COLONNE 3', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FIL_SOUD10/10', N'NM COLONNE 3', N'H - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FIL_SOUDURE_HC10/10', N'MAG FOURNI', N'DIVERS', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FIL_SOUDURE_HC12/10', N'NM COLONNE 3', N'H - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FIL_TEND3.2GALV', N'NM COLONNE 1', N'B - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILA.', N'MAG COLONNE 4', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILE.DPECHE', N'MAGBU COLONNE 1', N'B  - BLANCHE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILM_ETIR.', N'MAG FOURNI', N'DIVERS', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.ABEK/1', N'NM COLONNE 3', N'K - VERT', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FILT.BRI272490', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDSM25X200', N'MAGBU COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDSM32X920', N'MAGBU COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDSM35X920X800', N'MAGBU COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDSM40X800', N'MAGBU COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FORE.SDSM45X990', N'MAGBU COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FOUR.FUM', N'MAG FOURNI', N'DIVERS', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FOUR.FUM', N'NM COLONNE 4', N'P - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FOUR.PVC100', N'MAG COLONNE 4', N'D - JAUNE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FOUR.PVC70', N'MAG COLONNE 4', N'D - JAUNE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FOUR.STH41387117300', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FOYE.SEA_C069', N'NM COLONNE 1', N'A - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FOYE.SEA_C071', N'NM COLONNE 1', N'A - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FOYE.TRA020204_LR', N'NM COLONNE 1', N'A - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FOYE.TRA020206_LV', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FREI.AXE_B10', N'MAG COLONNE 2', N'M - VERT', 49)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FREI.REN7701207640', N'MAGBU COLONNE 3', N'H - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.1000V11A', N'NM COLONNE 4', N'N - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.1000V440', N'NM COLONNE 4', N'N - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.2BR.MAX.60A', N'MAG COLONNE 2', N'I - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.2BR.MAX.ASS', N'MAG COLONNE 2', N'I - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.2BR10A', N'MAG COLONNE 2', N'I - ROUGE', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.2BR15A', N'MAG COLONNE 2', N'I - ROUGE', 17)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.2BR20A', N'MAG COLONNE 2', N'I - ROUGE', 16)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.2BR25A', N'MAG COLONNE 2', N'I - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.2BR2A', N'MAG COLONNE 2', N'I - ROUGE', 40)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.2BR30A', N'MAG COLONNE 2', N'I - ROUGE', 27)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.2BR3A', N'MAG COLONNE 2', N'I - ROUGE', 27)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.2BR5A', N'MAG COLONNE 2', N'I - ROUGE', 21)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.2BR7.5A', N'MAG COLONNE 2', N'I - ROUGE', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.M2BR10A', N'MAG COLONNE 2', N'I - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.M2BR15A', N'MAG COLONNE 2', N'I - ROUGE', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.M2BR20A', N'MAG COLONNE 2', N'I - ROUGE', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.M2BR30A', N'MAG COLONNE 2', N'I - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.M2BR4A', N'MAG COLONNE 2', N'I - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.M2BR5A', N'MAG COLONNE 2', N'I - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.S15A', N'MAG COLONNE 2', N'I - ROUGE', 11)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.S16A', N'MAG COLONNE 2', N'I - ROUGE', 47)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.S25A', N'MAG COLONNE 2', N'I - ROUGE', 16)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.S40A', N'MAG COLONNE 2', N'I - ROUGE', 16)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.S5A', N'MAG COLONNE 2', N'I - ROUGE', 92)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.S8A', N'MAG COLONNE 2', N'I - ROUGE', 33)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'FUSI.VER5X20_15A', N'NM COLONNE 2', N'E - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GACH.ECH17801052130', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GACH.ELEC12V', N'MAG COLONNE 4', N'E- JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GAIN.12/10', N'NM COLONNE 3', N'H - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GAIN.ECHC508000020', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GAIN.NOR102256', N'MAGBU COLONNE 2', N'C - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GAIN.THER3M85815', N'NM COLONNE 2', N'C - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GAIN.THER3M85824', N'NM COLONNE 2', N'C - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GAIN.THER3M85833', N'NM COLONNE 2', N'C - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GAIN.THER3M85842', N'NM COLONNE 2', N'C - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GAIN.THER3M85851', N'NM COLONNE 2', N'C - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GAIN.THERBIZ217004', N'NM COLONNE 2', N'C - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GAIN.VELC120', N'NM COLONNE 1', N'D - GRIS', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_ACTIVGRIPT10', N'NM COLONNE 3', N'J - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_ACTIVGRIPT9', N'NM COLONNE 3', N'J - ROUGE', 24)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_DEF.T9/10', N'NM COLONNE 3', N'J - ROUGE', 18)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_FOURRE10', N'NM COLONNE 3', N'J - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_FOURRE11', N'NM COLONNE 3', N'J - ROUGE', 22)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_FOURRE12', N'NM COLONNE 3', N'J - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_FOURRE8', N'NM COLONNE 3', N'J - ROUGE', 18)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_GLADIA.10', N'NM COLONNE 3', N'J - ROUGE', 43)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_GLADIA.7', N'NM COLONNE 3', N'J - ROUGE', 42)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_GLADIA.9', N'NM COLONNE 3', N'J - ROUGE', 46)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_GRIPFRIZ9', N'NM COLONNE 3', N'J - ROUGE', 49)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_HYCR.10', N'NM COLONNE 3', N'J - ROUGE', 51)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_HYCR.8', N'NM COLONNE 3', N'J - ROUGE', 36)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_HYCR.9', N'NM COLONNE 3', N'J - ROUGE', 32)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_HYDRO10', N'NM COLONNE 3', N'J - ROUGE', 30)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_HYDRO7', N'NM COLONNE 3', N'J - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_HYFLEX10', N'MAG FOURNI', N'DIVERS', 60)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_HYFLEX10', N'NM COLONNE 3', N'J - ROUGE', 144)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_HYFLEX11', N'MAG FOURNI', N'DIVERS', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_HYFLEX11', N'NM COLONNE 3', N'J - ROUGE', 36)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_HYFLEX9', N'MAG FOURNI', N'DIVERS', 36)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_HYFLEX9', N'NM COLONNE 3', N'J - ROUGE', 147)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_ISLANDT10', N'NM COLONNE 3', N'J - ROUGE', 17)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_ISLANDT9', N'NM COLONNE 3', N'J - ROUGE', 24)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_JERS.10', N'NM COLONNE 3', N'J - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_JERS.8', N'NM COLONNE 3', N'J - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_JERS.9', N'NM COLONNE 3', N'J - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_MONOTHERM', N'NM COLONNE 3', N'J - ROUGE', 42)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_MT10', N'NM COLONNE 3', N'J - ROUGE', 48)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_MT8', N'NM COLONNE 3', N'J - ROUGE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_MT9', N'MAG FOURNI', N'DIVERS', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_MT9', N'NM COLONNE 3', N'J - ROUGE', 40)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_NITRIL10', N'MAG FOURNI', N'DIVERS', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_NITRIL10', N'NM COLONNE 3', N'J - ROUGE', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_NITRIL11', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_NITRIL9', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_RIP.10', N'NM COLONNE 3', N'J - ROUGE', 47)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_RIP.11', N'NM COLONNE 3', N'J - ROUGE', 32)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_RIP.8', N'NM COLONNE 3', N'J - ROUGE', 33)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_RIP.9', N'NM COLONNE 3', N'J - ROUGE', 19)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_SOLV.9', N'NM COLONNE 3', N'J - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_SOUD.L', N'NM COLONNE 3', N'H - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_TNT.8-9', N'NM COLONNE 3', N'J - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_TRONC.L', N'MAG FOURNI', N'DIVERS', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_TRONC.L', N'NM COLONNE 3', N'I - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_TRONC.M', N'MAG FOURNI', N'DIVERS', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_TRONC.XL', N'MAG FOURNI', N'DIVERS', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_TRONC.XL', N'NM COLONNE 3', N'I - BLEU', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_VIBRA.10', N'NM COLONNE 3', N'J - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_VIBRA.8', N'NM COLONNE 3', N'J - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_VIBRA.9', N'NM COLONNE 3', N'J - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GANT_WELLNIT9', N'NM COLONNE 3', N'J - ROUGE', 95)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GARN.P100', N'MAG FOURNI', N'DIVERS', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GARN.P120', N'MAG FOURNI', N'DIVERS', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GARN.P80', N'MAG FOURNI', N'DIVERS', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GAZO.', N'PARC', N'CARBURANT', 436.89)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GAZO.*', N'PARC', N'CARBURANT', 0.8999863)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GAZO.LUTZ', N'MAG FOURNI', N'DIVERS', 1193.11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GEL_ANTISEP.100ML', N'MAG COLONNE 1', N'C - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GEL_ANTISEP.350ML', N'MAG FOURNI', N'DIVERS', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GEL_ANTISEP.350ML', N'MAG COLONNE 1', N'C - JAUNE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GEL_CAP599990', N'NM COLONNE 2', N'C - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GEL_JAVEL_WC', N'MAG FOURNI', N'DIVERS', 21)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GEL_JAVEL_WC', N'MAG COLONNE 1', N'B - VERT', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GEL_SIPHON1', N'MAG COLONNE 1', N'C - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GEL_WC', N'MAG COLONNE 1', N'B - VERT', 24)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GNR_BF', N'PARC', N'CARBURANT', 1084.38)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOMM.', N'NM COLONNE 2', N'E - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUJ.ENC08/120/55', N'MAG COLONNE 4', N'E - VERT', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUJ.ENC10/60', N'MAG COLONNE 4', N'E - VERT', 44)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUJ.ENC16/30/145A4', N'MAG COLONNE 4', N'E - VERT', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUL.LEG075602', N'NM COLONNE 1', N'B - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUL.SICS2565012', N'NM COLONNE 1', N'B - VERT', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.1/2L10X45', N'MAG COLONNE 3', N'Q - BLANC', 23)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.1/2L10X50', N'MAG COLONNE 3', N'Q - BLANC', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.1/2L6X45', N'MAG COLONNE 3', N'Q - BLANC', 22)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.1/2L8X40', N'MAG COLONNE 3', N'Q - BLANC', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.1/2L8X45', N'MAG COLONNE 3', N'Q - BLANC', 13)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.BETA03', N'MAG COLONNE 3', N'Q - BLANC', 64)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.BETA04', N'MAG COLONNE 3', N'Q - BLANC', 14)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.BETA05', N'MAG COLONNE 3', N'Q - BLANC', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.BETA06', N'MAG COLONNE 3', N'Q - BLANC', 24)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.BETA07', N'MAG COLONNE 3', N'Q - BLANC', 22)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.CJ10', N'NM COLONNE 3', N'H - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.CLIP04.5', N'MAG COLONNE 3', N'Q - BLANC', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.CLIP07.5', N'MAG COLONNE 3', N'Q - BLANC', 14)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.CLIP10.5', N'MAG COLONNE 3', N'Q - BLANC', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.CLIP6', N'MAG COLONNE 3', N'Q - BLANC', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.CLIP9.5', N'MAG COLONNE 3', N'Q - BLANC', 13)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.EL10X30', N'MAG COLONNE 2', N'I - BLEU', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.EL10X40', N'MAG COLONNE 2', N'I - BLEU', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.EL10X50', N'MAG COLONNE 2', N'I - BLEU', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.EL10X60', N'MAG COLONNE 2', N'I - BLEU', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.EL10X80', N'MAG COLONNE 2', N'I - BLEU', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.EL12X50', N'MAG COLONNE 2', N'I - BLEU', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.EL12X60', N'MAG COLONNE 2', N'I - BLEU', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.EL12X80', N'MAG COLONNE 2', N'I - BLEU', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.EL6X80', N'MAG COLONNE 2', N'I - BLEU', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.EL8X30', N'MAG COLONNE 2', N'I - BLEU', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.EL8X40', N'MAG COLONNE 2', N'I - BLEU', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.EL8X50', N'MAG COLONNE 2', N'I - BLEU', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.EL8X60', N'MAG COLONNE 2', N'I - BLEU', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.EL8X80', N'MAG COLONNE 2', N'I - BLEU', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.EUT27327', N'MAGBU COLONNE 2', N'C - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.F2,5X50', N'MAG COLONNE 3', N'Q - BLANC', 400)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.F2.8X25', N'MAG COLONNE 3', N'Q - BLANC', 500)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.F2.9X35', N'MAG COLONNE 3', N'Q - BLANC', 400)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.F2X50', N'MAG COLONNE 3', N'Q - BLANC', 307)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.F3.2X63', N'MAG COLONNE 3', N'Q - BLANC', 200)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.F3.5X60', N'MAG COLONNE 3', N'Q - BLANC', 200)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.F4.2X50', N'MAG COLONNE 3', N'Q - BLANC', 200)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.F4X40', N'MAG COLONNE 3', N'Q - BLANC', 385)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.F4X80', N'MAG COLONNE 3', N'Q - BLANC', 200)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.F5.8X60', N'MAG COLONNE 3', N'Q - BLANC', 48)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.F5X80', N'MAG COLONNE 3', N'Q - BLANC', 250)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.F6,3X 80', N'MAG COLONNE 3', N'Q - BLANC', 38)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.F6,3X100', N'MAG COLONNE 3', N'Q - BLANC', 95)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.F8X100', N'MAG COLONNE 3', N'Q - BLANC', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GOUP.F8X63', N'MAG COLONNE 3', N'Q - BLANC', 22)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRAI.10X125H1', N'MAG COLONNE 2', N'H - VERT', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRAI.10X150H1', N'MAG COLONNE 2', N'H - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRAI.10X150H2', N'MAG COLONNE 2', N'H - VERT', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRAI.10X150H3', N'MAG COLONNE 2', N'H - VERT', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRAI.6X100H1', N'MAG COLONNE 2', N'H - VERT', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRAI.8X100_45', N'MAG COLONNE 2', N'H - VERT', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRAI.8X125H1', N'MAG COLONNE 2', N'H - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRAI.BIO', N'MAGASIN LUBRIFIANT', N'C2 ROUGE', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRAI.BIO5KG', N'MAGASIN LUBRIFIANT', N'C2 ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRAI.CTFLON_AL', N'MAG COLONNE 4', N'A - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRAI.DE_MONTAGE', N'MAG COLONNE 1', N'B - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRAI.EPLITH00', N'MAGASIN LUBRIFIANT', N'C2 ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRAI.INT.LS1/2', N'MAGASIN LUBRIFIANT', N'C2 ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRAI.INT.LS1/2C', N'MAGASIN LUBRIFIANT', N'C2 ROUGE', 17)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRAI.LXC2', N'MAG FOURNI', N'LUBRIFIANT', 48)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRAI.LXC2', N'MAGASIN LUBRIFIANT', N'C2 ROUGE', 44)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRAI.LXC2-5KG', N'MAGASIN LUBRIFIANT', N'C2 ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRAI.MW5KG', N'MAGASIN LUBRIFIANT', N'C2 ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRAT.GIVRE', N'MAGBU COLONNE 3', N'H - BLEU', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRAT.WOLFKM', N'NM COLONNE 4', N'P - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRIL.CAM14L_PLAST', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRIL.CAM14L_PLAST', N'MAG COLONNE 4', N'C - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRIL.CAM14L_TOLE', N'MAG COLONNE 4', N'C - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRIL.CAM7L_PLAST', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GRIL.CAM7L_TOLE', N'MAG COLONNE 4', N'C - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GUID.HUS505698101', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GUID.HUS505698103', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GUID.STH17722705530', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GUID.STH30030005217', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GUID.STH30030006813', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GUID.STH30030009413', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GUID.STH30030009417', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GUID.STH30030009421', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GUID.STH30050003905', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GUID.STH30050004809', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GUID.STH30050004813', N'MAG FOURNI', N'DIVERS', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GUID.STH30050007409', N'MAGBU COLONNE 2', N'D - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'GUIP.NC14', N'MAG COLONNE 4', N'C - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HACH.600GR', N'MAGBU COLONNE 2', N'D - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HACH.60CM', N'MAGBU COLONNE 2', N'D - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HAMP.GIRO', N'MAGBU COLONNE 2', N'B - BLANCHE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HARN.PET89C71AAA.01', N'NM COLONNE 3', N'I - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HAUT_BEH20-9237', N'NM COLONNE 1', N'D - GRIS', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HELI.580MM', N'MAGBU COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HORA.24V_TFX', N'MAGBU COLONNE 2', N'C - ROSE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HOUS.SIEGE/500', N'MAGBU COLONNE 3', N'H - BLEU', 340)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUBL.LEG177764', N'NM COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.10W40/5', N'MAGASIN LUBRIFIANT', N'C1 ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.2TBIO1', N'MAG FOURNI', N'LUBRIFIANT', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.2TBIO1', N'MAGASIN LUBRIFIANT', N'C1 ROUGE', 44)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.5W40FAP', N'MAGASIN LUBRIFIANT', N'C4 VERT', 19)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.5W40FAP-5', N'MAGASIN LUBRIFIANT', N'C4 VERT', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.75W/80-2', N'MAGASIN LUBRIFIANT', N'C1 ROUGE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.BIOECOHYDI3268-20', N'MAGASIN LUBRIFIANT', N'C4 VERT', 80)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.BIOHYD46-205', N'MAGASIN LUBRIFIANT', N'C4 VERT', 205)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.BIOHYDI46-20', N'MAGASIN LUBRIFIANT', N'C4 VERT', 26)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.CHAINBIO1', N'MAGASIN LUBRIFIANT', N'C1 ROUGE', 35)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.CHAINBIO5', N'MAG FOURNI', N'LUBRIFIANT', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.CHAINBIO5', N'MAGASIN LUBRIFIANT', N'C1 ROUGE', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.COF5', N'MAGASIN LUBRIFIANT', N'C2 ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.COUPE5L', N'MAGASIN LUBRIFIANT', N'C1 ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.EMBASE1', N'MAGASIN LUBRIFIANT', N'C2 ROUGE', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.MOUW80W90-5', N'MAGASIN LUBRIFIANT', N'C1 ROUGE', 4)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.MP100 -5', N'MAGASIN LUBRIFIANT', N'C2 ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.MP46-5', N'MAGASIN LUBRIFIANT', N'C2 ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.RINCIL5', N'MAGASIN LUBRIFIANT', N'C1 ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.SEATEAM-5', N'MAGASIN LUBRIFIANT', N'C2 ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.TC3_5W30-5L', N'MAGASIN LUBRIFIANT', N'C1 ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.TCMC10W40', N'MAGASIN LUBRIFIANT', N'C1 ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.TGLS90-5', N'MAGASIN LUBRIFIANT', N'C1 ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.TRANSATF', N'MAGASIN LUBRIFIANT', N'C1 ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.TSP80W90-1', N'MAGASIN LUBRIFIANT', N'C1 ROUGE', 18)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.TT+15W40-20', N'MAG FOURNI', N'LUBRIFIANT', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.TT+15W40-60', N'MAGASIN LUBRIFIANT', N'C4 VERT', 148)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.TUB-60', N'MAGASIN LUBRIFIANT', N'C4 VERT', 120)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HUIL.TUUMC10W40-60', N'MAGASIN LUBRIFIANT', N'C4 VERT', 60)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HYDR.CLEANER', N'MAGASIN LUBRIFIANT', N'C1 ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'HYST.ROS.STH-FH', N'NM COLONNE 1', N'A - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'INDI.AK9400U1', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'INDI.PIEZO6-28VCC', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'INSE.MOUSSE', N'MAG COLONNE 1', N'C - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'INSE.POMP.', N'MAG FOURNI', N'DIVERS', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'INSE.POMP.', N'MAG COLONNE 1', N'C - VERT', 42)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'INSE.PUNAISE', N'MAG FOURNI', N'DIVERS', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'INSE.PUNAISE', N'MAG COLONNE 1', N'C - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'INSE.VOLANT', N'MAG COLONNE 1', N'C - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'INTE.A4_12ONG', N'NM COLONNE 2', N'G - ROUGE', 17)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'INTE.A4_6ONG', N'NM COLONNE 2', N'G - ROUGE', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'INTE.BER013353', N'MAGBU COLONNE 2', N'C - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'INTE.ECH16340041030', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'INTE.LEG008694', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'INTE.LEG080601', N'NM COLONNE 2', N'E - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'INTE.SCHBN310-01Z', N'NM COLONNE 1', N'A - BLEU', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'INTE.SCHBN310RZ-5', N'NM COLONNE 1', N'A - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'INTE.SCHENN35021', N'NM COLONNE 2', N'E - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'INTE.SCHENN35022', N'NM COLONNE 2', N'E - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ISIF.105-32XM1"-1/4', N'MAG COLONNE 4', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ISOL.COM4B3', N'NM COLONNE 3', N'H - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JAMB.SIP', N'NM COLONNE 3', N'K - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JAUG.EUT27212', N'MAGBU COLONNE 2', N'C - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JAVE.2.6%', N'MAG FOURNI', N'DIVERS', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JAVE.2.6%', N'MAG COLONNE 1', N'B - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JERR.DBLE', N'MAG COLONNE 1', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JERR.RAP6', N'MAG COLONNE 1', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JEU_AUMS1', N'NM COLONNE 1', N'A - BLEU', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JEU_AUMS2', N'NM COLONNE 1', N'A - BLEU', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JEU_FLUAC280', N'NM COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JEU_FLUTL224', N'NM COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JEU_FLUTLAC220', N'NM COLONNE 4', N'N - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JEU_FLUTLAC283', N'NM COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JEU_KNI002012', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JEU_TOURN.PH-PZ', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JEU_TOURN.SL-PH', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JEU_TOURN.TX', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JEU_WER05073601001', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.70X20X4750', N'MAGBU COLONNE 2', N'E - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.A_LEVRE', N'NM COLONNE 3', N'H - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.BELPA 1"', N'NM COLONNE 4', N'M - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CAOUT20/27', N'MAG COLONNE 1', N'G- VERT', 70)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CLA0123040400', N'MAGBU COLONNE 2', N'B - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CLA6005010620', N'MAGBU COLONNE 2', N'B - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CU06X10', N'MAG COLONNE 2', N'M - BLANC', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CU06X15', N'MAG COLONNE 2', N'M - BLANC', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CU08X14', N'MAG COLONNE 2', N'M - BLANC', 14)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CU10X16', N'MAG COLONNE 2', N'M - BLANC', 117)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CU12X18', N'MAG COLONNE 2', N'M - BLANC', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CU13X18', N'MAG COLONNE 2', N'M - BLANC', 38)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CU14X20', N'MAG COLONNE 2', N'M - BLANC', 70)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CU15X20', N'MAG COLONNE 2', N'M - BLANC', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CU16.2X21.9X2', N'MAG COLONNE 2', N'M - BLANC', 95)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CU16X22', N'MAG COLONNE 2', N'M - BLANC', 21)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CU17X22', N'MAG COLONNE 2', N'M - BLANC', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CU18X22', N'MAG COLONNE 2', N'M - BLANC', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CU18X24', N'MAG COLONNE 2', N'M - BLANC', 132)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CU18X24X2', N'MAG COLONNE 2', N'M - BLANC', 207)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CU20X26', N'MAG COLONNE 2', N'M - BLANC', 44)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CU21X26', N'MAG COLONNE 2', N'M - BLANC', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CU21X28', N'MAG COLONNE 2', N'M - BLANC', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CU22X27', N'MAG COLONNE 2', N'M - BLANC', 57)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CU22X29', N'MAG COLONNE 2', N'M - BLANC', 41)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CU24X30', N'MAG COLONNE 2', N'M - BLANC', 55)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CU26X32', N'MAG COLONNE 2', N'M - BLANC', 32)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.CU30X36', N'MAG COLONNE 2', N'M - BLANC', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.ECH10101042231', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.ECH12312424430', N'MAGBU COLONNE 2', N'E - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.ECH12312515030', N'MAGBU COLONNE 2', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.ECH12312540630', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.ECH12314003930', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.ECH12314005560', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.ECH13001006231', N'MAGBU COLONNE 2', N'E - BLEU', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.ECH13001022430', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.ECH13001603932', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.ECH13001606232', N'MAGBU COLONNE 2', N'E - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.ECH13001642231', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.ECH13101621230', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.ECH13101640030', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.ECH90072000012', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.ECHV100000040', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.ECHV103000070', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.ECHV104000210', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.EUT27254', N'MAGBU COLONNE 2', N'C - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.EUT27838', N'MAGBU COLONNE 2', N'C - VERT', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.EUT27949', N'MAGBU COLONNE 2', N'C - VERT', 2)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.FAUF400', N'MAGBU COLONNE 2', N'B - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.KAR53631000', N'MAGBU COLONNE 2', N'C - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.KAR63624840', N'MAGBU COLONNE 2', N'C - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.KAR63626100', N'MAGBU COLONNE 2', N'C - JAUNE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.KAR63653300', N'MAGBU COLONNE 2', N'C - JAUNE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.KAR63653400', N'MAGBU COLONNE 2', N'C - JAUNE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.LOC1721267', N'MAG COLONNE 4', N'A - VERT', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.LOM12130560', N'MAGBU COLONNE 2', N'C - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.LOM44000720', N'MAGBU COLONNE 2', N'C - JAUNE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.LOM4680039', N'MAGBU COLONNE 2', N'C - JAUNE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.NOR102531', N'MAGBU COLONNE 2', N'C - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.NOR102545', N'MAGBU COLONNE 2', N'C - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.NOR102596', N'MAGBU COLONNE 2', N'C - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.NOR103890', N'MAGBU COLONNE 2', N'C - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.NOR103944', N'MAGBU COLONNE 2', N'C - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.NOR104041', N'MAGBU COLONNE 2', N'C - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.ORE49816', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.ORE49831', N'MAGBU COLONNE 2', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.STH11201290900', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.STH11231290901', N'MAGBU COLONNE 2', N'D - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.STH11231290905', N'MAGBU COLONNE 2', N'D - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.STH11291290900', N'MAGBU COLONNE 2', N'D - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JOIN.UNIVERSEL', N'MAG COLONNE 4', N'B - BLANC', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JONC.AQU19L', N'MAG COLONNE 1', N'G- VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JONC.DBLE100/80', N'NM COLONNE 4', N'M - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JONC_ECH12316910630', N'MAGBU COLONNE 2', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JONC_ECH90070600010', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JUGU.4 PTS', N'NM COLONNE 3', N'K - VERT', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JUPE_BXT206', N'MAGBU COLONNE 3', N'I - VERTE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JUPE_BXT208', N'MAGBU COLONNE 3', N'I - VERTE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'JUPE_SAT208', N'MAGBU COLONNE 3', N'I - VERTE', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'KIT_ACCES.TABLEAU', N'NM COLONNE 2', N'F - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'KIT_BAHCO4', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'KIT_BAHCO4.8', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'KIT_BAHCO5.5', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'KIT_FLUTOOLPAK', N'NM COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'KIT_NETTOYAGE', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'KIT_NOR103461', N'MAGBU COLONNE 2', N'C - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_200X30X20', N'MAG COLONNE 2', N'H - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_CUTPOCHE', N'MAG COLONNE 2', N'I VERT', 80)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_CUTPROF.', N'MAG FOURNI', N'DIVERS', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_CUTPROF.', N'MAG COLONNE 2', N'I VERT', 14)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_D190', N'MAG COLONNE 2', N'H - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_DES37701', N'MAGBU COLONNE 2', N'E - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_DES37702', N'MAGBU COLONNE 2', N'E - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_GRAT08CM', N'MAG COLONNE 2', N'I VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_GRAT12CM', N'MAG COLONNE 2', N'I VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_OTE32020112', N'MAG COLONNE 2', N'I VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_RABOT82MM', N'MAG COLONNE 2', N'I VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_SAB.ACIER150', N'MAGBU COLONNE 3', N'G - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_SAB.BOIS225', N'MAGBU COLONNE 3', N'G - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_SAB.BOIS300', N'MAGBU COLONNE 3', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_SAB.MU150', N'MAGBU COLONNE 3', N'G - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_SAB.PROG150', N'MAGBU COLONNE 3', N'G - ROUGE', 23.18)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_SAB.PROG225', N'MAGBU COLONNE 3', N'G - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_SAB.PROG300', N'MAGBU COLONNE 3', N'G - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_SAUT.BOIS_STRAT100', N'MAGBU COLONNE 3', N'G - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_SAUT.BOIS100', N'MAGBU COLONNE 3', N'G - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_SAUT.BOIS105', N'MAGBU COLONNE 3', N'G - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_SAUT.BOIS50', N'MAGBU COLONNE 3', N'G - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_SAUT.BOIS75', N'MAGBU COLONNE 3', N'G - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_SAUT.INV69', N'MAGBU COLONNE 3', N'G - ROUGE', 0.5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_SAUT.MU105', N'MAGBU COLONNE 3', N'G - ROUGE', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_SCIE_ EL.', N'MAGBU COLONNE 3', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_SCIE_INVERSE', N'MAG COLONNE 2', N'H - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_SCIE_METAUX', N'MAG COLONNE 2', N'I VERT', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_SCIE_PL.', N'MAGBU COLONNE 3', N'G - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_SCIE760', N'MAGBU COLONNE 3', N'G - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_STH44046823103', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_TRAPEZE', N'MAG COLONNE 2', N'I VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_VOLET', N'NM COLONNE 1', N'B - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAME_WOLPROTZ51', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAMP.CUR18438355', N'NM COLONNE 1', N'A - BLEU', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAMP.LEDSF3W', N'NM COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAMP.RA3LED', N'MAG COLONNE 2', N'I - BLANC', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAMP.SANE.SWL120', N'NM COLONNE 1', N'A - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LANC.FLAMME', N'NM COLONNE 3', N'H - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LASU.CD5', N'MAGASIN LUBRIFIANT', N'C3 ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LASU.CM5', N'MAGASIN LUBRIFIANT', N'C3 ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LASU.IG3', N'MAGASIN LUBRIFIANT', N'C3 ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LASU.IG5', N'MAGASIN LUBRIFIANT', N'C3 ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LASU.VCG5', N'MAGASIN LUBRIFIANT', N'C3 ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAVE_GLACE2LH', N'MAGBU COLONNE 3', N'H - ROUGE', 29)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAVE_GLACE5LH', N'MAG FOURNI', N'DIVERS', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAVE_PONT_CH.', N'MAG COLONNE 1', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAVE_PONT_NYL', N'MAG COLONNE 1', N'E - BLEU', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LAVE_PT_MET.', N'NM COLONNE 4', N'P - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LEVI.1', N'NM COLONNE 4', N'M - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LEVI.2', N'NM COLONNE 4', N'M - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LEVI.ECHA235000060', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LEVI.EUT27200', N'MAGBU COLONNE 2', N'C - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LEVI.STH11251215000', N'MAGBU COLONNE 2', N'D - BLEU', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LEVI.STH12312303930', N'MAGBU COLONNE 2', N'E - BLEU', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LIME 3,2MM', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LIME_04.8MM', N'MAGBU COLONNE 2', N'D - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LIME_04MM', N'MAG FOURNI', N'DIVERS', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LIME_04MM', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LIME_05.5MM', N'MAGBU COLONNE 2', N'D - BLEU', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LIME_05MM', N'MAGBU COLONNE 2', N'D - BLEU', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LIME_4.5MM', N'MAGBU COLONNE 2', N'D - BLEU', 8)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LIME_CAR.EFF125', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LIME_FRAISE360', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LIME_OR12211', N'MAGBU COLONNE 2', N'D - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LIME_TIERS_PT100', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LIME_TRI.MD200', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LIME_TRI.MD300', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LING.15', N'MAG COLONNE 1', N'C - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LING.90', N'MAG FOURNI', N'DIVERS', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LING.90', N'MAG COLONNE 1', N'C - VERT', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LING.DEGR.SOLV', N'MAGBU COLONNE 3', N'I - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LING.DEPOUS', N'MAG COLONNE 1', N'E - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LING.DEPOUS.SOL', N'MAG COLONNE 1', N'E - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LING.LUNET', N'NM COLONNE 3', N'K - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LING.WC', N'MAG FOURNI', N'DIVERS', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LING.WC', N'MAG COLONNE 1', N'C - VERT', 43)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LIQU.FREIN_ESP', N'MAGBU COLONNE 3', N'I - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LIQU.LR30_20L', N'MAGASIN LUBRIFIANT', N'C4 VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LIQU.LRD_5L', N'MAGBU COLONNE 3', N'I - BLEU', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LIQU.MOLY', N'MAG COLONNE 4', N'A - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LIQU.VAISSEL1L', N'MAG FOURNI', N'DIVERS', 23)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LIQU.VAISSEL1L', N'MAG COLONNE 1', N'B - VERT', 29)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LONG.SAR638201', N'NM COLONNE 1', N'B - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LONG.SAR63840', N'NM COLONNE 1', N'B - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LONG.TRACT58582', N'NM COLONNE 3', N'I - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LOQU.ECH17801222130', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LOQU.ECH17809052632', N'MAGBU COLONNE 2', N'E - BLEU', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LUNE.BOL_VIPPSI', N'NM COLONNE 3', N'K - BLEU', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LUNE.DE PROTECT.', N'NM COLONNE 3', N'K - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LUNE.DIODE', N'NM COLONNE 3', N'K - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LUNE.FUMEE', N'NM COLONNE 3', N'K - BLEU', 28)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LUNE.JETABLE', N'NM COLONNE 3', N'K - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LUNE.SANBUE', N'NM COLONNE 3', N'K - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LUNE.SOUD.', N'NM COLONNE 3', N'K - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LUNE.TEINT4', N'NM COLONNE 3', N'K - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LUNE.TEINT6', N'NM COLONNE 3', N'K - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LUNE.X1.5', N'NM COLONNE 3', N'K - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LUNE.X2', N'NM COLONNE 3', N'K - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'LUNE.X2.5', N'NM COLONNE 3', N'K - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MAIL.RAC.10.8', N'MAG COLONNE 4', N'D - JAUNE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MAIL.RAC.13.8', N'MAG COLONNE 4', N'D - JAUNE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MAIL.RAP.GO6MM', N'MAG COLONNE 4', N'D - JAUNE', 22)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MAIL.RAP.ON3MM', N'MAG COLONNE 4', N'D - JAUNE', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MAIL.RAP.ON6MM', N'MAG COLONNE 4', N'D - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MAIL.RAP.ON8MM', N'MAG COLONNE 4', N'D - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MALE_ACO523303', N'MAG COLONNE 4', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MAME.CONIQ1/2', N'MAGBU COLONNE 3', N'I - VERTE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MAME.DM1/2 Z', N'MAG COLONNE 2', N'I - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MAME.GAL.DM3/4', N'MAG COLONNE 4', N'F - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MAME.GCU.DM1/2', N'MAG COLONNE 4', N'F - ROUGE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MAME.GCU.DM3/4', N'MAG COLONNE 4', N'F - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MAME.GCU.DMR3/4-1/2', N'MAG COLONNE 4', N'F - ROUGE', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MAME.GCU.MF1/2-3/4', N'MAG COLONNE 4', N'F - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MAME.ZIN.F1/2', N'MAG COLONNE 2', N'I - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.180_12MM', N'MAG FOURNI', N'DIVERS', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.180CREPIS', N'MAG COLONNE 4', N'C - BLEU', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.180LAQTEN', N'MAG COLONNE 4', N'C - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.180MUR-PLAF', N'MAG FOURNI', N'DIVERS', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.70_12MM', N'MAG FOURNI', N'DIVERS', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.ACO523348', N'MAG COLONNE 4', N'F - ROUGE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.BC', N'NM COLONNE 4', N'P - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.BECHE', N'NM COLONNE 4', N'P - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.BM', N'NM COLONNE 4', N'P - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.BM.VIS', N'NM COLONNE 4', N'P - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.CU12', N'MAG COLONNE 4', N'F - ROUGE', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.EP3730', N'NM COLONNE 4', N'M - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.FAUCIL', N'NM COLONNE 4', N'P - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.FRENE_HACHET', N'MAG COLONNE 4', N'B - ROSE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.FRENE450G', N'MAG COLONNE 4', N'B - ROSE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.GAL.F3/4', N'MAG COLONNE 4', N'F - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.HOUE', N'NM COLONNE 4', N'P - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.J1.5', N'NM COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.J2.5', N'NM COLONNE 2', N'D - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.LB200', N'NM COLONNE 4', N'N - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.LB250', N'NM COLONNE 4', N'N - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.LPF', N'NM COLONNE 4', N'P - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.MCAD253161', N'NM COLONNE 1', N'A - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.MERLFIB', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.NOR102592', N'MAGBU COLONNE 2', N'C - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.NOR103979', N'MAGBU COLONNE 2', N'C - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.PIO60/40', N'NM COLONNE 4', N'P - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.PIO65/45', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.PVC100FF', N'MAG COLONNE 1', N'F - ROUGE', 21)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.PVC32FF', N'MAG COLONNE 4', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.PVC50FF', N'MAG COLONNE 4', N'F - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.PVC80FF', N'MAG COLONNE 4', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.RAT', N'NM COLONNE 4', N'P - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.STH8812100', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.STH8812101', N'NM COLONNE 4', N'P - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.STH8812102', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.STH8812143', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.SWIFFER', N'MAG COLONNE 1', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.WOLZMA150', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.WOLZMT1', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANC.WOLZMT2', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANE.ECH1780100533', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANI.DRTE1.6TO', N'MAG COLONNE 4', N'D - JAUNE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANI.DRTE10', N'MAG COLONNE 4', N'D - JAUNE', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANI.DRTE12', N'MAG COLONNE 4', N'D - JAUNE', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANI.DRTE14', N'MAG COLONNE 4', N'D - JAUNE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANI.DRTE16', N'MAG COLONNE 4', N'D - JAUNE', 4)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANI.DRTE18', N'MAG COLONNE 4', N'D - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANI.DRTE2.8TO', N'MAG COLONNE 4', N'D - JAUNE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANI.DRTE2TO', N'MAG FOURNI', N'DIVERS', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANI.DRTE2TO', N'MAG COLONNE 4', N'D - JAUNE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANI.DRTE3.15TO', N'MAG COLONNE 4', N'D - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANI.DRTE6', N'MAG COLONNE 4', N'D - JAUNE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANI.DRTE8', N'MAG COLONNE 4', N'D - JAUNE', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANI.LYRE12MM', N'MAG COLONNE 4', N'D - JAUNE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANI.LYRE1T300', N'MAG COLONNE 4', N'D - JAUNE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANI.LYRE2T', N'MAG COLONNE 4', N'D - JAUNE', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANI.LYRE2T6', N'MAG COLONNE 4', N'D - JAUNE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANI.LYRE3/4', N'MAG COLONNE 4', N'D - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANI.NOR103067', N'MAGBU COLONNE 2', N'C - ROUGE', 58)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANI.NOR103068', N'MAGBU COLONNE 2', N'C - ROUGE', 49)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANI.PALP.CAP3T', N'MAG COLONNE 4', N'D - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANI.PALPCAP5T', N'MAG COLONNE 4', N'D - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MANO_0-10BG', N'MAGBU COLONNE 3', N'I - VERTE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MARQ.BLC', N'NM COLONNE 2', N'G - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MARQ.BLEU_MED', N'MAG COLONNE 4', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MARQ.JAUNE', N'MAG COLONNE 4', N'B - ROUGE', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MARQ.MULTI_SURF.', N'NM COLONNE 2', N'G - ROUGE', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MARQ.NOIR_PER.2.5', N'NM COLONNE 2', N'G - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MARQ.NOIR_TAB', N'NM COLONNE 2', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MARQ.NOIR_TAB1.9', N'NM COLONNE 2', N'G - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MARQ.ROUG_PER.2.5', N'NM COLONNE 2', N'G - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MARQ.TAB.ASS', N'NM COLONNE 2', N'G - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MART.COF.', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MASQ.AP', N'NM COLONNE 3', N'K - VERT', 40)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MASQ.SIL1/2', N'NM COLONNE 3', N'K - VERT', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MASS.1,5ME', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MASS.UNI15GR', N'MAGBU COLONNE 3', N'H - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MASS.UNI20GR', N'MAGBU COLONNE 3', N'H - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MASS.UNI40GR', N'MAGBU COLONNE 3', N'H - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MASS.UNI45GR', N'MAGBU COLONNE 3', N'H - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MASS.UNI50GR', N'MAGBU COLONNE 3', N'H - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MASS.UNI5GR', N'MAGBU COLONNE 3', N'H - BLEU', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MAST.290DC', N'MAG FOURNI', N'DIVERS', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MAST.290DC', N'MAG COLONNE 4', N'A - VERT', 21)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MAST.ACRYL.BLC', N'MAG FOURNI', N'DIVERS', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MAST.ACRYL.BLC', N'MAG COLONNE 4', N'A - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MAST.FIXALI', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MAST.FIXALI', N'MAG COLONNE 4', N'A - VERT', 13)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MAST.POLY.BLC', N'MAG COLONNE 4', N'A - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC01', N'MAG COLONNE 2', N'L - BLEU', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC01.5', N'MAG COLONNE 2', N'L - BLEU', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC02', N'MAG COLONNE 2', N'L - BLEU', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC02.5', N'MAG COLONNE 2', N'L - BLEU', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC03', N'MAG COLONNE 2', N'L - BLEU', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC03.5', N'MAG COLONNE 2', N'L - BLEU', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC04', N'MAG COLONNE 2', N'L - BLEU', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC04.2', N'MAG COLONNE 2', N'L - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC04.5', N'MAG COLONNE 2', N'L - BLEU', 14)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC05', N'MAG COLONNE 2', N'L - BLEU', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC05.5', N'MAG COLONNE 2', N'L - BLEU', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC06', N'MAG COLONNE 2', N'L - BLEU', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC06.5', N'MAG COLONNE 2', N'L - BLEU', 21)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC06.75', N'MAG COLONNE 2', N'L - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC07', N'MAG COLONNE 2', N'L - BLEU', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC07.5', N'MAG COLONNE 2', N'L - BLEU', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC08', N'MAG COLONNE 2', N'L - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC08.5', N'MAG COLONNE 2', N'L - BLEU', 17)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC09', N'MAG COLONNE 2', N'L - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC09.5', N'MAG COLONNE 2', N'L - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC10', N'MAG COLONNE 2', N'L - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC10.5', N'MAG COLONNE 2', N'L - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC11', N'MAG COLONNE 2', N'L - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC11.5', N'MAG COLONNE 2', N'L - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC12', N'MAG COLONNE 2', N'L - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC12.5', N'MAG COLONNE 2', N'L - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC13', N'MAG COLONNE 2', N'L - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC13.5', N'MAG COLONNE 2', N'L - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC14', N'MAG COLONNE 2', N'L - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC14.5', N'MAG COLONNE 2', N'L - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC15', N'MAG COLONNE 2', N'L - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC15.5', N'MAG COLONNE 2', N'L - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC16', N'MAG COLONNE 2', N'L - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AC16C', N'MAG COLONNE 2', N'L - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AF50MM', N'MAGBU COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MECH.AF55MM', N'MAGBU COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MEMB.CLA6000145465', N'MAGBU COLONNE 2', N'B - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MEMB.ECHP003001850', N'MAGBU COLONNE 2', N'E - BLEU', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MEMB.STH11231214700', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MEMB.STH11291214800', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MEMB.STH41291214700', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MENT./CASQUE', N'NM COLONNE 3', N'K - VERT', 16)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MESU.3ML', N'MAG COLONNE 4', N'B - VERT', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MESU.5ML', N'MAG COLONNE 4', N'B - VERT', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'METR.ALU', N'MAG COLONNE 4', N'B - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'METR.POL.', N'MAG COLONNE 4', N'B - VERT', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'METR.STH00008811200', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MEUL.CRAYON', N'MAG COLONNE 2', N'H - ROUGE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MEUL.SPHERIQ.', N'MAG COLONNE 2', N'H - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MEUL.TIGE10X13', N'MAG COLONNE 2', N'H - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MEUL.TIGE13X20OG', N'MAG COLONNE 2', N'H - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MEUL.TIGE20X25', N'MAG COLONNE 2', N'H - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MEUL.TIGEPL10X50', N'MAG COLONNE 2', N'H - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MEUL.TIGEPL40X10', N'MAG COLONNE 2', N'H - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MICR.ONDE', N'MAG COLONNE 1', N'E - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MINE_HB0.7', N'NM COLONNE 2', N'G - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MINI_GBIC1000-LX', N'NM COLONNE 1', N'A - BLEU', 18)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MODE.EG_GENPAC92C', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MODU.G/V5T', N'NM COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MODU.SCHBMXDDO3202K', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MONT.ROUL', N'MAG FOURNI', N'DIVERS', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MONT.ROUL400', N'MAG FOURNI', N'DIVERS', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MORT.CH330', N'MAG FOURNI', N'DIVERS', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MORT.CH330', N'MAG COLONNE 4', N'A - VERT', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MOTE.AUMZ011.892', N'NM COLONNE 1', N'A - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MOTE.GAL104', N'MAGBU COLONNE 2', N'C - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MOUI.25', N'MAG COLONNE 1', N'E - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MOUI.35', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MOUS.100MM', N'MAG COLONNE 4', N'D - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MOUS.60MM', N'MAG COLONNE 4', N'D - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MOUS.CANALISATION', N'MAG COLONNE 1', N'B - VERT', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MOUS.PU500ML', N'MAG COLONNE 1', N'B - BLEU', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'MVA_18-MBSPCT 1/2', N'MAGBU COLONNE 2', N'B - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'NETT.BACT1L', N'MAG COLONNE 1', N'B - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'NETT.DALLE', N'MAGBU COLONNE 3', N'H - BLEU', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'NETT.KAR.TRACER550', N'MAGBU COLONNE 3', N'H - ROSE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'NETT.MORT.CBC', N'MAGASIN LUBRIFIANT', N'C4 VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'NETT.MORTIER', N'MAG COLONNE 1', N'C - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'NETT.SOL_ET_SURF.', N'MAG COLONNE 1', N'B - VERT', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'NETT.SOLBIO1L', N'MAG COLONNE 1', N'B - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'NETT.SURFACE', N'MAG FOURNI', N'DIVERS', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'NETT.SURFACE', N'MAG COLONNE 1', N'B - VERT', 26)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'NETT.TC A4', N'MAGBU COLONNE 3', N'H - ROSE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'NEZ_ROB15/21', N'MAG COLONNE 1', N'G- VERT', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'NEZ_ROB15/21L', N'MAG COLONNE 1', N'G- VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'NEZ_ROB20/27', N'MAGBU COLONNE 3', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'NEZ_ROB20/27L', N'MAG COLONNE 1', N'G- VERT', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'NIPP.L25-1"', N'NM COLONNE 4', N'M - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'NIPP.LN20-1"', N'NM COLONNE 4', N'M - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'NITR.1400X10MEP.2MM', N'MAG FOURNI', N'DIVERS', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'NITR.1400X10MEP.3MM', N'MAG FOURNI', N'DIVERS', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'NITR.1400X10MEP.4MM', N'MAG FOURNI', N'DIVERS', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'NIVE.RECT60', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'NIVE.RECT80', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ONDU.S2SSRS1000', N'NM COLONNE 1', N'A - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PALI.59.6EP25', N'NM COLONNE 1', N'D - GRIS', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PALI.STH41387403200', N'MAGBU COLONNE 2', N'D - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PANC.KM9_700X200', N'NM COLONNE 4', N'N - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PANC.KM9_700X200CL2', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PANN."AC.INT.ECH"', N'MAGBU COLONNE 2', N'E - BLEU', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PANN."CASQ.OBLIG"', N'MAGBU COLONNE 2', N'E - BLEU', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PANN."CHANT.INT"', N'MAGBU COLONNE 2', N'E - BLEU', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PANN."DEF.DE_FUMER"', N'MAGBU COLONNE 2', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PANN."DEF.FUM"', N'MAGBU COLONNE 2', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PANN."INT.STAT"200', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PANN.AK5_700CL1', N'NM COLONNE 4', N'O - PALETTE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PANN.AK5_700CL2', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PANN.CYCL.PATERRE', N'NM COLONNE 4', N'N - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PANT.FOR.FIO_2XL', N'NM COLONNE 3', N'I - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PANT.FOR.ORE295453/XL', N'NM COLONNE 3', N'I - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PANT.PLUIE_3IG', N'NM COLONNE 3', N'K - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAPI.A3BLANC', N'NM COLONNE 4', N'O - PALETTE', 14)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAPI.A3BLEU', N'NM COLONNE 4', N'O - PALETTE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAPI.A3BRIST', N'NM COLONNE 2', N'G - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAPI.A3IV160', N'NM COLONNE 2', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAPI.A3V160', N'NM COLONNE 4', N'O - PALETTE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAPI.A4BLANC', N'NM COLONNE 4', N'O - PALETTE', 158)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAPI.A4BLANC160G', N'NM COLONNE 2', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAPI.A4BLEU', N'NM COLONNE 2', N'E - BLEU', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAPI.A4BLEU160', N'NM COLONNE 2', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAPI.A4IV', N'NM COLONNE 2', N'G - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAPI.A4IV160', N'NM COLONNE 2', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAPI.A4JAUNE', N'NM COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAPI.A4SAUM', N'NM COLONNE 2', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAPI.A4VERT', N'NM COLONNE 4', N'N - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAPI.A4VG160', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAPI.E/M_BLC1000', N'MAG FOURNI', N'DIVERS', 108)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAPI.E/M_BLC1000', N'NM COLONNE 4', N'O - PALETTE', 158)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAPI.E/M_TORK', N'MAG FOURNI', N'DIVERS', 24)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAPI.TOIL380M', N'MAG FOURNI', N'DIVERS', 69)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAPI.TOIL380M', N'NM COLONNE 4', N'O - PALETTE', 40)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PASS.', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PASS.ECH69621206032', N'MAGBU COLONNE 2', N'E - BLEU', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAST.NET.WC', N'MAG COLONNE 1', N'B - VERT', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PATE_HT1200', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PATE_HT1200', N'MAG COLONNE 1', N'B - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PATI.ECH169920040431', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PATI.ESCAB.', N'MAG COLONNE 4', N'E- JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PATT.SCHENN48934', N'NM COLONNE 2', N'D - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PATT.VIS10_L316', N'MAG COLONNE 1', N'A VERT', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PATT.VIS7X40', N'MAG COLONNE 1', N'A VERT', 33)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PATT.VIS8X80BI', N'MAG COLONNE 1', N'A VERT', 51)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAUM.SOUD100', N'NM COLONNE 3', N'H - ROUGE', 14)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAUM.SOUD120', N'NM COLONNE 3', N'H - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAUM.SOUD60', N'NM COLONNE 3', N'H - ROUGE', 17)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAUM.SOUD80', N'NM COLONNE 3', N'H - ROUGE', 16)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAVI.ALLEMAGNE', N'MAG COLONNE 2', N'K - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAVI.EUROPE', N'MAG COLONNE 2', N'K - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PAVI.FRANCE', N'MAG COLONNE 2', N'K - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEDA.YNY1278500000', N'NM COLONNE 4', N'M - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEIN.ACCRGRIS', N'MAGASIN LUBRIFIANT', N'C3 ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEIN.AR1RAL6005', N'MAGASIN LUBRIFIANT', N'C3 ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEIN.AR2.5RAL3020', N'MAGASIN LUBRIFIANT', N'C3 ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEIN.AR3RAL6001', N'MAGASIN LUBRIFIANT', N'C3 ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEIN.AR3RAL6005', N'MAGASIN LUBRIFIANT', N'C3 ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEIN.AR3RAL7000', N'MAGASIN LUBRIFIANT', N'C3 ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEIN.AR3RAL9003', N'MAGASIN LUBRIFIANT', N'C3 ROUGE', 2)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEIN.AR3RAL9005', N'MAGASIN LUBRIFIANT', N'C3 ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEIN.BOIS3020', N'MAGASIN LUBRIFIANT', N'C3 ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEIN.COMUSPISCINE15', N'MAGASIN LUBRIFIANT', N'C4 VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEIN.NOIR', N'MAGASIN LUBRIFIANT', N'C4 VERT', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEIN.SATRAL7035', N'MAGASIN LUBRIFIANT', N'C4 VERT', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEIN.SIGNBLANC', N'MAGASIN LUBRIFIANT', N'C3 ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEIN.SP1023_SOL', N'MAG COLONNE 1', N'B - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEIN.SP3020_SOL', N'MAG COLONNE 1', N'B - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEIN.SP9003', N'MAG FOURNI', N'DIVERS', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEIN.SP9016_SOL', N'MAG COLONNE 1', N'B - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEIN.SPGALV', N'MAG FOURNI', N'DIVERS', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEIN.SPGALV', N'MAG COLONNE 1', N'A - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEIN.SPINOX', N'MAG COLONNE 1', N'A - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEIN.SPNOIRB', N'MAG COLONNE 1', N'A - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEIN.SPNOIRM', N'MAG FOURNI', N'DIVERS', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEIN.SPZI', N'MAG COLONNE 1', N'A - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PELL.NEIGE', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PELL.PM_MET', N'MAG COLONNE 1', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PELL+MANCHE', N'NM COLONNE 4', N'P - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PEND.NOIR', N'NM COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PERF.2TR20F', N'NM COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PERF.2TR60F', N'NM COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PIED_ACU', N'MAG COLONNE 4', N'B - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PIGE_STH41308937800', N'MAGBU COLONNE 2', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PIGN.ECH61030056930', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PIGN.STH11136402000', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PIGN.STH11146402001', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PIGN.STH11216402000', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PIGN.STH11216402004', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PIGN.STH11220071001', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PIGN.STH11226402000', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PIGN.STH11250071002', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PIGN.STH11256402000', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PIGN.STH11286402000', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PIGN.STH11296402000', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PILE_6V', N'NM COLONNE 2', N'D - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PILE_6V50AHLD', N'NM COLONNE 2', N'D - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PILE_9V', N'MAG COLONNE 2', N'I - BLANC', 21)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PILE_CR1/2 AA', N'MAG COLONNE 2', N'I - BLANC', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PILE_CR17335SE', N'MAG COLONNE 2', N'I - BLANC', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PILE_CR2430', N'MAG COLONNE 2', N'I - BLANC', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PILE_LR03', N'MAG COLONNE 2', N'I - BLANC', 41)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PILE_LR03_32PCES', N'MAG COLONNE 2', N'I - BLANC', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PILE_LR1', N'MAG COLONNE 2', N'I - BLANC', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PILE_LR14', N'MAG COLONNE 2', N'I - BLANC', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PILE_LR20', N'MAG COLONNE 2', N'I - BLANC', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PILE_LR2025', N'MAG COLONNE 2', N'I - BLANC', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PILE_LR44', N'MAG COLONNE 2', N'I - BLANC', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PILE_LR6', N'MAG COLONNE 2', N'I - BLANC', 60)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PILE_LS26500', N'MAG COLONNE 2', N'I - BLANC', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PINC.COUP.TUB42MM', N'NM COLONNE 4', N'M - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PINC.FAC185.20VE', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PINC.FAC187.20CPE', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PINC.GRILLAGE', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PINC.KNI8705300', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PINC.REN7703297520', N'MAGBU COLONNE 3', N'I - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PINC.SAFW000010882', N'NM COLONNE 3', N'H - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PIOC.CANT2', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PIQU.FER16-1M', N'NM COLONNE 1', N'B - VERT', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PIQU.K5B', N'NM COLONNE 4', N'N - BLEU', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PIQU.T1', N'NM COLONNE 1', N'B - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PIQU.T2', N'NM COLONNE 1', N'B - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PIST.SILMC', N'MAG FOURNI', N'DIVERS', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PIST.SILMC', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PITO.12-120', N'MAG COLONNE 4', N'E- JAUNE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PITO.ORD4.5X30', N'MAG COLONNE 2', N'I - BLEU', 96)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PLAN.BULBE80MM', N'NM COLONNE 4', N'P - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PLAQ.ECH10153442230', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PLAQ.ECH61044456830', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PLAQ.JM448001', N'MAGBU COLONNE 2', N'C - JAUNE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PLAQ.REN7701208142', N'MAGBU COLONNE 3', N'H - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PLAQ.REN7701209864', N'MAGBU COLONNE 3', N'H - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PLAQ.REN7701210142', N'MAGBU COLONNE 3', N'H - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PLAT.COURBE', N'NM COLONNE 4', N'N - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PLAT.DENT10', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PNEU_155/70/13W*', N'NM COLONNE 1', N'C - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PNEU_155R15R560', N'NM COLONNE 1', N'C - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PNEU_165/65/14W', N'NM COLONNE 1', N'C - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PNEU_175/65/14', N'NM COLONNE 1', N'C - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PNEU_175/65/14W', N'NM COLONNE 1', N'C - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PNEU_195/70/15C', N'NM COLONNE 1', N'C - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PNEU_215/70/15CW', N'NM COLONNE 1', N'C - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PNEU_225/65/16CW', N'NM COLONNE 1', N'C - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PNEU_27375', N'NM COLONNE 1', N'C - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PNEU_MOB2P1/4-17M259', N'NM COLONNE 1', N'C - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POCH.A_PIVOT_CA', N'NM COLONNE 2', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POCH.CPFCCA', N'NM COLONNE 2', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POCH.PERF.TR', N'NM COLONNE 2', N'G - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POCH.PLASTA3-125', N'NM COLONNE 2', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POCH.PLASTA3-75/80', N'NM COLONNE 2', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POCH.PLASTA4-125', N'NM COLONNE 2', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POCH.PLASTA4-75/80', N'NM COLONNE 2', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POCH.POLYA4', N'NM COLONNE 2', N'F - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIG.BOIS', N'NM COLONNE 3', N'H - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIG.ECH17722811120', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIG.PARE_COUP16', N'NM COLONNE 4', N'N - BLEU', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIG.PARE_COUP18', N'NM COLONNE 4', N'N - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIG.STH11221903400', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIG.STH11281903400', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIG.TIRAGE', N'NM COLONNE 4', N'M - VERT', 4)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIN.50AS', N'MAG COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIN.ECH12313704260', N'MAGBU COLONNE 2', N'E - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIN.ECH12313719830', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIN.FAC985959', N'MAGBU COLONNE 3', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIN.JT+RESS', N'MAGBU COLONNE 3', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIN.MAC300X16', N'NM COLONNE 4', N'N - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIN.MAC400X18', N'NM COLONNE 4', N'N - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIN.MP19X50', N'NM COLONNE 4', N'N - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIN.MP25X75', N'NM COLONNE 4', N'N - BLEU', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIN.SDS+', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIN.SDSMAX', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIN.STH41161215100', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIN.TP100', N'MAG COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIN.TP120', N'MAG COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIN.TP160', N'MAG COLONNE 1', N'B - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIN.TP180', N'MAG COLONNE 1', N'B - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIN.TP50', N'MAG COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIN.TP60', N'MAG COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIN.TP70', N'MAG COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIN.TP70TOR', N'MAG COLONNE 1', N'B - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POIN.TP80', N'MAG COLONNE 1', N'B - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POMP.GRAISSEKLD2', N'MAG FOURNI', N'DIVERS', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PORT.BLOC A4', N'NM COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PORT.BRET.SOL4074412', N'MAGBU COLONNE 2', N'E- JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PORT.ECRAN_S54CE', N'NM COLONNE 3', N'K - BLEU', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PORT.EMB.MAG.', N'MAG COLONNE 2', N'H - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PORT.REST6833*', N'MAGBU COLONNE 3', N'I - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PORT.SAF11380', N'NM COLONNE 3', N'H - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POST_IT38X51', N'NM COLONNE 2', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POST_IT76X127FLUO', N'NM COLONNE 2', N'G - ROUGE', 33)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POST_IT76X76_4C', N'NM COLONNE 2', N'G - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POTE.POMP1.18M', N'NM COLONNE 1', N'B - VERT', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POUB.GP', N'MAGASIN 1ER ETAGE', N'SOL', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POUB.M50L', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POUC.6-29', N'MAG COLONNE 4', N'C - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POUC.R0-18', N'MAG FOURNI', N'DIVERS', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POUC.R03-15', N'MAG FOURNI', N'DIVERS', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POUC.R2-21', N'MAG FOURNI', N'DIVERS', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POUC.R2-21', N'MAG COLONNE 4', N'C - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POUC.R2-21BL', N'MAG COLONNE 4', N'C - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POUC.R4-25', N'MAG FOURNI', N'DIVERS', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POUC.R4-25', N'MAG COLONNE 4', N'C - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POUC.R4-25BL', N'MAG COLONNE 4', N'C - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POUC.R6-29', N'MAG FOURNI', N'DIVERS', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POUC.R6-29', N'MAG COLONNE 4', N'C - BLEU', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POUD.400GR', N'MAG COLONNE 4', N'B - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POUD.CATAL.', N'MAG COLONNE 1', N'B - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POUD.FOURMI', N'MAG COLONNE 1', N'C - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POUL.ECH17721515133', N'MAGBU COLONNE 2', N'E - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POUL.ECH17721543130', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POUL.ECHP22002080', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POUL.STH11221950400', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POUL.STH11251950401', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'POUS.STH11211412100', N'MAGBU COLONNE 2', N'D - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PRES.BM13353', N'MAGBU COLONNE 2', N'C - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PRES.ET16', N'NM COLONNE 2', N'D - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PRIM.COL', N'MAG COLONNE 4', N'B - BLANC', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PRIS.CLA7701017668', N'MAGBU COLONNE 2', N'B - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PRIS.FLASH05006', N'NM COLONNE 2', N'E - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PRIS.LEG051181', N'NM COLONNE 2', N'E - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PRIS.LEG052082', N'NM COLONNE 2', N'E - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PRIS.LEG052984', N'NM COLONNE 2', N'E - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PRIS.LEG057518', N'NM COLONNE 2', N'E - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PRIS.MG15306', N'NM COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PRIS.SCHENN36030', N'NM COLONNE 2', N'E - ROUGE', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PROF.CAOUT/BATARD', N'MAGASIN 1ER ETAGE', N'SOL', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PROF.D65/80/2545', N'MAGASIN 1ER ETAGE', N'SOL', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PROF.D70/80/2960', N'MAGASIN 1ER ETAGE', N'SOL', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PROF.EX52/60/1350/010', N'MAGASIN 1ER ETAGE', N'SOL', 54)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PROJ.30WLED', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PROJ.ARI50482', N'MAG FOURNI', N'DIVERS', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PROJ.ARI50482', N'NM COLONNE 2', N'D - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PROJ.ARI50483', N'MAG FOURNI', N'DIVERS', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PROJ.ARI50483', N'NM COLONNE 2', N'D - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PROT.DOC80V', N'NM COLONNE 2', N'G - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PROT.ECH69900150430', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PROT.ECHC550000090', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PROT.ECHC550000100', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PROT.FACIALE', N'NM COLONNE 3', N'K - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PROT.WALTERS', N'NM COLONNE 1', N'B - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PULV.1.5L', N'MAG FOURNI', N'DIVERS', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PULV.5L', N'NM COLONNE 4', N'O - PALETTE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'PULV.600ML', N'MAG FOURNI', N'DIVERS', 17)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.+ECROU', N'NM COLONNE 4', N'M - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.GAZ1/2M', N'MAG COLONNE 2', N'I - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.GAZ1/4F', N'MAG COLONNE 2', N'I - JAUNE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.GAZ1/4M', N'MAG COLONNE 2', N'I - JAUNE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.GAZ1/4M+B', N'MAG COLONNE 2', N'I - JAUNE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.GAZ3/4F', N'MAG COLONNE 2', N'I - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.GAZ3/4M', N'MAG COLONNE 2', N'I - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.H1/2-12S', N'MAGBU COLONNE 3', N'I - VERTE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.H4G8FDLORX', N'MAGBU COLONNE 3', N'I - VERTE', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.H5G12FDLORX', N'MAGBU COLONNE 3', N'I - VERTE', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.H8G15FDLORX', N'MAGBU COLONNE 3', N'I - VERTE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HA05A10MZ16A', N'MAGBU COLONNE 3', N'I - VERTE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HA05A10RO16A', N'MAGBU COLONNE 3', N'I - VERTE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HA05A10RO16A90', N'MAGBU COLONNE 3', N'I - VERTE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HA05A12MZ18A', N'MAGBU COLONNE 3', N'I - VERTE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HA05A12RO20A', N'MAGBU COLONNE 3', N'I - VERTE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HA05A12RO20A90', N'MAGBU COLONNE 3', N'I - VERTE', 3)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HA06A08MU', N'MAGBU COLONNE 3', N'I - VERTE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HA06A12MZ18A', N'MAGBU COLONNE 3', N'I - VERTE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HA06A12RO18A', N'MAGBU COLONNE 3', N'I - VERTE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HA06A12RO18A90', N'MAGBU COLONNE 3', N'I - VERTE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HA06A13RY20A', N'MAGBU COLONNE 3', N'I - VERTE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HA06A14MZ20A', N'MAGBU COLONNE 3', N'I - VERTE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HA06A14RO20A', N'MAGBU COLONNE 3', N'I - VERTE', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HA08A15RO22A', N'MAGBU COLONNE 3', N'I - VERTE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HA08A16RO24A', N'MAGBU COLONNE 3', N'I - VERTE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HA08A16RO24A90', N'MAGBU COLONNE 3', N'I - VERTE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HA08A17MZ24A', N'MAGBU COLONNE 3', N'I - VERTE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HA10A18MZ26A', N'MAGBU COLONNE 3', N'I - VERTE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HA10A18RO26A', N'MAGBU COLONNE 3', N'I - VERTE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HCP0606FG90B', N'MAGBU COLONNE 3', N'I - VERTE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HDNPPAV11313', N'MAGBU COLONNE 2', N'B - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HES12A25MZ36B', N'MAGBU COLONNE 3', N'I - VERTE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HES12A25RO36B', N'MAGBU COLONNE 3', N'I - VERTE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ABRA.115X50P100', N'MAG COLONNE 2', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ABRA.115X50P60', N'MAG COLONNE 2', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ABRA.115X50P80', N'MAG COLONNE 2', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ABRA.D150P100', N'MAG COLONNE 2', N'P - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ABRA.D150P80', N'MAG COLONNE 2', N'P - ROUGE', 130)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ABRA.ROLOCP80', N'MAG COLONNE 2', N'P - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ABRA.SEC 150', N'MAG COLONNE 2', N'P - ROUGE', 36)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ABRA.SEC120', N'MAG COLONNE 2', N'P - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ABRA.SEC220', N'MAG COLONNE 2', N'P - ROUGE', 73)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ABRA.SEC80', N'MAG COLONNE 2', N'P - ROUGE', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ABSO.30L', N'MAGASIN LUBRIFIANT', N'C4 VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ABSO.FEUIL', N'MAGASIN LUBRIFIANT', N'C4 VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ACTI.BIO_1KG', N'MAG COLONNE 1', N'C - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ACTI.BIO_1L', N'MAG FOURNI', N'DIVERS', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ACTI.BIO_1L', N'MAG COLONNE 1', N'C - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ACTI.COLLE', N'MAG COLONNE 4', N'B - BLANC', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ADAP.LEG050382', N'NM COLONNE 2', N'E - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ADAP.PD1/4', N'MAG COLONNE 2', N'H - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ADAP.SDS+MAX', N'MAGBU COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ADBL.5L', N'MAGBU COLONNE 3', N'H - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AGEN.MINIST.SP', N'NM COLONNE 3', N'L - JAUNE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AGIT.ACAFE', N'NM COLONNE 2', N'G - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AGRA.23/12/1000', N'NM COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AGRA.24/6/500', N'NM COLONNE 2', N'E - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AGRA.26/6/1000', N'NM COLONNE 2', N'E - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AGRA.DB10', N'NM COLONNE 2', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AGRA.DB24/26-40F', N'NM COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AGRA.EPR', N'MAGBU COLONNE 1', N'B  - BLANCHE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AGRA.HPG', N'MAG COLONNE 2', N'H - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AGRA.N10', N'NM COLONNE 2', N'E - BLEU', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AGRA.N4_14MM', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AILE.EUTMC85', N'MAGBU COLONNE 2', N'C - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AIMA.15F', N'NM COLONNE 2', N'F - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AIMA.B22(6)', N'NM COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AIMA.SCHBP20S', N'NM COLONNE 1', N'A - BLEU', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ALAR.SDR', N'MAGBU COLONNE 2', N'B - BLANCHE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ALIM.HPVAN90C-480B-1A', N'NM COLONNE 1', N'A - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ALIM.J9562ACC', N'NM COLONNE 1', N'A - BLEU', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ALIM.TDKLAMDSP10-24', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ALLO.280', N'MAGBU COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ALLU.GAZ_FL', N'MAG COLONNE 1', N'G- VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMARRE 24X6000', N'NM COLONNE 1', N'B - VERT', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMO_3 7.5X102', N'MAG COLONNE 4', N'A - BLANC', 140)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMO_3 7.5X132', N'MAG COLONNE 4', N'A - BLANC', 140)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPL.BEH20-0054', N'NM COLONNE 1', N'D - GRIS', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.114215', N'MAGBU COLONNE 2', N'C - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.11W_B22', N'NM COLONNE 2', N'D - JAUNE', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.15W_E27', N'NM COLONNE 2', N'D - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.18W_B22', N'NM COLONNE 2', N'D - JAUNE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.18W_E27', N'NM COLONNE 2', N'D - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.40W_B22', N'NM COLONNE 2', N'D - JAUNE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.42W_E27', N'NM COLONNE 2', N'D - JAUNE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.53W_E27', N'NM COLONNE 2', N'D - JAUNE', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.60W_E27*', N'NM COLONNE 2', N'D - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.60W_E27/24V', N'NM COLONNE 2', N'D - JAUNE', 18)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.70W_E27', N'NM COLONNE 2', N'D - JAUNE', 18)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.8W_E27', N'NM COLONNE 2', N'D - JAUNE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.92W_B22', N'NM COLONNE 2', N'D - JAUNE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.92W_E27', N'NM COLONNE 2', N'D - JAUNE', 13)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.BAI4.8V0.75A', N'NM COLONNE 2', N'D - JAUNE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.CHIM20', N'MAG COLONNE 4', N'E - VERT', 18)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.CHIM24', N'MAG COLONNE 4', N'E - VERT', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.E14POIRE15W', N'NM COLONNE 2', N'D - JAUNE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.FEU24V25W', N'MAG FOURNI', N'DIVERS', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.FEU24V25W', N'MAGBU COLONNE 3', N'I - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.GRAIS12V10W', N'MAGBU COLONNE 3', N'I - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.GRAIS12V5W', N'MAGBU COLONNE 3', N'I - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.GRAIS24V5W', N'MAGBU COLONNE 3', N'I - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.H35W', N'NM COLONNE 2', N'D - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.HALO.H1', N'MAGBU COLONNE 3', N'I - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.HALO.H3', N'MAGBU COLONNE 3', N'I - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.HALO.H4', N'MAGBU COLONNE 3', N'I - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.HALO.H4EC', N'MAGBU COLONNE 3', N'I - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.HALO.H7', N'MAGBU COLONNE 3', N'I - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.HALO.H7PR', N'MAGBU COLONNE 3', N'I - ROUGE', 16)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.HALO12V21W', N'MAGBU COLONNE 3', N'I - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.IODEH1-24V', N'MAGBU COLONNE 3', N'I - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.LED6W', N'NM COLONNE 2', N'D - JAUNE', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.MINIWATT3W', N'MAGBU COLONNE 3', N'I - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.MINIWATT5W24V', N'MAGBU COLONNE 3', N'I - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.NAVE12V10W', N'MAGBU COLONNE 3', N'I - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.NAVE12V10W8X30', N'MAGBU COLONNE 3', N'I - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.NAVE12V3W', N'MAGBU COLONNE 3', N'I - ROUGE', 1)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.ORB130188', N'NM COLONNE 2', N'D - JAUNE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.STOP_AMB.', N'MAGBU COLONNE 3', N'I - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.STOP_BA15S', N'MAGBU COLONNE 3', N'I - ROUGE', 27)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.STOP16W', N'MAGBU COLONNE 3', N'I - ROUGE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.STOP24V21/5W', N'MAGBU COLONNE 3', N'I - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.TEM24V4W', N'MAGBU COLONNE 3', N'I - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.TEMO24/2W', N'MAGBU COLONNE 3', N'I - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.TEMO4W', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AMPO.TEMO4W', N'MAGBU COLONNE 3', N'I - ROUGE', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ANNE.CLE_DN18', N'NM COLONNE 2', N'E - BLEU', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ANNE.ECH30121004630', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ANNE.STH1287918400', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ANOD.PLA177524', N'NM COLONNE 3', N'H - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ANTE.RHEA_AL', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ANTE.RHEA_AN', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ANTI_CREVAISON1L', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ANTI_FOURMIS', N'MAG COLONNE 1', N'B - VERT', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ANTI_RET.FGCT6 10', N'NM COLONNE 3', N'H - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ANTI_RET.FOXT6 10', N'NM COLONNE 3', N'H - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ANTI_TRABLOCFOR10', N'NM COLONNE 3', N'I - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ARBR.ROH14899', N'NM COLONNE 3', N'H - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ARBR.STH41377113200', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ARBR.STH41387103203', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ARRE.REN7704000989', N'MAGBU COLONNE 3', N'I - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ARRE.STH11226567700', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ARRE.STH11256507700', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ARRE.STH11296567701', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ASPE.2T', N'MAGASIN LUBRIFIANT', N'C1 ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ASPE.4T', N'MAGASIN LUBRIFIANT', N'C1 ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ASSI.180DIAM', N'MAG COLONNE 2', N'H - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ASSO.COLLIER', N'MAG COLONNE 2', N'K - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ASSO.VISTCB/TCC', N'MAG COLONNE 2', N'K - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ASSO.VISTTCBAP', N'MAG COLONNE 2', N'K - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ASSY_C10X140', N'MAG COLONNE 2', N'M - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ASSY_C10X60', N'MAG COLONNE 2', N'M - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ASSY_C8X 60', N'MAG COLONNE 2', N'M - ROUGE', 49)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ASSY_C8X120', N'MAG COLONNE 2', N'M - ROUGE', 55)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ASSY_C8X50', N'MAG COLONNE 2', N'M - ROUGE', 46)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ASSY_E4.5X 35', N'MAG COLONNE 2', N'O - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ASSY_E4.5X40', N'MAG COLONNE 2', N'O - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ASSY_E4.5X50', N'MAG COLONNE 2', N'O - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ASSY_E4X35', N'MAG COLONNE 2', N'O - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ASSY_E4X45', N'MAG COLONNE 2', N'O - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ASSY_E4X60', N'MAG COLONNE 2', N'O - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ASSY_E5X50', N'MAG COLONNE 2', N'O - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ASSY+FPTF4.5X50', N'MAG COLONNE 2', N'O - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ASSY+FPTF4X30', N'MAG COLONNE 2', N'O - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ASSY+FPTF4X40', N'MAG COLONNE 2', N'O - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ATTA.53X47', N'NM COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ATTA.CAPOT_GM', N'MAGBU COLONNE 2', N'B - BLEU', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ATTA.CAPOT_PM', N'MAGBU COLONNE 2', N'B - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ATTA.CASE3S', N'NM COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AXE_1200P707', N'MAGBU COLONNE 2', N'C - ROSE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AXE_ECH12311705020', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AXE_ECH61031007130', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AXE_ECH61031056930', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'AXE_ECHJ485000030', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAC_T3GRIS', N'MAG COLONNE 1', N'D - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAC_T3ROUGE', N'MAG COLONNE 1', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAC_T4BLEU', N'MAG COLONNE 1', N'D - ROUGE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAC_T4GRIS', N'MAG COLONNE 1', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAC_T4ROUGE', N'MAG COLONNE 1', N'D - ROUGE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAC_T4VERT', N'MAG COLONNE 1', N'D - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BACH.2X3NYLON', N'MAGBU COLONNE 3', N'I - BLANC', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BACH.3X4NYLON', N'MAGBU COLONNE 3', N'I - BLANC', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BACH.4X5NYLON', N'MAGBU COLONNE 3', N'I - BLANC', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BACH.4X6NYLON', N'MAGBU COLONNE 3', N'I - BLANC', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BACH.PROSILO', N'MAG FOURNI', N'DIVERS', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BACT.MECBCR100ML', N'MAGBU COLONNE 3', N'I - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAGU.AUTOC16', N'MAG COLONNE 2', N'M - BLANC', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAGU.ECH10021227930', N'MAGBU COLONNE 2', N'E - BLEU', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAGU.ECH10021302830', N'MAGBU COLONNE 2', N'E - BLEU', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAGU.KAR63624800', N'MAGBU COLONNE 2', N'C - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAGU.KAR63632730', N'MAGBU COLONNE 2', N'C - JAUNE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAGU.ORE22273', N'MAGBU COLONNE 2', N'D - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAGU.ORE68210', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAGU.P/TOUR.32A16', N'MAG COLONNE 2', N'H - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAGU.RELIER_3MM', N'NM COLONNE 2', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAGU.RELIER_6MM', N'NM COLONNE 2', N'G - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAGU.RELIER_9MM', N'NM COLONNE 2', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAGU.STH00003591220', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAGU.STH00006421216', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAGU.STH61041307130', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BALA.CANT.', N'NM COLONNE 4', N'P - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BALA.COCO38', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BALA.COCO60', N'NM COLONNE 4', N'P - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BALA.EG600MM', N'MAGBU COLONNE 1', N'A - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BALA.EG600MM+GICL', N'MAGBU COLONNE 1', N'A - JAUNE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BALA.EGCLA6005012539', N'MAGBU COLONNE 1', N'A - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BALA.EGREN7701068753', N'MAGBU COLONNE 1', N'A - JAUNE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BALA.EGREN7701068755', N'MAGBU COLONNE 1', N'A - JAUNE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BALA.EGRVI5001865594', N'MAGBU COLONNE 1', N'A - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BALA.FIBRE60', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BALA.ISK79019316', N'MAGBU COLONNE 2', N'C - ROSE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BALA.MCOURT', N'MAG COLONNE 1', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BALA.MLONG', N'MAG COLONNE 1', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BALA.REN7711421795', N'MAGBU COLONNE 1', N'A - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BALA.SOIE', N'NM COLONNE 4', N'P - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BALA.WOLUAM50', N'NM COLONNE 4', N'P - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BALA.WOLUBM25', N'NM COLONNE 4', N'P - ROUGE', 1)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BALA.WOLUBM40', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAND.ABRP100', N'MAG COLONNE 2', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAND.ABRP120', N'MAG COLONNE 2', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAND.ABRP80', N'MAG COLONNE 2', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAND.JT_ARM', N'MAG COLONNE 2', N'K - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAND.PERF12', N'NM COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAND.PERF17', N'NM COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAND_PARA.EP10', N'MAGASIN 1ER ETAGE', N'SOL', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BANJ.14-8MM', N'MAGBU COLONNE 3', N'I - VERTE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BANJ.HA06B17', N'MAGBU COLONNE 3', N'I - VERTE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BANJ.NOR102112', N'MAGBU COLONNE 2', N'C - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BARR.INSECT.', N'MAG FOURNI', N'DIVERS', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BARR.LG34388', N'NM COLONNE 2', N'E - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BARR.LG34389', N'NM COLONNE 2', N'E - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BARR.OR1X50', N'NM COLONNE 4', N'O - PALETTE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BATT.COOSCA00003', N'NM COLONNE 2', N'D - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BATT.STARN5', N'MAGBU COLONNE 3', N'H - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BATT.STARN6', N'MAGBU COLONNE 3', N'H - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAVE.NOR104408', N'MAGBU COLONNE 2', N'C - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAVE.NOR104410', N'MAGBU COLONNE 2', N'C - ROUGE', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BAVE.NOR110198', N'MAGBU COLONNE 2', N'C - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BEC_HUSQ505598002', N'MAGBU COLONNE 2', N'D - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BEC_HUSQ505598002', N'MAGBU COLONNE 2', N'E- JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BEC_HUSQ505598003', N'MAGBU COLONNE 2', N'E- JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BEC_MELANG', N'MAG FOURNI', N'DIVERS', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BEC_VERSEUR2279B', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BECH.', N'MAG FOURNI', N'DIVERS', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BECH.', N'NM COLONNE 4', N'P - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BLOC.0471210705', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BLOC_BEH20-9585', N'NM COLONNE 1', N'D - GRIS', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BLOC_BRE1159321018', N'NM COLONNE 2', N'E - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BLOC_DBA4', N'NM COLONNE 2', N'G - ROUGE', 13)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BLOC_DBA5', N'NM COLONNE 2', N'G - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BLOC_DBA7', N'NM COLONNE 2', N'G - ROUGE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BLOC_DE_CHANT', N'NM COLONNE 2', N'E - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BLOC_SCHA9N21492', N'NM COLONNE 1', N'A - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BLOC_W102038', N'NM COLONNE 1', N'A - BLEU', 48)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BLOC_W102898', N'NM COLONNE 1', N'A - BLEU', 48)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BLOC_WC', N'MAG FOURNI', N'DIVERS', 95)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BLOC_WC', N'MAG COLONNE 1', N'C - VERT', 60)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOBI.ECH69621406830', N'MAGBU COLONNE 2', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOIT.CD-TR', N'NM COLONNE 2', N'F - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOIT.ECH3030747533', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOIT.LEG089125', N'NM COLONNE 2', N'C - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOIT.LEG089224', N'NM COLONNE 2', N'C - BLEU', 14)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOIT.LEG089341', N'NM COLONNE 2', N'C - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOIT.LEG089401', N'NM COLONNE 2', N'C - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOIT.PW12042', N'NM COLONNE 2', N'C - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOIT.SAR04508', N'NM COLONNE 2', N'C - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOIT.SAR04509', N'NM COLONNE 2', N'C - BLEU', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOIT.SAR04510', N'NM COLONNE 2', N'C - BLEU', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOIT.SAR04511', N'NM COLONNE 2', N'C - BLEU', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOIT.SAR04513', N'NM COLONNE 2', N'C - BLEU', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOIT.SAR04516', N'NM COLONNE 2', N'C - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOIT.SAR04517', N'NM COLONNE 2', N'C - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOIT.SCH03350', N'NM COLONNE 2', N'C - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOIT.SCHENN05005', N'NM COLONNE 2', N'C - BLEU', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOIT.SCHENN05010', N'NM COLONNE 2', N'C - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOLL.DN100', N'NM COLONNE 1', N'B - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BONN.S/CASQUE', N'NM COLONNE 3', N'K - BLEU', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BORN.BIZ300444', N'NM COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BORN.CES040031', N'NM COLONNE 2', N'D - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BORN.CES040032', N'NM COLONNE 2', N'D - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BORN.WAG222412', N'NM COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BORN.WAG2273203', N'NM COLONNE 2', N'D - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BORN.WAG2273204', N'NM COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BORN.WAG273101', N'NM COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BORN.WAG273103', N'NM COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BORN.WAG273104', N'NM COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BORN.WAG273105', N'NM COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOTT.SIPT41', N'NM COLONNE 3', N'I - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOTT.T37', N'NM COLONNE 3', N'L - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOTT.T40', N'NM COLONNE 3', N'L - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOTT.T41', N'NM COLONNE 3', N'L - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOTT.T42', N'NM COLONNE 3', N'L - VERT', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOTT.T43', N'NM COLONNE 3', N'L - VERT', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOTT.T44', N'NM COLONNE 3', N'L - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOTT.T45', N'NM COLONNE 3', N'L - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOTT.T47', N'NM COLONNE 3', N'L - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUC.1/2RAC100', N'NM COLONNE 4', N'M - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUC.BIL303L20', N'MAG FOURNI', N'DIVERS', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUC.BIL303L20', N'NM COLONNE 3', N'K - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUC.BIL656SML', N'NM COLONNE 3', N'K - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUC.BM303286', N'MAGBU COLONNE 2', N'C - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUC.CD1000L', N'NM COLONNE 4', N'M - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUC.DEL23331', N'NM COLONNE 3', N'H - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUC.DNABLE', N'MAGBU COLONNE 2', N'C - ROSE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUC.ECH13160009861', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUC.ECH61043450030', N'MAGBU COLONNE 2', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUC.ECH61051001930', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUC.GAL.M3/4', N'MAG COLONNE 4', N'F - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUC.HONSMART_FIT', N'NM COLONNE 3', N'K - BLEU', 0.5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUC.HYDC3/8F', N'MAGBU COLONNE 3', N'I - VERTE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUC.HYDC3/8M', N'MAGBU COLONNE 3', N'I - VERTE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUC.LAIT.M3/8', N'MAG COLONNE 4', N'F - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUC.MPVC100', N'MAG COLONNE 1', N'F - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUC.STH00003500510', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUC.STH00003500520', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUC.STH00003500521', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUC.STH00003500530', N'MAGBU COLONNE 2', N'D - BLEU', 1)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUC.STH11241409500', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUG.CHARC12YC', N'MAGBU COLONNE 3', N'I - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUG.CHARCJ6Y', N'MAGBU COLONNE 3', N'I - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUG.EY42LJS3', N'MAGBU COLONNE 3', N'I - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUG.NGKB6HS', N'MAGBU COLONNE 3', N'I - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUG.NGKBCP5ES', N'MAGBU COLONNE 3', N'I - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUG.NGKBK5ESZ', N'MAGBU COLONNE 3', N'I - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUG.NGKBKR5EK', N'MAGBU COLONNE 3', N'I - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUG.NGKBKR6E', N'MAGBU COLONNE 3', N'I - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUG.NGKBP6ES', N'MAGBU COLONNE 3', N'I - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUG.NGKBPMR6A', N'MAGBU COLONNE 3', N'H - ROUGE', 0)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUG.NGKBPMR6A', N'MAGBU COLONNE 3', N'I - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUG.QL77JC4', N'MAGBU COLONNE 3', N'I - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUG.REN7701040208', N'MAGBU COLONNE 3', N'I - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUG.REN8200490950', N'MAGBU COLONNE 3', N'I - ROUGE', 16)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUG.REN8671004853', N'MAGBU COLONNE 3', N'I - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUG.REN8671017928', N'MAGBU COLONNE 3', N'I - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUL.1ERG12X50', N'MAG COLONNE 3', N'V - BLEU', 81)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUL.1ERG12X60', N'MAG COLONNE 3', N'V - BLEU', 116)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUL.NOR110162', N'MAGBU COLONNE 2', N'C - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUL.P05X40', N'MAG COLONNE 2', N'O - BLEU', 47)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUL.P06X30', N'MAG COLONNE 2', N'O - BLEU', 138)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUL.P06X40', N'MAG COLONNE 2', N'O - BLEU', 194)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUL.P08X40', N'MAG COLONNE 2', N'O - BLEU', 53)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUL.P08X70', N'MAG COLONNE 2', N'O - BLEU', 58)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUL.P10X40', N'MAG COLONNE 2', N'O - BLEU', 65)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BOUL.P10X60', N'MAG COLONNE 2', N'O - BLEU', 65)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BP_LEG080505', N'NM COLONNE 2', N'E - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BP_LEG080552', N'NM COLONNE 2', N'E - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BP_SCHENN33026', N'NM COLONNE 2', N'E - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BRAC.ETROIT200', N'NM COLONNE 2', N'E - BLEU', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BRAN.ECH35101052931', N'MAGBU COLONNE 2', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BRET.ORE537804', N'NM COLONNE 3', N'I - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BRET.SOL4300334', N'MAGBU COLONNE 2', N'E- JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BRID.ECH69901140430', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROC_VERS1L', N'MAG COLONNE 1', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROC_VERS5L', N'MAG COLONNE 1', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.200X20X20', N'NM COLONNE 3', N'H - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.A_ENCOLLER', N'MAG COLONNE 4', N'C - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.BOUGIE', N'MAG COLONNE 1', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.CHIEND', N'MAG COLONNE 1', N'E - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.ETRIER', N'MAG COLONNE 1', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.MET4RG', N'MAG COLONNE 1', N'E - BLEU', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.MET5RG', N'MAG COLONNE 1', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.PEINT20', N'MAG COLONNE 4', N'C - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.PEINT25', N'MAG COLONNE 4', N'C - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.PEINT30', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.PEINT30', N'MAG COLONNE 4', N'C - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.PEINT40', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.PEINT40', N'MAG COLONNE 4', N'C - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.PEINT50', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.PEINT50', N'MAG COLONNE 4', N'C - BLEU', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.PEINT60', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.PEINT60', N'MAG COLONNE 4', N'C - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.PEINT70', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.PEINT70', N'MAG COLONNE 4', N'C - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.PEINT8', N'MAG COLONNE 4', N'C - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.PEINT80', N'MAG FOURNI', N'DIVERS', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.PEINT80', N'MAG COLONNE 4', N'C - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.PEINTRAD40', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.PEINTRAD40', N'MAG COLONNE 4', N'C - BLEU', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.ROT.CIRC115', N'MAG FOURNI', N'DIVERS', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.ROT.CIRC115', N'NM COLONNE 3', N'H - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.ROT.CIRC125', N'NM COLONNE 3', N'H - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.ROT.FC', N'NM COLONNE 3', N'H - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.ROT100', N'NM COLONNE 3', N'H - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BROS.WC+R.', N'MAG COLONNE 1', N'E - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BUFF_THERMAL', N'NM COLONNE 3', N'K - BLEU', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BURI.MAC300X24', N'NM COLONNE 4', N'N - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BURI.MAC400X28', N'NM COLONNE 4', N'N - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BURI.PLAT250SDS+', N'NM COLONNE 4', N'N - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BURI.PLATMAX400', N'NM COLONNE 4', N'N - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BUSE_12/10', N'NM COLONNE 3', N'H - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BUSE_16/10', N'NM COLONNE 3', N'H - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BUSE_CONIQUE', N'NM COLONNE 3', N'H - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BUTE.COUD7X02,2', N'MAG COLONNE 4', N'E- JAUNE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BUTO.STH11147909600', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BUTO.STH11167909600', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BUTO.STH11227909900', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BUTO.STH11227909905', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BUTO.STH11227909920', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BUTO.STH11257909904', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BUTO.STH11297909900', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BUTO.STH11297909902', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'BUTO.STH11297909903', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABL.AC10X20M', N'NM COLONNE 1', N'B - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABL.AC12MM', N'MAGASIN 1ER ETAGE', N'SOL', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABL.AC3MM-A2', N'NM COLONNE 1', N'B - VERT', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABL.AC6MM', N'MAGASIN 1ER ETAGE', N'SOL', 45)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABL.CAT5', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABL.CAT6', N'NM COLONNE 1', N'A - BLEU', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABL.ECH17800143230', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABL.ECHV430000960', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABL.EUT27203*', N'MAGBU COLONNE 2', N'C - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABL.HO5VV5F5X0.75', N'NM COLONNE 1', N'A - BLEU', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABL.LIYCY19X0,5', N'NM COLONNE 2', N'C - ROUGE', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABL.R2V3G1.5', N'NM COLONNE 2', N'C - ROUGE', 300)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABL.R2V3G2.5', N'NM COLONNE 1', N'A - BLEU', 195)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABL.RNF2G2.5', N'NM COLONNE 2', N'C - ROUGE', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABL.RNF3G1.5', N'NM COLONNE 1', N'A - BLEU', 610)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABL.RNF3G2.5', N'NM COLONNE 1', N'A - BLEU', 220)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABL.STH00003500900', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABL.STH41287113300', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABL.USB/MICRO_USB', N'NM COLONNE 2', N'F - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABL.USB2A/A3', N'NM COLONNE 2', N'F - BLEU', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABL.USB2A/B5', N'NM COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABL.YNY126311AS00', N'NM COLONNE 4', N'M - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABO.RVI5000808166', N'MAGBU COLONNE 3', N'I - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABO.RVI5021136902', N'MAGBU COLONNE 3', N'I - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABO.RVI5021136903', N'MAGBU COLONNE 3', N'I - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABO.RVI7484553916', N'MAGBU COLONNE 3', N'I - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABO.SOR3425', N'MAGBU COLONNE 3', N'I - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CABO.SOR3426', N'MAGBU COLONNE 3', N'I - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CACH.EUT27235', N'MAGBU COLONNE 2', N'C - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CADE.30', N'MAG COLONNE 4', N'E- JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CADE.40', N'MAG COLONNE 4', N'E- JAUNE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CADE.50', N'MAG COLONNE 4', N'E- JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CADE.50 DE_SECURITE', N'MAG COLONNE 4', N'E- JAUNE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CADE.6ASI', N'MAG COLONNE 4', N'E- JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CADE/PG', N'MAG COLONNE 4', N'E- JAUNE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CAFE.ELEC', N'MAG COLONNE 1', N'E - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CAGE_ECH17721041030', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CAGE_STH95129332380', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CAHI.A4', N'NM COLONNE 2', N'G - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CAHI.MEET', N'NM COLONNE 2', N'G - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CAHI.SPIRA4', N'NM COLONNE 2', N'G - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CAHI.SPIRA5', N'NM COLONNE 2', N'G - ROUGE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CAIS.DB', N'MAGASIN 1ER ETAGE', N'SOL', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALC', N'NM COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALC.12_CHIFFRES', N'NM COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALE.12M', N'NM COLONNE 3', N'L - JAUNE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALE_1MM', N'MAG COLONNE 4', N'C - JAUNE', 815)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALE_2MM', N'MAG COLONNE 4', N'C - JAUNE', 805)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALE_3MM', N'MAG COLONNE 4', N'C - JAUNE', 775)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALE_4MM', N'MAG COLONNE 4', N'B - JAUNE', 814)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALE_5MM', N'MAG COLONNE 4', N'B - JAUNE', 799)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALE_6MM', N'MAG COLONNE 4', N'B - JAUNE', 825)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALE_8MM', N'MAG COLONNE 4', N'B - JAUNE', 860)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALE_APAP', N'MAG FOURNI', N'DIVERS', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALE_BIS.BR', N'MAG COLONNE 4', N'B - JAUNE', 120)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALE_BIS.VERT', N'MAG COLONNE 4', N'B - JAUNE', 130)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALE_FCH.30X40', N'MAG COLONNE 4', N'B - JAUNE', 210)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALE_FCH.30X80', N'MAG COLONNE 4', N'B - JAUNE', 400)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALE_M1000G', N'MAG COLONNE 2', N'L - BLANC', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALE_M140.200G', N'MAG COLONNE 2', N'L - BLANC', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALE_M1500G', N'MAG COLONNE 2', N'L - BLANC', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALE_M230.320G', N'MAG COLONNE 2', N'L - BLANC', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALE_M400G', N'MAG COLONNE 2', N'L - BLANC', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALE_M450.520G', N'MAG COLONNE 2', N'L - BLANC', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALE_M600G', N'MAG COLONNE 2', N'L - BLANC', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALE_M800G', N'MAG COLONNE 2', N'L - BLANC', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALE_UNI16X50', N'MAG COLONNE 4', N'B - JAUNE', 340)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALE_UNI20X50', N'MAG COLONNE 4', N'B - JAUNE', 420)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALI.STH11108934000', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CALO.GAL461007', N'MAGBU COLONNE 2', N'C - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CAMI.7L+RECH.', N'MAG COLONNE 4', N'C - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CAPU.VIS_ETERNIT', N'MAG COLONNE 4', N'E- JAUNE', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CARN.DE_CONSTAT', N'NM COLONNE 2', N'F - ROUGE', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CARR.8MM', N'MAG COLONNE 4', N'E- JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CARR.ECH61002007131', N'MAGBU COLONNE 2', N'E - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.BOB1MIC', N'NM COLONNE 4', N'M - BLEU', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.BROLC1280NP', N'NM COLONNE 2', N'F - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.BROLC980CN', N'NM COLONNE 2', N'F - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.BROTN2000', N'NM COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.BROTN241BK', N'NM COLONNE 2', N'F - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.BROTN241C', N'NM COLONNE 2', N'F - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.BROTN241M', N'NM COLONNE 2', N'F - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.BROTN241Y', N'NM COLONNE 2', N'F - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.BROTN3060', N'NM COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.BUT+PROP', N'NM COLONNE 3', N'H - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.CANFX10', N'NM COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.ENCRE_N', N'NM COLONNE 2', N'G - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.EPST1301', N'NM COLONNE 2', N'F - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.EPST1306', N'NM COLONNE 2', N'F - BLEU', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.HP3HZ52AE', N'NM COLONNE 2', N'F - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.HPHC920XLKIT', N'NM COLONNE 2', N'F - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.MEM.4GO', N'NM COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.MSI_GT720', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.NOR101510', N'MAGBU COLONNE 2', N'C - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.RICGC21C', N'NM COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.RICGC21K', N'NM COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.RICGC21M', N'NM COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.RICGC21Y', N'NM COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.SAMMLT-D250E', N'NM COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.SCHBMXAMI0410', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.SCHBMXCPS2000', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.SCHXUZX2004', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CART.SDHC32GO', N'NM COLONNE 2', N'F - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CASQ.C1', N'NM COLONNE 3', N'K - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CASQ.CHT.BLC', N'NM COLONNE 3', N'K - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CASQ.STEREO', N'NM COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CASS.SIGN', N'NM COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CASS.TIMB.4911', N'NM COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CATA_RVI5010096738', N'MAGBU COLONNE 3', N'I - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CAVA.NOR104455', N'MAGBU COLONNE 2', N'C - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CD-R', N'NM COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CEIN.PORTE_OUT.', N'NM COLONNE 3', N'I - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAI.AC2.5', N'NM COLONNE 2', N'D - ROUGE', 19)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAI.AC3', N'NM COLONNE 2', N'D - ROUGE', 23)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAI.AC6INOX', N'NM COLONNE 1', N'B - VERT', 14)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAI.ORE91VXL055E', N'MAG FOURNI', N'DIVERS', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAI.STH36100030044', N'MAGBU COLONNE 2', N'D - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAI.STH36290030067', N'MAGBU COLONNE 2', N'D - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAI.STH38680030072', N'MAGBU COLONNE 2', N'D - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAI.STH39700030074', N'MAGBU COLONNE 2', N'D - BLEU', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAI.STH39910030060', N'MAGBU COLONNE 2', N'D - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAI.STH39910030066', N'MAGBU COLONNE 2', N'D - BLEU', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAI.STH39910030084', N'MAGBU COLONNE 2', N'D - BLEU', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAI.STH39970030050', N'MAGBU COLONNE 2', N'D - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAM.11.2/10-24', N'MAGBU COLONNE 3', N'H - VERTE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAM.13.6/24', N'MAGBU COLONNE 3', N'H - VERTE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAM.15E13', N'MAGBU COLONNE 3', N'H - VERTE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAM.2"1/4-17', N'MAGBU COLONNE 3', N'H - VERTE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAM.2"3/4-18', N'MAGBU COLONNE 3', N'H - VERTE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAM.350X4.00-8', N'MAGBU COLONNE 3', N'H - VERTE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAM.EUT28353', N'MAGBU COLONNE 3', N'H - VERTE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAP.CERC.INOX', N'NM COLONNE 3', N'H - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAR.PIANO40MM', N'NM COLONNE 1', N'B - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAS.CLOU_CONE', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAU.BIZ700217', N'NM COLONNE 2', N'C - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAU.TR43', N'NM COLONNE 3', N'I - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHAU.TR44', N'NM COLONNE 3', N'I - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEM.250GR', N'NM COLONNE 2', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.00008810400', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.10X60', N'MAG COLONNE 2', N'J - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.12X60', N'MAG COLONNE 2', N'J - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.12X66', N'MAG COLONNE 2', N'J - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.12X71', N'MAG COLONNE 2', N'J - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.14X75*', N'MAG COLONNE 2', N'J - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.6X30', N'MAG FOURNI', N'DIVERS', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.6X30', N'MAG COLONNE 2', N'J - ROUGE', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.7X35', N'MAG COLONNE 2', N'J - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.8X46', N'MAG FOURNI', N'DIVERS', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.8X46', N'MAG COLONNE 2', N'J - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.B12/10', N'MAG COLONNE 4', N'E - VERT', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.B14/10', N'MAG COLONNE 4', N'E - VERT', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.B14/25', N'MAG COLONNE 4', N'E - VERT', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.B18/15', N'MAG COLONNE 4', N'E - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.BASC', N'MAG COLONNE 2', N'J - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.COL10X62', N'MAG COLONNE 2', N'J - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.COL14X76', N'MAG COLONNE 2', N'J - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.COL7X37', N'MAG COLONNE 2', N'J - ROUGE', 900)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.COL8X40', N'MAG COLONNE 2', N'J - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.COL8X52', N'MAG COLONNE 2', N'J - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.FRAP.FK5X25', N'MAG COLONNE 2', N'J - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.FRAP.FK6X60', N'MAG COLONNE 2', N'J - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.FRAP.FK6X80', N'MAG COLONNE 2', N'J - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.FRAP.SK6X60', N'MAG COLONNE 2', N'J - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.FRAP.SK6X80', N'MAG COLONNE 2', N'J - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.PARCR16X24', N'MAG COLONNE 2', N'J - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.PARCR4X32', N'MAG COLONNE 2', N'J - ROUGE', 500)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.PARCR5X12', N'MAG COLONNE 2', N'J - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.PARCR5X32', N'MAG COLONNE 2', N'J - ROUGE', 160)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.PARCR5X37', N'MAG COLONNE 2', N'J - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.PARCR6X52', N'MAG COLONNE 2', N'J - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.PARCR8X65', N'MAG COLONNE 2', N'J - ROUGE', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.PARCRNYL8X45', N'MAG COLONNE 2', N'J - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.POLYFIX6X28', N'MAG COLONNE 2', N'J - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.POLYFIX8X33', N'MAG COLONNE 2', N'J - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.S12/10', N'MAG COLONNE 4', N'E - VERT', 64)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.S12/40', N'MAG COLONNE 4', N'E - VERT', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.S12/50', N'MAG COLONNE 4', N'E - VERT', 21)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHEV.S8/55/10', N'MAG COLONNE 4', N'E - VERT', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHIF.BLANC', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CHIF.BLANC', N'MAG COLONNE 1', N'C - ROUGE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CIRC.ECHP022002100', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CIRC.EXT08', N'MAG COLONNE 2', N'L - BLEU', 115)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CIRC.EXT12', N'MAG COLONNE 2', N'L - BLEU', 105)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CIRC.EXT16', N'MAG COLONNE 2', N'L - BLEU', 105)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CIRC.EXT17', N'MAG COLONNE 2', N'L - BLEU', 115)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CIRC.TRA020202', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CIRC.TRA020204', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CISE.BUREAU', N'NM COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLAP.GAL461003', N'MAGBU COLONNE 2', N'C - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLAS.10N', N'NM COLONNE 2', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLAS.5BL', N'NM COLONNE 3', N'L - JAUNE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLAS.5N', N'NM COLONNE 3', N'L - JAUNE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLAS.5RG', N'NM COLONNE 3', N'L - JAUNE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLAS.5V', N'NM COLONNE 3', N'L - JAUNE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLAS.8RG', N'NM COLONNE 3', N'L - JAUNE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLAS.8VM', N'NM COLONNE 3', N'L - JAUNE', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLAS.DOSLARG', N'NM COLONNE 2', N'E - BLEU', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLAS.DOSLIT', N'NM COLONNE 2', N'E - BLEU', 18)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLAV.+SOURIS', N'NM COLONNE 2', N'F - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLAV.6X6X13.8', N'NM COLONNE 1', N'D - GRIS', 40)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLAV.6X6X32', N'NM COLONNE 1', N'D - GRIS', 46)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLAV.8X7X55.8', N'NM COLONNE 1', N'D - GRIS', 40)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLAV.MOB.847215', N'NM COLONNE 4', N'M - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLAV.NOR103460', N'MAGBU COLONNE 2', N'C - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLE_ECH13X19', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLE_ECH89751801131', N'MAGBU COLONNE 2', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLE_ECKRA2585', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLE_GAZ', N'MAG COLONNE 1', N'G- VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLE_ST14"', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLE_STH11298903401', N'MAGBU COLONNE 2', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLE_TRIA32X50', N'NM COLONNE 4', N'M - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLE_TRIACIER', N'NM COLONNE 4', N'M - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLE_USB04G+LOG', N'NM COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLE_USB08G', N'NM COLONNE 2', N'F - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLE_USB32G', N'NM COLONNE 2', N'F - BLEU', 2)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLE_USB32GMF', N'NM COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLIP.BIZ710241', N'NM COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLIP.SPIT011203', N'NM COLONNE 2', N'D - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLIP_ECH12312703930', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLIP_ECH13201326630', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLIP_ECHP022007890', N'MAGBU COLONNE 2', N'E - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLIQ.ART1/2', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLIQ.STH11241957200', N'MAGBU COLONNE 2', N'D - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLIQ.STH17721840630', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CLOC.BL04238910', N'MAGBU COLONNE 2', N'E- JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COFF.AGI221001', N'NM COLONNE 4', N'N - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COFF.EMBMIXTMINI', N'MAG COLONNE 2', N'H - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COFF.EMBPOZI', N'MAG COLONNE 2', N'H - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COFF.EMBTX', N'MAG COLONNE 2', N'H - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COFF.FRTULTRA', N'MAGBU COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COFF.FRTULTRA_INOX', N'MAG COLONNE 2', N'L - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COIF.ECH15901203433', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COIN_D''EMMENCH', N'MAG COLONNE 2', N'L - BLANC', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COIN_PL25', N'MAGBU COLONNE 2', N'D - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COIN_PL30', N'MAGBU COLONNE 2', N'D - JAUNE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.AT14', N'MAG COLONNE 1', N'A VERT', 68)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.AT18', N'MAG COLONNE 1', N'A VERT', 58)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.AT22', N'MAG COLONNE 1', N'A VERT', 82)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.AT28', N'MAG COLONNE 1', N'A VERT', 59)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.BDE10-16', N'MAG COLONNE 4', N'G - JAUNE', 133)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.BDE12-20', N'MAG COLONNE 4', N'G - JAUNE', 34)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.BDE16-25', N'MAG COLONNE 4', N'G - JAUNE', 17)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.BDE20-32', N'MAG COLONNE 4', N'G - JAUNE', 17)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.BDE25-40', N'MAG COLONNE 4', N'G - JAUNE', 18)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.BDE30-45', N'MAG COLONNE 4', N'G - JAUNE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.BDE32-50', N'MAG COLONNE 4', N'G - JAUNE', 14)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.BDE40-60', N'MAG COLONNE 4', N'G - JAUNE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.BDE50-70', N'MAG COLONNE 4', N'G - JAUNE', 14)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.BDE60-80', N'MAG COLONNE 4', N'G - JAUNE', 37)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.BDE70-90', N'MAG COLONNE 4', N'G - JAUNE', 24)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.BDE80-100', N'MAG COLONNE 4', N'G - JAUNE', 24)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.CYANO', N'MAG FOURNI', N'DIVERS', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.DBGEL', N'NM COLONNE 2', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.DBSTICK8.2', N'NM COLONNE 2', N'E - BLEU', 13)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.ETTR', N'MAG FOURNI', N'DIVERS', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.ETTR', N'MAG COLONNE 4', N'A - VERT', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.GAL80X40', N'NM COLONNE 4', N'M - ROUGE', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.NOR101729', N'MAGBU COLONNE 2', N'C - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.OET15-18', N'NM COLONNE 3', N'H - ROUGE', 14)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.PVC32HP', N'MAG COLONNE 4', N'F - ROUGE', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.SCHENN47930', N'NM COLONNE 2', N'D - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.SCHENN47942', N'NM COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.SCHENN47962', N'NM COLONNE 2', N'D - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COLL.SCHENN47992', N'NM COLONNE 2', N'D - ROUGE', 200)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COMB.JET2', N'NM COLONNE 3', N'K - JAUNE', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COMB.JET3', N'MAG FOURNI', N'DIVERS', 30)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COMB.JET3', N'NM COLONNE 3', N'K - JAUNE', 19)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COMB.JET4', N'MAG FOURNI', N'DIVERS', 30)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COMB.JET4', N'NM COLONNE 3', N'K - JAUNE', 46)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COMB.JET5', N'NM COLONNE 3', N'K - JAUNE', 46)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COMB.PLUIE_TL', N'NM COLONNE 3', N'K - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COMB.PLUIE_XL', N'NM COLONNE 3', N'K - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COMM.YNM7263502000', N'NM COLONNE 4', N'M - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COMP.PRES23285P', N'MAG COLONNE 1', N'G- VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COMP.STER10X10', N'NM COLONNE 4', N'N - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CONE_DC30CM', N'MAG FOURNI', N'DIVERS', 13)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CONE_DC50CM', N'MAG FOURNI', N'DIVERS', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CONE_DC50CM_TELESC', N'MAG COLONNE 2', N'K - ROUGE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CONN.AUM51.0', N'NM COLONNE 1', N'A - BLEU', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CONN.NEX420.666', N'NM COLONNE 1', N'A - BLEU', 19)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CONN.SEA099', N'NM COLONNE 1', N'A - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CONN.SEA101', N'NM COLONNE 1', N'A - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CONN.TH.BLEU1.5-2.5', N'MAG COLONNE 2', N'I - ROUGE', 65)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CONN.TH.ROUG0.5-1.5', N'MAG COLONNE 2', N'I - ROUGE', 85)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CONT.HAGETC225', N'NM COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CONT.NOVI15', N'MAGASIN 1ER ETAGE', N'SOL', 4.65)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CONT.NOVI18', N'MAGASIN 1ER ETAGE', N'SOL', 4.685)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CONT.OK10WBP', N'MAGASIN 1ER ETAGE', N'SOL', 2.579999)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CONT.OK5WBP', N'MAGASIN 1ER ETAGE', N'SOL', 3.05)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CONT.PM5', N'MAGBU COLONNE 2', N'C - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CONT.SCHA9C24732', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CONV.AR1', N'MAGASIN LUBRIFIANT', N'C2 JAUNE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CONV.JMC_JK0030A1', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COQU.CENTS42CE', N'NM COLONNE 3', N'K - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.DLANC3', N'MAGBU COLONNE 2', N'D - BLEU', 46)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.DLANC3.5', N'MAGBU COLONNE 2', N'D - BLEU', 31)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.DLANC4', N'MAGBU COLONNE 2', N'D - BLEU', 80)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.DLANC4.5', N'MAGBU COLONNE 2', N'D - BLEU', 32)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.ERC4404000205', N'NM COLONNE 1', N'A - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.FLETL75', N'NM COLONNE 2', N'E - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.HDMI-2M', N'NM COLONNE 2', N'E - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.LUNET', N'NM COLONNE 3', N'K - BLEU', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.MAC1.5', N'MAG COLONNE 4', N'B - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.MAC1.5 PINCK', N'MAG COLONNE 4', N'B - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.MAC2', N'MAG COLONNE 4', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.POLY10', N'NM COLONNE 1', N'B - VERT', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.POLY14', N'NM COLONNE 1', N'B - VERT', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.POLY16', N'NM COLONNE 1', N'B - VERT', 88)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.POLY22', N'NM COLONNE 1', N'B - VERT', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.POLY24', N'NM COLONNE 1', N'B - VERT', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.POLY8', N'NM COLONNE 1', N'B - VERT', 85)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.RJ45CAT6-1M', N'NM COLONNE 1', N'A - BLEU', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.RJ45CAT6-20M', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.RJ45CAT6-30M', N'NM COLONNE 1', N'A - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.RJ45CAT6-3M', N'NM COLONNE 1', N'A - BLEU', 2)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.RJ45CAT6-7M', N'NM COLONNE 1', N'A - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.RJ45CAT7-10M', N'NM COLONNE 1', N'A - BLEU', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.RJ45CAT7-15M', N'NM COLONNE 1', N'A - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.RJ45CAT7-20M', N'NM COLONNE 1', N'A - BLEU', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.RJ45CAT7-3M', N'NM COLONNE 1', N'A - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.RJ45CAT7-5M', N'NM COLONNE 1', N'A - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.RJ45CAT7-7M', N'NM COLONNE 1', N'A - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.SCHBMXFCC201', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.SCHBMXFCC203', N'NM COLONNE 4', N'N - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.STH11221902900', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORD.STH11281902900', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORN.AC150X15', N'PARC', N'METAUX', 6.15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORN.AC20X3', N'PARC', N'METAUX', 37.2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORN.AC30X3', N'PARC', N'METAUX', 6.2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORN.AC40X4', N'PARC', N'METAUX', 18.6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORN.AC50X5', N'PARC', N'METAUX', 24)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CORP.EUT27332', N'MAGBU COLONNE 2', N'C - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.B7701393251', N'MAGBU COLONNE 3', N'I - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.BPL+D13', N'MAGBU COLONNE 3', N'I - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.BPL+D16', N'MAGBU COLONNE 3', N'I - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.BPL-D13', N'MAGBU COLONNE 3', N'I - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.BPL-D13A_SOUD', N'MAGBU COLONNE 3', N'I - ROUGE', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.BPL-D16', N'MAGBU COLONNE 3', N'I - ROUGE', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.CFB', N'MAG COLONNE 2', N'I - ROUGE', 16)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.CFB4', N'MAG COLONNE 2', N'I - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.CMB4', N'MAG COLONNE 2', N'I - ROUGE', 319)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.COEUR13', N'MAG COLONNE 4', N'D - JAUNE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.COEUR18', N'MAG COLONNE 4', N'D - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.OB5', N'MAG COLONNE 2', N'I - ROUGE', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.OB6', N'MAG COLONNE 2', N'I - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.OB8', N'MAG COLONNE 2', N'I - ROUGE', 55)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.OJ6', N'MAG COLONNE 2', N'I - ROUGE', 53)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.OJ8', N'MAG COLONNE 2', N'I - ROUGE', 155)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.PFIB6.3', N'MAG COLONNE 2', N'I - ROUGE', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.PFIR2.8', N'MAG COLONNE 2', N'I - ROUGE', 65)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.PFIR6.3/0.25', N'MAG COLONNE 2', N'I - ROUGE', 150)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.PMR2.86/0.5', N'MAG COLONNE 2', N'I - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.PRB', N'MAG COLONNE 2', N'I - ROUGE', 48)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.REST6646', N'MAG COLONNE 2', N'I - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.SOUD10X6.8', N'MAG COLONNE 2', N'I - ROUGE', 30)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.SOUD12X6.8', N'MAG COLONNE 2', N'I - ROUGE', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.SOUD8X6.8', N'MAG COLONNE 2', N'I - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.TH.OB8', N'MAG COLONNE 2', N'I - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.TH.PFB1.5-2.5', N'MAG COLONNE 2', N'I - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.TH.PFR0.5-1.5', N'MAG COLONNE 2', N'I - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.TH.PMB1.5-2.5', N'MAG COLONNE 2', N'I - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.TH.PMR0.5-1.5', N'MAG COLONNE 2', N'I - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.TUB.10-10', N'MAG COLONNE 2', N'I - ROUGE', 85)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.TUB.10-6', N'MAG COLONNE 2', N'I - ROUGE', 65)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.TUB.10-8', N'MAG COLONNE 2', N'I - ROUGE', 65)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.TUB.16-10', N'MAG COLONNE 2', N'I - ROUGE', 65)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.TUB.16-6', N'MAG COLONNE 2', N'I - ROUGE', 85)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COSS.TUB.16-8', N'MAG COLONNE 2', N'I - ROUGE', 72)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COTT.FOREST.M', N'NM COLONNE 3', N'I - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COTT.FOREST.XL', N'NM COLONNE 3', N'I - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COTT.FOREST.XS', N'NM COLONNE 3', N'I - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUD.100PVC20MF', N'MAG COLONNE 1', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUD.100PVC45F', N'MAG COLONNE 1', N'F - ROUGE', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUD.100PVC45MF', N'MAG COLONNE 1', N'F - ROUGE', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUD.100PVC87F', N'MAG COLONNE 1', N'F - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUD.100PVC87MF', N'MAG COLONNE 1', N'F - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUD.110PVC45F', N'MAG COLONNE 1', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUD.32PVC45F', N'MAG COLONNE 4', N'F - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUD.32PVC45MF', N'MAG COLONNE 4', N'F - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUD.32PVC87F', N'MAG COLONNE 4', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUD.33.7X2.6', N'NM COLONNE 3', N'H - ROUGE', 34)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUD.CU12', N'MAG COLONNE 4', N'F - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUD.CU16', N'MAG COLONNE 4', N'F - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUD.GALV.F1"', N'MAG COLONNE 4', N'F - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUD.GALV.F1/2', N'MAG COLONNE 4', N'F - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUD.GCU12-3/8F', N'MAG COLONNE 4', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUD.ISI32X32', N'MAG COLONNE 4', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUD.PER1/2X16', N'MAG COLONNE 4', N'F - ROUGE', 13)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUP.19GCU', N'MAG COLONNE 1', N'G- VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUP.AC_F1/2PAS6', N'MAG COLONNE 2', N'I - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUP.AC_F1/4PAS6', N'MAG COLONNE 2', N'I - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUP.AC_M1/4PAS6', N'MAG COLONNE 2', N'I - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUP.AC_M3/8PAS6', N'MAG COLONNE 2', N'I - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUP.AC_PAS6', N'MAG COLONNE 2', N'I - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUP.AC_PAS8SECURITE', N'MAG COLONNE 2', N'I - JAUNE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUP.CIRCUIT100A', N'MAGBU COLONNE 3', N'I - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUP.CIRCUIT150A', N'MAGBU COLONNE 3', N'I - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUP.ECH69922956830', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUP.GROM1/2F', N'MAGBU COLONNE 3', N'I - VERTE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUP.GROM3/8M', N'MAGBU COLONNE 3', N'I - VERTE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUP.WOLRMM', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUR.GAL104', N'MAGBU COLONNE 2', N'C - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUR.NOR101697', N'MAGBU COLONNE 2', N'C - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUR.NOR103637', N'MAGBU COLONNE 2', N'C - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUR.REN8200830182', N'MAGBU COLONNE 3', N'H - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUR.REN8200830187', N'MAGBU COLONNE 3', N'H - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUR.WOL42005', N'MAGBU COLONNE 2', N'D - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUR.WOL42009', N'MAGBU COLONNE 2', N'D - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUS.ECH13192311120', N'MAGBU COLONNE 2', N'E - BLEU', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUT. ASTEACK', N'NM COLONNE 4', N'N - BLEU', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUT.AENDI12', N'MAGBU COLONNE 3', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUT.AENDI14', N'MAG COLONNE 1', N'G- VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUT.COL1X200', N'MAG COLONNE 1', N'G- VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUT.COL2X1', N'MAG COLONNE 1', N'G- VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUT.COL2X200', N'MAG COLONNE 1', N'G- VERT', 1)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUT.ECH69901654530', N'MAGBU COLONNE 2', N'E - BLEU', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUT.GRIGNOT', N'MAG COLONNE 2', N'I VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUT.MAROUF', N'MAG COLONNE 4', N'C - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUT.PEINT6', N'MAG FOURNI', N'DIVERS', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUT.PEINT7', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUT.PEINT8', N'MAG COLONNE 1', N'G- VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUT.PEINTI10', N'MAG COLONNE 1', N'G- VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUT.PEINTI8', N'MAGBU COLONNE 3', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUT.SN300', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUT.STH40017133801', N'MAGBU COLONNE 2', N'E - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUT.STH40017133803', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUT.STH41127134100', N'MAGBU COLONNE 2', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUT.STH41197134100', N'MAG FOURNI', N'DIVERS', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUV.A4-CI', N'NM COLONNE 2', N'G - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUV.ECH13031306230', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUV.ECH13132840630', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUV.ECH14587143130', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUV.ECH61027542230', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUV.ECH61027627631', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUV.ECHA160000241', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUV.ECHA162000020', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUV.ECHA320000080', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUV.F700X700/125', N'PARC', N'CARBURANT', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'COUV.P1P2', N'NM COLONNE 3', N'K - VERT', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CRAI.BLEU_GRAS', N'MAG COLONNE 4', N'B - ROUGE', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CRAI.DE_BRIANC', N'MAG COLONNE 4', N'B - ROUGE', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CRAI.JAU.N_GRAS', N'MAG COLONNE 4', N'B - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CRAI.JAU.SURF.LIS', N'MAG COLONNE 4', N'B - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CRAI.PNEU', N'MAG COLONNE 4', N'B - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CRAI.ROU.GRAS', N'MAG COLONNE 4', N'B - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CRAM.ANTI_DERAP', N'NM COLONNE 3', N'J - ROUGE', 17)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CRAY.ANIL.', N'MAG COLONNE 4', N'B - ROUGE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CRAY.CHARP', N'MAG COLONNE 4', N'B - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CREM.HYD.', N'MAG FOURNI', N'DIVERS', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CREM.HYD.', N'MAG COLONNE 1', N'C - JAUNE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CREP.HIFSH63585', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CROC.1.5T', N'MAG COLONNE 4', N'D - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CROC.CTRVT7X200', N'MAG COLONNE 4', N'E- JAUNE', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CROC.CTRVT7X250', N'MAG COLONNE 4', N'E- JAUNE', 19)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CROC.SORC95007', N'MAGBU COLONNE 3', N'I - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CROC.STH00003530605', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CROC.WOLRTM', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CROC_FUM4DTS', N'NM COLONNE 4', N'P - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CROC_PLAST16590', N'MAGBU COLONNE 3', N'G - ROUGE', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CUIS.T40', N'NM COLONNE 3', N'L - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CUIS.T41', N'NM COLONNE 3', N'L - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CUIS.T42', N'NM COLONNE 3', N'L - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CUIS.T43', N'NM COLONNE 3', N'L - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CUIS.T44', N'NM COLONNE 3', N'L - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CUIS.T45', N'NM COLONNE 3', N'L - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CUIV.ECROUI08', N'NM COLONNE 1', N'B - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CULO.100PVC45F', N'MAG COLONNE 1', N'F - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CULO.100PVC45MF', N'MAG COLONNE 1', N'F - ROUGE', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CULO.100PVC45MF*', N'MAG COLONNE 1', N'F - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CURA.D.1LTC3', N'MAGBU COLONNE 3', N'I - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CURA.DTC3_300ML', N'MAGBU COLONNE 3', N'I - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CURA.MEC133005', N'MAGBU COLONNE 2', N'B - BLEU', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CURA.MEC157005', N'MAGBU COLONNE 3', N'I - BLEU', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CURA.MEC174005', N'MAGBU COLONNE 3', N'I - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CUTT.DEP', N'MAG COLONNE 2', N'I VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CUTT.PROF', N'MAG COLONNE 2', N'I VERT', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CUTT.SECURIT', N'MAG COLONNE 2', N'I VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'CUVE_CLA6005033220', N'MAGBU COLONNE 2', N'B - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DEBO.1L', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DEBO.1L', N'MAG COLONNE 1', N'C - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DEGR.HD2', N'MAG COLONNE 1', N'C - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DEGR.HD2', N'NM COLONNE 4', N'O - PALETTE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DEMI_RAC.ALU.2"', N'NM COLONNE 4', N'M - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DEMI_RAC.ALU.40', N'NM COLONNE 4', N'M - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DEMI_RAC.ALU25/1"F', N'NM COLONNE 4', N'M - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DEMI_RAC.ALU50/51', N'NM COLONNE 4', N'M - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DEMO.750ML', N'MAGBU COLONNE 3', N'H - ROSE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DENU.CABLE', N'MAG COLONNE 2', N'I VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DESH.BIO5L', N'NM COLONNE 4', N'O - PALETTE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DESO.CLIP_MEL.', N'MAG COLONNE 1', N'C - VERT', 30)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DESO.COQ.MELON', N'MAG COLONNE 1', N'C - VERT', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DESO.MECHE', N'MAG COLONNE 1', N'C - VERT', 29)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DETE.MVTS', N'NM COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DETE.RX40QZPT', N'NM COLONNE 2', N'D - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DETE.SCHXUX0ARCTT16', N'NM COLONNE 1', N'A - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DETE.SCHXUX0ARCTT16T', N'NM COLONNE 1', N'A - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DETE.STARNET', N'MAGBU COLONNE 3', N'H - ROSE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DEVI.ESCARGOT', N'NM COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DEVI.FILASSE', N'MAG COLONNE 4', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DIAP.ECH12311215030', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DIAP.ECH12314103930', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DIFF.SAF12189', N'NM COLONNE 3', N'H - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DILU.5L_BIO', N'MAGASIN LUBRIFIANT', N'C2 JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DILU.N5L', N'MAGASIN LUBRIFIANT', N'C2 JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DILU.P5L', N'MAGASIN LUBRIFIANT', N'C2 JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DILU.TEX30', N'MAGASIN LUBRIFIANT', N'C4 VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DIOD./LUNET', N'NM COLONNE 3', N'K - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISJ.FG261140', N'NM COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISJ.FG261150', N'NM COLONNE 2', N'D - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISJ.MG21407', N'NM COLONNE 1', N'A - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISJ.SCHA9N61522', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISJ.SCHA9N61526', N'NM COLONNE 1', N'A - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISJ.SCHA9N61528', N'NM COLONNE 1', N'A - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISJ.SCHNLSN10C', N'NM COLONNE 2', N'D - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISP.HYDROCARBURES', N'MAG FOURNI', N'DIVERS', 6)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.115DIAM', N'MAGBU COLONNE 3', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.115DIAMCA', N'MAGBU COLONNE 3', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.115EB', N'MAG COLONNE 2', N'H - ROUGE', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.115TR', N'MAG COLONNE 2', N'H - ROUGE', 37)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.125DIAM', N'MAGBU COLONNE 3', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.125DIAMCA', N'MAGBU COLONNE 3', N'G - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.125EB', N'MAG COLONNE 2', N'H - ROUGE', 22)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.125F1', N'MAG COLONNE 2', N'H - ROUGE', 62)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.125MULTICUT', N'MAGBU COLONNE 3', N'G - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.125TR2.5', N'MAG COLONNE 2', N'H - ROUGE', 48)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.180DIAMCA', N'MAG COLONNE 2', N'H - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.230DIAM', N'MAG COLONNE 2', N'H - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.230DIAMU', N'MAG COLONNE 2', N'H - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.230EB', N'MAG COLONNE 2', N'H - ROUGE', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.230TR.EP3', N'MAG COLONNE 2', N'H - ROUGE', 40)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.300DIAM', N'MAG COLONNE 2', N'H - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.63TR', N'MAGBU COLONNE 3', N'G - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.65TR', N'MAGBU COLONNE 3', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.BLEU', N'MAGBU COLONNE 3', N'H - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.KM25', N'MAGBU COLONNE 2', N'B - BLANCHE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.LAM110X40', N'MAG COLONNE 2', N'H - ROUGE', 34)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.LAM110X80', N'MAG COLONNE 2', N'H - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.LAM125X40', N'MAG COLONNE 2', N'H - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.LAM125X80', N'MAG COLONNE 2', N'H - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.LAM180X40', N'MAG COLONNE 2', N'H - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.REN7701204286', N'MAGBU COLONNE 3', N'I - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.REN7701206339', N'MAGBU COLONNE 3', N'I - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.REN7701209839', N'MAGBU COLONNE 3', N'I - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.TACHY125', N'MAGBU COLONNE 3', N'H - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DISQ.TACHY140', N'MAGBU COLONNE 3', N'H - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DIST.PT900F', N'MAG COLONNE 1', N'F - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DIST.SAV350ML', N'MAG COLONNE 1', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DOLI.1G', N'MAG COLONNE 1', N'C - JAUNE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DOMI.10MM', N'NM COLONNE 2', N'D - ROUGE', 17)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DOMI.16MM', N'NM COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DOMI.25MM', N'NM COLONNE 2', N'D - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DOMI.6MM', N'NM COLONNE 2', N'D - ROUGE', 14)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DOSS.SUSP30', N'NM COLONNE 2', N'F - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DOUI.FAC17H', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DOUI.FACEF6DM8L', N'MAG COLONNE 2', N'H - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DOUI.FACSTM.8', N'MAG COLONNE 2', N'H - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DOUI.SAMSH14', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'DVD_+R', N'NM COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECHE.WOLORM', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECLA.RVI5021186039', N'MAGBU COLONNE 3', N'I - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRA.CENS54CE', N'NM COLONNE 3', N'K - BLEU', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRA.CENS59CE', N'NM COLONNE 3', N'K - BLEU', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRA.PLEX107X52', N'NM COLONNE 3', N'H - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRA.PLEX108X88', N'NM COLONNE 3', N'H - ROUGE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRA.PLEXI.EXT9000', N'NM COLONNE 3', N'H - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRA.PLEXI.EXT9100', N'NM COLONNE 3', N'H - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRA.PLEXI.INT9000', N'NM COLONNE 3', N'H - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRA.PLEXI.INT9100V', N'NM COLONNE 3', N'H - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRA.POLY108X51', N'NM COLONNE 3', N'H - ROUGE', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRA.STH00008840511', N'NM COLONNE 3', N'K - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.08ETCAOL1290', N'MAGBU COLONNE 3', N'I - VERTE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.AIL06', N'MAG COLONNE 3', N'T - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.AIL08', N'MAG COLONNE 3', N'T - ROUGE', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.AIL10', N'MAG COLONNE 3', N'T - ROUGE', 41)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.AIL12', N'MAG COLONNE 3', N'T - ROUGE', 13)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.BN04', N'MAG COLONNE 3', N'T - ROUGE', 139)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.BN05', N'MAG COLONNE 3', N'T - ROUGE', 200)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.BN06', N'MAG COLONNE 3', N'T - ROUGE', 242)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.BN08', N'MAG COLONNE 3', N'T - ROUGE', 56)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.BN10', N'MAG COLONNE 3', N'T - ROUGE', 118)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.BN10A2', N'MAG COLONNE 4', N'E - ROUGE', 67)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.BN12', N'MAG COLONNE 3', N'T - ROUGE', 96)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.BN1210.9', N'MAG COLONNE 3', N'T - ROUGE', 34)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.BN14', N'MAG COLONNE 3', N'T - ROUGE', 84)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.BN16', N'MAG COLONNE 3', N'T - ROUGE', 46)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.BN18', N'MAG COLONNE 3', N'T - ROUGE', 53)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.BN20', N'MAG COLONNE 3', N'T - ROUGE', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.CAOS12-90', N'MAGBU COLONNE 3', N'I - VERTE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.CLA11363160', N'MAGBU COLONNE 2', N'B - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.CLA6005000461', N'MAGBU COLONNE 2', N'B - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.CU06', N'MAG COLONNE 3', N'T - ROUGE', 81)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.ECH61032052130', N'MAGBU COLONNE 2', N'E - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.ECH90010605020', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.ECH90050200008', N'MAGBU COLONNE 2', N'E - BLEU', 103)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.ECH90051100010', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.EUT27368', N'MAGBU COLONNE 2', N'C - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.FTG', N'NM COLONNE 1', N'D - GRIS', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.GCU06', N'MAG COLONNE 3', N'T - ROUGE', 91)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.H04', N'MAG COLONNE 3', N'T - ROUGE', 708)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.H05', N'MAG COLONNE 3', N'T - ROUGE', 438)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.H05A2', N'MAG COLONNE 4', N'E - ROUGE', 150)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.H06', N'MAG COLONNE 3', N'T - ROUGE', 387)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.H07', N'MAG COLONNE 3', N'T - ROUGE', 242)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.H08', N'MAG COLONNE 3', N'T - ROUGE', 390)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.H08A2', N'MAG COLONNE 4', N'E - ROUGE', 177)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.H10', N'MAG COLONNE 3', N'T - ROUGE', 558)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.H10A2', N'MAG COLONNE 4', N'E - ROUGE', 86)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.H12', N'MAG COLONNE 3', N'T - ROUGE', 381)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.H12A2', N'MAG COLONNE 4', N'E - ROUGE', 85)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.H14', N'MAG COLONNE 3', N'T - ROUGE', 175)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.H16', N'MAG COLONNE 3', N'T - ROUGE', 145)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.H16_10.9', N'MAG COLONNE 3', N'T - ROUGE', 175)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.H16A2', N'MAG COLONNE 4', N'E - ROUGE', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.H18', N'MAG FOURNI', N'DIVERS', 200)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.H18', N'MAG COLONNE 3', N'T - ROUGE', 32)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.H20', N'MAG COLONNE 3', N'T - ROUGE', 36)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.H22', N'MAG COLONNE 3', N'T - ROUGE', 24)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.H22A2', N'MAG COLONNE 3', N'T - ROUGE', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.H24', N'MAG COLONNE 3', N'T - ROUGE', 96)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.H27', N'MAG COLONNE 3', N'T - ROUGE', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.H30', N'MAG COLONNE 3', N'T - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.NOR103018', N'MAGBU COLONNE 2', N'C - ROUGE', 118)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.NOR103019', N'MAGBU COLONNE 2', N'C - ROUGE', 93)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.NOR103022', N'MAGBU COLONNE 2', N'C - ROUGE', 104)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.ROND06', N'MAG COLONNE 3', N'T - ROUGE', 200)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.SER230', N'MAGBU COLONNE 3', N'G - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.STH00009550801', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ECRO.STH11241418300', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EFFA.', N'NM COLONNE 2', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EFFA.FEUTRE', N'NM COLONNE 2', N'G - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EFFA.FLUO', N'NM COLONNE 2', N'G - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELAG.WOLOR750', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELAG.WOLOS83', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELEC.AHRPE3-063Z11', N'MAGBU COLONNE 3', N'I - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELEC.DS670_4', N'NM COLONNE 3', N'H - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELEC.DS800_2,5', N'NM COLONNE 3', N'H - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELEC.DS800_3.2', N'MAG FOURNI', N'DIVERS', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELEC.DS800_3.2', N'NM COLONNE 3', N'H - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELEC.DS800_4', N'NM COLONNE 3', N'H - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELEC.RUT.2.5', N'NM COLONNE 3', N'H - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELEC.RUT.3.2', N'NM COLONNE 3', N'H - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELEM.FILT/EAU', N'NM COLONNE 4', N'M - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELEM.PERSAB33062', N'MAGBU COLONNE 1', N'B - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELIN.AC12/25M', N'NM COLONNE 1', N'B - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELIN.AC12/3M', N'NM COLONNE 1', N'B - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELIN.AC14/3M', N'NM COLONNE 1', N'B - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELIN.AC14/5M', N'NM COLONNE 1', N'B - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELIN.AC20/6M', N'NM COLONNE 1', N'B - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELIN.AC22/6M', N'NM COLONNE 1', N'B - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELIN.EL3T1.5M', N'MAG COLONNE 4', N'D - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELIN.EL3T1M', N'MAG COLONNE 4', N'D - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELIN.EL3T2M', N'MAG COLONNE 4', N'D - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELIN.EL3T3M', N'MAG FOURNI', N'DIVERS', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELIN.EL3T3M', N'MAG COLONNE 4', N'D - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELIN.EL3T3MR', N'MAG COLONNE 4', N'D - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELIN.EL3T4M', N'MAG COLONNE 4', N'D - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELIN.EL4T4M', N'MAG FOURNI', N'DIVERS', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ELIN.EL5T3M', N'MAG COLONNE 4', N'D - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBA.JMC_BASELINE_01ALV', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBA.LEG031950', N'NM COLONNE 2', N'D - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBA.LEG031955', N'NM COLONNE 2', N'D - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBA.SCHABE7P08T330', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBA.SCHABE7R16T230*', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.614176717', N'MAG COLONNE 2', N'H - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.A_COL40', N'MAG COLONNE 4', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.AW10', N'MAG COLONNE 2', N'H - VERT', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.AW25', N'MAG COLONNE 2', N'H - VERT', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.AW25*', N'MAG COLONNE 2', N'H - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.AW30', N'MAG COLONNE 2', N'H - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.BORNPH1', N'MAG COLONNE 2', N'H - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.BORNPH2', N'MAG COLONNE 2', N'H - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.BORNPZ1', N'MAG COLONNE 2', N'H - VERT', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.BORNPZ2', N'MAG COLONNE 2', N'H - VERT', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.BORNPZ3', N'MAG COLONNE 2', N'H - VERT', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.CAB1.5MM', N'NM COLONNE 2', N'E - ROUGE', 200)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.CAB10MM', N'NM COLONNE 2', N'E - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.CAB1MM', N'NM COLONNE 2', N'E - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.CAB2.5MM', N'NM COLONNE 2', N'E - ROUGE', 300)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.CAB4MM', N'NM COLONNE 2', N'E - ROUGE', 300)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.CAB6MM', N'NM COLONNE 2', N'E - ROUGE', 300)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.DP_N4', N'MAG COLONNE 2', N'H - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.DP_N6L90', N'MAG COLONNE 2', N'H - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.EH1-3-25', N'MAG COLONNE 2', N'H - VERT', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.EH1-4-25', N'MAG COLONNE 2', N'H - VERT', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.EH1-5-25', N'MAG COLONNE 2', N'H - VERT', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.EH1-6-25', N'MAG COLONNE 2', N'H - VERT', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.EH3-1.5-50', N'MAG COLONNE 2', N'H - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.EH3-2.5-50', N'MAG COLONNE 2', N'H - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.EH3-2-50', N'MAG COLONNE 2', N'H - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.EH3-3-50', N'MAG COLONNE 2', N'H - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.EH3-4-50', N'MAG COLONNE 2', N'H - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.EH3-5-50', N'MAG COLONNE 2', N'H - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.EH3-6-50', N'MAG COLONNE 2', N'H - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.EH3-8-50', N'MAG COLONNE 2', N'H - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.FACEB32', N'NM COLONNE 4', N'N - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.FACEC32', N'NM COLONNE 4', N'N - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.FT0.8X5.5L25', N'MAG COLONNE 2', N'H - VERT', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.FT1.2X6.5L50', N'MAG COLONNE 2', N'H - VERT', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.FT1.2X8L50', N'MAG COLONNE 2', N'H - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.FT1X5.5L25', N'MAG COLONNE 2', N'H - VERT', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.FT1X6L50', N'MAG COLONNE 2', N'H - VERT', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.FT3.5X70', N'MAG COLONNE 2', N'H - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.FT3X70', N'MAG COLONNE 2', N'H - VERT', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.FT4.5X45', N'MAG COLONNE 2', N'H - VERT', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.FT4X70', N'MAG COLONNE 2', N'H - VERT', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.KRA2671', N'MAG COLONNE 2', N'H - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.KRA2672', N'MAG COLONNE 2', N'H - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.KRA2673', N'MAG COLONNE 2', N'H - VERT', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.KRA2674', N'MAG COLONNE 2', N'H - VERT', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.PHN1L25', N'MAG COLONNE 2', N'H - VERT', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.PHN2L50', N'MAG COLONNE 2', N'H - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.PZN1L25', N'MAG COLONNE 2', N'H - VERT', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.PZN1L90', N'MAG COLONNE 2', N'H - VERT', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.PZN2L25', N'MAG COLONNE 2', N'H - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.PZN2L90', N'MAG COLONNE 2', N'H - VERT', 3)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.PZN3L25', N'MAG COLONNE 2', N'H - VERT', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.PZN3L90', N'MAG COLONNE 2', N'H - VERT', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.SOL50', N'MAGBU COLONNE 2', N'E- JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.TS2.5', N'MAG COLONNE 2', N'H - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.TS3', N'MAG COLONNE 2', N'H - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.TS4', N'MAG COLONNE 2', N'H - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.TS5', N'MAG COLONNE 2', N'H - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.TX10', N'MAG COLONNE 2', N'H - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.TX20', N'MAG COLONNE 2', N'H - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.TX27', N'MAG COLONNE 2', N'H - VERT', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.TX30', N'MAG COLONNE 2', N'H - VERT', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'EMBO.TX40', N'MAG COLONNE 2', N'H - VERT', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.HES12A25RO36B90', N'MAGBU COLONNE 3', N'I - VERTE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.MAL6A7', N'MAG COLONNE 2', N'I - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.MAL8', N'MAG COLONNE 2', N'I - BLANC', 17)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.MAL9A10', N'MAG COLONNE 2', N'I - BLANC', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.MCAD272220', N'NM COLONNE 1', N'A - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.MCAD902830', N'NM COLONNE 1', N'A - BLEU', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.RFA', N'NM COLONNE 3', N'H - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.RFO', N'NM COLONNE 3', N'H - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.RMA', N'NM COLONNE 3', N'H - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.RMO', N'NM COLONNE 3', N'H - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.UNGAL.F1/2', N'MAG COLONNE 4', N'F - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.UNGAL.F3/4', N'MAG COLONNE 4', N'F - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACC.UNGCU16-1/2F', N'MAG COLONNE 4', N'F - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RACL.VIT35', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RAIL_HILTI', N'NM COLONNE 1', N'B - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RALL.GAL.M60X1/2', N'MAG COLONNE 4', N'F - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RALL.GAL.M60X3/4 M', N'MAG COLONNE 4', N'F - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RALL.SOL50CM', N'MAGBU COLONNE 2', N'E- JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RAMP.SIGNAL', N'MAG FOURNI', N'DIVERS', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RAMP.SIGNAL.MAGNETIQ.', N'MAG FOURNI', N'DIVERS', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RAPE.CHIM800CC', N'MAGBU COLONNE 3', N'H - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RAPE_PLAT300', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RATE.WOLDOM40', N'NM COLONNE 4', N'P - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RATI.', N'MAG COLONNE 4', N'A - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RATI.WOLHUM15', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RECE.RHEARE-CHS-A1AL', N'NM COLONNE 1', N'A - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RECE.RHEARE-CHS-A1AV', N'NM COLONNE 1', N'A - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RECE.RHEARE-CHS-A1BA', N'NM COLONNE 1', N'A - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RECE.RHEARE-CHS-AAM', N'NM COLONNE 1', N'A - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RECH.CAMION14L', N'MAG FOURNI', N'DIVERS', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RECH.CAMION14L', N'MAG COLONNE 4', N'C - BLEU', 0.2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RECH.CAMION7L', N'MAG FOURNI', N'DIVERS', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'REDU.CU14-12', N'MAG COLONNE 4', N'F - ROUGE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'REDU.CU16-12', N'MAG COLONNE 4', N'F - ROUGE', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'REDU.GALMF1"-1/2', N'MAG COLONNE 4', N'F - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'REDU.GALMF1"-3/4', N'MAG COLONNE 4', N'F - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'REDU.GALMF1/2-3/8', N'MAG COLONNE 4', N'F - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'REDU.GALMF3/4-1/2', N'MAG COLONNE 4', N'F - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'REDU.GCU.F14-1/2', N'MAG COLONNE 4', N'F - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'REDU.GCU.M16-3/4', N'MAG COLONNE 4', N'F - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'REDU.GCU.M16-3/4*', N'MAG COLONNE 4', N'F - ROUGE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'REDU.PVC100/40', N'MAG COLONNE 1', N'F - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'REDU.PVC100/50', N'MAG COLONNE 1', N'F - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'REDU.PVC100/63', N'MAG COLONNE 1', N'F - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'REDU.PVC100/75', N'MAG COLONNE 1', N'F - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'REDU.PVC40/32', N'MAG COLONNE 4', N'F - ROUGE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'REDU.PVC40/32P', N'MAG COLONNE 4', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'REDU.PVC50/40P', N'MAG COLONNE 4', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'REGL.30', N'NM COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'REGL.50', N'NM COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'REGL.COL.', N'MAG COLONNE 4', N'C - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RELA.SCHABR7S33', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RELA.SCHRM22TR33', N'NM COLONNE 4', N'N - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RENI.CLA7700037706', N'MAGBU COLONNE 2', N'B - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RENO.SURFACE', N'MAG COLONNE 1', N'B - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'REPU.MART.', N'MAG COLONNE 1', N'B - VERT', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'REPU.MOUST.', N'MAG FOURNI', N'DIVERS', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'REPU.TIQUE_PEAU', N'MAG COLONNE 1', N'C - JAUNE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'REPU.TIQUE_VET.', N'MAG COLONNE 1', N'C - JAUNE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESE.CLA7700065294', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESI.AUMZ022.918', N'NM COLONNE 1', N'A - BLEU', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESI.AUMZ025.084', N'NM COLONNE 1', N'A - BLEU', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESI.EP/AC', N'NM COLONNE 3', N'H - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESI.EP/AL', N'NM COLONNE 3', N'H - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESI.EP/MH', N'NM COLONNE 3', N'H - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESI.EP/PL', N'NM COLONNE 3', N'H - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESI.EP/TM', N'NM COLONNE 3', N'H - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.ECH12311315030', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.ECH12311347530', N'MAGBU COLONNE 2', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.ECH12312247530', N'MAGBU COLONNE 2', N'E - BLEU', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.ECH15901103432', N'MAGBU COLONNE 2', N'E - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.ECH17722040630', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.ECH17723440630', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.ECH17801307530', N'MAGBU COLONNE 2', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.ECH17801322130', N'MAGBU COLONNE 2', N'E - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.ECH17801335631', N'MAGBU COLONNE 2', N'E - BLEU', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.ECH17801342230', N'MAGBU COLONNE 2', N'E - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.ECH17801352630', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.ECH17804305230', N'MAGBU COLONNE 2', N'E - BLEU', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.ECH17804342230', N'MAGBU COLONNE 2', N'E - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.ECHP022002090', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.ECHP022010370', N'MAGBU COLONNE 2', N'E - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.ECHV450000141', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.ECHV452000050', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.EUT27480', N'MAGBU COLONNE 2', N'C - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.JM467004', N'MAGBU COLONNE 2', N'C - JAUNE', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.JM467005', N'MAGBU COLONNE 2', N'C - JAUNE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.JM467006', N'MAGBU COLONNE 2', N'C - JAUNE', 16)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.NOR102946', N'MAGBU COLONNE 2', N'C - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.STH11231900600', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.STH11241953500', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.STH11281223000', N'MAGBU COLONNE 2', N'D - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RESS.STH41387119100', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RIVE.4,X17A2', N'MAG COLONNE 3', N'Q - VERT', 0.5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RIVE.4.8X12', N'MAG COLONNE 3', N'Q - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RIVE.4.8X14', N'MAG COLONNE 3', N'Q - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RIVE.4.8X16A2', N'MAG COLONNE 3', N'Q - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RIVE.4.8X18AV', N'MAG COLONNE 3', N'Q - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RIVE.4.8X25AV', N'MAG COLONNE 3', N'Q - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROBI.A_SOUD18', N'MAG COLONNE 4', N'F - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROBI.ABS1/2', N'MAG COLONNE 4', N'F - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROBI.ABS3/4', N'MAG COLONNE 4', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROBI.BM000543', N'MAGBU COLONNE 2', N'C - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROBI.D''ARRET1/2', N'MAG COLONNE 4', N'F - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROBI.D''ARRET12', N'MAG COLONNE 4', N'F - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROBI.DE_PURGE1/4', N'MAG COLONNE 4', N'F - ROUGE', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROBI.EQR.ROS.3/8', N'MAG COLONNE 4', N'F - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROBI.MAL', N'MAG COLONNE 4', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROBI.PRE13088', N'MAG COLONNE 1', N'D - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROBI.PUIS1/2', N'MAG COLONNE 4', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROLL.CORRECT2', N'NM COLONNE 2', N'E - BLEU', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.AXE_BASCUL', N'MAGBU COLONNE 2', N'C - ROSE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CAR04X12X1,25', N'MAG COLONNE 3', N'U - ROUGE', 114)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CAR04X20', N'MAG COLONNE 3', N'U - ROUGE', 303)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CAR05X20X1,25', N'MAG COLONNE 3', N'U - ROUGE', 200)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CAR06X18', N'MAG COLONNE 3', N'U - ROUGE', 148)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CAR06X25X1.25', N'MAG COLONNE 3', N'U - ROUGE', 254)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CAR08X24X3', N'MAG COLONNE 3', N'U - ROUGE', 150)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CAR08X25X1,5', N'MAG COLONNE 3', N'U - ROUGE', 81)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CAR10X30X1.5', N'MAG COLONNE 3', N'U - ROUGE', 345)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CAR10X30X3', N'MAG COLONNE 3', N'U - ROUGE', 47)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CAR10X30X4', N'MAG COLONNE 3', N'U - ROUGE', 40)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CAR12X40X2', N'MAG COLONNE 3', N'U - ROUGE', 140)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CAR12X50X4', N'MAG COLONNE 3', N'U - ROUGE', 52)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CAR14X50X2,5', N'MAG COLONNE 3', N'U - ROUGE', 75)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CAR16X30X3', N'MAG COLONNE 3', N'U - ROUGE', 125)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CAR16X50X3', N'MAG COLONNE 3', N'U - ROUGE', 63)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CAR18X56X4', N'MAG COLONNE 3', N'U - ROUGE', 54)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CAR20X60X3', N'MAG COLONNE 3', N'U - ROUGE', 140)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CAR24X50X2', N'MAG COLONNE 3', N'U - ROUGE', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CAR24X60X4', N'MAG COLONNE 3', N'U - ROUGE', 26)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CAR30X60X4', N'MAG COLONNE 3', N'U - ROUGE', 24)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CON05X12', N'MAG COLONNE 2', N'M - VERT', 96)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CON06X14', N'MAG COLONNE 2', N'M - VERT', 255)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CON07X18', N'MAG COLONNE 2', N'M - VERT', 266)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CON08X18', N'MAG COLONNE 2', N'M - VERT', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CON10X22', N'MAG COLONNE 2', N'M - VERT', 28)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CON12X26', N'MAG COLONNE 2', N'M - VERT', 138)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CUV4X9A2', N'MAG COLONNE 2', N'M - VERT', 40)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.CUV6X13A2', N'MAG COLONNE 2', N'M - VERT', 41)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.ECH17721441030', N'MAGBU COLONNE 2', N'E - BLEU', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.ECH61023904130', N'MAGBU COLONNE 2', N'E - BLEU', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.EUT27358', N'MAGBU COLONNE 2', N'C - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.EV04', N'MAG COLONNE 2', N'M - VERT', 130)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.EV05', N'MAG COLONNE 2', N'M - VERT', 160)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.EV06', N'MAG COLONNE 2', N'M - VERT', 105)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.EV07', N'MAG COLONNE 2', N'M - VERT', 200)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.EV08', N'MAG COLONNE 2', N'M - VERT', 40)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.EV10', N'MAG COLONNE 2', N'M - VERT', 28)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.EV14', N'MAG COLONNE 2', N'M - VERT', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.EV16', N'MAG COLONNE 2', N'M - VERT', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.EV18', N'MAG COLONNE 2', N'M - VERT', 26)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.GAL448004', N'MAGBU COLONNE 2', N'C - JAUNE', 19)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.GR04', N'MAG COLONNE 2', N'M - VERT', 70)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.GR05', N'MAG COLONNE 2', N'M - VERT', 151)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.GR06', N'MAG COLONNE 2', N'M - VERT', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.GR08', N'MAG COLONNE 2', N'M - VERT', 107)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.GR10', N'MAG COLONNE 2', N'M - VERT', 53)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.GR12', N'MAG COLONNE 2', N'M - VERT', 133)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.GR14', N'MAG COLONNE 2', N'M - VERT', 51)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.GR16', N'MAG COLONNE 2', N'M - VERT', 31)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.GR16A2', N'MAG COLONNE 4', N'E - ROUGE', 30)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.GR18', N'MAG COLONNE 2', N'M - VERT', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.GR20', N'MAG COLONNE 2', N'M - VERT', 70)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.GR22', N'MAG COLONNE 2', N'M - VERT', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.GR24', N'MAG COLONNE 2', N'M - VERT', 23)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.NOR102505', N'MAGBU COLONNE 2', N'C - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.PL.CH06', N'MAG COLONNE 3', N'U - ROUGE', 1287)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.PL.CH10', N'MAG COLONNE 3', N'U - ROUGE', 427)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.PL.CH12', N'MAG COLONNE 3', N'U - ROUGE', 255)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.PL.CH14', N'MAG COLONNE 3', N'U - ROUGE', 33)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.PL.CH16', N'MAG COLONNE 3', N'U - ROUGE', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.PL.CH17AB', N'MAG COLONNE 3', N'U - ROUGE', 96)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.PL.CH18', N'MAG COLONNE 3', N'U - ROUGE', 18)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.PL.CH20', N'MAG COLONNE 3', N'U - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.PL.CH22', N'MAG COLONNE 3', N'U - ROUGE', 69)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.PL.CH24', N'MAG COLONNE 3', N'U - ROUGE', 67)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.PL.CH26', N'MAG COLONNE 3', N'U - ROUGE', 35)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.PL.CH27', N'MAG COLONNE 3', N'U - ROUGE', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.PL.CH40', N'MAG COLONNE 3', N'U - ROUGE', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.PL.DEC05', N'MAG COLONNE 3', N'U - ROUGE', 500)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.PL.DEC06A2', N'MAG COLONNE 4', N'E - ROUGE', 250)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.PL.DEC08', N'MAG COLONNE 3', N'U - ROUGE', 234)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.PL.DEC08A2', N'MAG COLONNE 4', N'E - ROUGE', 140)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.PL.DEC10A2', N'MAG COLONNE 4', N'E - ROUGE', 284)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.PL.DEC12A2', N'MAG COLONNE 4', N'E - ROUGE', 136)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.PL.DEC14', N'MAG COLONNE 3', N'U - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.PL10A2', N'MAG COLONNE 4', N'E - ROUGE', 46)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.PL20', N'MAG COLONNE 3', N'U - ROUGE', 49)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.RESS10', N'MAG COLONNE 3', N'U - ROUGE', 470)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.RESS12', N'MAG COLONNE 2', N'M - VERT', 99)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.RESS8', N'MAG COLONNE 2', N'M - VERT', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.STH00009580923', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.STH00009581021', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROND.STH11191628925', N'MAGBU COLONNE 2', N'D - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROTA.KAR47632530', N'MAGBU COLONNE 2', N'C - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROTA.KAR47670220', N'MAGBU COLONNE 2', N'C - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROTU.EUT27577', N'MAGBU COLONNE 2', N'C - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROTU.EUT27580', N'MAGBU COLONNE 2', N'C - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROUE_200 X20X50', N'MAGBU COLONNE 2', N'C - NOIR', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROUL.COLLEUR', N'MAG COLONNE 4', N'C - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROUL.ECH90080006001', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROUL.ECH90080036000', N'MAGBU COLONNE 2', N'E - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROUL.ECH90080406001', N'MAGBU COLONNE 2', N'E - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROUL.ECH90081000629', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROUL.ECH90081006201', N'MAGBU COLONNE 2', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROUL.ECH90081206201', N'MAGBU COLONNE 2', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROUL.JETABLE180', N'MAG COLONNE 4', N'C - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROUL.NOR102571', N'MAGBU COLONNE 2', N'C - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROUL.NOR104028', N'MAGBU COLONNE 2', N'C - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROUL.SKF16011', N'NM COLONNE 1', N'D - GRIS', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'ROUL.SKF6000-2RSI', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.2FACE12/10M', N'MAG COLONNE 2', N'K - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.3M800.12', N'MAG COLONNE 2', N'K - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.3M800.14', N'MAG COLONNE 2', N'K - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.AB', N'NM COLONNE 2', N'E - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.AB19X66', N'NM COLONNE 2', N'E - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.AUTOFUS', N'MAG COLONNE 2', N'K - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.DYMS0720530S', N'NM COLONNE 2', N'E - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.IBLC15', N'MAG COLONNE 2', N'K - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.IBLC50', N'MAG COLONNE 2', N'K - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.IBLEU15', N'MAG COLONNE 2', N'K - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.IBLEU50', N'MAG COLONNE 2', N'K - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.IBRUN15', N'MAG COLONNE 2', N'K - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.IGRIS15', N'MAG COLONNE 2', N'K - ROUGE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.IJAUNE15', N'MAG COLONNE 2', N'K - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.INOIR15', N'MAG COLONNE 2', N'K - ROUGE', 30)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.INOIR19', N'MAG COLONNE 2', N'K - ROUGE', 22)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.INOIR50', N'MAG COLONNE 2', N'K - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.IROUG15', N'MAG COLONNE 2', N'K - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.IROUG50', N'MAG COLONNE 2', N'K - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.IVERT15', N'MAG COLONNE 2', N'K - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.IVERT50', N'MAG COLONNE 2', N'K - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.IVIOL15', N'MAG COLONNE 2', N'K - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.IV-J15', N'MAG COLONNE 2', N'K - ROUGE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.MASQ25', N'MAG COLONNE 2', N'K - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.MASQ25CL', N'MAG COLONNE 2', N'K - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.MASQ40', N'MAG COLONNE 2', N'K - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.MASQ50CL', N'MAG COLONNE 2', N'K - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.SIGN', N'MAG COLONNE 2', N'K - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.SIGNLARG', N'MAG FOURNI', N'DIVERS', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.SIGNLARG', N'MAG COLONNE 2', N'K - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.TEFLON', N'MAG COLONNE 2', N'K - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUBA.TOILE', N'MAG COLONNE 2', N'K - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUST.DN25MM', N'MAGBU COLONNE 3', N'H - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'RUST.DN35MM', N'MAGBU COLONNE 3', N'H - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SAC_KAR69074790', N'MAG COLONNE 1', N'E - BLANC', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SAC_LESTAGE', N'NM COLONNE 4', N'N - BLEU', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SAC_POUB120LB', N'MAG FOURNI', N'DIVERS', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SAC_POUB130L', N'MAG FOURNI', N'DIVERS', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SAC_POUB130L', N'MAG COLONNE 1', N'E - ROUGE', 301)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SAC_POUB30L', N'MAG FOURNI', N'DIVERS', 14)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SAC_POUB30L', N'MAG COLONNE 1', N'E - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SAC_POUB50L', N'MAG FOURNI', N'DIVERS', 24)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SAC_POUB50L', N'MAG COLONNE 1', N'E - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SAC_POUB6L', N'MAG COLONNE 1', N'E - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SAC_STH49015009031', N'MAG COLONNE 1', N'E - BLANC', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SACO.HUS505690510', N'NM COLONNE 3', N'I - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SAND.L100', N'MAG FOURNI', N'DIVERS', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SAND.L100', N'MAGBU COLONNE 3', N'G - ROUGE', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SAND.L90', N'MAGBU COLONNE 3', N'G - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SAND.LOT', N'MAGBU COLONNE 3', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SANG.13191721530', N'MAGBU COLONNE 2', N'E - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SANG.2T2.5M', N'MAG COLONNE 4', N'D - JAUNE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SANG.3T2M', N'MAG COLONNE 4', N'D - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SANG.3T3M', N'MAG COLONNE 4', N'D - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SANG.3T4M', N'MAG COLONNE 4', N'D - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SANG.3T5M', N'MAG COLONNE 4', N'D - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SANG.AR25AUTO', N'MAG FOURNI', N'DIVERS', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SANG.AR5M1T2DGEC', N'MAG COLONNE 4', N'D - JAUNE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SANG.AR5M900', N'MAG COLONNE 4', N'D - JAUNE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SANG.AR5M900SF', N'MAG COLONNE 4', N'D - JAUNE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SANG.AR9M2TDGEC', N'MAG FOURNI', N'DIVERS', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SANG.AR9M2TDGEC', N'MAG COLONNE 4', N'D - JAUNE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SANG.ARSF1T35MM', N'MAG FOURNI', N'DIVERS', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SAPI.STH00008812800', N'MAGBU COLONNE 2', N'D - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SATU.BOIS_CLAIR', N'MAGASIN LUBRIFIANT', N'C3 ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SAVO.AT4L', N'MAG COLONNE 1', N'B - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SAVO.GEL350', N'MAG COLONNE 1', N'B - VERT', 66)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SAVO.GEL500ML', N'MAG COLONNE 1', N'B - VERT', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SAVO.GELGS', N'MAG COLONNE 1', N'B - VERT', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SCHA.BIO5', N'MAG FOURNI', N'DIVERS', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SCHA.BIO5', N'MAGBU COLONNE 3', N'H - ROSE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SCIE_BUC530MM', N'MAG COLONNE 1', N'G- VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SCIE_BUC762MM', N'MAG COLONNE 1', N'G- VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SCIE_CIRC.GKS65', N'NM COLONNE 4', N'M - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SCIE_DTS_DOUCES', N'MAGBU COLONNE 2', N'E - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SCIE_TREPAN52', N'MAGBU COLONNE 2', N'F - BLEU', 2)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SEAU_POLY.12L', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SEGM.ECH10001143230', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SEGM.ECHA101000070', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SEL_ADOUCIS.', N'PARC', N'CARBURANT', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SEL_DNEIG.', N'NM COLONNE 4', N'O - PALETTE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SERF.PAN+LANG.ERG', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SERP.', N'MAG FOURNI', N'DIVERS', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SERP.', N'MAG COLONNE 1', N'E - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SERP.ITALIEN.', N'MAGBU COLONNE 2', N'D - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SERR.CABLE03', N'MAG COLONNE 4', N'D - JAUNE', 54)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SERR.CABLE06.5', N'MAG COLONNE 4', N'D - JAUNE', 52)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SERR.CABLE08', N'MAG COLONNE 4', N'D - JAUNE', 28)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SERR.CABLE10', N'MAG COLONNE 4', N'D - JAUNE', 28)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SERR.CABLE13', N'MAG COLONNE 4', N'D - JAUNE', 33)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SERR.CABLE14', N'MAG COLONNE 4', N'D - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SERR.CABLE16', N'MAG COLONNE 4', N'D - JAUNE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SERR.CABLE19', N'MAG COLONNE 4', N'D - JAUNE', 13)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SERR.CABLE22', N'MAG COLONNE 4', N'D - JAUNE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SERR.ENC.AX30', N'MAG COLONNE 4', N'E- JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SERR.WIL856460', N'MAG COLONNE 4', N'E- JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SILE.ECH10090714730', N'MAGBU COLONNE 2', N'E - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SILE.ECH61091040430', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SILE.ECH61091051830', N'MAGBU COLONNE 2', N'E - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SILE.STH11297909700', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SILI.NEUT.BLC', N'MAG COLONNE 4', N'A - VERT', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SILI.NEUT.GRIS', N'MAG COLONNE 4', N'A - VERT', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SILI.NEUT.TRANS', N'MAG COLONNE 4', N'A - VERT', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SILI.SAN.BLC', N'MAG COLONNE 4', N'A - VERT', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SILI.SAN.TRANS', N'MAG COLONNE 4', N'A - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SIRE.WERMA11100075', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SOCL.LEG052249*', N'NM COLONNE 2', N'C - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SOCL.LEG052949', N'NM COLONNE 2', N'C - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SOCL.LEG055558', N'NM COLONNE 2', N'E - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SOCL.LEG055707', N'NM COLONNE 2', N'E - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SOND.VEG52/12M', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SORT.LEG069888', N'NM COLONNE 2', N'E - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SORT.LEG664795', N'NM COLONNE 2', N'E - ROUGE', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SOUD.33%Z', N'NM COLONNE 3', N'H - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SOUP.KAR28848720', N'MAGBU COLONNE 2', N'C - JAUNE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SOUR.OPT.VERT.', N'NM COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SOUS_CHEM.ASS', N'NM COLONNE 2', N'F - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SP95.E5LUTZ', N'MAG FOURNI', N'DIVERS', 1409.33)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SP95E5', N'PARC', N'CARBURANT', 2657.86)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPID.', N'MAGBU COLONNE 2', N'C - NOIR', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPIR.N10', N'NM COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPIR.N6', N'NM COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPIR.N8', N'NM COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.CARB', N'MAGBU COLONNE 3', N'I - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.COKP', N'MAG FOURNI', N'DIVERS', 16)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.COKP', N'MAGBU COLONNE 3', N'I - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.COKP750ML', N'MAG COLONNE 1', N'C - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.COLLE', N'MAG COLONNE 4', N'A - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.DECO', N'MAGBU COLONNE 3', N'H - ROSE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.DEGI', N'MAG FOURNI', N'DIVERS', 13)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.DEGI.750', N'MAG COLONNE 1', N'A - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.DEGO', N'MAG FOURNI', N'DIVERS', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.DEGO', N'MAG COLONNE 4', N'A - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.DEGR.FB', N'MAG FOURNI', N'DIVERS', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.DEGR.FB', N'MAG COLONNE 1', N'B - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.DEGRIP', N'MAG FOURNI', N'DIVERS', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.DEGRIP', N'MAG COLONNE 1', N'A - ROUGE', 18)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.DEPOUS.', N'MAG COLONNE 1', N'B - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.DESI.ONE_SHOT', N'MAG COLONNE 1', N'C - VERT', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.DESO', N'MAG FOURNI', N'DIVERS', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.DESO', N'MAG COLONNE 1', N'C - VERT', 18)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.DESO.D', N'MAG FOURNI', N'DIVERS', 13)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.DESO.D', N'MAG COLONNE 1', N'C - VERT', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.DEST.OD', N'MAG FOURNI', N'DIVERS', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.DETA.', N'MAG COLONNE 1', N'B - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.DETE.FUIT', N'MAG COLONNE 4', N'A - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.HUILE_COUPE', N'MAG FOURNI', N'DIVERS', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.HUILE_COUPE', N'MAG COLONNE 1', N'A - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.LISSE_JOINT', N'MAG COLONNE 1', N'A - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.LUBR.BLANC', N'MAG FOURNI', N'DIVERS', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.LUBR.CM', N'MAG FOURNI', N'DIVERS', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.LUBR.INTFGOG', N'MAG FOURNI', N'DIVERS', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.LUBR.INTFLTF', N'MAG FOURNI', N'DIVERS', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.LUBR.INTFLTF', N'MAG COLONNE 1', N'B - BLEU', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.LUBR.TEF', N'MAG COLONNE 1', N'A - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.MOUS.N', N'MAG FOURNI', N'DIVERS', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.MOUS.NDD', N'MAG COLONNE 1', N'C - VERT', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.MOUST+TIQ', N'MAG COLONNE 1', N'C - JAUNE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.NETT.ECR', N'MAG COLONNE 1', N'C - VERT', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.NETT.ELEC', N'MAG FOURNI', N'DIVERS', 13)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.NETT.ELEC', N'MAG COLONNE 1', N'B - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.NETT.ELECSR', N'MAG COLONNE 1', N'B - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.NETT.FR', N'MAG FOURNI', N'DIVERS', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.NETT.FR', N'MAGBU COLONNE 3', N'I - BLEU', 34)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.NETT.VIT', N'MAG FOURNI', N'DIVERS', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.NETT.VIT', N'MAG COLONNE 1', N'C - VERT', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.NEUT.ROUIL', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.NEUT.ROUIL', N'MAG COLONNE 1', N'A - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.SILICONE', N'MAG COLONNE 1', N'A - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.SOUD', N'MAG FOURNI', N'DIVERS', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.SOUD', N'MAG COLONNE 1', N'A - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.SOUF', N'MAG COLONNE 1', N'C - VERT', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.START', N'MAG FOURNI', N'DIVERS', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SPRA.VERN.PROT', N'MAG COLONNE 1', N'B - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'STAR.4-22W', N'NM COLONNE 2', N'D - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'STAR.4-65W', N'NM COLONNE 2', N'D - ROUGE', 12)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'STAR.U', N'NM COLONNE 2', N'D - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'STIC.VNF', N'MAGBU COLONNE 2', N'E - BLEU', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'STYL.+SOCL', N'NM COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'STYL.G-2BL', N'NM COLONNE 2', N'G - ROUGE', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'STYL.G-2N', N'NM COLONNE 2', N'G - ROUGE', 29)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'STYL.G-2R', N'NM COLONNE 2', N'G - ROUGE', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'STYL.G-2V', N'NM COLONNE 2', N'G - ROUGE', 19)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'STYL.TOPBALL_R', N'NM COLONNE 2', N'G - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SUCE.KAR69062400', N'NM COLONNE 4', N'N - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SUCR.DOSE', N'NM COLONNE 2', N'G - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SUPP.ECH17804805630', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SUPP.GUIPON', N'MAG COLONNE 4', N'C - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SUPP.LOM79511090', N'MAGBU COLONNE 2', N'C - JAUNE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SUPP.NY2826202000', N'NM COLONNE 4', N'M - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SUPP.SCHXUZX2003', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SUPP.STH56057504327', N'MAGBU COLONNE 2', N'D - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SUPP.STH56057504328', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SUPP.STH56057504329', N'MAGBU COLONNE 2', N'D - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SURL.JNE', N'NM COLONNE 2', N'G - ROUGE', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SURL.LAV.', N'NM COLONNE 2', N'G - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SURL.OR.', N'NM COLONNE 2', N'G - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SURL.POLYC.', N'NM COLONNE 3', N'K - BLEU', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SURL.RGE', N'NM COLONNE 2', N'G - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SURL.ROSE', N'NM COLONNE 2', N'G - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SURL.TURQ', N'NM COLONNE 2', N'G - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SURL.VERT', N'NM COLONNE 2', N'G - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'SWIT.HP2915', N'NM COLONNE 1', N'A - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TABL.FAUCH', N'NM COLONNE 3', N'K - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAIL.32MM', N'MAG COLONNE 2', N'L - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAIL.45MM', N'MAG COLONNE 2', N'L - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAIL.CRAY+RES', N'NM COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAMB.DR2000', N'NM COLONNE 2', N'F - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAMB.DR241CL', N'NM COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAMB.ECH17500543130', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAMI.12X50', N'MAG FOURNI', N'DIVERS', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAMI.12X50', N'MAG COLONNE 4', N'A - BLANC', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAMI.15X130', N'MAG COLONNE 4', N'A - BLANC', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAMI.16X85', N'MAG COLONNE 4', N'A - BLANC', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAMI.18X85', N'MAG FOURNI', N'DIVERS', 36)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAMI.20X85', N'MAG COLONNE 4', N'A - BLANC', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAMI.22', N'MAG COLONNE 4', N'A - BLANC', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAMP.', N'MAG FOURNI', N'DIVERS', 80)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAMP.', N'MAG COLONNE 1', N'E - JAUNE', 53)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAMP.PVC100', N'MAG COLONNE 1', N'F - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAMP.PVC32', N'MAG COLONNE 4', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAMP.PVC40', N'MAG COLONNE 4', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAMP.PVC50', N'MAG COLONNE 4', N'F - ROUGE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAMP.SPI011876', N'NM COLONNE 2', N'D - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAMP.SPI046320', N'NM COLONNE 2', N'D - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAPI.CAILL150X100', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAPI.CAILL60X80', N'MAG FOURNI', N'DIVERS', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAPI.COCO40X80', N'NM COLONNE 4', N'P - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAPI.COCO60X80', N'MAG FOURNI', N'DIVERS', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAPI.COCO60X80', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAPI.COULOIR900/1500', N'NM COLONNE 4', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAPI.SOURIS', N'NM COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TAPI.SOURIS_XXL', N'NM COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TARA.M8', N'MAG COLONNE 2', N'L - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TE_ACO523339', N'MAG COLONNE 4', N'F - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TE_CU12', N'MAG COLONNE 4', N'F - ROUGE', 11)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TE_CU14', N'MAG COLONNE 4', N'F - ROUGE', 13)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TE_CU14-12-14', N'MAG COLONNE 4', N'F - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TE_GAL.F1/2-90', N'MAG COLONNE 4', N'F - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TE_GAL1"F', N'MAG COLONNE 4', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TE_PVC.F40', N'MAG COLONNE 4', N'F - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TE_PVC.F50', N'MAG COLONNE 4', N'F - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TE_PVC.MF100+T', N'MAG COLONNE 1', N'F - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TE_PVC.MFF40', N'MAG COLONNE 4', N'F - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TE_PVC100-87MF', N'MAG COLONNE 1', N'F - ROUGE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TECH.5L', N'MAGASIN LUBRIFIANT', N'C3 ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TELE.FIND26.01', N'NM COLONNE 2', N'D - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TENA.230', N'NM COLONNE 4', N'N - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TENA.250', N'MAG FOURNI', N'DIVERS', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TEND.ACTL0014', N'MAG COLONNE 4', N'D - JAUNE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TETE_ATTILINA', N'MAGBU COLONNE 2', N'E - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TETE_ECHX047000330', N'MAGBU COLONNE 2', N'E - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TETE_HUS531009225', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TETI.GAL414116', N'MAGBU COLONNE 2', N'C - JAUNE', 17)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TETI.RECH.SAVON', N'MAG COLONNE 1', N'B - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'THER.CAFE', N'MAG COLONNE 1', N'E - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'THER.CAFE_PPE', N'MAG COLONNE 1', N'E - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIGE_FIL+E+R08', N'MAG COLONNE 4', N'E - VERT', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIGE_FIL+E+R20', N'MAG COLONNE 4', N'E - VERT', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIGE_FIL04AB', N'MAG COLONNE 3', N'V - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIGE_FIL05AZ', N'MAG COLONNE 3', N'V - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIGE_FIL06AZ', N'MAG COLONNE 3', N'V - JAUNE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIGE_FIL07AZ', N'MAG COLONNE 3', N'V - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIGE_FIL07BI', N'MAG COLONNE 3', N'V - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIGE_FIL08AZ', N'MAG COLONNE 3', N'V - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIGE_FIL10AZ', N'MAG COLONNE 3', N'V - JAUNE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIGE_FIL12AZ', N'MAG COLONNE 3', N'V - JAUNE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIGE_FIL14AZ', N'MAG COLONNE 3', N'X - BLANC', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIGE_FIL16BI', N'MAG COLONNE 3', N'X - BLANC', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIGE_FIL18AZ', N'MAG COLONNE 3', N'X - BLANC', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIGE_FIL20AZ', N'MAG COLONNE 3', N'X - BLANC', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIGE_FIL24AZ', N'MAG COLONNE 3', N'X - BLANC', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIGE_FIL30AZ4.6', N'MAG COLONNE 3', N'X - BLANC', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIGE_SCHXUZ2001', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TC06X060', N'MAG COLONNE 2', N'M - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TC06X070', N'MAG COLONNE 2', N'M - ROUGE', 200)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TC08X080', N'MAG COLONNE 2', N'M - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TC08X120', N'MAG COLONNE 2', N'M - ROUGE', 408)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TH06X040', N'MAG COLONNE 2', N'M - ROUGE', 205)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TH06X050', N'MAG COLONNE 2', N'M - ROUGE', 180)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TH06X050A2', N'MAG COLONNE 4', N'E - ROUGE', 40)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TH06X060', N'MAG COLONNE 2', N'M - ROUGE', 195)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TH06X060A2', N'MAG COLONNE 4', N'E - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TH06X100', N'MAG COLONNE 2', N'M - ROUGE', 49)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TH08X040', N'MAG COLONNE 2', N'M - ROUGE', 79)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TH08X045', N'MAG COLONNE 2', N'M - ROUGE', 99)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TH08X060', N'MAG COLONNE 2', N'M - ROUGE', 54)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TH08X070', N'MAG COLONNE 2', N'M - ROUGE', 150)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TH08X100', N'MAG COLONNE 2', N'M - ROUGE', 212)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TH10X040', N'MAG COLONNE 2', N'M - ROUGE', 64)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TH10X050', N'MAG COLONNE 2', N'M - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TH10X060', N'MAG COLONNE 2', N'M - ROUGE', 32)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TH10X070', N'MAG COLONNE 2', N'M - ROUGE', 28)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TH10X080', N'MAG COLONNE 2', N'M - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TH10X100', N'MAG COLONNE 2', N'M - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TH10X120', N'MAG COLONNE 2', N'M - ROUGE', 71)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TH12X 70', N'MAG COLONNE 2', N'M - ROUGE', 42)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TIRE.TH12X120', N'MAG COLONNE 2', N'M - ROUGE', 17)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOIL.ABR50X120', N'MAG FOURNI', N'DIVERS', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOIL.ABR50X40', N'MAG COLONNE 2', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOIL.ABR50X60', N'MAG COLONNE 2', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOIL.ABR50X80', N'MAG COLONNE 2', N'P - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOLE_1.5MX3MX8MM', N'PARC', N'SERRURERIE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOLE_1MX2MX10MM', N'PARC', N'SERRURERIE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOLE_1MX2MX2MMA2', N'PARC', N'SERRURERIE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOLE_1MX2MX4MM', N'PARC', N'SERRURERIE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOLE_LAR5/7_1.5X3', N'PARC', N'SERRURERIE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOLE_LAR5/7_1X2', N'PARC', N'SERRURERIE', 2.5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TONE.SAMML-D2850', N'NM COLONNE 2', N'F - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TORC.MIG', N'NM COLONNE 3', N'H - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TORC.VAISSEL', N'MAG FOURNI', N'DIVERS', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TORC.VAISSEL', N'MAG COLONNE 1', N'E - JAUNE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOUR.F2.5X60', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOUR.F2X60', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOUR.F3X150', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOUR.F6.5X150', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOUR.FFACAN2.5X75', N'NM COLONNE 4', N'N - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOUR.FFACAN4X200', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOUR.FVE0.4X2.5X80', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOUR.FVE0.5X3X100', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOUR.FVE0.5X3X80', N'NM COLONNE 4', N'N - BLEU', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOUR.FVE0.6X3.5X100', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOUR.H08MM', N'MAG COLONNE 3', N'X - BLANC', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOUR.H10MM', N'MAG COLONNE 3', N'X - BLANC', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOUR.H12MM', N'MAG COLONNE 3', N'X - BLANC', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOUR.PZ11X150VE', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOUR.PZ1VE1X100', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOUR.PZ2X200', N'NM COLONNE 4', N'N - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOUR.ROB412103', N'NM COLONNE 4', N'M - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TOUR.TFACAEX6X35', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TRAC.BL.HYDRO', N'MAG COLONNE 1', N'A - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TRAC.BLEU', N'MAG COLONNE 1', N'A - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TRAC.CARREL', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TRAC.JAUNE', N'MAG COLONNE 1', N'B - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TRAC.ORANGE', N'MAG COLONNE 1', N'A - ROUGE', 17)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TRAC.ROUGE', N'MAG FOURNI', N'DIVERS', 28)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TRAC.ROUGE', N'MAG COLONNE 1', N'A - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TRAC.VERT', N'MAG COLONNE 1', N'A - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TRAN.AUMZ002.880', N'NM COLONNE 1', N'A - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TRES.E4MM', N'MAGBU COLONNE 2', N'C - NOIR', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TREU.300KG_SANG', N'MAGBU COLONNE 2', N'D - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TRIA.REM.', N'MAGBU COLONNE 3', N'I - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TRIE.12C', N'NM COLONNE 2', N'G - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TRIE.24C', N'NM COLONNE 2', N'G - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TRIF.500LEDS', N'TRANSIT STOCK', N'NON STOCKE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TROM.25', N'NM COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TRUE.ANGLE', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_C30/2', N'PARC', N'METAUX', 24.8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_C40', N'PARC', N'METAUX', 24.8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_C50X4', N'PARC', N'METAUX', 18)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_CONT10/10', N'NM COLONNE 3', N'H - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_CONT12/10', N'NM COLONNE 3', N'H - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_ECH61020643130', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_ECHC050000050', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_ECHC050000880', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_ETANCHE', N'MAG COLONNE 4', N'B - BLANC', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_GERM30W', N'NM COLONNE 1', N'B - VERT', 21)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_HAL230W', N'NM COLONNE 2', N'D - JAUNE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_HAL400W', N'NM COLONNE 2', N'D - JAUNE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_IRL20', N'NM COLONNE 1', N'B - VERT', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_IRL32', N'NM COLONNE 1', N'B - VERT', 16)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_LED6W', N'NM COLONNE 2', N'D - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_N18W', N'NM COLONNE 2', N'D - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_N18WLEDS', N'NM COLONNE 1', N'B - VERT', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_N22WLEDS', N'NM COLONNE 1', N'B - VERT', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_N55W', N'NM COLONNE 2', N'D - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_N58W', N'NM COLONNE 1', N'B - VERT', 17)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_NOR102774', N'MAGBU COLONNE 2', N'C - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_ORB131640', N'NM COLONNE 2', N'D - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_R21.3X2.3', N'PARC', N'METAUX', 30)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_R26.9X2.3', N'PARC', N'METAUX', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_R33.7X2.5', N'PARC', N'METAUX', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_RECT100/50/5', N'PARC', N'METAUX', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_RECT40/27/2', N'PARC', N'METAUX', 24.4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_RECT50/30/4', N'PARC', N'METAUX', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_RECT60/30/3', N'PARC', N'METAUX', 12)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_SMINOX', N'NM COLONNE 1', N'B - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUBE_STH41387107115', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TURB.AG80MM', N'NM COLONNE 4', N'N - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUYA.ALIM.INJ', N'MAGBU COLONNE 2', N'C - ROSE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUYA.ECH13201043130', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUYA.ESS11.3X3.0', N'MAGBU COLONNE 2', N'C - NOIR', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUYA.ESS12', N'MAGBU COLONNE 2', N'C - NOIR', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUYA.ESS3.5X2.25X8.0', N'MAGBU COLONNE 2', N'C - NOIR', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUYA.ESS7.5X12.5', N'MAGBU COLONNE 2', N'C - NOIR', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUYA.ESS7.5X3.0', N'MAGBU COLONNE 2', N'C - NOIR', 13)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUYA.ESS9.3X3.0', N'MAGBU COLONNE 2', N'C - NOIR', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUYA.SOL0064234', N'MAGBU COLONNE 2', N'E- JAUNE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUYA.STH11233587703', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUYA.TRANSP10', N'MAGBU COLONNE 2', N'C - NOIR', 2.5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TUYA.TRANSP6', N'MAGBU COLONNE 2', N'C - NOIR', 7.8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'TWIS.UP', N'NM COLONNE 2', N'F - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'UNIT.DC LUCA05BL', N'NM COLONNE 1', N'A - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VALV.CLA6005011557', N'MAGBU COLONNE 2', N'B - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VALV.TR413', N'MAGBU COLONNE 3', N'H - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VALV.TR414L', N'MAGBU COLONNE 3', N'H - BLEU', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VALV.V8R_GROM', N'MAGBU COLONNE 2', N'B - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VANN.ABS1"', N'MAG COLONNE 4', N'F - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VANN.ABS3/4+P', N'MAG COLONNE 4', N'F - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VANN.ABS3/8F', N'MAG COLONNE 2', N'I - JAUNE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VANN.ABS3/8F', N'MAG COLONNE 4', N'F - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TCF3.5X16', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TCF3.5X20', N'MAG COLONNE 2', N'N - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TCF3.5X45', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TCF3X20', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TCF3X25', N'MAG COLONNE 2', N'N - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TCF4.5X20', N'MAG COLONNE 2', N'N - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TCF4.5X40', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TCF4.5X50', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TCF4X16', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TCF4X20', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TCF4X35', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TCF5X 30', N'MAG COLONNE 2', N'N - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TCF5X 35', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TCF5X80', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TCF6X160', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TCF6X70', N'MAG COLONNE 2', N'N - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TFT03X016', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TFT04X040', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TFT04X050', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TFT04X060', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TFT04X070', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TFT05X050', N'MAG COLONNE 2', N'N - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TFT05X060', N'MAG COLONNE 2', N'N - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TFT05X070', N'MAG COLONNE 2', N'N - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TFT06X040', N'MAG COLONNE 2', N'N - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TFT06X110', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TFT06X120', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TFT06X40', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TFT3.5X035', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TFT3.5X040', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TFT3.5X050', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TFT4.5X030', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TFT4.5X040FT', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TFT4.5X045', N'MAG COLONNE 2', N'N - ROUGE', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TFT4.5X060', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TFT4.5X070', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TFT4.5X080', N'MAG COLONNE 2', N'N - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TFT5X50A2', N'MAG COLONNE 4', N'E - ROUGE', 80)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VBA_TRC3.5X20', N'MAG COLONNE 2', N'N - ROUGE', 0.35)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VERN.MARIN', N'MAGASIN LUBRIFIANT', N'C3 ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VERR.105X50I', N'NM COLONNE 3', N'H - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VERR.105X50N11', N'NM COLONNE 3', N'H - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VERR.105X50N12', N'NM COLONNE 3', N'H - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VERR.105X50N13', N'NM COLONNE 3', N'H - ROUGE', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VERR.AVIN', N'NM COLONNE 2', N'G - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VERR.BC', N'NM COLONNE 2', N'G - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VEST.FOR.M', N'NM COLONNE 3', N'I - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VEST.FOR.S', N'NM COLONNE 3', N'I - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VEST.FOR.XL', N'NM COLONNE 3', N'I - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VINA.BLANC', N'MAG COLONNE 1', N'C - VERT', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_AIL8X80', N'MAG COLONNE 4', N'E- JAUNE', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_AWTR3X10', N'MAG COLONNE 2', N'L - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_AWTR3X16', N'MAG COLONNE 2', N'L - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_AWTR3X30', N'MAG COLONNE 2', N'L - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_AXE_BASCUL', N'MAGBU COLONNE 2', N'C - ROSE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_BIZ700049', N'NM COLONNE 2', N'C - ROUGE', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC04X10', N'MAG COLONNE 3', N'Y - BLEU', 500)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC04X20', N'MAG COLONNE 3', N'Y - BLEU', 245)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC04X25', N'MAG COLONNE 3', N'Y - BLEU', 86)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC04X70', N'MAG COLONNE 3', N'Y - BLEU', 80)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC05X10', N'MAG COLONNE 3', N'Y - BLEU', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC05X16', N'MAG COLONNE 3', N'Y - BLEU', 250)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC05X20', N'MAG COLONNE 4', N'E - ROUGE', 250)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC05X20A2', N'MAG COLONNE 4', N'E - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC05X25', N'MAG COLONNE 3', N'Y - BLEU', 40)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC05X30', N'MAG COLONNE 3', N'Y - BLEU', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC05X40', N'MAG COLONNE 3', N'Y - BLEU', 75)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC05X70', N'MAG COLONNE 3', N'Y - BLEU', 92)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC06X16', N'MAG COLONNE 3', N'Y - BLEU', 250)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC06X20', N'MAG COLONNE 3', N'Y - BLEU', 185)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC06X30', N'MAG COLONNE 3', N'Y - BLEU', 47)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC06X40', N'MAG COLONNE 3', N'Y - BLEU', 75)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC06X60', N'MAG COLONNE 3', N'Y - BLEU', 82)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC06X70', N'MAG COLONNE 3', N'Y - BLEU', 200)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC06X80', N'MAG COLONNE 3', N'Y - BLEU', 200)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC08X25', N'MAG COLONNE 3', N'Y - BLEU', 59)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC08X45', N'MAG COLONNE 3', N'Y - BLEU', 64)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC08X50', N'MAG COLONNE 3', N'Y - BLEU', 90)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC08X55', N'MAG COLONNE 3', N'Y - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC08X70', N'MAG COLONNE 3', N'Y - BLEU', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC10X40', N'MAG COLONNE 3', N'Y - BLEU', 24)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC10X50', N'MAG COLONNE 3', N'Y - BLEU', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_CHC14X40', N'MAG COLONNE 3', N'Y - BLEU', 44)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_ECH17723640630', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_ECH90010505012', N'MAGBU COLONNE 2', N'E - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_ECH90016205020', N'MAGBU COLONNE 2', N'E - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_ECH90023804010', N'MAGBU COLONNE 2', N'E - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_ECH90024204010', N'MAGBU COLONNE 2', N'E - BLEU', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_EUT12X30', N'MAGBU COLONNE 2', N'C - VERT', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_EUT27915', N'MAGBU COLONNE 2', N'C - VERT', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_FHC05X10', N'MAG COLONNE 3', N'V - BLEU', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_FHC06X10A2', N'MAG COLONNE 4', N'E - ROUGE', 200)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_FHC10X40', N'MAG COLONNE 3', N'V - BLEU', 46)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_FHC12X40', N'MAG COLONNE 3', N'V - BLEU', 94)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_FHC12X50', N'MAG COLONNE 3', N'V - BLEU', 84)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_FHC12X60', N'MAG COLONNE 3', N'V - BLEU', 319)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_FHC12X70A2', N'MAG COLONNE 4', N'E - ROUGE', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_FHC12X80', N'MAG COLONNE 3', N'V - BLEU', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_FHC12X90', N'MAG COLONNE 3', N'V - BLEU', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_FHC14X50', N'MAG COLONNE 3', N'V - BLEU', 44)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_FHC14X70', N'MAG COLONNE 3', N'V - BLEU', 16)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_INV10X105', N'MAG COLONNE 2', N'L - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_NOR103073', N'MAGBU COLONNE 2', N'C - ROUGE', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_NOR103077', N'MAGBU COLONNE 2', N'C - ROUGE', 121)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_NOR103085', N'MAGBU COLONNE 2', N'C - ROUGE', 91)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_PIAS4.8X13', N'MAG COLONNE 2', N'L - ROUGE', 900)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_PIAS4.8X16', N'MAG COLONNE 2', N'L - ROUGE', 970)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_PIAS4.8X19', N'MAG COLONNE 2', N'L - ROUGE', 1000)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_PIAS4.8X22', N'MAG COLONNE 2', N'L - ROUGE', 813)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_PIAS5.5X45', N'MAG COLONNE 2', N'O - ROUGE', 399)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_STH00009536605', N'MAGBU COLONNE 2', N'D - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_STH11216407110', N'MAGBU COLONNE 2', N'D - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_STH90223711020', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_STH90744784435', N'MAGBU COLONNE 2', N'D - BLEU', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_STH90744784475', N'MAGBU COLONNE 2', N'D - BLEU', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_STH90744784675', N'MAGBU COLONNE 2', N'D - BLEU', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TCAB16X180_AB', N'MAG COLONNE 4', N'E - ROUGE', 36)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TCAB20X100_6.8', N'MAG COLONNE 4', N'E - ROUGE', 170)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TCAB20X160_6.8', N'MAG COLONNE 4', N'E - ROUGE', 91)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TCB04X45', N'MAG COLONNE 2', N'L - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TCB05X10', N'MAG COLONNE 2', N'O - ROUGE', 200)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TCB05X12', N'MAG COLONNE 2', N'O - ROUGE', 200)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TCB05X50', N'MAG COLONNE 2', N'O - ROUGE', 16)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TCB06X60', N'MAG COLONNE 2', N'O - ROUGE', 98)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TCB06X70', N'MAG COLONNE 2', N'O - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TCBAP3.5X13', N'MAG COLONNE 2', N'O - ROUGE', 890)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TCBAP3.5X9.5', N'MAG COLONNE 2', N'O - ROUGE', 900)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TCF04X25', N'MAG COLONNE 2', N'O - ROUGE', 484)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TCF04X35', N'MAG COLONNE 2', N'M - BLEU', 95)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TCF04X45', N'MAG COLONNE 2', N'M - BLEU', 85)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TCF05X20', N'MAG COLONNE 2', N'O - ROUGE', 200)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TCF05X30', N'MAG COLONNE 2', N'M - BLEU', 42)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TCF05X45', N'MAG COLONNE 2', N'M - BLEU', 96)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TCF05X50', N'MAG COLONNE 2', N'M - BLEU', 91)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TCF05X70', N'MAG COLONNE 2', N'M - BLEU', 60)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TCF06X35', N'MAG COLONNE 2', N'M - BLEU', 69)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TCF06X60', N'MAG COLONNE 2', N'O - ROUGE', 108)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TCF06X70', N'MAG COLONNE 2', N'M - BLEU', 47)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TFC06X30A2', N'MAG COLONNE 4', N'E - ROUGE', 190)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TFF04X20', N'MAG COLONNE 2', N'L - ROUGE', 87)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TFF04X60', N'MAG COLONNE 2', N'L - ROUGE', 26)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TFF05X16', N'MAG COLONNE 2', N'L - ROUGE', 145)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TFF05X80', N'MAG COLONNE 2', N'L - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TFF05X90A2', N'MAG COLONNE 4', N'E - ROUGE', 190)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TFF06X30A2', N'MAG COLONNE 4', N'E - ROUGE', 92)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TFF06X80A2', N'MAG COLONNE 4', N'E - ROUGE', 33)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TFF08X25A2', N'MAG COLONNE 4', N'E - ROUGE', 38)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TFF08X40', N'MAG COLONNE 2', N'L - ROUGE', 169)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TFF08X50', N'MAG COLONNE 2', N'L - ROUGE', 77)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TFF08X90', N'MAG COLONNE 2', N'L - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TFF10X45', N'MAG COLONNE 2', N'L - ROUGE', 30)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TFF10X50', N'MAG COLONNE 2', N'L - ROUGE', 176)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP06X50', N'MAG COLONNE 3', N'S - ROUGE', 163)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP06X60', N'MAG COLONNE 3', N'S - ROUGE', 159)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP06X70', N'MAG COLONNE 3', N'S - ROUGE', 108)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP06X80', N'MAG COLONNE 3', N'S - ROUGE', 98)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP06X90', N'MAG COLONNE 3', N'S - ROUGE', 96)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP08X100', N'MAG COLONNE 3', N'S - ROUGE', 98)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP08X110', N'MAG COLONNE 3', N'S - ROUGE', 45)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP08X120', N'MAG COLONNE 3', N'S - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP08X150', N'MAG COLONNE 3', N'S - ROUGE', 47)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP08X50', N'MAG COLONNE 3', N'S - ROUGE', 200)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP08X60', N'MAG COLONNE 3', N'S - ROUGE', 18)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP08X70', N'MAG COLONNE 3', N'S - ROUGE', 192)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP08X80', N'MAG COLONNE 3', N'S - ROUGE', 64)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP08X90', N'MAG COLONNE 3', N'S - ROUGE', 83)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP10X100', N'MAG COLONNE 3', N'S - ROUGE', 26)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP10X100A2', N'MAG COLONNE 4', N'E - ROUGE', 69)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP10X110', N'MAG COLONNE 3', N'S - ROUGE', 23)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP10X120', N'MAG COLONNE 3', N'S - ROUGE', 22)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP10X140', N'MAG COLONNE 3', N'S - ROUGE', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP10X180', N'MAG COLONNE 3', N'S - ROUGE', 45)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP10X40', N'MAG COLONNE 3', N'S - ROUGE', 73)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP10X40A2', N'MAG COLONNE 4', N'E - ROUGE', 61)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP10X50', N'MAG COLONNE 3', N'S - ROUGE', 37)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP10X50A2', N'MAG COLONNE 4', N'E - ROUGE', 125)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP10X50A4', N'MAG COLONNE 3', N'S - ROUGE', 24)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP10X60', N'MAG COLONNE 3', N'S - ROUGE', 33)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP10X60A2', N'MAG COLONNE 4', N'E - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP10X70', N'MAG COLONNE 3', N'S - ROUGE', 159)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP10X70A2', N'MAG COLONNE 4', N'E - ROUGE', 45)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP10X80', N'MAG COLONNE 3', N'S - ROUGE', 98)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP10X80A2', N'MAG COLONNE 4', N'E - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP10X90', N'MAG COLONNE 3', N'S - ROUGE', 123)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP12X100', N'MAG COLONNE 3', N'S - ROUGE', 70)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP12X120', N'MAG COLONNE 3', N'R - ROUGE', 65)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP12X130', N'MAG COLONNE 3', N'R - ROUGE', 19)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP12X50', N'MAG COLONNE 3', N'S - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP12X60', N'MAG COLONNE 3', N'S - ROUGE', 83)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP12X60A2', N'MAG COLONNE 4', N'E - ROUGE', 35)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP12X70', N'MAG COLONNE 3', N'S - ROUGE', 35)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP12X80', N'MAG COLONNE 3', N'S - ROUGE', 140)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP12X90', N'MAG COLONNE 3', N'S - ROUGE', 76)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP14X100', N'MAG COLONNE 3', N'R - ROUGE', 43)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP14X110', N'MAG COLONNE 3', N'R - ROUGE', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP14X50', N'MAG COLONNE 3', N'R - ROUGE', 19)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP14X60', N'MAG COLONNE 3', N'R - ROUGE', 70)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP14X70', N'MAG COLONNE 3', N'R - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP14X80', N'MAG COLONNE 3', N'R - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP14X90', N'MAG COLONNE 3', N'R - ROUGE', 18)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP16X100', N'MAG COLONNE 3', N'R - ROUGE', 107)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP16X140', N'MAG COLONNE 3', N'R - ROUGE', 23)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP16X160', N'MAG COLONNE 3', N'R - ROUGE', 23)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP16X50', N'MAG COLONNE 3', N'R - ROUGE', 12)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP16X50_10.9', N'MAG COLONNE 3', N'R - ROUGE', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP16X60', N'MAG COLONNE 3', N'R - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP16X60A2', N'MAG COLONNE 4', N'E - ROUGE', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP16X70', N'MAG COLONNE 3', N'R - ROUGE', 26)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP16X80', N'MAG COLONNE 3', N'R - ROUGE', 13)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP16X80_10.9', N'MAG FOURNI', N'DIVERS', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP16X90', N'MAG COLONNE 3', N'R - ROUGE', 109)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP18X100', N'MAG COLONNE 3', N'R - ROUGE', 21)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP18X70', N'MAG COLONNE 3', N'R - ROUGE', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP18X80', N'MAG COLONNE 3', N'R - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP20X 80', N'MAG COLONNE 3', N'R - ROUGE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP20X100', N'MAG COLONNE 3', N'R - ROUGE', 22)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP20X120', N'MAG COLONNE 3', N'R - ROUGE', 30)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP20X130', N'MAG COLONNE 3', N'Q - ROUGE', 19)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP20X140_10.9', N'MAG COLONNE 3', N'Q - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP20X180', N'MAG COLONNE 3', N'Q - ROUGE', 39)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP20X200', N'MAG COLONNE 3', N'Q - ROUGE', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THP22X80A2', N'MAG COLONNE 3', N'Q - ROUGE', 62)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THPAB12X110', N'MAG COLONNE 3', N'S - ROUGE', 58)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THPAB12X80', N'MAG COLONNE 3', N'S - ROUGE', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THPAB14X120', N'MAG COLONNE 3', N'R - ROUGE', 34)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THPAB16X110', N'MAG COLONNE 3', N'R - ROUGE', 143)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THPAB18X120', N'MAG COLONNE 3', N'R - ROUGE', 24)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THPAB18X70', N'MAG COLONNE 3', N'R - ROUGE', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THPAB20X150', N'MAG COLONNE 3', N'Q - ROUGE', 47)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THPAB20X220', N'MAG COLONNE 3', N'Q - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THPAB22X110', N'MAG COLONNE 3', N'Q - ROUGE', 9)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THPAB24X120', N'MAG COLONNE 3', N'Q - ROUGE', 14)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THPAB24X150', N'MAG COLONNE 3', N'Q - ROUGE', 53)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THPAB24X80', N'MAG COLONNE 3', N'Q - ROUGE', 8)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THPAB27X100', N'MAG COLONNE 3', N'Q - ROUGE', 15)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THPAB30X80', N'MAG COLONNE 3', N'Q - ROUGE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT04X10', N'MAG COLONNE 3', N'X - ROUGE', 160)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT04X25', N'MAG COLONNE 3', N'X - ROUGE', 555)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT04X35', N'MAG COLONNE 3', N'X - ROUGE', 186)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT05X20', N'MAG COLONNE 3', N'X - ROUGE', 168)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT05X30', N'MAG COLONNE 3', N'X - ROUGE', 164)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT05X40', N'MAG COLONNE 3', N'X - ROUGE', 184)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT06X16', N'MAG COLONNE 3', N'X - ROUGE', 438)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT06X20', N'MAG COLONNE 3', N'X - ROUGE', 190)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT06X25', N'MAG COLONNE 3', N'X - ROUGE', 494)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT06X30', N'MAG COLONNE 3', N'X - ROUGE', 200)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT06X40', N'MAG COLONNE 3', N'X - ROUGE', 107)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT06X50', N'MAG COLONNE 3', N'X - ROUGE', 57)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT06X60', N'MAG COLONNE 3', N'X - ROUGE', 169)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT08X16', N'MAG COLONNE 3', N'X - ROUGE', 196)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT08X20', N'MAG COLONNE 3', N'X - ROUGE', 200)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT08X25', N'MAG COLONNE 3', N'X - ROUGE', 150)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT08X30', N'MAG COLONNE 3', N'X - ROUGE', 96)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT08X35', N'MAG COLONNE 3', N'X - ROUGE', 63)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT08X35A2', N'MAG COLONNE 4', N'E - ROUGE', 90)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT08X40', N'MAG COLONNE 3', N'X - ROUGE', 109)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT08X50', N'MAG COLONNE 3', N'X - ROUGE', 29)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT08X50A2', N'MAG COLONNE 4', N'E - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT08X60', N'MAG COLONNE 3', N'X - ROUGE', 34)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT08X70', N'MAG COLONNE 3', N'X - ROUGE', 270)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT08X80', N'MAG COLONNE 3', N'X - ROUGE', 79)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT08X90A2', N'MAG COLONNE 4', N'E - ROUGE', 58)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT10X100', N'MAG COLONNE 3', N'X - ROUGE', 24)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT10X110', N'MAG COLONNE 3', N'X - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT10X20', N'MAG COLONNE 3', N'X - ROUGE', 49)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT10X25', N'MAG COLONNE 3', N'X - ROUGE', 106)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT10X30', N'MAG COLONNE 3', N'X - ROUGE', 177)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT10X35', N'MAG COLONNE 3', N'X - ROUGE', 93)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT10X40', N'MAG COLONNE 3', N'X - ROUGE', 208)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT10X50', N'MAG COLONNE 3', N'X - ROUGE', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT10X50A4', N'MAG COLONNE 4', N'E - ROUGE', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT10X60', N'MAG COLONNE 3', N'X - ROUGE', 41)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT10X60A2', N'MAG COLONNE 4', N'E - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT10X60A4', N'MAG COLONNE 4', N'E - ROUGE', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT10X70', N'MAG COLONNE 3', N'X - ROUGE', 93)
GO
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT10X70A2', N'MAG COLONNE 4', N'E - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT10X80', N'MAG COLONNE 3', N'X - ROUGE', 111)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT10X90', N'MAG COLONNE 3', N'X - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT12X100', N'MAG COLONNE 3', N'W - ROUGE', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT12X120', N'MAG COLONNE 3', N'W - ROUGE', 36)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT12X25', N'MAG COLONNE 3', N'W - ROUGE', 94)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT12X30', N'MAG COLONNE 3', N'W - ROUGE', 71)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT12X30A2', N'MAG COLONNE 4', N'E - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT12X35', N'MAG COLONNE 3', N'W - ROUGE', 84)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT12X40', N'MAG COLONNE 3', N'W - ROUGE', 22)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT12X50', N'MAG COLONNE 3', N'W - ROUGE', 154)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT12X60', N'MAG COLONNE 3', N'W - ROUGE', 95)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT12X70', N'MAG COLONNE 3', N'W - ROUGE', 46)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT12X80', N'MAG COLONNE 3', N'W - ROUGE', 46)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT12X90', N'MAG COLONNE 3', N'W - ROUGE', 46)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT14X120', N'MAG COLONNE 3', N'W - ROUGE', 21)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT14X35', N'MAG COLONNE 3', N'W - ROUGE', 21)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT14X40', N'MAG COLONNE 3', N'W - ROUGE', 94)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT14X50', N'MAG COLONNE 3', N'W - ROUGE', 82)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT14X60', N'MAG COLONNE 3', N'W - ROUGE', 62)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT14X80', N'MAG COLONNE 3', N'W - ROUGE', 21)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT16X 60PF', N'MAG COLONNE 3', N'W - ROUGE', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT16X100', N'MAG COLONNE 3', N'W - ROUGE', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT16X40', N'MAG COLONNE 3', N'W - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT16X40A2', N'MAG COLONNE 4', N'E - ROUGE', 30)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT16X45', N'MAG COLONNE 3', N'W - ROUGE', 46)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT16X50', N'MAG COLONNE 3', N'W - ROUGE', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT16X60', N'MAG COLONNE 3', N'W - ROUGE', 105)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT18X40', N'MAG COLONNE 3', N'W - ROUGE', 10)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT18X50', N'MAG COLONNE 3', N'V - ROUGE', 7)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT18X70', N'MAG COLONNE 3', N'V - ROUGE', 13)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT18X80', N'MAG COLONNE 3', N'V - ROUGE', 21)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT20X40', N'MAG COLONNE 3', N'V - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT20X50', N'MAG COLONNE 3', N'V - ROUGE', 111)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT20X60', N'MAG COLONNE 3', N'V - ROUGE', 43)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_THT24X60', N'MAG COLONNE 3', N'V - ROUGE', 21)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC06X30Z', N'MAG COLONNE 4', N'G - ROUGE', 120)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC06X40Z', N'MAG COLONNE 4', N'G - ROUGE', 169)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC06X50Z', N'MAG COLONNE 4', N'G - ROUGE', 146)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC06X60Z', N'MAG COLONNE 4', N'G - ROUGE', 342)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC06X70N', N'MAG COLONNE 4', N'G - ROUGE', 48)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC06X70Z', N'MAG COLONNE 4', N'G - ROUGE', 279)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC08X100N', N'MAG COLONNE 4', N'G - ROUGE', 198)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC08X100Z', N'MAG COLONNE 4', N'G - ROUGE', 96)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC08X110N', N'MAG COLONNE 4', N'G - ROUGE', 42)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC08X110Z', N'MAG COLONNE 4', N'G - ROUGE', 48)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC08X160Z', N'MAG COLONNE 4', N'G - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC08X40Z', N'MAG COLONNE 4', N'G - ROUGE', 42)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC08X60N', N'MAG COLONNE 4', N'G - ROUGE', 95)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC08X60Z', N'MAG COLONNE 4', N'G - ROUGE', 76)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC08X70Z', N'MAG COLONNE 4', N'G - ROUGE', 193)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC08X80Z', N'MAG COLONNE 4', N'G - ROUGE', 382)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC08X90Z', N'MAG COLONNE 4', N'G - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC10X100Z', N'MAG COLONNE 4', N'G - ROUGE', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC10X120Z', N'MAG COLONNE 4', N'G - ROUGE', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC10X140Z', N'MAG COLONNE 4', N'G - ROUGE', 18)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC10X160Z', N'MAG COLONNE 4', N'G - ROUGE', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC10X60Z', N'MAG COLONNE 4', N'G - ROUGE', 358)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC10X70Z', N'MAG COLONNE 4', N'G - ROUGE', 99)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC10X80Z', N'MAG COLONNE 4', N'G - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC12X100Z', N'MAG COLONNE 4', N'G - ROUGE', 90)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC12X110Z', N'MAG COLONNE 4', N'G - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC12X120Z', N'MAG COLONNE 4', N'G - ROUGE', 25)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC12X160Z', N'MAG COLONNE 4', N'G - ROUGE', 20)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC12X200Z', N'MAG COLONNE 4', N'G - ROUGE', 14)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC12X250Z', N'MAG COLONNE 4', N'G - ROUGE', 6)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC12X50Z', N'MAG COLONNE 4', N'G - ROUGE', 50)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC12X70Z', N'MAG COLONNE 4', N'G - ROUGE', 23)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC12X80Z', N'MAG COLONNE 4', N'G - ROUGE', 32)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC12X90Z', N'MAG COLONNE 4', N'G - ROUGE', 51)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC14X120Z', N'MAG COLONNE 4', N'G - ROUGE', 13)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TRCC14X160Z', N'MAG COLONNE 4', N'G - ROUGE', 18)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TTCB4.2X38', N'MAG COLONNE 2', N'M - BLEU', 60)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TTCB4.8X45', N'MAG COLONNE 2', N'M - BLEU', 95)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TTH08X19', N'MAG COLONNE 2', N'L - ROUGE', 29)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TTH4.8X16', N'MAG COLONNE 2', N'L - ROUGE', 60)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TTH5.5X16', N'MAG COLONNE 2', N'L - ROUGE', 96)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TTH6.3X16', N'MAG COLONNE 2', N'L - ROUGE', 100)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TTH6.3X22', N'MAG COLONNE 2', N'L - ROUGE', 80)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VIS_TTH6.5X16', N'MAG COLONNE 2', N'L - ROUGE', 80)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'VULC.50ML', N'MAGBU COLONNE 3', N'H - BLEU', 1)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'WADE.T43', N'NM COLONNE 3', N'L - VERT', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'WADE.T44', N'NM COLONNE 3', N'L - VERT', 3)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'WADE.T45', N'NM COLONNE 3', N'L - VERT', 2)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'WHIT.SPIRIT5', N'MAG FOURNI', N'PEINTURE', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'WHIT.SPIRIT5', N'MAG FOURNI', N'DIVERS', 4)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'WHIT.SPIRIT5', N'MAGASIN LUBRIFIANT', N'C2 JAUNE', 5)
INSERT [dbo].[STOCK] ([ID_PIECE], [ID_MAG], [ID_ADR], [QTE_STOCKEE]) VALUES (N'XENO.TRA252133', N'NM COLONNE 1', N'A - BLEU', 2)
SET ANSI_PADDING ON
GO
